/*********************************************************************
*                SEGGER Microcontroller GmbH & Co. KG                *
*        Solutions for real time microcontroller applications        *
**********************************************************************
*                                                                    *
*        (c) 1996 - 2014  SEGGER Microcontroller GmbH & Co. KG       *
*                                                                    *
*        Internet: www.segger.com    Support:  support@segger.com    *
*                                                                    *
**********************************************************************

** emWin V5.26 - Graphical user interface for embedded applications **
All  Intellectual Property rights  in the Software belongs to  SEGGER.
emWin is protected by  international copyright laws.  Knowledge of the
source code may not be used to write a similar product.  This file may
only be used in accordance with the following terms:

The software has been licensed to  ARM LIMITED whose registered office
is situated at  110 Fulbourn Road,  Cambridge CB1 9NJ,  England solely
for  the  purposes  of  creating  libraries  for  ARM7, ARM9, Cortex-M
series,  and   Cortex-R4   processor-based  devices,  sublicensed  and
distributed as part of the  MDK-ARM  Professional  under the terms and
conditions  of  the   End  User  License  supplied  with  the  MDK-ARM
Professional. 
Full source code is available at: www.segger.com

We appreciate your understanding and fairness.
----------------------------------------------------------------------
File        : WIDGET_Amplifier.c
Purpose     : Shows how to create a radial menu with motion support
Requirements: WindowManager - (x)
              MemoryDevices - (x)
              AntiAliasing  - (x)
              VNC-Server    - ( )
              PNG-Library   - ( )
              TrueTypeFonts - ( )
----------------------------------------------------------------------
*/

#include "DIALOG.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define ID_WIN_0        (GUI_ID_USER + 0x00)

#define AMP_COLOR_GRAY   0x4C4B4D
#define AMP_COLOR_GREEN  0x00E800
#define AMP_COLOR_YELLOW 0x46D6FF

/*********************************************************************
*
*       Types
*
**********************************************************************
*/
typedef struct {
  int x;
  int y;
  int Pressed;
  int Delay;
} ANIM;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
/*********************************************************************
*
*       Knob 140x140
*/
static GUI_CONST_STORAGE unsigned long _acknob_gray_trans_140x140[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF7F7F7, 
        0xFFF6F6F6, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFF0F0F0, 0xFFEEEEEE, 0xFFEBEBEB, 0xFFE7E7E7, 0xFFE3E3E3, 0xFFDFDFDF, 0xFFDDDDDD, 0xFFDCDCDC, 0xFFD8D8D8, 0xFFD3D3D3, 0xFFCDCCCE, 0xFFC8C7C9, 0xFFC4C3C5, 0xFFC3C2C4, 0xFFB9B8BC, 0xE6B8B7BB, 0xC2B7B6BA, 
        0xA1B6B5B9, 0x83B7B6BA, 0x67B8B7BB, 0x4FB9B8BC, 0x39BAB9BD, 0x27C2C1C5, 0x18C3C2C6, 0x0CC5C4C8, 0x04C7C6CA, 0x00C7C6CA, 0x04C5C4C8, 0x0CC4C3C7, 0x18C2C1C5, 0x27C0BFC3, 0x39C0BFC3, 0x4FBFBEC2, 0x67BFBEC2, 0x83BFBEC2, 0xA1C0BFC3, 0xC2C0BFC3, 
        0xE6C0BFC1, 0xFFC6C6C6, 0xFFC7C7C7, 0xFFC9C9C9, 0xFFCCCCCC, 0xFFD0D0D0, 0xFFD4D4D4, 0xFFD9D9D9, 0xFFDCDCDC, 0xFFE0E0E0, 0xFFE3E3E3, 0xFFE7E7E7, 0xFFEAEAEA, 0xFFEDEDED, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF6F6F6, 0xFFF7F7F7, 0xFFF8F8F8, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF4F4F4, 
        0xFFF3F3F3, 0xFFEFEFEF, 0xFFEDEDED, 0xFFE9E9E9, 0xFFE6E6E6, 0xFFE3E3E3, 0xFFDFDFDF, 0xFFDADADA, 0xFFD6D6D6, 0xFFCECECE, 0xFFCBCBCB, 0xFFC5C5C5, 0xFFBBBBBB, 0xF5B0AFB1, 0xC2A6A5A7, 0x929F9EA0, 0x649D9C9E, 0x38A5A4A8, 0x0EA5A4A8, 0x00A7A6AA, 
        0x00AAA9AD, 0x00AEADB1, 0x00B2B1B5, 0x00B6B4BA, 0x00B9B7BD, 0x00BFBEC2, 0x00C1C0C4, 0x00C5C4C8, 0x00C8C7CB, 0x00C9C8CC, 0x00C8C7CB, 0x00C6C5C9, 0x00C5C4C8, 0x00C4C3C7, 0x00C3C2C6, 0x00C1C0C4, 0x00BFBEC2, 0x00BDBCC0, 0x00BBBABE, 0x00B9B8BC, 
        0x0EB9B8BC, 0x38B5B4B6, 0x64B7B7B7, 0x92B9B9B9, 0xC2BCBCBC, 0xF5C1C1C1, 0xFFC6C6C6, 0xFFCCCCCC, 0xFFD0D0D0, 0xFFD6D6D6, 0xFFD9D9D9, 0xFFDEDEDE, 0xFFE2E2E2, 0xFFE5E5E5, 0xFFE9E9E9, 0xFFEDEDED, 0xFFF1F1F1, 0xFFF3F3F3, 0xFFF4F4F4, 0xFFF7F7F7, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFF3F3F3, 0xFFF2F2F2, 
        0xFFEBEBEB, 0xFFE9E9E9, 0xFFE4E4E4, 0xFFDFDFDF, 0xFFDADADA, 0xFFD6D6D6, 0xFFD0D0D0, 0xFFCACACA, 0xFFC6C6C6, 0xFFAEADAF, 0xD8A1A0A2, 0x9D929193, 0x638C8B8D, 0x2B8E8D8F, 0x00929193, 0x00969597, 0x0099989A, 0x009E9DA1, 0x00A09FA3, 0x00A4A3A7, 
        0x00A8A7AB, 0x00ABA9AF, 0x00AFADB3, 0x00B4B2B8, 0x00B7B5BB, 0x00BCBBBF, 0x00BDBCC0, 0x00BFBEC2, 0x00C4C3C7, 0x00C8C7CB, 0x00CAC9CD, 0x00C9C8CC, 0x00C7C6CA, 0x00C3C2C6, 0x00C2C1C5, 0x00C0BFC3, 0x00BFBEC2, 0x00BFBEC2, 0x00BEBDC1, 0x00BDBCC0, 
        0x00BCBBBF, 0x00B8B7B9, 0x00B7B6B8, 0x00B7B6B8, 0x00B5B4B6, 0x2BB2B1B3, 0x63B1B0B2, 0x9DB6B5B7, 0xD8BCBBBD, 0xFFC6C5C7, 0xFFC9C8CA, 0xFFCFCED0, 0xFFD5D4D6, 0xFFD9D8DA, 0xFFDDDCDE, 0xFFE4E3E5, 0xFFEAE9EB, 0xFFEDEDED, 0xFFEEEEEE, 0xFFF1F1F1, 
        0xFFF5F5F5, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF7F7F7, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFAFAFA, 0xFFF3F3F3, 0xFFF0F0F0, 0xFFF2F2F2, 0xFFEAEAEA, 0xFFE2E2E2, 
        0xFFE5E5E5, 0xFFD9D9D9, 0xFFD9D9D9, 0xFFD5D5D5, 0xFFCDCDCD, 0xFFC5C5C5, 0xFFB7B7B7, 0xDC9C9C9C, 0x99828282, 0x57828183, 0x17818082, 0x00848385, 0x008A898B, 0x00908F91, 0x00929193, 0x00949395, 0x00959496, 0x009E9DA1, 0x00A09FA3, 0x00A3A2A6, 
        0x00A6A5A9, 0x00A8A6AC, 0x00ABA9AF, 0x00AEACB2, 0x00B0AFB3, 0x00B7B6BA, 0x00B8B7BB, 0x00BBBABE, 0x00C0BFC3, 0x00C4C3C7, 0x00C6C5C9, 0x00C7C6CA, 0x00C6C5C9, 0x00C6C5C9, 0x00C5C4C8, 0x00C4C3C7, 0x00C2C1C5, 0x00C1C0C4, 0x00BEBDC1, 0x00BBBABE, 
        0x00B9B8BC, 0x00BCBBBD, 0x00BAB9BB, 0x00B7B6B8, 0x00B4B3B5, 0x00B0AFB1, 0x00ADACAE, 0x00AFAEB0, 0x17B3B2B4, 0x57B1B0B2, 0x99B5B4B6, 0xDCBEBDBF, 0xFFC8C7C9, 0xFFD0CFD1, 0xFFD5D4D6, 0xFFDAD9DB, 0xFFDEDDDF, 0xFFE3E3E3, 0xFFE7E7E7, 0xFFEDEDED, 
        0xFFF0F0F0, 0xFFF2F2F2, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFEEEEEE, 0xFFEFEFEF, 0xFFF2F2F2, 0xFFEAEAEA, 0xFFE4E4E4, 0xFFDFDFDF, 
        0xFFD3D3D3, 0xFFD6D6D6, 0xFFD1D1D1, 0xFFBDBDBD, 0xFF9C9C9C, 0xB47E7E7E, 0x6B707070, 0x23717171, 0x00777777, 0x0079787A, 0x007B7A7C, 0x007E7D7F, 0x00838284, 0x00868587, 0x008A898B, 0x008F8E90, 0x00949395, 0x00949397, 0x0097969A, 0x009C9B9F, 
        0x00A1A0A4, 0x00A6A5A9, 0x00AAA9AD, 0x00AEADB1, 0x00B1B0B4, 0x00B2B1B5, 0x00B5B4B6, 0x00B9B8BA, 0x00BDBCBE, 0x00C1C0C2, 0x00C4C3C5, 0x00C7C6C8, 0x00C8C7C9, 0x00C8C7C9, 0x00C6C5C7, 0x00C3C2C4, 0x00C1C0C2, 0x00C0BFC1, 0x00BFBEC0, 0x00BEBDBF, 
        0x00BEBDBF, 0x00BAB9BB, 0x00BAB9BB, 0x00BAB9BB, 0x00BAB9BB, 0x00B7B6B8, 0x00B3B2B4, 0x00B1B0B2, 0x00B0AFB1, 0x00ABAAAC, 0x00AAA9AB, 0x23ACABAD, 0x6BB2B1B3, 0xB4B9B8BA, 0xFFC1C0C2, 0xFFCAC9CB, 0xFFD1D0D2, 0xFFDADADA, 0xFFDDDDDD, 0xFFE1E1E1, 
        0xFFE7E7E7, 0xFFECECEC, 0xFFF1F1F1, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF5F5F5, 0xFFECECEC, 0xFFF6F6F6, 0xFFECECEC, 0xFFDEDEDE, 0xFFDEDEDE, 0xFFD9D9D9, 0xFFCFCFCF, 
        0xFFCFCFCF, 0xFFB6B6B6, 0xEC929292, 0x9C6F6F6F, 0x4D666666, 0x006A6A6A, 0x006D6D6D, 0x006F6F6F, 0x00747474, 0x00757476, 0x007A797B, 0x00807F81, 0x00848385, 0x00868587, 0x00888789, 0x008B8A8C, 0x008E8D8F, 0x00939296, 0x0097969A, 0x009B9A9E, 
        0x009F9EA2, 0x00A2A1A5, 0x00A4A3A7, 0x00A7A6AA, 0x00A9A8AA, 0x00B2B1B3, 0x00B5B4B6, 0x00BAB9BB, 0x00BDBCBE, 0x00C0BFC1, 0x00C4C3C5, 0x00C8C7C9, 0x00CCCBCD, 0x00C9C8CA, 0x00C8C7C9, 0x00C7C6C8, 0x00C6C5C7, 0x00C4C3C5, 0x00C2C1C3, 0x00C0BFC1, 
        0x00BFBEC0, 0x00C0BFC1, 0x00BDBCBE, 0x00B9B8BA, 0x00B7B6B8, 0x00B6B5B7, 0x00B4B3B5, 0x00B3B2B4, 0x00B2B1B3, 0x00B2B1B3, 0x00AEADAF, 0x00AAA9AB, 0x00A8A7A9, 0x00A9A8AA, 0x4DAEADAF, 0x9CB7B6B8, 0xECBFBEC0, 0xFFC9C9C9, 0xFFD0D0D0, 0xFFD8D8D8, 
        0xFFDFDFDF, 0xFFE3E3E3, 0xFFE8E8E8, 0xFFECECEC, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFF0F0F0, 0xFFECECEC, 0xFFE1E1E1, 0xFFDFDFDF, 0xFFDDDDDD, 0xFFD3D3D3, 0xFFCCCCCC, 0xFFB6B6B6, 
        0xEA939393, 0x946B6B6B, 0x405E5E5E, 0x005A5A5A, 0x00626262, 0x00686868, 0x00676767, 0x006B6B6B, 0x00747474, 0x00747375, 0x00777678, 0x007A797B, 0x007D7C7E, 0x00807F81, 0x00848385, 0x0089888A, 0x008C8B8D, 0x00929193, 0x00979698, 0x009F9EA0, 
        0x00A8A7A9, 0x00B0AFB1, 0x00B8B7B9, 0x00BEBDBF, 0x00C2C1C3, 0x00C7C6C8, 0x00CACACA, 0x00CECECE, 0x00D1D1D1, 0x00D4D4D4, 0x00D7D7D7, 0x00DDDDDD, 0x00E1E1E1, 0x00E3E3E3, 0x00E4E4E4, 0x00E5E5E5, 0x00E2E2E2, 0x00DCDCDC, 0x00D3D3D3, 0x00CACACA, 
        0x00C4C4C4, 0x00C1C0C2, 0x00BEBDBF, 0x00BBBABC, 0x00B9B8BA, 0x00B9B8BA, 0x00B7B6B8, 0x00B3B2B4, 0x00B0AFB1, 0x00B1B0B2, 0x00B0AFB1, 0x00B0AFB1, 0x00AEADAF, 0x00ABAAAC, 0x00A8A7A9, 0x00A9A8AA, 0x40ACABAD, 0x94B2B2B2, 0xEABEBEBE, 0xFFCCCCCC, 
        0xFFD5D5D5, 0xFFD8D8D8, 0xFFDCDCDC, 0xFFE5E5E5, 0xFFEDEDED, 0xFFF0F0F0, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFECECEC, 0xFFE9E9E9, 0xFFE0E0E0, 0xFFE0E0E0, 0xFFD4D4D4, 0xFFCCCCCC, 0xFFC3C3C3, 0xF6A1A1A1, 0x9C787878, 
        0x42676767, 0x00616161, 0x005F5F5F, 0x005D5D5D, 0x005D5D5D, 0x005F5F5F, 0x00636363, 0x00656565, 0x00666666, 0x00706F71, 0x00737274, 0x00767577, 0x007A797B, 0x00828183, 0x008D8C8E, 0x00979698, 0x009D9C9E, 0x00ACABAD, 0x00AFAEB0, 0x00B3B2B4, 
        0x00B7B6B8, 0x00BAB9BB, 0x00BDBCBE, 0x00C0BFC1, 0x00C3C3C3, 0x00C8C8C8, 0x00CBCBCB, 0x00CECECE, 0x00D1D1D1, 0x00D4D4D4, 0x00D7D7D7, 0x00DCDCDC, 0x00E0E0E0, 0x00E2E2E2, 0x00E5E5E5, 0x00EAEAEA, 0x00EEEEEE, 0x00F2F2F2, 0x00F5F5F5, 0x00F7F7F7, 
        0x00F9F9F9, 0x00EEEDEF, 0x00E3E2E4, 0x00D3D2D4, 0x00C4C3C5, 0x00BDBCBE, 0x00BBBABC, 0x00BAB9BB, 0x00B8B7B9, 0x00B0AFB1, 0x00B0AFB1, 0x00B0AFB1, 0x00B0AFB1, 0x00ADACAE, 0x00A9A8AA, 0x00A7A6A8, 0x00A8A7A9, 0x00A7A7A7, 0x42ABABAB, 0x9CB3B3B3, 
        0xF6BFBFBF, 0xFFCCCCCC, 0xFFD8D8D8, 0xFFDEDEDE, 0xFFE1E1E1, 0xFFE9E9E9, 0xFFECECEC, 0xFFF1F1F1, 0xFFF5F5F5, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFDEDEDE, 0xFFD9D9D9, 0xFFD1D1D1, 0xFFC7C7C7, 0xFFACACAC, 0xB2828282, 0x546A6A6A, 0x006A6A6A, 
        0x006E6E6E, 0x00656565, 0x00656565, 0x00636363, 0x005E5E5E, 0x005D5D5D, 0x00616161, 0x00676767, 0x006A6A6A, 0x0069686A, 0x00747377, 0x00828185, 0x008E8D91, 0x0099989A, 0x00A2A1A3, 0x00A8A7A9, 0x00A9A8AA, 0x00A9A9A9, 0x00ACACAC, 0x00B0B0B0, 
        0x00B4B4B4, 0x00B7B7B7, 0x00BBBBBB, 0x00BFBFBF, 0x00C2C2C2, 0x00C8C8C8, 0x00CACACA, 0x00CDCDCD, 0x00D1D1D1, 0x00D4D4D4, 0x00D8D8D8, 0x00DCDCDC, 0x00DFDFDF, 0x00E7E7E7, 0x00E8E8E8, 0x00E9E9E9, 0x00EAEAEA, 0x00EDEDED, 0x00F3F3F3, 0x00F9F9F9, 
        0x00FEFEFE, 0x00FFFEFF, 0x00FFFEFF, 0x00FFFEFF, 0x00F9F8FA, 0x00ECEBED, 0x00D9D8DA, 0x00C3C2C4, 0x00B2B1B3, 0x00BAB9BB, 0x00B4B3B5, 0x00AFAEB0, 0x00ADACAE, 0x00ADACAE, 0x00ADACAE, 0x00ACABAD, 0x00ACABAD, 0x00A9A9A9, 0x00A5A5A5, 0x00A3A3A3, 
        0x54AAAAAA, 0xB2BABABA, 0xFFC8C8C8, 0xFFD1D1D1, 0xFFD3D3D3, 0xFFDEDEDE, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFDBDBDB, 0xFFD6D6D6, 0xFFCECECE, 0xFFBDBDBD, 0xD69D9D9D, 0x73818181, 0x12787878, 0x00797979, 0x00737373, 
        0x006B6B6B, 0x006B6B6B, 0x00656565, 0x00616161, 0x00606060, 0x005D5D5D, 0x005C5C5C, 0x00656565, 0x00706F71, 0x00878688, 0x008E8D91, 0x00959498, 0x0098979B, 0x009A999B, 0x009E9D9F, 0x00A2A1A3, 0x00A4A3A5, 0x00ACACAC, 0x00AEAEAE, 0x00B2B2B2, 
        0x00B5B5B5, 0x00B8B8B8, 0x00BBBBBB, 0x00C0C1BF, 0x00C2C3C1, 0x00C8C8C8, 0x00C9C9C9, 0x00CCCCCC, 0x00D0D0D0, 0x00D4D4D4, 0x00D8D8D8, 0x00DBDBDB, 0x00DEDEDE, 0x00E1E1E1, 0x00E4E4E4, 0x00E9E9E9, 0x00EEEEEE, 0x00F2F2F2, 0x00F5F5F5, 0x00F9F9F9, 
        0x00FBFBFB, 0x00FDFCFE, 0x00FFFEFF, 0x00FFFEFF, 0x00FFFEFF, 0x00FDFCFE, 0x00F8F7F9, 0x00EEEDEF, 0x00E6E5E7, 0x00C4C3C5, 0x00BBBABC, 0x00B2B1B3, 0x00B0AFB1, 0x00B1B0B2, 0x00B0AFB1, 0x00ADACAE, 0x00AAA9AB, 0x00A9A9A9, 0x00A9A9A9, 0x00A7A7A7, 
        0x00A4A4A4, 0x12A4A4A4, 0x73AFAFAF, 0xD6C0C0C0, 0xFFCFCFCF, 0xFFD6D6D6, 0xFFDBDBDB, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE5E5E5, 0xFFDEDEDE, 0xFFDCDCDC, 0xFFD3D3D3, 0xFFC5C5C5, 0xFFADACAE, 0xA1949395, 0x3B828183, 0x00828183, 0x00828183, 0x00787779, 0x00727173, 
        0x00737274, 0x006E6D6F, 0x0069686A, 0x00636264, 0x00626163, 0x00676668, 0x00737274, 0x007F7E80, 0x00888789, 0x008D8C8E, 0x008F8E90, 0x00939294, 0x00979698, 0x009A999B, 0x009E9D9F, 0x00A3A2A4, 0x00A6A5A7, 0x00A9A9A9, 0x00ACACAC, 0x00B0B0B0, 
        0x00B4B4B4, 0x00B7B7B7, 0x00BBBBBB, 0x00BFBFBF, 0x00C2C2C2, 0x00C6C6C6, 0x00C9C9C9, 0x00CECECE, 0x00D1D1D1, 0x00D4D4D4, 0x00D8D8D8, 0x00DCDCDC, 0x00E0E0E0, 0x00E2E2E2, 0x00E6E6E6, 0x00EBEBEB, 0x00EEEEEE, 0x00F1F1F1, 0x00F5F5F5, 0x00FAFAFA, 
        0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00FBFBFB, 0x00F8F8F8, 0x00F3F3F3, 0x00EFEFEF, 0x00EDEDED, 0x00E0E0E0, 0x00CCCCCC, 0x00BBBBBB, 0x00B1B1B1, 0x00ADADAD, 0x00ADADAD, 0x00ADADAD, 0x00ABAAAC, 0x00A9A8AA, 0x00A8A7A9, 
        0x00A8A7A9, 0x00A5A4A6, 0x00A3A2A4, 0x3BA9A8AA, 0xA1B2B1B3, 0xFFCBCBCB, 0xFFCECECE, 0xFFD7D7D7, 0xFFE2E2E2, 0xFFE9E9E9, 0xFFECECEC, 0xFFF1F2F0, 0xFFF7F8F6, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF2F2F2, 0xFFECECEC, 0xFFE5E5E5, 0xFFDFDFDF, 0xFFD8D8D8, 0xFFCFCFCF, 0xFFBEBEBE, 0xDCAAAAAA, 0x72929193, 0x08908F91, 0x008A898B, 0x00848385, 0x00807F81, 0x007D7C7E, 0x0079787A, 
        0x00767577, 0x00727173, 0x00706F71, 0x006F6E70, 0x00717072, 0x00767577, 0x007D7C7E, 0x00848385, 0x0089888A, 0x008B8A8C, 0x008E8D8F, 0x00929193, 0x00969597, 0x0099989A, 0x009D9C9E, 0x00A2A1A3, 0x00A5A4A6, 0x00A8A8A8, 0x00ABABAB, 0x00B0B0B0, 
        0x00B3B3B3, 0x00B7B7B7, 0x00BBBBBB, 0x00BFBFBF, 0x00C2C2C2, 0x00C6C6C6, 0x00C9C9C9, 0x00CECECE, 0x00D1D1D1, 0x00D4D4D4, 0x00D8D8D8, 0x00DCDCDC, 0x00E0E0E0, 0x00E3E3E3, 0x00E7E7E7, 0x00ECECEC, 0x00EFEFEF, 0x00F2F2F2, 0x00F6F6F6, 0x00FBFBFB, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00FAFAFA, 0x00F7F7F7, 0x00F2F2F2, 0x00EEEEEE, 0x00E9E9E9, 0x00E4E4E4, 0x00DDDDDD, 0x00D4D4D4, 0x00C9C9C9, 0x00BDBDBD, 0x00B1B1B1, 0x00AAAAAA, 0x00ADACAE, 0x00ABAAAC, 0x00ABAAAC, 
        0x00ABAAAC, 0x00A7A6A8, 0x00A2A1A3, 0x00A2A1A3, 0x08A6A5A7, 0x72AFAFAF, 0xDCC1C1C1, 0xFFD1D1D1, 0xFFD7D7D7, 0xFFDEDEDE, 0xFFE9E9E9, 0xFFEFF0EE, 0xFFEFF0EE, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFF1F1F1, 0xFFECECEC, 0xFFE4E4E4, 0xFFDDDDDD, 0xFFD6D6D6, 0xFFC9C9C9, 0xFFBABABA, 0xB6A8A8A8, 0x49979797, 0x00949395, 0x008F8E90, 0x008B8A8C, 0x008B8A8C, 0x00888789, 0x00818082, 0x007E7D7F, 
        0x007F7E80, 0x00727173, 0x00737274, 0x00767577, 0x007A797B, 0x007E7D7F, 0x00828183, 0x00858486, 0x00868587, 0x008A898B, 0x008D8C8E, 0x00908F91, 0x00949395, 0x00989799, 0x009C9B9D, 0x00A09FA1, 0x00A3A2A4, 0x00A8A8A8, 0x00ABABAB, 0x00AFAFAF, 
        0x00B3B3B3, 0x00B6B6B6, 0x00BABABA, 0x00BEBEBE, 0x00C1C1C1, 0x00C6C6C6, 0x00C9C9C9, 0x00CECECE, 0x00D1D1D1, 0x00D4D4D4, 0x00D8D8D8, 0x00DDDDDD, 0x00E0E0E0, 0x00E4E4E4, 0x00E8E8E8, 0x00ECECEC, 0x00F0F0F0, 0x00F3F3F3, 0x00F7F7F7, 0x00FCFCFC, 
        0x00FFFFFF, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F9F9F9, 0x00F6F6F6, 0x00F0F0F0, 0x00EBEBEB, 0x00E5E5E5, 0x00E3E3E3, 0x00E0E0E0, 0x00DCDCDC, 0x00D5D5D5, 0x00CBCBCB, 0x00C0C0C0, 0x00B8B8B8, 0x00AFAEB0, 0x00ACABAD, 0x00AAA9AB, 
        0x00ABAAAC, 0x00A9A8AA, 0x00A4A3A5, 0x00A2A1A3, 0x00A2A1A3, 0x00A0A0A0, 0x49AAAAAA, 0xB6BBBBBB, 0xFFCBCBCB, 0xFFD6D6D6, 0xFFDDDDDD, 0xFFE4E4E4, 0xFFEAEAEA, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFF9F9F9, 0xFFF7F7F7, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE4E4E4, 0xFFDBDBDB, 0xFFD3D3D3, 0xFFC9C9C9, 0xFFB8B8B8, 0x96A9A9A9, 0x26A0A0A0, 0x009B9B9B, 0x00989799, 0x00989799, 0x00939294, 0x008B8A8C, 0x008A898B, 0x008A898B, 0x00807F81, 
        0x00727173, 0x00706F71, 0x00717072, 0x00747375, 0x00777678, 0x007B7A7C, 0x007E7D7F, 0x00828183, 0x00848385, 0x00888789, 0x008B8A8C, 0x008F8E90, 0x00939294, 0x00979698, 0x009B9A9C, 0x009F9EA0, 0x00A2A1A3, 0x00A7A7A7, 0x00AAAAAA, 0x00AEAEAE, 
        0x00B2B2B2, 0x00B6B6B6, 0x00BABABA, 0x00BEBEBE, 0x00C1C1C1, 0x00C5C5C5, 0x00C9C9C9, 0x00CDCDCD, 0x00D1D1D1, 0x00D4D4D4, 0x00D8D8D8, 0x00DDDDDD, 0x00E1E1E1, 0x00E5E5E5, 0x00E8E8E8, 0x00EDEDED, 0x00F1F1F1, 0x00F4F4F4, 0x00F8F8F8, 0x00FCFCFC, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F8F8F8, 0x00F4F4F4, 0x00EEEEEE, 0x00E9E9E9, 0x00E3E3E3, 0x00DFDFDF, 0x00DADADA, 0x00D6D6D6, 0x00D3D3D3, 0x00CFCFCF, 0x00CBCBCB, 0x00C8C8C8, 0x00B6B5B7, 0x00B0AFB1, 0x00ABAAAC, 
        0x00AAA9AB, 0x00AAA9AB, 0x00A8A7A9, 0x00A6A5A7, 0x00A6A5A7, 0x00A2A2A2, 0x009F9F9F, 0x26A6A6A6, 0x96B9B9B9, 0xFFC9C9C9, 0xFFD2D2D2, 0xFFDADADA, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 
        0xFFF7F7F7, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFEAEAEA, 0xFFE4E4E4, 0xFFDADADA, 0xFFD0D0D0, 0xFFC6C6C6, 0xF0BDBDBD, 0x7CAEAEAE, 0x08A4A4A4, 0x00A2A2A2, 0x00A3A3A3, 0x009B9A9C, 0x00979698, 0x00959496, 0x00949395, 0x008B8A8C, 0x007A797B, 0x006D6C6E, 
        0x00686769, 0x006E6D6F, 0x00706F71, 0x00737274, 0x00767577, 0x0079787A, 0x007D7C7E, 0x00818082, 0x00848385, 0x00878688, 0x008A898B, 0x008E8D8F, 0x00929193, 0x00969597, 0x009A999B, 0x009E9D9F, 0x00A2A1A3, 0x00A6A6A6, 0x00A9A9A9, 0x00ADADAD, 
        0x00B1B1B1, 0x00B5B5B5, 0x00B9B9B9, 0x00BDBDBD, 0x00C0C0C0, 0x00C5C5C5, 0x00C8C8C8, 0x00CDCDCD, 0x00D1D1D1, 0x00D5D5D5, 0x00D8D8D8, 0x00DDDDDD, 0x00E1E1E1, 0x00E5E5E5, 0x00E8E8E8, 0x00EDEDED, 0x00F1F1F1, 0x00F5F5F5, 0x00F9F9F9, 0x00FCFCFC, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FBFBFB, 0x00F7F7F7, 0x00F2F2F2, 0x00ECECEC, 0x00E7E7E7, 0x00E3E3E3, 0x00DFDFDF, 0x00DADADA, 0x00D6D6D6, 0x00D3D3D3, 0x00CECECE, 0x00CACACA, 0x00C6C6C6, 0x00C0BFC1, 0x00B9B8BA, 0x00B1B0B2, 
        0x00ADACAE, 0x00ACABAD, 0x00AAA9AB, 0x00A8A8A8, 0x00A6A6A6, 0x00A4A4A4, 0x00A4A4A4, 0x00A2A2A2, 0x08A4A4A4, 0x7CB1B1B1, 0xF0C5C5C5, 0xFFD4D4D4, 0xFFD9D9D9, 0xFFE2E2E2, 0xFFE8E8E8, 0xFFEFEFEF, 0xFFF4F4F4, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFF9F9F9, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 
        0xFFF4F4F4, 0xFFF0F0F0, 0xFFEBEBEB, 0xFFE2E2E2, 0xFFDBDBDB, 0xFFD1D1D1, 0xFFC4C4C4, 0xDFBBBBBB, 0x68B6B6B6, 0x00AEAEAE, 0x00A9A9A9, 0x00A7A7A7, 0x00A4A4A4, 0x00A2A1A3, 0x009F9EA0, 0x0099989A, 0x008C8B8D, 0x00777678, 0x00656466, 0x00626163, 
        0x0069686A, 0x006B6A6C, 0x006E6D6F, 0x00727173, 0x00767577, 0x0079787A, 0x007C7B7D, 0x007F7E80, 0x00828183, 0x00868587, 0x0089888A, 0x008D8C8E, 0x00919092, 0x00959496, 0x0099989A, 0x009D9C9E, 0x00A1A0A2, 0x00A5A5A5, 0x00A8A8A8, 0x00ACACAC, 
        0x00B0B0B0, 0x00B4B4B4, 0x00B8B8B8, 0x00BCBCBC, 0x00BFBFBF, 0x00C5C5C5, 0x00C8C8C8, 0x00CDCDCD, 0x00D1D1D1, 0x00D5D5D5, 0x00D9D9D9, 0x00DEDEDE, 0x00E1E1E1, 0x00E6E6E6, 0x00E9E9E9, 0x00EDEDED, 0x00F2F2F2, 0x00F6F6F6, 0x00FAFAFA, 0x00FDFDFD, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00F9F9F9, 0x00F4F4F4, 0x00F0F0F0, 0x00EAEAEA, 0x00E5E5E5, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D4D4D4, 0x00D0D0D0, 0x00CBCBCB, 0x00C5C5C5, 0x00C1C1C1, 0x00BFBEC0, 0x00BBBABC, 0x00B5B4B6, 
        0x00B0AFB1, 0x00AEADAF, 0x00ACABAD, 0x00A9A9A9, 0x00A7A7A7, 0x00A8A8A8, 0x00A6A6A6, 0x00A2A2A2, 0x00A0A0A0, 0x00A3A3A3, 0x68AFAFAF, 0xDFC2C2C2, 0xFFD2D2D2, 0xFFDADADA, 0xFFE2E2E2, 0xFFEAEAEA, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF9F9F9, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF4F4F4, 
        0xFFEFEFEF, 0xFFE9E9E9, 0xFFE2E2E2, 0xFFD9D9D9, 0xFFD1D1D1, 0xFFC8C8C8, 0xD4C0C0C0, 0x5ABBBBBB, 0x00B8B8B8, 0x00B3B3B3, 0x00B0B0B0, 0x00ADADAD, 0x00A6A6A6, 0x00A3A2A4, 0x00A4A3A5, 0x008D8C8E, 0x00676668, 0x00575658, 0x00646365, 0x006A696B, 
        0x00626163, 0x00676668, 0x006B6A6C, 0x00706F71, 0x00747375, 0x00767577, 0x0079787A, 0x007C7B7D, 0x007E7D7F, 0x00848385, 0x00878688, 0x008B8A8C, 0x008F8E90, 0x00939294, 0x00979698, 0x009C9B9D, 0x009F9EA0, 0x00A4A4A4, 0x00A7A7A7, 0x00ACACAC, 
        0x00B0B0B0, 0x00B4B4B4, 0x00B8B8B8, 0x00BCBCBC, 0x00BFBFBF, 0x00C4C4C4, 0x00C8C8C8, 0x00CDCDCD, 0x00D1D1D1, 0x00D5D5D5, 0x00D9D9D9, 0x00DEDEDE, 0x00E2E2E2, 0x00E7E7E7, 0x00E9E9E9, 0x00EEEEEE, 0x00F3F3F3, 0x00F7F7F7, 0x00FBFBFB, 0x00FEFEFE, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F6F6F6, 0x00F1F1F1, 0x00EDEDED, 0x00E7E7E7, 0x00E3E3E3, 0x00DEDEDE, 0x00DADADA, 0x00D3D3D3, 0x00CECECE, 0x00CBCBCB, 0x00C7C7C7, 0x00C3C3C3, 0x00C0C0C0, 0x00B9B8BA, 0x00B7B6B8, 0x00B3B2B4, 
        0x00AFAEB0, 0x00ACACAC, 0x00ABABAB, 0x00ABABAB, 0x00ABABAB, 0x00ACACAC, 0x00A5A5A5, 0x00A4A4A4, 0x00A6A6A6, 0x00A2A2A2, 0x009F9F9F, 0x5AAEAEAE, 0xD4C2C2C2, 0xFFD0D0D0, 0xFFD9D9D9, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF5F5F5, 0xFFF8F8F8, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF1F1F1, 
        0xFFEAEAEA, 0xFFE3E3E3, 0xFFDBDBDB, 0xFFD1D1D1, 0xFFC8C8C8, 0xCEC3C3C3, 0x51C1C1C1, 0x00C1C1C1, 0x00BEBEBE, 0x00B7B7B7, 0x00B3B3B3, 0x00B1B1B1, 0x00ACACAC, 0x00AAA9AB, 0x00818082, 0x005E5D5F, 0x00585759, 0x005B5A5C, 0x0059585A, 0x005E5D5F, 
        0x0069686A, 0x00676668, 0x006A696B, 0x006E6D6F, 0x00717072, 0x00737274, 0x00767577, 0x007A797B, 0x007D7C7E, 0x00838284, 0x00868587, 0x008A898B, 0x008E8D8F, 0x00929193, 0x00969597, 0x009B9A9C, 0x009E9D9F, 0x00A4A4A4, 0x00A7A7A7, 0x00ABABAB, 
        0x00AFAFAF, 0x00B3B3B3, 0x00B7B7B7, 0x00BCBCBC, 0x00BFBFBF, 0x00C4C4C4, 0x00C8C8C8, 0x00CDCDCD, 0x00D1D1D1, 0x00D5D5D5, 0x00D9D9D9, 0x00DEDEDE, 0x00E2E2E2, 0x00E8E8E8, 0x00EAEAEA, 0x00EFEFEF, 0x00F4F4F4, 0x00F8F8F8, 0x00FCFCFC, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FAFAFA, 0x00F5F5F5, 0x00F0F0F0, 0x00EBEBEB, 0x00E6E6E6, 0x00E1E1E1, 0x00DBDBDB, 0x00D8D8D8, 0x00D3D3D3, 0x00CFCFCF, 0x00CBCBCB, 0x00C6C6C6, 0x00C1C1C1, 0x00BDBDBD, 0x00B8B7B9, 0x00B6B5B7, 0x00B2B1B3, 
        0x00ACABAD, 0x00A7A7A7, 0x00A7A7A7, 0x00A9A9A9, 0x00ABABAB, 0x00A9A9A9, 0x00AAAAAA, 0x00AAAAAA, 0x00A6A6A6, 0x00A1A1A1, 0x00A1A1A1, 0x00A6A6A6, 0x51ABABAB, 0xCEC7C7C7, 0xFFD0D0D0, 0xFFDADADA, 0xFFE3E3E3, 0xFFE9E9E9, 0xFFEFEFEF, 0xFFF4F4F4, 
        0xFFF6F6F6, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF3F3F3, 0xFFE8E8E8, 
        0xFFE2E2E2, 0xFFDDDDDD, 0xFFD0D0D0, 0xFFC6C6C6, 0xCECACACA, 0x4ED0D0D0, 0x00C7C7C7, 0x00C3C3C3, 0x00C2C2C2, 0x00B8B8B8, 0x00BABABA, 0x00B3B3B3, 0x00B2B2B2, 0x006D6C6E, 0x005B5A5C, 0x00515052, 0x00565557, 0x005A595B, 0x00585759, 0x005B5A5C, 
        0x00636264, 0x00656466, 0x00676668, 0x006B6A6C, 0x006E6D6F, 0x00717072, 0x00757476, 0x0079787A, 0x007C7B7D, 0x00818082, 0x00848385, 0x0089888A, 0x008D8C8E, 0x00908F91, 0x00949395, 0x0099989A, 0x009D9C9E, 0x00A2A2A2, 0x00A6A6A6, 0x00ABABAB, 
        0x00AFAFAF, 0x00B3B3B3, 0x00B7B7B7, 0x00BCBCBC, 0x00C0C0C0, 0x00C3C3C3, 0x00C7C7C7, 0x00CCCCCC, 0x00D1D1D1, 0x00D4D4D4, 0x00D9D9D9, 0x00DEDEDE, 0x00E2E2E2, 0x00E6E6E6, 0x00EAEAEA, 0x00EFEFEF, 0x00F3F3F3, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 
        0x00FEFEFE, 0x00FFFFFF, 0x00FEFEFE, 0x00F8F8F8, 0x00F3F3F3, 0x00EEEEEE, 0x00E9E9E9, 0x00E4E4E4, 0x00E0E0E0, 0x00DADADA, 0x00D6D6D6, 0x00D0D0D0, 0x00CCCCCC, 0x00C8C8C8, 0x00C3C3C3, 0x00BDBDBD, 0x00BABABA, 0x00B6B6B6, 0x00B2B2B2, 0x00ACACAC, 
        0x00A7A7A7, 0x00A4A4A4, 0x00A2A2A2, 0x009F9F9F, 0x009D9D9D, 0x00ABABAB, 0x00A9A9A9, 0x00ACACAC, 0x00A7A7A7, 0x00A4A3A5, 0x00A6A5A7, 0x00A8A7A9, 0x009B9A9C, 0x4EADADAD, 0xCEBFBFBF, 0xFFD2D2D2, 0xFFDCDCDC, 0xFFE2E2E2, 0xFFEAEAEA, 0xFFF1F1F1, 
        0xFFF4F4F4, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF6F6F6, 0xFFF4F4F4, 0xFFE6E6E6, 0xFFE5E5E5, 
        0xFFE1E1E1, 0xFFCCCCCC, 0xFFC8C8C8, 0xD4D1D1D1, 0x51D1D1D1, 0x00CECECE, 0x00C8C8C8, 0x00C9C9C9, 0x00C1C1C1, 0x00C6C6C6, 0x00BDBDBD, 0x00B1B1B1, 0x00616161, 0x00535254, 0x004E4D4F, 0x004D4C4E, 0x00535254, 0x00585759, 0x005A595B, 0x005D5C5E, 
        0x00616062, 0x00636264, 0x00666567, 0x0069686A, 0x006D6C6E, 0x00706F71, 0x00747375, 0x00787779, 0x007B7A7C, 0x00807F81, 0x00838284, 0x00878688, 0x008B8A8C, 0x008F8E90, 0x00939294, 0x00989799, 0x009C9B9D, 0x00A1A1A1, 0x00A5A5A5, 0x00AAAAAA, 
        0x00AEAEAE, 0x00B2B2B2, 0x00B6B6B6, 0x00BBBBBB, 0x00BFBFBF, 0x00C3C3C3, 0x00C7C7C7, 0x00CCCCCC, 0x00D1D1D1, 0x00D4D4D4, 0x00D9D9D9, 0x00DEDEDE, 0x00E2E2E2, 0x00E7E7E7, 0x00EBEBEB, 0x00EFEFEF, 0x00F3F3F3, 0x00F8F8F8, 0x00FDFDFD, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F7F7F7, 0x00F2F2F2, 0x00EDEDED, 0x00E8E8E8, 0x00E2E2E2, 0x00DEDEDE, 0x00D7D7D7, 0x00D4D4D4, 0x00CECECE, 0x00C9C9C9, 0x00C5C5C5, 0x00C1C1C1, 0x00BBBBBB, 0x00B7B7B7, 0x00B4B4B4, 0x00B0B0B0, 0x00AAAAAA, 
        0x00A5A5A5, 0x00A2A2A2, 0x009F9F9F, 0x009C9C9C, 0x009A9A9A, 0x00989898, 0x00ACACAC, 0x00A9A9A9, 0x00A8A8A8, 0x00A7A6A8, 0x00A9A8AA, 0x009F9EA0, 0x00A7A6A8, 0x00A2A2A2, 0x51AEAEAE, 0xD4C0C0C0, 0xFFD1D1D1, 0xFFDCDCDC, 0xFFE4E4E4, 0xFFEBEBEB, 
        0xFFF1F1F1, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE1E1E1, 0xFFDDDDDD, 
        0xFFD4D4D4, 0xFFC5C5C5, 0xDFCDCDCD, 0x5ADBDBDB, 0x00D7D7D7, 0x00D5D5D5, 0x00CECECE, 0x00CACACA, 0x00CECECE, 0x00C1C1C1, 0x00B6B6B6, 0x00585858, 0x00484848, 0x00454446, 0x004B4A4C, 0x004F4E50, 0x00515052, 0x00545355, 0x0059585A, 0x005C5B5D, 
        0x005B5A5C, 0x00616062, 0x00646365, 0x00676668, 0x006B6A6C, 0x006E6D6F, 0x00727173, 0x00767577, 0x0079787A, 0x007D7C7E, 0x00818082, 0x00858486, 0x0089888A, 0x008D8C8E, 0x00919092, 0x00969597, 0x009A999B, 0x009F9F9F, 0x00A3A3A3, 0x00A8A8A8, 
        0x00ADADAD, 0x00B1B1B1, 0x00B5B5B5, 0x00BABABA, 0x00BEBEBE, 0x00C3C3C3, 0x00C7C7C7, 0x00CCCCCC, 0x00D1D1D1, 0x00D4D4D4, 0x00D9D9D9, 0x00DEDEDE, 0x00E2E2E2, 0x00E8E8E8, 0x00ECECEC, 0x00F0F0F0, 0x00F5F5F5, 0x00F9F9F9, 0x00FEFEFE, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FBFBFB, 0x00F5F5F5, 0x00F0F0F0, 0x00EBEBEB, 0x00E6E6E6, 0x00E0E0E0, 0x00DCDCDC, 0x00D5D5D5, 0x00D1D1D1, 0x00CBCBCB, 0x00C7C7C7, 0x00C2C2C2, 0x00BDBDBD, 0x00B8B8B8, 0x00B4B4B4, 0x00B0B0B0, 0x00ACACAC, 0x00A7A7A7, 
        0x00A3A3A3, 0x009F9F9F, 0x009B9B9B, 0x00979797, 0x00949494, 0x00929292, 0x00949494, 0x00A7A6A8, 0x00A8A7A9, 0x00AEADAF, 0x00A2A1A3, 0x00A7A6A8, 0x00A5A4A6, 0x009E9E9E, 0x00A2A2A2, 0x5AAFAFAF, 0xDFC3C3C3, 0xFFD4D4D4, 0xFFDDDDDD, 0xFFE6E6E6, 
        0xFFEDEDED, 0xFFF2F2F2, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF7F7F7, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEEEEEE, 0xFFE6E6E6, 0xFFE2E2E2, 0xFFD1D1D1, 
        0xFFC6C6C6, 0xF0D3D3D3, 0x68E0E0E0, 0x00DFDFDF, 0x00DADADA, 0x00D4D4D4, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00BABABA, 0x004D4D4D, 0x00444444, 0x00454545, 0x00464547, 0x004C4B4D, 0x00504F51, 0x004F4E50, 0x00504F51, 0x00565557, 0x0059585A, 
        0x0059585A, 0x005F5E60, 0x00626163, 0x00656466, 0x0069686A, 0x006C6B6D, 0x00706F71, 0x00757476, 0x00787779, 0x007B7A7C, 0x007F7E80, 0x00838284, 0x00878688, 0x008B8A8C, 0x008F8E90, 0x00959496, 0x00989799, 0x009E9E9E, 0x00A2A2A2, 0x00A7A7A7, 
        0x00ACACAC, 0x00B0B0B0, 0x00B4B4B4, 0x00BABABA, 0x00BEBEBE, 0x00C2C2C2, 0x00C6C6C6, 0x00CCCCCC, 0x00D0D0D0, 0x00D5D5D5, 0x00D9D9D9, 0x00DFDFDF, 0x00E3E3E3, 0x00E8E8E8, 0x00EDEDED, 0x00F2F2F2, 0x00F6F6F6, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FDFDFD, 0x00F9F9F9, 0x00F3F3F3, 0x00EEEEEE, 0x00E9E9E9, 0x00E3E3E3, 0x00DDDDDD, 0x00D9D9D9, 0x00D3D3D3, 0x00CFCFCF, 0x00C9C9C9, 0x00C4C4C4, 0x00C0C0C0, 0x00BBBBBB, 0x00B5B5B5, 0x00B1B1B1, 0x00ACACAC, 0x00A9A9A9, 0x00A4A4A4, 
        0x00A0A0A0, 0x009C9C9C, 0x00989898, 0x00939393, 0x00909090, 0x00909090, 0x00878787, 0x008C8B8D, 0x00ABAAAC, 0x00A6A5A7, 0x00AEADAF, 0x00A6A5A7, 0x00A3A2A4, 0x00A3A3A3, 0x00A0A0A0, 0x00A5A5A5, 0x68B4B4B4, 0xF0C6C6C6, 0xFFD4D4D4, 0xFFE0E0E0, 
        0xFFE8E8E8, 0xFFEEEEEE, 0xFFF3F3F3, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFE9E9E9, 0xFFE0E0E0, 0xFFD5D5D5, 0xFFC9C9C9, 
        0xFFD0D0D0, 0x7CE4E4E4, 0x00EAEAEA, 0x00E2E2E2, 0x00DEDEDE, 0x00D6D6D6, 0x00D9D9D9, 0x00D4D4D4, 0x00BCBCBC, 0x00515151, 0x003F3F3F, 0x003D3D3D, 0x00434343, 0x00454446, 0x00464547, 0x0049484A, 0x004B4A4C, 0x004E4D4F, 0x00525153, 0x00565557, 
        0x0059585A, 0x005D5C5E, 0x00605F61, 0x00636264, 0x00676668, 0x006A696B, 0x006E6D6F, 0x00737274, 0x00767577, 0x0079787A, 0x007D7C7E, 0x00818082, 0x00868587, 0x0089888A, 0x008E8D8F, 0x00939294, 0x00979698, 0x009D9D9D, 0x00A0A0A0, 0x00A6A6A6, 
        0x00ABABAB, 0x00AFAFAF, 0x00B4B4B4, 0x00BABABA, 0x00BEBEBE, 0x00C2C2C2, 0x00C6C6C6, 0x00CCCCCC, 0x00D0D0D0, 0x00D5D5D5, 0x00D9D9D9, 0x00DFDFDF, 0x00E3E3E3, 0x00E9E9E9, 0x00EEEEEE, 0x00F3F3F3, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FCFCFC, 0x00F8F8F8, 0x00F1F1F1, 0x00ECECEC, 0x00E7E7E7, 0x00E1E1E1, 0x00DBDBDB, 0x00D7D7D7, 0x00D1D1D1, 0x00CCCCCC, 0x00C7C7C7, 0x00C2C2C2, 0x00BDBDBD, 0x00B8B8B8, 0x00B2B2B2, 0x00AEAEAE, 0x00A8A8A8, 0x00A5A5A5, 0x00A1A1A1, 
        0x009D9D9D, 0x00999999, 0x00959595, 0x00919191, 0x008E8E8E, 0x008B8A8C, 0x00878688, 0x00868587, 0x00858486, 0x00A8A7A9, 0x00A9A8AA, 0x00AAA9AB, 0x00A7A6A8, 0x00A7A7A7, 0x00A3A3A3, 0x00A0A0A0, 0x00A5A5A5, 0x7CB4B4B4, 0xFFC8C8C8, 0xFFD8D8D8, 
        0xFFE1E1E1, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEAEAEA, 0xFFE4E4E4, 0xFFD9D9D9, 0xFFC5C5C5, 0xFFD0D0D0, 
        0x96EAEAEA, 0x08EDEDED, 0x00E8E8E8, 0x00E7E7E7, 0x00E3E3E3, 0x00E6E6E6, 0x00D8D8D8, 0x00CACACA, 0x00515151, 0x00333333, 0x003F3F3F, 0x003F3F3F, 0x00404040, 0x00434244, 0x00424143, 0x00454446, 0x004B4A4C, 0x004F4E50, 0x00504F51, 0x00535254, 
        0x00575658, 0x005A595B, 0x005D5C5E, 0x00616062, 0x00646365, 0x00686769, 0x006C6B6D, 0x00706F71, 0x00737274, 0x00777678, 0x007B7A7C, 0x007F7E80, 0x00848385, 0x00888789, 0x008C8B8D, 0x00929193, 0x00969597, 0x009B9B9B, 0x009F9F9F, 0x00A5A5A5, 
        0x00AAAAAA, 0x00AEAEAE, 0x00B3B3B3, 0x00B9B9B9, 0x00BDBDBD, 0x00C2C2C2, 0x00C6C6C6, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00DFDFDF, 0x00E3E3E3, 0x00E9E9E9, 0x00EEEEEE, 0x00F4F4F4, 0x00F8F8F8, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FEFEFE, 0x00FAFAFA, 0x00F5F5F5, 0x00EFEFEF, 0x00E9E9E9, 0x00E4E4E4, 0x00DEDEDE, 0x00D8D8D8, 0x00D3D3D3, 0x00CECECE, 0x00CACACA, 0x00C4C4C4, 0x00BFBFBF, 0x00BABABA, 0x00B5B5B5, 0x00AFAFAF, 0x00ABABAB, 0x00A5A5A5, 0x00A2A2A2, 0x009D9D9D, 
        0x00999999, 0x00969696, 0x00929292, 0x008E8E8E, 0x008B8B8B, 0x00848385, 0x008B8A8C, 0x007D7C7E, 0x007D7C7E, 0x00828183, 0x00A3A2A4, 0x00AAA9AB, 0x00ACABAD, 0x00A8A8A8, 0x00A5A5A5, 0x00A0A0A0, 0x009F9F9F, 0x08A8A8A8, 0x96BBBBBB, 0xFFCECECE, 
        0xFFDADADA, 0xFFE4E4E4, 0xFFEAEAEA, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF3F3F3, 0xFFEDEDED, 0xFFE4E4E4, 0xFFDCDCDC, 0xFFCFCFCF, 0xFFCECECE, 0xB6E6E6E6, 
        0x26FAFAFA, 0x00F2F2F2, 0x00EAEAEA, 0x00ECECEC, 0x00E7E7E7, 0x00DFDFDF, 0x00D3D3D3, 0x00515151, 0x00343434, 0x00353535, 0x00323232, 0x00424242, 0x003C3C3C, 0x00414042, 0x00414042, 0x00454446, 0x004A494B, 0x004C4B4D, 0x004D4C4E, 0x00504F51, 
        0x00545355, 0x00575658, 0x005A595B, 0x005E5D5F, 0x00626163, 0x00656466, 0x0069686A, 0x006E6D6F, 0x00717072, 0x00757476, 0x00787779, 0x007D7C7E, 0x00828183, 0x00868587, 0x008A898B, 0x00908F91, 0x00949395, 0x00999999, 0x009D9D9D, 0x00A3A3A3, 
        0x00A9A9A9, 0x00ADADAD, 0x00B2B2B2, 0x00B8B8B8, 0x00BCBCBC, 0x00C1C1C1, 0x00C5C5C5, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00E0E0E0, 0x00E4E4E4, 0x00E9E9E9, 0x00EEEEEE, 0x00F4F4F4, 0x00F9F9F9, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FEFEFE, 0x00F7F7F7, 0x00F3F3F3, 0x00EDEDED, 0x00E7E7E7, 0x00E1E1E1, 0x00DBDBDB, 0x00D5D5D5, 0x00D0D0D0, 0x00CACACA, 0x00C6C6C6, 0x00C0C0C0, 0x00BBBBBB, 0x00B6B6B6, 0x00B1B1B1, 0x00ABABAB, 0x00A7A7A7, 0x00A2A3A1, 0x009FA09E, 0x009A9A9A, 
        0x00959595, 0x00929292, 0x008E8E8E, 0x00898989, 0x00878787, 0x00848385, 0x007C7B7D, 0x00818082, 0x00757476, 0x00737274, 0x00828183, 0x00A3A2A4, 0x00A8A7A9, 0x00AAAAAA, 0x00A7A7A7, 0x00A5A5A5, 0x00A3A3A3, 0x00A3A3A3, 0x26ADADAD, 0xB6BFBFBF, 
        0xFFD0D0D0, 0xFFDCDCDC, 0xFFE4E4E4, 0xFFEDEDED, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFE8E8E8, 0xFFDEDEDE, 0xFFD5D5D5, 0xFFC6C6C6, 0xDCE6E6E6, 0x49FAFAFA, 
        0x00FAFAFA, 0x00F8F8F8, 0x00F4F4F4, 0x00EDEDED, 0x00E9E9E9, 0x00E6E6E6, 0x005B5B5B, 0x002D2D2D, 0x002F2F2F, 0x00323232, 0x00373737, 0x00363636, 0x003A3A3A, 0x003B3A3C, 0x003F3E40, 0x00434244, 0x00454446, 0x00474648, 0x004B4A4C, 0x00504F51, 
        0x00535254, 0x00555456, 0x00585759, 0x005C5B5D, 0x00605F61, 0x00636264, 0x00686769, 0x006C6B6D, 0x006F6E70, 0x00737274, 0x00777678, 0x007C7B7D, 0x00807F81, 0x00848385, 0x0089888A, 0x008F8E90, 0x00939294, 0x00989898, 0x009C9C9C, 0x00A2A2A2, 
        0x00A7A7A7, 0x00ACACAC, 0x00B2B2B2, 0x00B7B7B7, 0x00BBBBBB, 0x00C1C1C1, 0x00C5C5C5, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00E0E0E0, 0x00E4E4E4, 0x00E9E9E9, 0x00EEEEEE, 0x00F4F4F4, 0x00F9F9F9, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FDFDFD, 0x00F6F6F6, 0x00F1F1F1, 0x00EBEBEB, 0x00E5E5E5, 0x00DFDFDF, 0x00D9D9D9, 0x00D3D3D3, 0x00CECECE, 0x00C8C8C8, 0x00C3C3C3, 0x00BEBEBE, 0x00B8B8B8, 0x00B3B3B3, 0x00AEAEAE, 0x00A8A8A8, 0x00A4A4A4, 0x00A0A19F, 0x009D9E9C, 0x00989898, 
        0x00939393, 0x008E8E8E, 0x008A8A8A, 0x00868686, 0x00838383, 0x007F7E80, 0x007C7B7D, 0x00757476, 0x00777678, 0x00737274, 0x00717072, 0x00848385, 0x00A9A8AA, 0x00AAAAAA, 0x00A8A8A8, 0x00A8A8A8, 0x00A7A7A7, 0x00A1A1A1, 0x00A0A0A0, 0x49B1B1B1, 
        0xDCC5C5C5, 0xFFD6D6D6, 0xFFDFDFDF, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFF6F6F6, 0xFFF6F6F6, 0xFFF4F4F4, 0xFFEBEBEB, 0xFFE3E3E3, 0xFFD9D9D9, 0xFFCBCBCB, 0xFFD4D4D4, 0x72FEFEFE, 0x00FBFBFB, 
        0x00FEFEFE, 0x00FCFCFC, 0x00F4F4F4, 0x00EDECEE, 0x00F4F3F5, 0x00747375, 0x00353436, 0x00272628, 0x002D2C2E, 0x002E2D2F, 0x00343335, 0x00333234, 0x00383739, 0x0039383A, 0x003C3B3D, 0x003F3E40, 0x00424143, 0x00454446, 0x00484749, 0x004D4C4E, 
        0x00504F51, 0x00535254, 0x00565557, 0x005A595B, 0x005D5C5E, 0x00616062, 0x00656466, 0x0069686A, 0x006C6B6D, 0x00717072, 0x00757476, 0x007A797B, 0x007E7D7F, 0x00828183, 0x00868587, 0x008C8B8D, 0x00908F91, 0x00979698, 0x009B9A9C, 0x00A1A1A1, 
        0x00A7A7A7, 0x00ABABAB, 0x00B1B1B1, 0x00B7B7B7, 0x00BBBBBB, 0x00C0C0C0, 0x00C5C5C5, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00E0E0E0, 0x00E5E5E5, 0x00EBEBEB, 0x00F0F0F0, 0x00F5F5F5, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 
        0x00FAFAFA, 0x00F4F4F4, 0x00EFEFEF, 0x00E7E7E7, 0x00E1E1E1, 0x00DCDCDC, 0x00D6D6D6, 0x00CFCFCF, 0x00CACACA, 0x00C5C5C5, 0x00C1C1C1, 0x00BABABA, 0x00B4B4B4, 0x00AFAFAF, 0x00AAAAAA, 0x00A5A5A5, 0x00A1A1A1, 0x009B9B9B, 0x00979797, 0x00939393, 
        0x008E8E8E, 0x008B8B8B, 0x00878787, 0x00838383, 0x00808080, 0x007C7C7C, 0x00767676, 0x00747474, 0x00737373, 0x006E6E6E, 0x00696969, 0x006F6F6F, 0x007B7B7B, 0x00AEAEAE, 0x00A8A8A8, 0x00A8A8A8, 0x00ADADAD, 0x009D9D9D, 0x00A7A7A7, 0x00A3A3A3, 
        0x72B8B8B8, 0xFFCDCDCD, 0xFFD5D5D5, 0xFFE0E0E0, 0xFFEAEAEA, 0xFFF1F1F1, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFE6E6E6, 0xFFD9D9D9, 0xFFD1D1D1, 0xFFCACACA, 0xA1EFEFEF, 0x08FFFFFF, 0x00FFFFFF, 
        0x00FBFBFB, 0x00FFFFFF, 0x00F9F9F9, 0x00FCFBFD, 0x00A3A2A4, 0x00383739, 0x00242325, 0x002E2D2F, 0x002E2D2F, 0x00282729, 0x00313032, 0x00323133, 0x00363537, 0x00383739, 0x003A393B, 0x003E3D3F, 0x00414042, 0x00434244, 0x00464547, 0x004A494B, 
        0x004D4C4E, 0x00515052, 0x00545355, 0x00575658, 0x005B5A5C, 0x005F5E60, 0x00636264, 0x00676668, 0x006A696B, 0x006F6E70, 0x00737274, 0x00787779, 0x007C7B7D, 0x00807F81, 0x00848385, 0x008A898B, 0x008E8D8F, 0x00969597, 0x009A999B, 0x00A0A0A0, 
        0x00A5A5A5, 0x00AAAAAA, 0x00B0B0B0, 0x00B5B5B5, 0x00BABABA, 0x00C0C0C0, 0x00C4C4C4, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00E1E1E1, 0x00E5E5E5, 0x00ECECEC, 0x00F1F1F1, 0x00F6F6F6, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 
        0x00F8F8F8, 0x00F2F2F2, 0x00ECECEC, 0x00E5E5E5, 0x00DFDFDF, 0x00D9D9D9, 0x00D3D3D3, 0x00CDCDCD, 0x00C8C8C8, 0x00C2C2C2, 0x00BEBEBE, 0x00B7B7B7, 0x00B1B1B1, 0x00ACACAC, 0x00A7A7A7, 0x00A1A1A1, 0x009E9E9E, 0x00989898, 0x00959595, 0x00909090, 
        0x008C8C8C, 0x00888888, 0x00848484, 0x00808080, 0x007D7D7D, 0x00787878, 0x00737373, 0x00717171, 0x00707070, 0x006C6C6C, 0x00656565, 0x00646464, 0x00696969, 0x008C8C8C, 0x00B1B1B1, 0x00AAAAAA, 0x00A7A7A7, 0x00ABABAB, 0x00A5A5A5, 0x00A1A1A1, 
        0x08A7A7A7, 0xA1C0C0C0, 0xFFCFCFCF, 0xFFDEDEDE, 0xFFE6E6E6, 0xFFEBEBEB, 0xFFF3F3F3, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFECECEC, 0xFFDFDFDF, 0xFFD0D0D0, 0xFFCCCCCC, 0xD6D2D2D2, 0x3BEFEFEF, 0x00FAFAFA, 0x00F9F9F9, 
        0x00FFFFFF, 0x00FFFFFF, 0x00F4F4F4, 0x00D9D8DA, 0x003E3D3F, 0x00313032, 0x002D2C2E, 0x00363537, 0x002F2E30, 0x0029282A, 0x00313032, 0x002F2E30, 0x002F2E30, 0x00353436, 0x00373638, 0x003B3A3C, 0x003E3D3F, 0x00403F41, 0x00434244, 0x00474648, 
        0x004A494B, 0x004E4D4F, 0x00504F51, 0x00545355, 0x00585759, 0x005C5B5D, 0x00605F61, 0x00646365, 0x00676668, 0x006C6B6D, 0x00706F71, 0x00757476, 0x0079787A, 0x007D7C7E, 0x00828183, 0x00888789, 0x008C8B8D, 0x00939294, 0x00979698, 0x009E9E9E, 
        0x00A3A3A3, 0x00A8A8A8, 0x00AEAEAE, 0x00B4B4B4, 0x00B8B8B8, 0x00BFBFBF, 0x00C4C4C4, 0x00CBCBCB, 0x00D0D0D0, 0x00D5D5D5, 0x00DADADA, 0x00E1E1E1, 0x00E6E6E6, 0x00EDEDED, 0x00F2F2F2, 0x00F8F8F8, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FBFBFB, 
        0x00F6F6F6, 0x00EFEFEF, 0x00E9E9E9, 0x00E2E2E2, 0x00DBDBDB, 0x00D6D6D6, 0x00D0D0D0, 0x00C9C9C9, 0x00C4C4C4, 0x00BEBEBE, 0x00B9B9B9, 0x00B3B3B3, 0x00ADADAD, 0x00A8A8A8, 0x00A3A3A3, 0x009D9D9D, 0x00999999, 0x00949494, 0x00919191, 0x008C8C8C, 
        0x00888888, 0x00848484, 0x00808080, 0x007C7C7C, 0x00797979, 0x00757575, 0x00717171, 0x006E6E6E, 0x006C6C6C, 0x00696969, 0x00646464, 0x005F5F5F, 0x005C5C5C, 0x00636363, 0x009E9E9E, 0x00A9A9A9, 0x00AAAAAA, 0x00ABABAB, 0x00AAAAAA, 0x00A4A4A4, 
        0x00A1A1A1, 0x3BB1B1B1, 0xD6C5C5C5, 0xFFD8D8D8, 0xFFDFDFDF, 0xFFE5E5E5, 0xFFF0F0F0, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFEDEDED, 0xFFE4E4E4, 0xFFD9D9D9, 0xFFCACACA, 0xFFCBCBCB, 0x73DCDCDC, 0x00E4E4E4, 0x00ECECEC, 0x00FEFEFE, 
        0x00F6F6F6, 0x00FFFFFF, 0x00FFFFFF, 0x00565557, 0x00383739, 0x003B3A3C, 0x00313032, 0x002E2D2F, 0x002B2A2C, 0x002D2C2E, 0x00302F31, 0x002C2B2D, 0x00313032, 0x00323133, 0x00343335, 0x00373638, 0x003B3A3C, 0x003E3D3F, 0x00414042, 0x00444345, 
        0x00464547, 0x004B4A4C, 0x004E4D4F, 0x00515052, 0x00555456, 0x0059585A, 0x005D5C5E, 0x00626163, 0x00656466, 0x006A696B, 0x006D6C6E, 0x00737274, 0x00777678, 0x007B7A7C, 0x00807F81, 0x00868587, 0x008A898B, 0x00919092, 0x00959496, 0x009C9C9C, 
        0x00A2A2A2, 0x00A7A7A7, 0x00ADADAD, 0x00B3B3B3, 0x00B8B8B8, 0x00BEBEBE, 0x00C3C3C3, 0x00CACACA, 0x00D0D0D0, 0x00D5D5D5, 0x00DBDBDB, 0x00E2E2E2, 0x00E7E7E7, 0x00EEEEEE, 0x00F3F3F3, 0x00F9F9F9, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 0x00FAFAFA, 
        0x00F4F4F4, 0x00ECECEC, 0x00E7E7E7, 0x00DFDFDF, 0x00D8D8D8, 0x00D3D3D3, 0x00CCCCCC, 0x00C5C5C5, 0x00C0C0C0, 0x00BABABA, 0x00B6B6B6, 0x00AFAFAF, 0x00A9A9A9, 0x00A4A4A4, 0x009F9F9F, 0x00999999, 0x00969696, 0x00909090, 0x008D8D8D, 0x00888888, 
        0x00848484, 0x00808080, 0x007C7C7C, 0x00787878, 0x00757575, 0x00707070, 0x006E6E6E, 0x006A6A6A, 0x00666666, 0x00646464, 0x00636363, 0x005F5F5F, 0x005B5B5B, 0x00555555, 0x006A6A6A, 0x00A8A8A8, 0x00A9A9A9, 0x00ADADAD, 0x00A7A7A7, 0x00AFAFAF, 
        0x00A4A4A4, 0x00A6A6A6, 0x73B8B8B8, 0xFFCDCDCD, 0xFFDADADA, 0xFFE3E3E3, 0xFFECECEC, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF4F4F4, 0xFFF0F0F0, 0xFFE6E6E6, 0xFFDCDCDC, 0xFFD3D3D3, 0xFFC5C5C5, 0xB2C8C8C8, 0x12DADADA, 0x00DFDFDF, 0x00E5E5E5, 0x00F0F0F0, 
        0x00F8F8F8, 0x00FEFEFE, 0x00929292, 0x00434244, 0x0039383A, 0x00383739, 0x00343335, 0x00333234, 0x00323133, 0x00313032, 0x002C2B2D, 0x00282729, 0x00323133, 0x002F2E30, 0x00313032, 0x00343335, 0x00373638, 0x003B3A3C, 0x003F3E40, 0x00424143, 
        0x00444345, 0x00484749, 0x004B4A4C, 0x004F4E50, 0x00535254, 0x00565557, 0x005B5A5C, 0x005F5E60, 0x00626163, 0x00686769, 0x006B6A6C, 0x00717072, 0x00757476, 0x0079787A, 0x007F7E80, 0x00848385, 0x00888789, 0x008F8E90, 0x00939294, 0x009A9A9A, 
        0x00A0A0A0, 0x00A6A6A6, 0x00ACACAC, 0x00B3B3B3, 0x00B7B7B7, 0x00BEBEBE, 0x00C3C3C3, 0x00CACACA, 0x00D0D0D0, 0x00D5D5D5, 0x00DBDBDB, 0x00E2E2E2, 0x00E7E7E7, 0x00EEEEEE, 0x00F3F3F3, 0x00F9F9F9, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F8F8, 
        0x00F2F2F2, 0x00EAEAEA, 0x00E4E4E4, 0x00DDDDDD, 0x00D6D6D6, 0x00D0D0D0, 0x00C9C9C9, 0x00C2C2C2, 0x00BDBDBD, 0x00B7B7B7, 0x00B2B2B2, 0x00ACACAC, 0x00A6A6A6, 0x00A1A1A1, 0x009C9C9C, 0x00969696, 0x00929292, 0x008C8C8C, 0x00898989, 0x00848484, 
        0x00808080, 0x007C7C7C, 0x00787878, 0x00747474, 0x00717171, 0x006A6A6A, 0x00696969, 0x00656565, 0x00606060, 0x005D5D5D, 0x005D5D5D, 0x005C5C5C, 0x00595959, 0x00585858, 0x00535353, 0x00838383, 0x00B1B1B1, 0x00A7A7A7, 0x00ADADAD, 0x00A9A9A9, 
        0x00A8A8A8, 0x00A4A4A4, 0x12ADADAD, 0xB2BFBFBF, 0xFFD4D4D4, 0xFFE1E1E1, 0xFFE8E8E8, 0xFFEFEFEF, 0xFFF5F5F5, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF2F2F2, 0xFFEBEBEB, 0xFFE2E2E2, 0xFFD9D9D9, 0xFFCDCDCD, 0xF6C0C0C0, 0x54C2C2C2, 0x00CFCFCF, 0x00D6D6D6, 0x00DDDDDD, 0x00E5E5E5, 
        0x00EEEEEE, 0x00D0D0D0, 0x00424242, 0x003B3A3C, 0x00403F41, 0x003B3A3C, 0x003E3D3F, 0x003C3B3D, 0x00363537, 0x00333234, 0x00302F31, 0x002B2A2C, 0x002B2A2C, 0x002D2C2E, 0x002E2D2F, 0x00302F31, 0x00333234, 0x00373638, 0x003B3A3C, 0x003F3E40, 
        0x00414042, 0x00454446, 0x00474648, 0x004B4A4C, 0x004F4E50, 0x00535254, 0x00575658, 0x005C5B5D, 0x005F5E60, 0x00656466, 0x00686769, 0x006E6D6F, 0x00737274, 0x00777678, 0x007C7B7D, 0x00828183, 0x00868587, 0x008D8C8E, 0x00919092, 0x00989898, 
        0x009E9E9E, 0x00A4A4A4, 0x00ABABAB, 0x00B2B2B2, 0x00B6B6B6, 0x00BDBDBD, 0x00C2C2C2, 0x00C9C9C9, 0x00D0D0D0, 0x00D5D5D5, 0x00DCDCDC, 0x00E3E3E3, 0x00E8E8E8, 0x00EFEFEF, 0x00F4F4F4, 0x00FAFAFA, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00F6F6F6, 
        0x00EFEFEF, 0x00E7E7E7, 0x00E1E1E1, 0x00D9D9D9, 0x00D2D2D2, 0x00CCCCCC, 0x00C5C5C5, 0x00BEBEBE, 0x00B9B9B9, 0x00B3B3B3, 0x00AEAEAE, 0x00A8A8A8, 0x00A2A2A2, 0x009D9D9D, 0x00979797, 0x00929292, 0x008E8E8E, 0x00878787, 0x00848484, 0x007F7F7F, 
        0x007B7B7B, 0x00777777, 0x00737373, 0x006F6F6F, 0x006D6D6D, 0x00666666, 0x00656565, 0x00636363, 0x005E5E5E, 0x005A5A5A, 0x00585858, 0x00575757, 0x00555555, 0x00595959, 0x00575757, 0x005B5B5B, 0x009D9D9D, 0x00ADADAD, 0x00B0B0B0, 0x00A7A7A7, 
        0x00AAAAAA, 0x00A7A7A7, 0x00A8A8A8, 0x54B4B4B4, 0xF6CACACA, 0xFFDCDCDC, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFF2F2F2, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFF0F0F0, 0xFFE7E7E7, 0xFFDEDEDE, 0xFFD2D2D2, 0xFFC1C1C1, 0x9CB7B7B7, 0x00BCBCBC, 0x00C5C5C5, 0x00D1D1D1, 0x00D2D2D2, 0x00DBDBDB, 
        0x00E3E3E3, 0x00686868, 0x00494949, 0x003D3C3E, 0x00424143, 0x003A393B, 0x003B3A3C, 0x00363537, 0x00323133, 0x00333234, 0x00353436, 0x00343335, 0x002E2D2F, 0x002C2B2D, 0x002D2C2E, 0x002D2C2E, 0x00302F31, 0x00333234, 0x00383739, 0x003B3A3C, 
        0x003D3C3E, 0x00414042, 0x00434244, 0x00474648, 0x004B4A4C, 0x004F4E50, 0x00545355, 0x00585759, 0x005B5A5C, 0x00616062, 0x00656466, 0x006A696B, 0x006F6E70, 0x00747375, 0x0079787A, 0x007F7E80, 0x00838284, 0x008A898B, 0x008F8E90, 0x00969696, 
        0x009D9D9D, 0x00A3A3A3, 0x00A9A9A9, 0x00B0B0B0, 0x00B5B5B5, 0x00BCBCBC, 0x00C2C2C2, 0x00C9C9C9, 0x00D0D0D0, 0x00D5D5D5, 0x00DCDCDC, 0x00E3E3E3, 0x00E9E9E9, 0x00F0F0F0, 0x00F6F6F6, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F3F3F3, 
        0x00EBEBEB, 0x00E3E3E3, 0x00DDDDDD, 0x00D5D5D5, 0x00CECECE, 0x00C8C8C8, 0x00C1C1C1, 0x00B9B9B9, 0x00B4B4B4, 0x00AEAEAE, 0x00A9A9A9, 0x00A2A2A2, 0x009C9C9C, 0x00989898, 0x00929292, 0x008D8D8D, 0x00898989, 0x00828282, 0x007F7F7F, 0x007B7B7B, 
        0x00767676, 0x00737373, 0x006F6F6F, 0x006B6B6B, 0x00686868, 0x00646464, 0x00616161, 0x005E5E5E, 0x005C5C5C, 0x00595959, 0x00575757, 0x00565656, 0x00575757, 0x00595959, 0x00575757, 0x005E5E5E, 0x006C6C6C, 0x00B0B0B0, 0x00A5A5A5, 0x00B2B2B2, 
        0x00AAAAAA, 0x00AAAAAA, 0x00A7A7A7, 0x00ADADAD, 0x9CBFBFBF, 0xFFD1D1D1, 0xFFDEDEDE, 0xFFE7E7E7, 0xFFEDEDED, 0xFFF5F5F5, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFEEEEEE, 0xFFE2E2E2, 0xFFD8D8D8, 0xFFC9C9C9, 0xEAB4B4B4, 0x42ADADAD, 0x00B7B7B7, 0x00BEBEBE, 0x00C2C2C2, 0x00D2D2D2, 0x00DADADA, 
        0x009B9B9B, 0x00414141, 0x00434343, 0x0049484A, 0x00414042, 0x00424143, 0x00414042, 0x003E3D3F, 0x003D3C3E, 0x00383739, 0x00333234, 0x00353436, 0x00323133, 0x002C2B2D, 0x002C2B2D, 0x002C2B2D, 0x002E2D2F, 0x00313032, 0x00353436, 0x00383739, 
        0x003A393B, 0x003E3D3F, 0x00414042, 0x00454446, 0x0049484A, 0x004C4B4D, 0x00515052, 0x00555456, 0x0059585A, 0x005E5D5F, 0x00626163, 0x00686769, 0x006D6C6E, 0x00717072, 0x00767577, 0x007C7B7D, 0x00818082, 0x0089888A, 0x008D8C8E, 0x00949494, 
        0x009B9B9B, 0x00A1A1A1, 0x00A8A8A8, 0x00AFAFAF, 0x00B4B4B4, 0x00BCBCBC, 0x00C1C1C1, 0x00C9C9C9, 0x00D0D0D0, 0x00D5D5D5, 0x00DCDCDC, 0x00E4E4E4, 0x00E9E9E9, 0x00F2F2F2, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FAFAFA, 0x00F1F1F1, 
        0x00E8E8E8, 0x00E0E0E0, 0x00DADADA, 0x00D2D2D2, 0x00CBCBCB, 0x00C5C5C5, 0x00BEBEBE, 0x00B6B6B6, 0x00B1B1B1, 0x00AAAAAA, 0x00A5A5A5, 0x009F9F9F, 0x00999999, 0x00949494, 0x008F8F8F, 0x00898989, 0x00858585, 0x007F7F7F, 0x007C7C7C, 0x00777777, 
        0x00737373, 0x006F6F6F, 0x006B6B6B, 0x00676767, 0x00646464, 0x00626262, 0x005C5C5C, 0x00575757, 0x00565656, 0x00565656, 0x00565656, 0x00575757, 0x005A5A5A, 0x005A5A5A, 0x00616161, 0x00626262, 0x00606060, 0x008C8C8C, 0x00AFAFAF, 0x00ABABAB, 
        0x00ADADAD, 0x00ABABAB, 0x00A9A9A9, 0x00ABABAB, 0x42B6B6B6, 0xEAC9C9C9, 0xFFDADADA, 0xFFE5E5E5, 0xFFEBEBEB, 0xFFF4F4F4, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFE3E3E3, 0xFFE4E4E4, 0xFFCFCFCF, 0xFFBEBEBE, 0x949E9E9E, 0x00A7A7A7, 0x00ABABAB, 0x00B6B6B6, 0x00C0C0C0, 0x00C2C2C2, 0x00BDBDBD, 
        0x00585858, 0x00494949, 0x00484848, 0x004D4C4E, 0x00444345, 0x00434244, 0x00424143, 0x003F3E40, 0x003D3C3E, 0x003B3A3C, 0x0039383A, 0x00363537, 0x00353436, 0x00323133, 0x00302F31, 0x002E2D2F, 0x002C2B2D, 0x002D2C2E, 0x002F2E30, 0x00333234, 
        0x00363537, 0x003B3A3C, 0x003E3D3F, 0x00424143, 0x00454446, 0x00484749, 0x004C4B4D, 0x00515052, 0x00555456, 0x005B5A5C, 0x005F5E60, 0x00646365, 0x006A696B, 0x006E6D6F, 0x00747375, 0x007B7A7C, 0x007F7E80, 0x00868587, 0x008B8A8C, 0x00929292, 
        0x00999999, 0x009F9F9F, 0x00A6A6A6, 0x00AEAEAE, 0x00B3B3B3, 0x00BABABA, 0x00C3C3C3, 0x00C9C9C9, 0x00CFCFCF, 0x00D7D7D7, 0x00DDDDDD, 0x00E3E3E3, 0x00EBEBEB, 0x00F3F3F3, 0x00F8F8F8, 0x00FEFEFE, 0x00FFFFFF, 0x00FDFDFD, 0x00F6F6F6, 0x00EDEDED, 
        0x00E6E6E6, 0x00DEDEDE, 0x00D6D6D6, 0x00D0D0D0, 0x00C9C9C9, 0x00C0C0C0, 0x00B9B9B9, 0x00B3B3B3, 0x00ABABAB, 0x00A5A5A5, 0x00A0A0A0, 0x009A9A9A, 0x00949494, 0x008F8F8F, 0x008A8A8A, 0x00848484, 0x00808080, 0x007A7A7A, 0x00777777, 0x00737373, 
        0x006F6F6F, 0x006B6B6B, 0x00676767, 0x00636363, 0x00616161, 0x005A5A5A, 0x00585858, 0x00565656, 0x00565656, 0x00585858, 0x005B5B5B, 0x005D5D5D, 0x005E5E5E, 0x005F5F5F, 0x005F5F5F, 0x00626262, 0x005D5D5D, 0x00686868, 0x00A9A9A9, 0x00ADADAD, 
        0x00B1B1B1, 0x00ADADAD, 0x00ABABAB, 0x00A8A8A8, 0x00A9A9A9, 0x94C5C5C5, 0xFFD0D0D0, 0xFFDDDDDD, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF2F2F2, 0xFFECECEC, 0xFFE5E5E5, 0xFFDADADA, 0xFFCBCBCB, 0xECA7A7A7, 0x40959595, 0x009B9B9B, 0x00A7A7A7, 0x00ADADAD, 0x00B3B3B3, 0x00C2C2C2, 0x00818181, 
        0x00535353, 0x004F4F4F, 0x00505050, 0x00474648, 0x0049484A, 0x00474648, 0x00464547, 0x00434244, 0x00414042, 0x003F3E40, 0x003D3C3E, 0x003B3A3C, 0x0039383A, 0x00353436, 0x00333234, 0x00313032, 0x002E2D2F, 0x002D2C2E, 0x002F2E30, 0x00313032, 
        0x00333234, 0x00383739, 0x003A393B, 0x003E3D3F, 0x00424143, 0x00454446, 0x004A494B, 0x004F4E50, 0x00535254, 0x0059585A, 0x005C5B5D, 0x00626163, 0x00676668, 0x006C6B6D, 0x00727173, 0x00787779, 0x007D7C7E, 0x00848385, 0x0089888A, 0x00909090, 
        0x00979797, 0x009D9D9D, 0x00A4A4A4, 0x00ACACAC, 0x00B2B2B2, 0x00B9B9B9, 0x00C2C2C2, 0x00C8C8C8, 0x00CFCFCF, 0x00D7D7D7, 0x00DDDDDD, 0x00E4E4E4, 0x00EDEDED, 0x00F3F3F3, 0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00FBFBFB, 0x00F3F3F3, 0x00EAEAEA, 
        0x00E4E4E4, 0x00D9D9D9, 0x00D1D1D1, 0x00CBCBCB, 0x00C4C4C4, 0x00BBBBBB, 0x00B4B4B4, 0x00AEAEAE, 0x00A6A6A6, 0x00A0A0A0, 0x009B9B9B, 0x00949494, 0x008E8E8E, 0x008A8A8A, 0x00848484, 0x007F7F7F, 0x007B7B7B, 0x00767676, 0x00737373, 0x006F6F6F, 
        0x006A6A6A, 0x00666666, 0x00626262, 0x005E5E5E, 0x005C5C5C, 0x00575757, 0x00575757, 0x00565656, 0x00585858, 0x005A5A5A, 0x005C5C5C, 0x005E5E5E, 0x005E5E5E, 0x00606060, 0x00636363, 0x00626262, 0x005F5F5F, 0x006B6B6B, 0x00848484, 0x00B3B3B3, 
        0x00AEAEAE, 0x00ACACAC, 0x00AFAFAF, 0x00A8A8A8, 0x00A8A8A8, 0x40B6B6B6, 0xECCACACA, 0xFFD8D8D8, 0xFFE4E4E4, 0xFFEDEDED, 0xFFF3F3F3, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEFEFEF, 0xFFE9E9E9, 0xFFE3E3E3, 0xFFD1D1D1, 0xFFBFBFBF, 0x9C8D8D8D, 0x008D8D8D, 0x00919191, 0x00A1A1A1, 0x00A3A3A3, 0x00ACACAC, 0x00A9A9A9, 0x00535353, 
        0x00515151, 0x00525252, 0x00555555, 0x00454446, 0x004F4E50, 0x004A494B, 0x00484749, 0x00464547, 0x00444345, 0x00424143, 0x00403F41, 0x003D3C3E, 0x003C3B3D, 0x0039383A, 0x00373638, 0x00343335, 0x00313032, 0x002F2E30, 0x002E2D2F, 0x002E2D2F, 
        0x002F2E30, 0x00343335, 0x00363537, 0x003A393B, 0x003D3C3E, 0x00414042, 0x00464547, 0x004B4A4C, 0x004F4E50, 0x00555456, 0x00585759, 0x005E5D5F, 0x00636264, 0x00686769, 0x006E6D6F, 0x00757476, 0x0079787A, 0x00818082, 0x00868587, 0x008D8D8D, 
        0x00949494, 0x009A9A9A, 0x00A2A2A2, 0x00AAAAAA, 0x00B0B0B0, 0x00B8B8B8, 0x00C0C0C0, 0x00C8C8C8, 0x00CECECE, 0x00D7D7D7, 0x00DEDEDE, 0x00E5E5E5, 0x00EEEEEE, 0x00F3F3F3, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F9F9, 0x00F0F0F0, 0x00E7E7E7, 
        0x00E0E0E0, 0x00D6D6D6, 0x00CECECE, 0x00C7C7C7, 0x00C0C0C0, 0x00B7B7B7, 0x00B0B0B0, 0x00AAAAAA, 0x00A2A2A2, 0x009B9B9B, 0x00969696, 0x00909090, 0x008A8A8A, 0x00858585, 0x00808080, 0x007A7A7A, 0x00767676, 0x00717171, 0x006E6E6E, 0x00696969, 
        0x00646464, 0x00606060, 0x005C5C5C, 0x00585858, 0x00565656, 0x00575757, 0x00575757, 0x00595959, 0x005B5B5B, 0x005E5E5E, 0x005F5F5F, 0x00606060, 0x00606060, 0x00636363, 0x00656565, 0x00656565, 0x00656565, 0x00686868, 0x00696969, 0x00A8A8A8, 
        0x00B2B2B2, 0x00ACACAC, 0x00B2B2B2, 0x00ABABAB, 0x00ABABAB, 0x00ABABAB, 0x9CC3C3C3, 0xFFD3D3D3, 0xFFE0E0E0, 0xFFE9E9E9, 0xFFEFEFEF, 0xFFF6F6F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEDEDED, 0xFFE6E6E6, 0xFFDADADA, 0xFFCDCDCD, 0xFFA4A4A4, 0x4D7B7B7B, 0x00868686, 0x008B8B8B, 0x00969696, 0x009B9B9B, 0x00A7A7A7, 0x007A7A7A, 0x00555555, 
        0x00555555, 0x00505050, 0x00545454, 0x004B4A4C, 0x00515052, 0x004D4C4E, 0x004B4A4C, 0x0049484A, 0x00474648, 0x00454446, 0x00434244, 0x00414042, 0x003F3E40, 0x003D3C3E, 0x003B3A3C, 0x00383739, 0x00353436, 0x00323133, 0x002F2E30, 0x002D2C2E, 
        0x002C2B2D, 0x00302F31, 0x00323133, 0x00363537, 0x0039383A, 0x003D3C3E, 0x00424143, 0x00474648, 0x004A494B, 0x00515052, 0x00545355, 0x005A595B, 0x005F5E60, 0x00656466, 0x006B6A6C, 0x00727173, 0x00767577, 0x007E7D7F, 0x00838284, 0x008A8A8A, 
        0x00929292, 0x00989898, 0x00A0A0A0, 0x00A9A9A9, 0x00AFAFAF, 0x00B7B7B7, 0x00C0C0C0, 0x00C7C7C7, 0x00CECECE, 0x00D8D8D8, 0x00DFDFDF, 0x00E6E6E6, 0x00EFEFEF, 0x00F4F4F4, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00F6F6F6, 0x00ECECEC, 0x00E3E3E3, 
        0x00DDDDDD, 0x00D2D2D2, 0x00CACACA, 0x00C3C3C3, 0x00BCBCBC, 0x00B2B2B2, 0x00ABABAB, 0x00A5A5A5, 0x009D9D9D, 0x00969696, 0x00929292, 0x008B8B8B, 0x00858585, 0x00808080, 0x007B7B7B, 0x00767676, 0x00727272, 0x006D6D6D, 0x00696969, 0x00646464, 
        0x005F5F5F, 0x005B5B5B, 0x00585858, 0x00565656, 0x00555555, 0x00595959, 0x005A5A5A, 0x005C5C5C, 0x005F5F5F, 0x00616161, 0x00626262, 0x00636363, 0x00636363, 0x00676767, 0x00636363, 0x00696969, 0x006C6C6C, 0x00636363, 0x006B6B6B, 0x008B8B8B, 
        0x00B6B6B6, 0x00AFAFAF, 0x00B0B0B0, 0x00AEAEAE, 0x00ADADAD, 0x00AAAAAA, 0x4DBBBBBB, 0xFFCDCDCD, 0xFFDADADA, 0xFFE6E6E6, 0xFFEDEDED, 0xFFF4F4F4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEAEAEA, 0xFFE2E2E2, 0xFFD3D3D3, 0xFFC8C8C8, 0xB4818181, 0x006F6F6F, 0x007B7B7B, 0x00848484, 0x00898989, 0x00959595, 0x00949494, 0x005C5C5C, 0x005F5F5F, 
        0x00595959, 0x00555555, 0x00545454, 0x00545355, 0x00515052, 0x00515052, 0x00504F51, 0x004D4C4E, 0x004B4A4C, 0x0049484A, 0x00474648, 0x00454446, 0x00444345, 0x00403F41, 0x003E3D3F, 0x003B3A3C, 0x00383739, 0x00353436, 0x00323133, 0x002F2E30, 
        0x002D2C2E, 0x002D2C2E, 0x002F2E30, 0x00323133, 0x00363537, 0x003A393B, 0x003F3E40, 0x00434244, 0x00464547, 0x004D4C4E, 0x00515052, 0x00565557, 0x005C5B5D, 0x00616062, 0x00686769, 0x006E6D6F, 0x00737274, 0x007B7A7C, 0x00807F81, 0x00888888, 
        0x00909090, 0x00979797, 0x009F9F9F, 0x00A8A8A8, 0x00AEAEAE, 0x00B7B7B7, 0x00BFBFBF, 0x00C7C7C7, 0x00CECECE, 0x00D8D8D8, 0x00DFDFDF, 0x00E6E6E6, 0x00EFEFEF, 0x00F6F6F6, 0x00FEFEFE, 0x00FFFFFF, 0x00FCFCFC, 0x00F2F2F2, 0x00E9E9E9, 0x00E0E0E0, 
        0x00D8D8D8, 0x00CDCDCD, 0x00C5C5C5, 0x00BDBDBD, 0x00B5B5B5, 0x00ACACAC, 0x00A5A5A5, 0x009F9F9F, 0x00979797, 0x00909090, 0x008B8B8B, 0x00858585, 0x007F7F7F, 0x007A7A7A, 0x00757575, 0x006F6F6F, 0x006B6B6B, 0x00686868, 0x00646464, 0x005F5F5F, 
        0x005A5A5A, 0x00575757, 0x00575757, 0x00575757, 0x00585858, 0x005D5D5D, 0x005E5E5E, 0x005F5F5F, 0x00606060, 0x00626262, 0x00646464, 0x00656565, 0x00666666, 0x00676767, 0x00666666, 0x00696969, 0x006D6D6D, 0x00686868, 0x00707070, 0x00737373, 
        0x00ABABAB, 0x00B4B4B4, 0x00ADADAD, 0x00AFAFAF, 0x00ACACAC, 0x00ADADAD, 0x00B0B0B0, 0xB4C6C6C6, 0xFFD5D5D5, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFF2F2F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE6E6E6, 0xFFDEDEDE, 0xFFD1D1D1, 0xFFB1B1B1, 0x6B666666, 0x00686868, 0x00717171, 0x007D7D7D, 0x00808080, 0x008E8E8E, 0x00767676, 0x005D5D5D, 0x00595959, 
        0x005A5A5A, 0x005D5D5D, 0x00575757, 0x0059585A, 0x00535254, 0x00545355, 0x00525153, 0x00504F51, 0x004E4D4F, 0x004C4B4D, 0x004A494B, 0x00484749, 0x00474648, 0x00444345, 0x00424143, 0x003F3E40, 0x003C3B3D, 0x003A393B, 0x00373638, 0x00333234, 
        0x00313032, 0x002C2B2D, 0x002D2C2E, 0x002F2E30, 0x00323133, 0x00363537, 0x003B3A3C, 0x00403F41, 0x00424143, 0x00484749, 0x004C4B4D, 0x00525153, 0x00585759, 0x005D5C5E, 0x00646365, 0x006A696B, 0x006F6E70, 0x00777678, 0x007C7B7D, 0x00858585, 
        0x008D8D8D, 0x00949494, 0x009D9D9D, 0x00A6A6A6, 0x00ADADAD, 0x00B6B6B6, 0x00BFBFBF, 0x00C7C7C7, 0x00CECECE, 0x00D8D8D8, 0x00DFDFDF, 0x00E7E7E7, 0x00F0F0F0, 0x00F8F8F8, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F9F9, 0x00EEEEEE, 0x00E5E5E5, 0x00DBDBDB, 
        0x00D2D2D2, 0x00C9C9C9, 0x00C0C0C0, 0x00B8B8B8, 0x00B0B0B0, 0x00A6A6A6, 0x009F9F9F, 0x00999999, 0x00919191, 0x008B8B8B, 0x00868686, 0x007F7F7F, 0x00797979, 0x00747474, 0x006F6F6F, 0x006A6A6A, 0x00666666, 0x00616161, 0x005E5E5E, 0x005A5A5A, 
        0x00575757, 0x00575757, 0x00585858, 0x005A5A5A, 0x005B5B5B, 0x005F5F5F, 0x00606060, 0x00616161, 0x00626262, 0x00636363, 0x00646464, 0x00666666, 0x00686868, 0x00686868, 0x006E6E6E, 0x00696969, 0x006B6B6B, 0x00737373, 0x006B6B6B, 0x00707070, 
        0x00919191, 0x00B9B9B9, 0x00B1B1B1, 0x00B1B1B1, 0x00ACACAC, 0x00AFAFAF, 0x00AAAAAA, 0x6BBEBEBE, 0xFFD1D1D1, 0xFFDEDEDE, 0xFFE6E6E6, 0xFFF0F0F0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE2E2E2, 0xFFD9D9D9, 0xFFCCCCCC, 0xDC838383, 0x23575757, 0x00616161, 0x006A6A6A, 0x00727272, 0x00797979, 0x00818181, 0x00646464, 0x00646464, 0x00595959, 
        0x005E5E5E, 0x00606060, 0x005C5C5C, 0x005C5B5D, 0x00575658, 0x00565557, 0x00555456, 0x00535254, 0x00515052, 0x004F4E50, 0x004D4C4E, 0x004B4A4C, 0x004A494B, 0x00484749, 0x00464547, 0x00434244, 0x00414042, 0x003F3E40, 0x003C3B3D, 0x00383739, 
        0x00353436, 0x00313032, 0x002F2E30, 0x002D2C2E, 0x002E2D2F, 0x00313032, 0x00353436, 0x003A393B, 0x003D3C3E, 0x00434244, 0x00474648, 0x004D4C4E, 0x00535254, 0x0059585A, 0x005F5E60, 0x00666567, 0x006B6A6C, 0x00737274, 0x00787779, 0x00818181, 
        0x00898989, 0x00919191, 0x009A9A9A, 0x00A4A4A4, 0x00AAAAAA, 0x00B5B5B5, 0x00BEBEBE, 0x00C6C6C6, 0x00CECECE, 0x00D8D8D8, 0x00E0E0E0, 0x00E8E8E8, 0x00F1F1F1, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00F5F5F5, 0x00EAEAEA, 0x00E1E1E1, 0x00D6D6D6, 
        0x00CCCCCC, 0x00C4C4C4, 0x00BBBBBB, 0x00B2B2B2, 0x00AAAAAA, 0x00A0A0A0, 0x00999999, 0x00939393, 0x008C8C8C, 0x00858585, 0x00818181, 0x007A7A7A, 0x00747474, 0x006F6F6F, 0x006A6A6A, 0x00646464, 0x00616161, 0x005A5A5A, 0x00595959, 0x00585858, 
        0x00585858, 0x00595959, 0x005C5C5C, 0x005E5E5E, 0x005F5F5F, 0x00626262, 0x00636363, 0x00656565, 0x00656565, 0x00666666, 0x00676767, 0x00696969, 0x006B6B6B, 0x006A6A6A, 0x00707070, 0x006D6D6D, 0x006E6E6E, 0x00757575, 0x006B6B6B, 0x00767676, 
        0x007C7C7C, 0x00B3B3B3, 0x00B5B5B5, 0x00B4B4B4, 0x00B1B1B1, 0x00B0B0B0, 0x00ACACAC, 0x23B7B7B7, 0xDCCBCBCB, 0xFFDADADA, 0xFFE2E2E2, 0xFFECECEC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDEDEDE, 0xFFD5D5D5, 0xFFC2C2C2, 0x99595959, 0x004F4F4F, 0x00595959, 0x00646464, 0x00686868, 0x00737373, 0x00727272, 0x00656565, 0x00626262, 0x00666666, 
        0x00646464, 0x005D5D5D, 0x005D5D5D, 0x005F5E60, 0x005B5A5C, 0x005A595B, 0x0059585A, 0x00575658, 0x00555456, 0x00535254, 0x00525153, 0x004F4E50, 0x004E4D4F, 0x004B4A4C, 0x0049484A, 0x00464547, 0x00434244, 0x00424143, 0x003F3E40, 0x003C3B3D, 
        0x0039383A, 0x00363537, 0x00333234, 0x002E2D2F, 0x002B2A2C, 0x002C2B2D, 0x00302F31, 0x00353436, 0x0039383A, 0x00403F41, 0x00444345, 0x004A494B, 0x00504F51, 0x00565557, 0x005C5B5D, 0x00636264, 0x00686769, 0x00706F71, 0x00757476, 0x007E7E7E, 
        0x00878787, 0x008F8F8F, 0x00989898, 0x00A2A2A2, 0x00A8A8A8, 0x00B3B3B3, 0x00BDBDBD, 0x00C5C5C5, 0x00CECECE, 0x00D8D8D8, 0x00E1E1E1, 0x00E9E9E9, 0x00F2F2F2, 0x00FDFDFD, 0x00FFFFFF, 0x00FDFDFD, 0x00F2F2F2, 0x00E7E7E7, 0x00DEDEDE, 0x00D2D2D2, 
        0x00C7C7C7, 0x00BEBEBE, 0x00B5B5B5, 0x00ACACAC, 0x00A4A4A4, 0x009A9A9A, 0x00939393, 0x008D8D8D, 0x00858585, 0x007F7F7F, 0x007B7B7B, 0x00747474, 0x006E6E6E, 0x00696969, 0x00646464, 0x005F5F5F, 0x005B5B5B, 0x00565656, 0x00565656, 0x00575757, 
        0x005A5A5A, 0x005D5D5D, 0x00606060, 0x00616161, 0x00626262, 0x00636363, 0x00656565, 0x00686868, 0x00696969, 0x006A6A6A, 0x006A6A6A, 0x006C6C6C, 0x006D6D6D, 0x006E6E6E, 0x006D6D6D, 0x00737373, 0x00737373, 0x006D6D6D, 0x00737373, 0x00787878, 
        0x00737373, 0x00A6A6A6, 0x00B5B5B5, 0x00B4B4B4, 0x00B5B5B5, 0x00AFAEB0, 0x00AEAEAE, 0x00B0AFB1, 0x99C4C4C4, 0xFFD6D6D6, 0xFFDFDFDF, 0xFFEAEAEA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDBDBDB, 0xFFCDCDCD, 0xFFA2A2A2, 0x57414141, 0x00484848, 0x00525252, 0x00555555, 0x00656565, 0x00676767, 0x006D6D6D, 0x00686769, 0x00676668, 0x00666567, 
        0x00656466, 0x00646365, 0x00626163, 0x00605F61, 0x005F5E60, 0x005E5D5F, 0x005D5C5E, 0x005B5A5C, 0x0059585A, 0x00575658, 0x00555456, 0x00535254, 0x00525153, 0x004E4D4F, 0x004D4C4E, 0x004B4A4C, 0x00484749, 0x00464547, 0x00434244, 0x00414042, 
        0x003F3E40, 0x0039383A, 0x00383739, 0x00343335, 0x00302F31, 0x002C2B2D, 0x002D2C2E, 0x00313032, 0x00343335, 0x003B3A3C, 0x003E3D3F, 0x00454446, 0x004C4B4D, 0x00515052, 0x00565557, 0x005D5C5E, 0x00636264, 0x006C6B6D, 0x00747375, 0x007B7A7C, 
        0x00838284, 0x008D8C8E, 0x00939294, 0x009C9B9D, 0x00A8A7A9, 0x00AFAFAF, 0x00BABABA, 0x00C4C4C4, 0x00CDCDCD, 0x00D7D7D7, 0x00E0E0E0, 0x00EAEAEA, 0x00F4F4F4, 0x00FFFFFF, 0x00FFFFFF, 0x00FAFAFA, 0x00EEEEEE, 0x00E2E2E2, 0x00D8D8D8, 0x00CCCCCC, 
        0x00C2C2C2, 0x00B7B7B7, 0x00AFAFAF, 0x00A6A6A6, 0x009E9E9E, 0x00969696, 0x008D8D8D, 0x00858585, 0x00818181, 0x00787878, 0x00737373, 0x006D6D6D, 0x00686868, 0x00646464, 0x005E5E5E, 0x00595959, 0x00565656, 0x00575757, 0x00595959, 0x005B5B5B, 
        0x005E5E5E, 0x00606060, 0x00616161, 0x00636363, 0x00656565, 0x00676767, 0x00686868, 0x006A6A6A, 0x006B6B6B, 0x006C6C6C, 0x006D6D6D, 0x006F6F6F, 0x00707070, 0x00727272, 0x00727272, 0x00737274, 0x00747375, 0x00757476, 0x00767577, 0x00777678, 
        0x00787779, 0x0089888A, 0x00BBBABC, 0x00B5B4B6, 0x00B5B4B6, 0x00B5B4B8, 0x00AFAEB0, 0x00B3B2B6, 0x57BBBABC, 0xFFCFCFCF, 0xFFDDDDDD, 0xFFE9E9E9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD8D8D8, 0xFFCDCDCD, 0xD8727272, 0x17393939, 0x003F3F3F, 0x004B4B4B, 0x004F4F4F, 0x005D5D5D, 0x00606060, 0x006B6B6B, 0x006B6A6C, 0x006A696B, 0x0069686A, 
        0x00676668, 0x00666567, 0x00656466, 0x00636264, 0x00616062, 0x00616062, 0x00605F61, 0x005E5D5F, 0x005C5B5D, 0x005A595B, 0x00585759, 0x00565557, 0x00555456, 0x00525153, 0x00504F51, 0x004E4D4F, 0x004C4B4D, 0x004A494B, 0x00474648, 0x00444345, 
        0x00424143, 0x003E3D3F, 0x003C3B3D, 0x00383739, 0x00343335, 0x002F2E30, 0x002D2C2E, 0x002E2D2F, 0x002F2E30, 0x00363537, 0x003A393B, 0x00403F41, 0x00464547, 0x004B4A4C, 0x00515052, 0x005A595B, 0x00626163, 0x00666567, 0x006E6D6F, 0x00767577, 
        0x007E7D7F, 0x00888789, 0x008F8E90, 0x0099989A, 0x00A4A3A5, 0x00AEAEAE, 0x00B9B9B9, 0x00C3C3C3, 0x00CDCDCD, 0x00D8D8D8, 0x00E1E1E1, 0x00EBEBEB, 0x00F6F6F6, 0x00FFFFFF, 0x00FDFDFD, 0x00F5F5F5, 0x00E9E9E9, 0x00DDDDDD, 0x00D3D3D3, 0x00C6C6C6, 
        0x00BCBCBC, 0x00B2B2B2, 0x00A9A9A9, 0x009E9E9E, 0x00969696, 0x008F8F8F, 0x00868686, 0x007E7E7E, 0x007A7A7A, 0x00747474, 0x006D6D6D, 0x00666666, 0x00616161, 0x005E5E5E, 0x005A5A5A, 0x00585858, 0x00585858, 0x005A5A5A, 0x005C5C5C, 0x005E5E5E, 
        0x00606060, 0x00626262, 0x00646464, 0x00666666, 0x00676767, 0x00696969, 0x006A6A6A, 0x006C6C6C, 0x006D6D6D, 0x006E6E6E, 0x00707070, 0x00717171, 0x00737373, 0x00737373, 0x00747474, 0x00747375, 0x00757476, 0x00777678, 0x00787779, 0x00787779, 
        0x0079787A, 0x00838284, 0x00B1B0B2, 0x00B8B7BB, 0x00B7B6BA, 0x00B6B5B9, 0x00B1B0B4, 0x00B3B2B6, 0x17B8B7B9, 0xD8CCCBCD, 0xFFDBDBDB, 0xFFE7E7E7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD9D9D9, 0xFFC8C8C8, 0x9D3C3C3C, 0x00323232, 0x00363636, 0x00424242, 0x00484848, 0x00535353, 0x00616161, 0x006F6F6F, 0x006E6D6F, 0x006D6C6E, 0x006C6B6D, 
        0x006B6A6C, 0x006A696B, 0x0069686A, 0x00676668, 0x00656466, 0x00656466, 0x00646365, 0x00626163, 0x00605F61, 0x005E5D5F, 0x005D5C5E, 0x005B5A5C, 0x0059585A, 0x00575658, 0x00555456, 0x00535254, 0x00515052, 0x004F4E50, 0x004C4B4D, 0x0049484A, 
        0x00474648, 0x00444345, 0x00414042, 0x003E3D3F, 0x003A393B, 0x00363537, 0x00323133, 0x002E2D2F, 0x002C2B2D, 0x00302F31, 0x00343335, 0x003A393B, 0x00403F41, 0x00454446, 0x004B4A4C, 0x00545355, 0x005C5B5D, 0x00616062, 0x0069686A, 0x00717072, 
        0x007A797B, 0x00858486, 0x008D8C8E, 0x00979698, 0x00A3A2A4, 0x00ADADAD, 0x00B8B8B8, 0x00C2C2C2, 0x00CCCCCC, 0x00D8D8D8, 0x00E2E2E2, 0x00EDEDED, 0x00F9F9F9, 0x00FFFFFF, 0x00FCFCFC, 0x00F1F1F1, 0x00E3E3E3, 0x00D8D8D8, 0x00CDCDCD, 0x00C0C0C0, 
        0x00B5B5B5, 0x00ABABAB, 0x00A1A1A1, 0x00969696, 0x008E8E8E, 0x00888888, 0x00808080, 0x00787878, 0x00737373, 0x006D6D6D, 0x00666666, 0x005E5E5E, 0x005A5A5A, 0x00585858, 0x00575757, 0x00595959, 0x005B5B5B, 0x005E5E5E, 0x00606060, 0x00626262, 
        0x00646464, 0x00666666, 0x00686868, 0x00696969, 0x006B6B6B, 0x006D6D6D, 0x006E6E6E, 0x006F6F6F, 0x00717171, 0x00727272, 0x00737373, 0x00747474, 0x00767676, 0x00757575, 0x00767676, 0x00777678, 0x00787779, 0x0079787A, 0x007A797B, 0x007A797B, 
        0x007B7A7C, 0x007D7C7E, 0x00A1A0A2, 0x00BBBABE, 0x00BAB9BD, 0x00B8B7BB, 0x00B3B2B6, 0x00B4B3B7, 0x00B4B3B5, 0x9DC7C6C8, 0xFFD6D6D6, 0xFFE3E3E3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD5D5D5, 0xFFABABAB, 0x631E1E1E, 0x002A2A2A, 0x00303030, 0x00383838, 0x003E3E3E, 0x00474747, 0x006B6B6B, 0x00757575, 0x00717072, 0x00717072, 0x006F6E70, 
        0x006E6D6F, 0x006E6D6F, 0x006C6B6D, 0x006B6A6C, 0x0069686A, 0x0069686A, 0x00676668, 0x00666567, 0x00646365, 0x00626163, 0x00616062, 0x005F5E60, 0x005E5D5F, 0x005B5A5C, 0x0059585A, 0x00575658, 0x00555456, 0x00535254, 0x00504F51, 0x004E4D4F, 
        0x004C4B4D, 0x00484749, 0x00464547, 0x00424143, 0x003F3E40, 0x003D3C3E, 0x00383739, 0x00333234, 0x002F2E30, 0x002D2C2E, 0x002F2E30, 0x00353436, 0x003C3B3D, 0x00424143, 0x00484749, 0x004E4D4F, 0x00535254, 0x005C5B5D, 0x00646365, 0x006D6C6E, 
        0x00767577, 0x00818082, 0x0089888A, 0x00949395, 0x00A09FA1, 0x00ABABAB, 0x00B7B7B7, 0x00C2C2C2, 0x00CCCCCC, 0x00D8D8D8, 0x00E3E3E3, 0x00EFEFEF, 0x00FBFBFB, 0x00FFFFFF, 0x00F9F9F9, 0x00EBEBEB, 0x00DCDCDC, 0x00D1D1D1, 0x00C6C6C6, 0x00B8B8B8, 
        0x00ADADAD, 0x00A3A3A3, 0x00999999, 0x008F8F8F, 0x00888888, 0x00828282, 0x007A7A7A, 0x00717171, 0x006C6C6C, 0x00646464, 0x005E5E5E, 0x00595959, 0x00575757, 0x00575757, 0x00595959, 0x005D5D5D, 0x00606060, 0x00626262, 0x00646464, 0x00666666, 
        0x00686868, 0x00696969, 0x006B6B6B, 0x006D6D6D, 0x006E6E6E, 0x006F6F6F, 0x00707070, 0x00727272, 0x00737373, 0x00747474, 0x00757575, 0x00777777, 0x00787878, 0x00787878, 0x00787878, 0x0079787A, 0x007A797B, 0x007B7A7C, 0x007C7B7D, 0x007C7B7D, 
        0x007D7C7E, 0x007A797B, 0x00939294, 0x00BCBBBF, 0x00BCBBBF, 0x00BAB9BD, 0x00B6B5B9, 0x00B5B4B8, 0x00B2B1B3, 0x63C2C1C3, 0xFFD2D2D2, 0xFFE0E0E0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFCDCDCD, 0xF5777777, 0x2B141414, 0x001F1F1F, 0x002A2A2A, 0x002E2E2E, 0x00353535, 0x00424242, 0x00757575, 0x00767676, 0x00747375, 0x00737274, 0x00727173, 
        0x00717072, 0x00717072, 0x006F6E70, 0x006E6D6F, 0x006D6C6E, 0x006C6B6D, 0x006B6A6C, 0x0069686A, 0x00676668, 0x00666567, 0x00656466, 0x00636264, 0x00626163, 0x005E5D5F, 0x005D5C5E, 0x005B5A5C, 0x0059585A, 0x00575658, 0x00545355, 0x00525153, 
        0x00504F51, 0x004D4C4E, 0x004A494B, 0x00464547, 0x00434244, 0x00424143, 0x003E3D3F, 0x0039383A, 0x00353436, 0x002F2E30, 0x002E2D2F, 0x002F2E30, 0x00343335, 0x003C3B3D, 0x00424143, 0x00484749, 0x004D4C4E, 0x00565557, 0x005E5D5F, 0x00666567, 
        0x00706F71, 0x007B7A7C, 0x00848385, 0x008F8E90, 0x009C9B9D, 0x00A9A9A9, 0x00B5B5B5, 0x00C0C0C0, 0x00CCCCCC, 0x00D9D9D9, 0x00E4E4E4, 0x00F0F0F0, 0x00FCFCFC, 0x00FFFFFF, 0x00F4F4F4, 0x00E4E4E4, 0x00D5D5D5, 0x00C9C9C9, 0x00BEBEBE, 0x00B0B0B0, 
        0x00A5A5A5, 0x009A9A9A, 0x00919191, 0x00878787, 0x00808080, 0x00797979, 0x00707070, 0x00676767, 0x00626262, 0x005B5B5B, 0x00595959, 0x00585858, 0x00595959, 0x005B5B5B, 0x005D5D5D, 0x00606060, 0x00646464, 0x00666666, 0x00676767, 0x00696969, 
        0x006B6B6B, 0x006C6C6C, 0x006E6E6E, 0x006F6F6F, 0x00717171, 0x00727272, 0x00737373, 0x00747474, 0x00757575, 0x00767676, 0x00777777, 0x00797979, 0x007A7A7A, 0x007A7A7A, 0x007B7B7B, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 
        0x007F7E80, 0x007D7C7E, 0x008A898B, 0x00B7B6BA, 0x00BDBCC0, 0x00BBBABE, 0x00B9B8BC, 0x00B7B6BA, 0x00B3B2B4, 0x2BBEBDBF, 0xF5CECECE, 0xFFDDDDDD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFC8C8C8, 0xC2454545, 0x00101010, 0x00141414, 0x00232323, 0x00262626, 0x002E2E2E, 0x004C4C4C, 0x007A7A7A, 0x00777777, 0x00777678, 0x00767577, 0x00757476, 
        0x00757476, 0x00747375, 0x00737274, 0x00717072, 0x00706F71, 0x00706F71, 0x006E6D6F, 0x006D6C6E, 0x006B6A6C, 0x006A696B, 0x0069686A, 0x00676668, 0x00666567, 0x00636264, 0x00626163, 0x00605F61, 0x005E5D5F, 0x005C5B5D, 0x0059585A, 0x00575658, 
        0x00555456, 0x00525153, 0x004F4E50, 0x004B4A4C, 0x00484749, 0x00464547, 0x00424143, 0x003E3D3F, 0x003B3A3C, 0x00363537, 0x00302F31, 0x002C2B2D, 0x002D2C2E, 0x00333234, 0x003B3A3C, 0x00424143, 0x00484749, 0x00515052, 0x0059585A, 0x00616062, 
        0x006B6A6C, 0x00767577, 0x00807F81, 0x008B8A8C, 0x00989799, 0x00A6A6A6, 0x00B2B2B2, 0x00BFBFBF, 0x00CBCBCB, 0x00DADADA, 0x00E6E6E6, 0x00F2F2F2, 0x00FEFEFE, 0x00FDFDFD, 0x00F1F1F1, 0x00DEDEDE, 0x00CFCFCF, 0x00C3C3C3, 0x00B6B6B6, 0x00A8A8A8, 
        0x009E9E9E, 0x00939393, 0x008A8A8A, 0x00808080, 0x00787878, 0x00707070, 0x00676767, 0x005F5F5F, 0x005B5B5B, 0x00575757, 0x00575757, 0x005A5A5A, 0x005E5E5E, 0x00616161, 0x00626262, 0x00656565, 0x00676767, 0x006A6A6A, 0x006B6B6B, 0x006D6D6D, 
        0x006F6F6F, 0x00707070, 0x00717171, 0x00737373, 0x00747474, 0x00747474, 0x00767676, 0x00777777, 0x00787878, 0x00797979, 0x007A7A7A, 0x007B7B7B, 0x007C7C7C, 0x007D7D7D, 0x007D7D7D, 0x007E7D7F, 0x007F7E80, 0x00807F81, 0x00818082, 0x00818082, 
        0x00818082, 0x00828183, 0x00868587, 0x00ACABAF, 0x00BEBDC1, 0x00BDBCC0, 0x00BBBABE, 0x00B8B7BB, 0x00B7B6B8, 0x00BAB9BB, 0xC2CBCBCB, 0xFFDADADA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFC2C2C2, 0x921C1C1C, 0x00080808, 0x000E0E0E, 0x00181818, 0x001D1D1D, 0x00282828, 0x00606060, 0x007C7C7C, 0x007C7C7C, 0x007B7A7C, 0x007A797B, 0x0079787A, 
        0x00787779, 0x00787779, 0x00777678, 0x00757476, 0x00747375, 0x00747375, 0x00727173, 0x00717072, 0x00706F71, 0x006F6E70, 0x006D6C6E, 0x006C6B6D, 0x006B6A6C, 0x0069686A, 0x00676668, 0x00656466, 0x00636264, 0x00616062, 0x005F5E60, 0x005C5B5D, 
        0x005B5A5C, 0x00575658, 0x00555456, 0x00525153, 0x004F4E50, 0x004C4B4D, 0x00484749, 0x00444345, 0x00414042, 0x003D3C3E, 0x00383739, 0x00323133, 0x002F2E30, 0x002F2E30, 0x00333234, 0x003A393B, 0x00414042, 0x004A494B, 0x00525153, 0x005B5A5C, 
        0x00656466, 0x00717072, 0x007B7A7C, 0x00888789, 0x00959496, 0x00A1A1A1, 0x00AFAFAF, 0x00BDBDBD, 0x00CBCBCB, 0x00DBDBDB, 0x00E7E7E7, 0x00F4F4F4, 0x00FFFFFF, 0x00F8F8F8, 0x00EBEBEB, 0x00D8D8D8, 0x00C8C8C8, 0x00BABABA, 0x00ADADAD, 0x009F9F9F, 
        0x00959595, 0x00898989, 0x00818181, 0x00777777, 0x006E6E6E, 0x00666666, 0x005E5E5E, 0x005A5A5A, 0x005A5A5A, 0x005A5A5A, 0x005B5B5B, 0x005E5E5E, 0x00636363, 0x00666666, 0x00686868, 0x00696969, 0x006C6C6C, 0x006E6E6E, 0x006F6F6F, 0x00717171, 
        0x00737373, 0x00747474, 0x00757575, 0x00767676, 0x00777777, 0x00787878, 0x00797979, 0x007A7A7A, 0x007B7B7B, 0x007C7C7C, 0x007D7D7D, 0x007E7E7E, 0x007F7F7F, 0x00808080, 0x00808080, 0x00818082, 0x00828183, 0x00838284, 0x00838284, 0x00848385, 
        0x00848385, 0x00868587, 0x00858486, 0x009F9EA2, 0x00BDBCC0, 0x00BEBDC1, 0x00BCBBBF, 0x00B9B8BC, 0x00BBBABC, 0x00B8B7B9, 0x92C8C8C8, 0xFFD7D7D7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFB6B6B6, 0x64000000, 0x00000000, 0x000B0B0B, 0x000E0E0E, 0x00131313, 0x00202020, 0x006E6E6E, 0x00797979, 0x00808080, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 
        0x007B7A7C, 0x007B7A7C, 0x007A797B, 0x00787779, 0x00777678, 0x00767577, 0x00757476, 0x00747375, 0x00737274, 0x00727173, 0x00706F71, 0x006F6E70, 0x006E6D6F, 0x006D6C6E, 0x006B6A6C, 0x0069686A, 0x00676668, 0x00656466, 0x00636264, 0x00616062, 
        0x005F5E60, 0x005A595B, 0x0059585A, 0x00575658, 0x00555456, 0x00525153, 0x004E4D4F, 0x004A494B, 0x00474648, 0x00424143, 0x003F3E40, 0x003A393B, 0x00353436, 0x002F2E30, 0x002E2D2F, 0x00333234, 0x0039383A, 0x00434244, 0x004B4A4C, 0x00545355, 
        0x005F5E60, 0x006C6B6D, 0x00767577, 0x00838284, 0x00908F91, 0x009E9E9E, 0x00ACACAC, 0x00BCBCBC, 0x00CBCBCB, 0x00DBDBDB, 0x00E8E8E8, 0x00F5F5F5, 0x00FFFFFF, 0x00F1F1F1, 0x00E4E4E4, 0x00D1D1D1, 0x00C0C0C0, 0x00B1B1B1, 0x00A2A2A2, 0x00959595, 
        0x008C8C8C, 0x007F7F7F, 0x00777777, 0x006D6D6D, 0x00646464, 0x005D5D5D, 0x00585858, 0x00575757, 0x00595959, 0x005F5F5F, 0x00606060, 0x00636363, 0x00676767, 0x006A6A6A, 0x006B6B6B, 0x006D6D6D, 0x00707070, 0x00707070, 0x00727272, 0x00747474, 
        0x00757575, 0x00767676, 0x00787878, 0x00797979, 0x007A7A7A, 0x007A7A7A, 0x007B7B7B, 0x007D7D7D, 0x007E7E7E, 0x007E7E7E, 0x007F7F7F, 0x00818181, 0x00828282, 0x00828282, 0x00828282, 0x00838284, 0x00848385, 0x00848385, 0x00858486, 0x00868587, 
        0x00868587, 0x00878688, 0x00848385, 0x0097969A, 0x00BDBCC0, 0x00C0BFC3, 0x00BDBCC0, 0x00BAB9BD, 0x00BDBCBE, 0x00B6B5B7, 0x64C6C6C6, 0xFFD5D5D5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFF858585, 0x38010101, 0x00000000, 0x00010101, 0x00070707, 0x000E0E0E, 0x001C1C1C, 0x007F7F7F, 0x00858585, 0x007F7F7F, 0x007F7E80, 0x007F7E80, 0x007E7D7F, 
        0x007E7D7F, 0x007D7C7E, 0x007C7B7D, 0x007C7B7D, 0x007B7A7C, 0x007A797B, 0x0079787A, 0x00777678, 0x00777678, 0x00767577, 0x00757476, 0x00747375, 0x00737274, 0x00717072, 0x00706F71, 0x006E6D6F, 0x006C6B6D, 0x006B6A6C, 0x0069686A, 0x00666567, 
        0x00656466, 0x00616062, 0x00605F61, 0x005D5C5E, 0x005A595B, 0x00575658, 0x00545355, 0x00515052, 0x004F4E50, 0x0049484A, 0x00464547, 0x00414042, 0x003B3A3C, 0x00353436, 0x00313032, 0x002F2E30, 0x002E2D2F, 0x0039383A, 0x00424143, 0x004B4A4C, 
        0x00565557, 0x00636264, 0x006F6E70, 0x007C7B7D, 0x0089888A, 0x00979797, 0x00ACACAC, 0x00B7B7B7, 0x00C9C9C9, 0x00DDDDDD, 0x00ECECEC, 0x00FCFCFC, 0x00FEFEFE, 0x00EDEDED, 0x00DADADA, 0x00C6C6C6, 0x00B5B5B5, 0x00A4A4A4, 0x00979797, 0x008B8B8B, 
        0x00808080, 0x00777777, 0x006C6C6C, 0x00606060, 0x005A5A5A, 0x00595959, 0x005A5A5A, 0x005E5E5E, 0x00626262, 0x00646464, 0x00666666, 0x00686868, 0x006B6B6B, 0x006D6D6D, 0x006F6F6F, 0x00717171, 0x00737373, 0x00757476, 0x00767577, 0x00787779, 
        0x0079787A, 0x007A797B, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007F7E80, 0x007F7E80, 0x00807F81, 0x00818082, 0x00828183, 0x00838284, 0x00838284, 0x00848385, 0x00858585, 0x00858585, 0x00868587, 0x00878688, 0x00878688, 0x00888789, 0x0089888A, 
        0x0089888A, 0x00868587, 0x008D8C8E, 0x008D8C90, 0x00BBBABE, 0x00C1C0C4, 0x00C0BFC3, 0x00BCBBBF, 0x00BDBCBE, 0x00BCBBBD, 0x38C4C4C4, 0xFFD0D0D0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xE66B6B6B, 0x0E010101, 0x00000000, 0x00000000, 0x00020202, 0x00080808, 0x00262626, 0x00838383, 0x00878787, 0x00828282, 0x00828183, 0x00828183, 0x00818082, 
        0x00818082, 0x00807F81, 0x007F7E80, 0x007F7E80, 0x007F7E80, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 0x007A797B, 0x0079787A, 0x00787779, 0x00777678, 0x00757476, 0x00767577, 0x00757476, 0x00737274, 0x00727173, 0x00706F71, 0x006E6D6F, 0x006C6B6D, 
        0x006A696B, 0x00686769, 0x00666567, 0x00636264, 0x00616062, 0x005E5D5F, 0x005B5A5C, 0x00585759, 0x00565557, 0x004F4E50, 0x004C4B4D, 0x00484749, 0x00424143, 0x003D3C3E, 0x00373638, 0x00333234, 0x00302F31, 0x00302F31, 0x003A393B, 0x00434244, 
        0x004D4C4E, 0x005A595B, 0x00666567, 0x00767577, 0x00868587, 0x00929292, 0x00A7A7A7, 0x00B6B6B6, 0x00C9C9C9, 0x00DCDCDC, 0x00EEEEEE, 0x00FDFDFD, 0x00F8F8F8, 0x00E6E6E6, 0x00D2D2D2, 0x00BCBCBC, 0x00ABABAB, 0x009B9B9B, 0x008E8E8E, 0x00818181, 
        0x00757575, 0x00686868, 0x00616161, 0x005B5B5B, 0x00595959, 0x005B5B5B, 0x005E5E5E, 0x00626262, 0x00666666, 0x00696969, 0x006B6B6B, 0x006E6E6E, 0x00707070, 0x00727272, 0x00747474, 0x00767676, 0x00777777, 0x00787779, 0x0079787A, 0x007A797B, 
        0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x00818082, 0x00828183, 0x00828183, 0x00838284, 0x00838284, 0x00848385, 0x00858486, 0x00868587, 0x00868587, 0x00878787, 0x00878787, 0x00888789, 0x00888789, 0x0089888A, 0x008A898B, 0x008A898B, 
        0x008A898B, 0x00888789, 0x008E8D8F, 0x008C8B8F, 0x00B7B6BA, 0x00C1C0C4, 0x00C1C0C4, 0x00BDBCC0, 0x00BEBDBF, 0x00BCBBBD, 0x0EC3C3C3, 0xE6CFCFCF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xC2494949, 0x00040404, 0x00010101, 0x00000000, 0x00000000, 0x00030303, 0x00383838, 0x00898989, 0x00888888, 0x00878787, 0x00868587, 0x00868587, 0x00858486, 
        0x00858486, 0x00848385, 0x00848385, 0x00838284, 0x00838284, 0x00828183, 0x00818082, 0x007F7E80, 0x007E7D7F, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 0x0079787A, 0x007A797B, 0x0079787A, 0x00777678, 0x00767577, 0x00747375, 0x00737274, 0x00717072, 
        0x006F6E70, 0x006D6C6E, 0x006C6B6D, 0x0069686A, 0x00676668, 0x00646365, 0x00616062, 0x005E5D5F, 0x005D5C5E, 0x00575658, 0x00535254, 0x004F4E50, 0x004B4A4C, 0x00464547, 0x00403F41, 0x0039383A, 0x00343335, 0x002C2B2D, 0x00323133, 0x00383739, 
        0x00424143, 0x00504F51, 0x005D5C5E, 0x006D6C6E, 0x007C7B7D, 0x008D8D8D, 0x00A1A1A1, 0x00B6B6B6, 0x00CACACA, 0x00DBDBDB, 0x00F2F2F2, 0x00FFFFFF, 0x00F1F1F1, 0x00D9D9D9, 0x00C4C4C4, 0x00AFAFAF, 0x009E9E9E, 0x008E8E8E, 0x00808080, 0x00727272, 
        0x00666666, 0x005B5B5B, 0x005A5A5A, 0x005A5A5A, 0x005D5D5D, 0x00606060, 0x00646464, 0x00686868, 0x006C6C6C, 0x006E6E6E, 0x00707070, 0x00727272, 0x00747474, 0x00767676, 0x00787878, 0x00797979, 0x007B7B7B, 0x007B7A7C, 0x007C7B7D, 0x007E7D7F, 
        0x007F7E80, 0x00818082, 0x00828183, 0x00848385, 0x00858486, 0x00858486, 0x00858486, 0x00868587, 0x00878688, 0x00878688, 0x00888789, 0x0089888A, 0x0089888A, 0x008A8A8A, 0x008A8A8A, 0x008A898B, 0x008B8A8C, 0x008C8B8D, 0x008C8B8D, 0x008D8C8E, 
        0x008D8C8E, 0x008C8B8D, 0x008F8E90, 0x008D8C90, 0x00B1B0B4, 0x00C1C0C4, 0x00C3C2C6, 0x00BFBEC2, 0x00BFBEC0, 0x00BCBBBD, 0x00C2C2C2, 0xC2CDCDCD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xA12F2F2F, 0x00090909, 0x00040404, 0x00030303, 0x00000000, 0x00000000, 0x004D4D4D, 0x008C8C8C, 0x00898989, 0x008A8A8A, 0x0089888A, 0x0089888A, 0x00888789, 
        0x00888789, 0x00878688, 0x00878688, 0x00868587, 0x00868587, 0x00858486, 0x00848385, 0x00838284, 0x00828183, 0x00818082, 0x00807F81, 0x007F7E80, 0x007E7D7F, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 0x007A797B, 0x0079787A, 0x00777678, 0x00757476, 
        0x00747375, 0x00727173, 0x00717072, 0x006F6E70, 0x006D6C6E, 0x006A696B, 0x00686769, 0x00656466, 0x00636264, 0x005E5D5F, 0x005B5A5C, 0x00575658, 0x00535254, 0x00504F51, 0x004B4A4C, 0x00434244, 0x003E3D3F, 0x00343335, 0x00323133, 0x00302F31, 
        0x00373638, 0x00474648, 0x00555456, 0x00636264, 0x00706F71, 0x00868686, 0x00999999, 0x00B3B3B3, 0x00C7C7C7, 0x00DBDBDB, 0x00F6F6F6, 0x00FDFDFD, 0x00E7E7E7, 0x00CCCCCC, 0x00B7B7B7, 0x00A1A1A1, 0x00909090, 0x007F7F7F, 0x00707070, 0x00646464, 
        0x005A5A5A, 0x005A5A5A, 0x005C5C5C, 0x00616161, 0x00656565, 0x00686868, 0x006B6B6B, 0x006F6F6F, 0x00717171, 0x00737373, 0x00747474, 0x00767676, 0x00787878, 0x007A7A7A, 0x007B7B7B, 0x007D7D7D, 0x007E7E7E, 0x007F7E80, 0x00818082, 0x00828183, 
        0x00838284, 0x00848385, 0x00858486, 0x00878688, 0x00888789, 0x00888789, 0x00888789, 0x0089888A, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008B8A8C, 0x008C8B8D, 0x008C8C8C, 0x008D8D8D, 0x008D8C8E, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008F8E90, 
        0x008F8E90, 0x008F8E90, 0x00908F91, 0x008E8D91, 0x00ABAAAE, 0x00C3C2C6, 0x00C5C4C8, 0x00C1C0C4, 0x00BFBEC0, 0x00BDBCBE, 0x00C1C1C1, 0xA1CACACA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x831F1F1F, 0x000B0B0B, 0x00070707, 0x00050505, 0x00010101, 0x00000000, 0x00626262, 0x008D8D8D, 0x008A8A8A, 0x008D8D8D, 0x008B8A8C, 0x008B8A8C, 0x008A898B, 
        0x008A898B, 0x0089888A, 0x0089888A, 0x0089888A, 0x00888789, 0x00878688, 0x00878688, 0x00868587, 0x00858486, 0x00858486, 0x00858486, 0x00848385, 0x00838284, 0x00828183, 0x00818082, 0x00807F81, 0x007F7E80, 0x007F7E80, 0x007D7C7E, 0x007C7B7D, 
        0x007A797B, 0x0079787A, 0x00777678, 0x00757476, 0x00747375, 0x00727173, 0x00706F71, 0x006D6C6E, 0x006B6A6C, 0x00686769, 0x00656466, 0x00605F61, 0x005D5C5E, 0x005A595B, 0x00555456, 0x004F4E50, 0x004A494B, 0x00403F41, 0x0039383A, 0x00302F31, 
        0x00302F31, 0x0039383A, 0x00454446, 0x00575658, 0x00686769, 0x007E7E7E, 0x00909090, 0x00AEAEAE, 0x00C4C4C4, 0x00DCDCDC, 0x00F9F9F9, 0x00F7F7F7, 0x00DBDBDB, 0x00BFBFBF, 0x00A9A9A9, 0x00919191, 0x007E7E7E, 0x006C6C6C, 0x00616161, 0x005C5C5C, 
        0x00595959, 0x00606060, 0x00646464, 0x00696969, 0x006C6C6C, 0x006F6F6F, 0x00717171, 0x00747474, 0x00767676, 0x00797979, 0x007A7A7A, 0x007C7C7C, 0x007E7E7E, 0x007F7F7F, 0x00808080, 0x00828282, 0x00838383, 0x00848385, 0x00858486, 0x00868587, 
        0x00878688, 0x00878688, 0x00888789, 0x0089888A, 0x008A898B, 0x008A898B, 0x008B8A8C, 0x008B8A8C, 0x008C8B8D, 0x008C8B8D, 0x008D8C8E, 0x008D8C8E, 0x008E8D8F, 0x008F8F8F, 0x008F8F8F, 0x008F8E90, 0x00908F91, 0x00908F91, 0x00919092, 0x00919092, 
        0x00929193, 0x00919092, 0x00919092, 0x00929195, 0x00A6A5A9, 0x00C5C4C8, 0x00C7C6CA, 0x00C3C2C6, 0x00C0BFC1, 0x00BFBEC0, 0x00C1C1C1, 0x83C8C8C8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x67191919, 0x000C0C0C, 0x000B0B0B, 0x00060606, 0x00040404, 0x00010101, 0x00767676, 0x00909090, 0x008E8E8E, 0x00909090, 0x008E8D8F, 0x008E8D8F, 0x008D8C8E, 
        0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008C8B8D, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x0089888A, 0x0089888A, 0x0089888A, 0x00888789, 0x00888789, 0x00868587, 0x00858486, 0x00848385, 0x00848385, 0x00838284, 0x00828183, 0x00818082, 
        0x007F7E80, 0x007E7D7F, 0x007C7B7D, 0x007B7A7C, 0x0079787A, 0x00787779, 0x00767577, 0x00747375, 0x00727173, 0x00717072, 0x006E6D6F, 0x0069686A, 0x00656466, 0x00626163, 0x005D5C5E, 0x00585759, 0x00545355, 0x004B4A4C, 0x00464547, 0x003B3A3C, 
        0x00323133, 0x00302F31, 0x00353436, 0x00484749, 0x005E5D5F, 0x00747474, 0x00868686, 0x00A8A8A8, 0x00C3C3C3, 0x00E2E2E2, 0x00FDFDFD, 0x00EDEDED, 0x00CBCBCB, 0x00AEAEAE, 0x00959595, 0x007C7C7C, 0x006B6B6B, 0x005E5E5E, 0x005A5A5A, 0x005E5E5E, 
        0x00606060, 0x00686868, 0x006C6C6C, 0x00707070, 0x00727272, 0x00757575, 0x00787878, 0x007A7A7A, 0x007A7A7A, 0x007E7E7E, 0x007F7F7F, 0x00818181, 0x00838383, 0x00848484, 0x00848484, 0x00868686, 0x00878787, 0x00888789, 0x0089888A, 0x008A898B, 
        0x008A898B, 0x008B8A8C, 0x008B8A8C, 0x008C8B8D, 0x008D8C8E, 0x008D8C8E, 0x008E8D8F, 0x008E8D8F, 0x008E8D8F, 0x008F8E90, 0x00908F91, 0x00908F91, 0x00908F91, 0x00929292, 0x00929292, 0x00929193, 0x00939294, 0x00939294, 0x00939294, 0x00949395, 
        0x00949395, 0x00949395, 0x00939294, 0x00959498, 0x00A1A0A4, 0x00C6C5C9, 0x00C9C8CC, 0x00C5C4C8, 0x00C2C1C3, 0x00C1C0C2, 0x00C1C1C1, 0x67C7C7C7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4F1A1A1A, 0x00121212, 0x00121212, 0x00080808, 0x000A0A0A, 0x00070707, 0x00898989, 0x00969696, 0x00949494, 0x00929292, 0x00929193, 0x00929193, 0x00919092, 
        0x00919092, 0x00919092, 0x00908F91, 0x00908F91, 0x00908F91, 0x008F8E90, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008C8B8D, 0x008A898B, 0x0089888A, 0x00888789, 0x00888789, 0x00888789, 0x00878688, 0x00858486, 
        0x00848385, 0x00838284, 0x00828183, 0x00818082, 0x007F7E80, 0x007E7D7F, 0x007D7C7E, 0x007B7A7C, 0x0079787A, 0x00787779, 0x00767577, 0x00737274, 0x006F6E70, 0x006B6A6C, 0x00676668, 0x00636264, 0x00605F61, 0x0059585A, 0x00555456, 0x004C4B4D, 
        0x00424143, 0x0039383A, 0x00333234, 0x003A393B, 0x004A494B, 0x00646464, 0x00797979, 0x009F9F9F, 0x00C0C0C0, 0x00E6E6E6, 0x00FBFBFB, 0x00DCDCDC, 0x00B6B6B6, 0x00959595, 0x007D7D7D, 0x00686868, 0x00606060, 0x005E5E5E, 0x00616161, 0x00686868, 
        0x006C6C6C, 0x00717171, 0x00757575, 0x00787878, 0x007A7A7A, 0x007D7D7D, 0x00808080, 0x00828282, 0x00818181, 0x00848484, 0x00858585, 0x00868686, 0x00888888, 0x00888888, 0x00898989, 0x008A8A8A, 0x008B8B8B, 0x008C8B8D, 0x008D8C8E, 0x008E8D8F, 
        0x008E8D8F, 0x008F8E90, 0x008F8E90, 0x00908F91, 0x00919092, 0x00919092, 0x00919092, 0x00919092, 0x00929193, 0x00929193, 0x00939294, 0x00939294, 0x00939294, 0x00949494, 0x00959595, 0x00959496, 0x00959496, 0x00969597, 0x00969597, 0x00969597, 
        0x00969597, 0x00979698, 0x00959496, 0x0098979B, 0x009D9CA0, 0x00C6C5C9, 0x00C9C8CC, 0x00C7C6CA, 0x00C5C4C6, 0x00C3C2C4, 0x00C1C1C1, 0x4FC6C6C6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x391E1E1E, 0x001A1A1A, 0x001A1A1A, 0x000C0C0C, 0x000F0F0F, 0x000C0C0C, 0x00959595, 0x009B9B9B, 0x00989898, 0x00929292, 0x00959496, 0x00959496, 0x00959496, 
        0x00949395, 0x00949395, 0x00939294, 0x00939294, 0x00939294, 0x00939294, 0x00929193, 0x00919092, 0x00919092, 0x00908F91, 0x00908F91, 0x008F8E90, 0x008E8D8F, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 
        0x008A898B, 0x0089888A, 0x00888789, 0x00878688, 0x00868587, 0x00858486, 0x00838284, 0x00828183, 0x00807F81, 0x007D7C7E, 0x007D7C7E, 0x007C7B7D, 0x007A797B, 0x00767577, 0x00727173, 0x006E6D6F, 0x006C6B6D, 0x00656466, 0x00605F61, 0x00585759, 
        0x00515052, 0x0049484A, 0x003A393B, 0x00323133, 0x00353436, 0x00535353, 0x006B6B6B, 0x00949494, 0x00B9B9B9, 0x00E5E5E5, 0x00F5F5F5, 0x00CCCCCC, 0x00A3A3A3, 0x007F7F7F, 0x006A6A6A, 0x005C5C5C, 0x005E5E5E, 0x00656565, 0x006D6D6D, 0x00737373, 
        0x00757575, 0x00797979, 0x007C7C7C, 0x007F7F7F, 0x00818181, 0x00848484, 0x00888888, 0x00888888, 0x00878787, 0x00898989, 0x008B8B8B, 0x008C8C8C, 0x008D8D8D, 0x008E8E8E, 0x008E8E8E, 0x008F8F8F, 0x00909090, 0x008E8D8F, 0x008F8E90, 0x00908F91, 
        0x00919092, 0x00919092, 0x00929193, 0x00939294, 0x00949395, 0x00939294, 0x00939294, 0x00949395, 0x00949395, 0x00959496, 0x00959496, 0x00969597, 0x00969597, 0x00969696, 0x00969696, 0x00979698, 0x00979698, 0x00979698, 0x00989799, 0x00989799, 
        0x00989799, 0x00989799, 0x00969597, 0x009A999D, 0x009A999D, 0x00C6C5C9, 0x00C9C8CC, 0x00C8C7CB, 0x00C8C7CB, 0x00C5C4C6, 0x00C2C2C2, 0x39C6C6C6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x27292929, 0x001B1B1B, 0x001B1A1C, 0x00161517, 0x00121113, 0x001F1E20, 0x00959496, 0x0099989A, 0x009B9A9C, 0x00969597, 0x00989799, 0x00979698, 0x00979698, 
        0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00969597, 0x00969597, 0x00969597, 0x00959496, 0x00959496, 0x00959496, 0x00949395, 0x00949395, 0x00939294, 0x00939294, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 0x00919092, 
        0x00919092, 0x008F8E90, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x00868587, 0x00858486, 0x00838284, 0x00818082, 0x007F7E80, 0x007C7B7D, 0x007A797B, 0x00787779, 0x00727173, 0x00717072, 0x006B6A6C, 
        0x00616062, 0x0059585A, 0x004F4E50, 0x00414042, 0x00353436, 0x003B3B3B, 0x00595959, 0x007F7F7F, 0x00B8B8B8, 0x00F0F0F0, 0x00E0E0E0, 0x00AEADAF, 0x007D7C7E, 0x005E5D5F, 0x00616062, 0x00676668, 0x006E6D6F, 0x00747375, 0x0079787A, 0x007D7C7E, 
        0x00807F81, 0x00828183, 0x00838284, 0x00868587, 0x00888789, 0x0089888A, 0x008B8A8C, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008F8E90, 0x00908F91, 0x00919092, 0x00929193, 0x00939294, 0x00949395, 0x00949395, 0x00949395, 0x00949395, 0x00959496, 
        0x00959496, 0x00969597, 0x00969597, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00989799, 0x00989799, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x009A999B, 
        0x009A999B, 0x0098999D, 0x0097989C, 0x0096979B, 0x009C9DA1, 0x00B9BABE, 0x00C4C5C9, 0x00C7C8CC, 0x00C6C7CB, 0x00C9C8CC, 0x00C7C6C8, 0x27C8C7C9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x182B2B2B, 0x001F1F1F, 0x001E1D1F, 0x001A191B, 0x00141315, 0x00262527, 0x00989799, 0x009C9B9D, 0x009C9B9D, 0x0099989A, 0x009A999B, 0x009A999B, 0x009A999B, 
        0x009A999B, 0x009A999B, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00989799, 0x00989799, 0x00979698, 0x00979698, 0x00969597, 0x00969597, 0x00969597, 0x00969597, 0x00959496, 0x00959496, 0x00959496, 
        0x00949395, 0x00939294, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 0x00908F91, 0x00908F91, 0x008F8E90, 0x008F8E90, 0x008E8D8F, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x00888789, 0x00868587, 0x00848385, 0x00818082, 0x00818082, 0x007D7C7E, 
        0x00767577, 0x006F6E70, 0x00686769, 0x005B5A5C, 0x004F4E50, 0x003C3C3C, 0x003B3B3B, 0x006C6C6C, 0x00ABABAB, 0x00E6E6E6, 0x00C6C6C6, 0x00838284, 0x005F5E60, 0x00676668, 0x006C6B6D, 0x00747375, 0x007C7B7D, 0x00828183, 0x00858486, 0x00878688, 
        0x0089888A, 0x008B8A8C, 0x008D8C8E, 0x008F8E90, 0x00908F91, 0x00919092, 0x00929193, 0x00949395, 0x00959496, 0x00949395, 0x00949395, 0x00959496, 0x00959496, 0x00969597, 0x00979698, 0x00979698, 0x00989799, 0x00979698, 0x00979698, 0x00989799, 
        0x00989799, 0x00989799, 0x0099989A, 0x0099989A, 0x0099989A, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009C9B9D, 0x009C9B9D, 
        0x009C9B9D, 0x009A9B9F, 0x00999A9E, 0x00999A9E, 0x009D9EA2, 0x00B7B8BC, 0x00C1C2C6, 0x00C5C6CA, 0x00C4C5C9, 0x00C9C8CC, 0x00C7C6CA, 0x18C9C8CA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0C2F2F2F, 0x00262626, 0x00232224, 0x001F1E20, 0x00171618, 0x002F2E30, 0x009B9A9C, 0x00A09FA1, 0x009C9B9D, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009D9C9E, 
        0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 
        0x009A999B, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00989799, 0x00989799, 0x00959496, 0x00949395, 0x00939294, 0x00939294, 0x00929193, 0x00919092, 0x00908F91, 0x008F8E90, 0x008D8C8E, 0x008D8C8E, 0x008B8A8C, 
        0x00878688, 0x00848385, 0x00818082, 0x007A797B, 0x00727173, 0x00616161, 0x004A4A4A, 0x003E3E3E, 0x00959595, 0x00DDDDDD, 0x00858585, 0x00646365, 0x00727173, 0x007B7A7C, 0x00807F81, 0x00878688, 0x008C8B8D, 0x008F8E90, 0x00919092, 0x00929193, 
        0x00929193, 0x00939294, 0x00949395, 0x00959496, 0x00969597, 0x00969597, 0x00969597, 0x00979698, 0x00989799, 0x009A999B, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 
        0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 
        0x009F9EA0, 0x009D9EA2, 0x009D9EA2, 0x009C9DA1, 0x009D9EA2, 0x00B5B6BA, 0x00BCBDC1, 0x00C1C2C6, 0x00C2C3C7, 0x00C9C8CC, 0x00C7C6CA, 0x0CC9C8CA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x04323232, 0x002B2B2B, 0x00272628, 0x00242325, 0x001B1A1C, 0x00363537, 0x009E9D9F, 0x00A3A2A4, 0x009D9C9E, 0x00A1A0A2, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 
        0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 
        0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009C9B9D, 0x009B9A9C, 0x009B9A9C, 0x009A999B, 0x00989799, 
        0x00969597, 0x00979698, 0x00989799, 0x00969597, 0x00929193, 0x008D8D8D, 0x007F7F7F, 0x00707070, 0x00696969, 0x00A3A3A3, 0x007C7C7C, 0x00888789, 0x00908F91, 0x00949395, 0x00979698, 0x009A999B, 0x009A999B, 0x009A999B, 0x009B9A9C, 0x009D9C9E, 
        0x009D9C9E, 0x009C9B9D, 0x009D9C9E, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009E9D9F, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 
        0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A1A0A2, 
        0x00A1A0A2, 0x009FA0A4, 0x009FA0A4, 0x009E9FA3, 0x009D9EA2, 0x00B2B3B7, 0x00B8B9BD, 0x00BDBEC2, 0x00BFC0C4, 0x00C7C6CA, 0x00C6C5C9, 0x04C9C8CA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00353535, 0x002E2E2E, 0x002A292B, 0x00282729, 0x00201F21, 0x003A393B, 0x009F9EA0, 0x00A3A2A4, 0x009D9C9E, 0x00A2A1A3, 0x00A1A0A2, 0x00A1A0A2, 0x00A09FA1, 
        0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 
        0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009C9B9D, 0x009E9D9F, 0x009D9C9E, 0x009B9A9C, 
        0x009A999B, 0x009A999B, 0x009A999B, 0x00979698, 0x00949395, 0x00919191, 0x00898989, 0x007C7C7C, 0x00A3A3A3, 0x00686868, 0x00707070, 0x007E7D7F, 0x008D8C8E, 0x00908F91, 0x00949395, 0x00979698, 0x00969597, 0x00969597, 0x00989799, 0x009A999B, 
        0x009B9A9C, 0x009B9A9C, 0x009C9B9D, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 
        0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 0x00A09FA1, 
        0x00A09FA1, 0x009E9FA3, 0x009FA0A4, 0x009E9FA3, 0x009C9DA1, 0x00B0B1B5, 0x00B5B6BA, 0x00BABBBF, 0x00BDBEC2, 0x00C4C3C7, 0x00C4C3C7, 0x00C8C7C9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x04393939, 0x00323232, 0x002E2D2F, 0x002C2B2D, 0x00252426, 0x0039383A, 0x009F9EA0, 0x00A09FA1, 0x009C9B9D, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 
        0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 
        0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009A999B, 0x009A999B, 0x00989799, 0x00979698, 0x00969597, 0x00969597, 0x00969597, 0x00959496, 0x00949395, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 
        0x008E8D8F, 0x008B8A8C, 0x00868587, 0x007F7E80, 0x007A797B, 0x00727272, 0x00656565, 0x00868686, 0x00DDDDDD, 0x00959595, 0x003D3D3D, 0x0049484A, 0x00616062, 0x006F6E70, 0x00777678, 0x00807F81, 0x00838284, 0x00868587, 0x008B8A8C, 0x008D8C8E, 
        0x008D8C8E, 0x008F8E90, 0x00908F91, 0x00919092, 0x00929193, 0x00939294, 0x00939294, 0x00949395, 0x00959496, 0x00979698, 0x00979698, 0x00979698, 0x00989799, 0x00989799, 0x0099989A, 0x0099989A, 0x009A999B, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 
        0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 
        0x009E9D9F, 0x009B9CA0, 0x009C9DA1, 0x009B9CA0, 0x009A9B9F, 0x00ADAEB2, 0x00B1B2B6, 0x00B6B7BB, 0x00B8B9BD, 0x00C0BFC3, 0x00C0BFC3, 0x04C6C5C7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0C3F3F3F, 0x00373737, 0x00323133, 0x00313032, 0x002B2A2C, 0x00363537, 0x009E9D9F, 0x009C9B9D, 0x009B9A9C, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 
        0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009B9A9C, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00989799, 
        0x00979698, 0x00979698, 0x00979698, 0x00969597, 0x00969597, 0x00959496, 0x00949395, 0x00949395, 0x00939294, 0x00959496, 0x00949395, 0x00929193, 0x00919092, 0x00908F91, 0x008E8D8F, 0x008D8C8E, 0x008B8A8C, 0x0089888A, 0x00878688, 0x00858486, 
        0x00818082, 0x007B7A7C, 0x00747375, 0x006C6B6D, 0x00676668, 0x00606060, 0x00848484, 0x00C7C7C7, 0x00E6E6E6, 0x00AAAAAA, 0x006B6B6B, 0x003A393B, 0x003B3A3C, 0x004E4D4F, 0x005A595B, 0x00676668, 0x006F6E70, 0x00767577, 0x007D7C7E, 0x00818082, 
        0x00818082, 0x00848385, 0x00868587, 0x00888789, 0x008A898B, 0x008B8A8C, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008E8D8F, 0x008F8E90, 0x008F8E90, 0x00908F91, 0x00919092, 0x00929193, 0x00939294, 0x00949395, 0x00949395, 0x00959496, 0x00959496, 
        0x00959496, 0x00969597, 0x00969597, 0x00969597, 0x00969597, 0x00979698, 0x00979698, 0x00989799, 0x00989799, 0x00989799, 0x00989799, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 
        0x009A999B, 0x0098999D, 0x00999A9E, 0x0098999D, 0x0097989C, 0x00AAABAF, 0x00AEAFB3, 0x00B1B2B6, 0x00B3B4B8, 0x00BBBABE, 0x00BDBCC0, 0x0CC5C4C6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x18434343, 0x003B3B3B, 0x00363537, 0x00343335, 0x00302F31, 0x00353436, 0x009D9C9E, 0x0099989A, 0x009B9A9C, 0x0099989A, 0x009A999B, 0x009A999B, 0x0099989A, 
        0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00969597, 0x00969597, 0x00959496, 0x00959496, 0x00949395, 
        0x00949395, 0x00949395, 0x00939294, 0x00939294, 0x00929193, 0x00919092, 0x00908F91, 0x008F8E90, 0x008E8D8F, 0x008E8D8F, 0x008C8B8D, 0x008B8A8C, 0x0089888A, 0x00878688, 0x00858486, 0x00838284, 0x00818082, 0x00807F81, 0x007C7B7D, 0x00787779, 
        0x00737274, 0x006D6C6E, 0x00676668, 0x00616062, 0x005E5D5F, 0x007E7E7E, 0x00AFAFAF, 0x00E1E1E1, 0x00F0F0F0, 0x00B8B8B8, 0x007E7E7E, 0x00585759, 0x003A393B, 0x00353436, 0x00424143, 0x00504F51, 0x005A595B, 0x00626163, 0x006C6B6D, 0x00717072, 
        0x00727173, 0x00787779, 0x007A797B, 0x007D7C7E, 0x007F7E80, 0x00818082, 0x00838284, 0x00858486, 0x00878688, 0x00888789, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008F8E90, 0x00908F91, 0x00908F91, 0x00908F91, 
        0x00919092, 0x00919092, 0x00929193, 0x00929193, 0x00929193, 0x00949395, 0x00949395, 0x00959496, 0x00959496, 0x00959496, 0x00969597, 0x00969597, 0x00969597, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 0x00979698, 
        0x00989799, 0x0096979B, 0x0097989C, 0x0095969A, 0x00949599, 0x00A8A9AD, 0x00ACADB1, 0x00AEAFB3, 0x00AFB0B4, 0x00B9B8BC, 0x00BBBABE, 0x18C4C3C5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x27454545, 0x003E3E3E, 0x003A393B, 0x00373638, 0x00323133, 0x00343335, 0x00949395, 0x009C9B9D, 0x00989799, 0x00989799, 0x00989799, 0x00989799, 0x00989799, 
        0x00979698, 0x00979698, 0x00979698, 0x00969597, 0x00969597, 0x00969597, 0x00969597, 0x00959496, 0x00959496, 0x00949395, 0x00949395, 0x00939294, 0x00939294, 0x00949395, 0x00939294, 0x00939294, 0x00929193, 0x00929193, 0x00929193, 0x00908F91, 
        0x008F8E90, 0x00908F91, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008A898B, 0x0089888A, 0x00878787, 0x00888888, 0x00888888, 0x00848484, 0x00818181, 0x007F7F7F, 0x007C7C7C, 0x00797979, 0x00767676, 0x00737373, 0x006C6C6C, 
        0x00636363, 0x005C5C5C, 0x005B5B5B, 0x006B6B6B, 0x00818181, 0x00A2A2A2, 0x00CCCCCC, 0x00F7F7F7, 0x00E6E6E6, 0x00BABABA, 0x00949494, 0x006B6A6C, 0x00545355, 0x00373638, 0x00333234, 0x003B3A3C, 0x0049484A, 0x00515052, 0x00575658, 0x005F5E60, 
        0x00656466, 0x006C6B6D, 0x006E6D6F, 0x00727173, 0x00767577, 0x007A797B, 0x007C7B7D, 0x007D7C7E, 0x007D7C7E, 0x00807F81, 0x00828183, 0x00838284, 0x00858486, 0x00868587, 0x00878688, 0x00888789, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008C8B8D, 
        0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008E8D8F, 0x008F8E90, 0x00908F91, 0x00908F91, 0x00919092, 0x00919092, 0x00929193, 0x00939294, 0x00939294, 0x00939294, 0x00939294, 0x00949395, 0x00949395, 0x00959496, 0x00959496, 
        0x00959496, 0x00939498, 0x00939498, 0x00929397, 0x0097989C, 0x00A2A3A7, 0x00A7A8AC, 0x00A9AAAE, 0x00AEAFB3, 0x00B3B2B6, 0x00B5B4B8, 0x27C4C3C5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x39494949, 0x00424242, 0x003F3E40, 0x003B3A3C, 0x00343335, 0x00353436, 0x008E8D8F, 0x0099989A, 0x00969597, 0x00969597, 0x00969597, 0x00969597, 0x00969597, 
        0x00969597, 0x00959496, 0x00959496, 0x00959496, 0x00949395, 0x00939294, 0x00939294, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 0x00919092, 0x00919092, 0x00919092, 0x00919092, 0x00908F91, 0x00908F91, 0x008F8E90, 0x008F8E90, 0x008D8C8E, 
        0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x00888789, 0x00878688, 0x00868587, 0x00848385, 0x00838284, 0x00818181, 0x00828282, 0x00808080, 0x007D7D7D, 0x007A7A7A, 0x00787878, 0x00757575, 0x00717171, 0x006D6D6D, 0x00686868, 0x00616161, 
        0x005D5D5D, 0x005F5F5F, 0x00686868, 0x007E7E7E, 0x00979797, 0x00B9B9B9, 0x00DDDDDD, 0x00FBFBFB, 0x00E5E5E5, 0x00BFBFBF, 0x009F9F9F, 0x007A797B, 0x00656466, 0x004B4A4C, 0x003B3A3C, 0x00333234, 0x0039383A, 0x00414042, 0x004B4A4C, 0x00545355, 
        0x0059585A, 0x00605F61, 0x00636264, 0x00676668, 0x006B6A6C, 0x006F6E70, 0x00737274, 0x00767577, 0x00787779, 0x0079787A, 0x007B7A7C, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x00818082, 0x00828183, 0x00838284, 0x00848385, 0x00858486, 0x00878688, 
        0x00888789, 0x00888789, 0x00888789, 0x0089888A, 0x008A898B, 0x008C8B8D, 0x008C8B8D, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x008F8E90, 0x00908F91, 0x00908F91, 0x00908F91, 0x00919092, 0x00919092, 0x00929193, 0x00929193, 
        0x00929193, 0x00919296, 0x00919296, 0x00909195, 0x0095969A, 0x009FA0A4, 0x00A4A5A9, 0x00A6A7AB, 0x00ABACB0, 0x00B1B0B4, 0x00B4B3B7, 0x39C5C4C6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x4F525252, 0x00474747, 0x00454446, 0x00403F41, 0x0039383A, 0x00383739, 0x00838284, 0x00969597, 0x00939294, 0x00949395, 0x00949395, 0x00949395, 0x00939294, 
        0x00939294, 0x00939294, 0x00929193, 0x00929193, 0x00929193, 0x00908F91, 0x00908F91, 0x00908F91, 0x008F8E90, 0x008E8D8F, 0x008E8D8F, 0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 
        0x00888789, 0x00878688, 0x00868587, 0x00848385, 0x00838284, 0x00828183, 0x00818082, 0x007F7E80, 0x007E7D7F, 0x007A7A7A, 0x007A7A7A, 0x00787878, 0x00757575, 0x00727272, 0x00707070, 0x006C6C6C, 0x00686868, 0x00606060, 0x005D5D5D, 0x005A5A5A, 
        0x005E5E5E, 0x006B6B6B, 0x007D7D7D, 0x00979797, 0x00B1B1B1, 0x00CECECE, 0x00EDEDED, 0x00FBFBFB, 0x00E0E0E0, 0x00C2C2C2, 0x00A9A9A9, 0x00878688, 0x00747375, 0x005F5E60, 0x0049484A, 0x00363537, 0x00302F31, 0x00323133, 0x003B3A3C, 0x00464547, 
        0x004B4A4C, 0x00545355, 0x00585759, 0x005D5C5E, 0x00626163, 0x00656466, 0x0069686A, 0x006E6D6F, 0x00717072, 0x00727173, 0x00747375, 0x00767577, 0x00787779, 0x0079787A, 0x007B7A7C, 0x007C7B7D, 0x007E7D7F, 0x007F7E80, 0x00818082, 0x00828183, 
        0x00838284, 0x00848385, 0x00848385, 0x00858486, 0x00868587, 0x00888789, 0x00888789, 0x0089888A, 0x0089888A, 0x0089888A, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008B8A8C, 0x008C8B8D, 0x008C8B8D, 0x008C8B8D, 0x008D8C8E, 0x008E8D8F, 0x008E8D8F, 
        0x008E8D8F, 0x008D8E92, 0x008D8E92, 0x008D8E92, 0x00929397, 0x009C9DA1, 0x00A0A1A5, 0x00A2A3A7, 0x00A7A8AC, 0x00ADACB0, 0x00B2B1B5, 0x4FC5C4C6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x675D5D5D, 0x004C4C4C, 0x0049484A, 0x00444345, 0x003E3D3F, 0x003D3C3E, 0x00777678, 0x00939294, 0x00919092, 0x00919092, 0x00929193, 0x00919092, 0x00919092, 
        0x00908F91, 0x00908F91, 0x008F8E90, 0x008F8E90, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008C8B8D, 0x008B8A8C, 0x008B8A8C, 0x008A898B, 0x008A898B, 0x0089888A, 0x00888789, 0x00888789, 0x00878688, 0x00868587, 0x00858486, 
        0x00848385, 0x00838284, 0x00828183, 0x00807F81, 0x007F7E80, 0x007E7D7F, 0x007C7B7D, 0x007A797B, 0x0079787A, 0x00767676, 0x00747474, 0x00717171, 0x006F6F6F, 0x006C6C6C, 0x00696969, 0x00646464, 0x00606060, 0x00595959, 0x005C5C5C, 0x00616161, 
        0x006D6D6D, 0x007F7F7F, 0x00929292, 0x00AAAAAA, 0x00C1C1C1, 0x00DADADA, 0x00F7F7F7, 0x00F8F8F8, 0x00DCDCDC, 0x00C5C5C5, 0x00AEAEAE, 0x008F8E90, 0x007C7B7D, 0x0069686A, 0x00575658, 0x00454446, 0x0039383A, 0x002F2E30, 0x00302F31, 0x0039383A, 
        0x00403F41, 0x004A494B, 0x004F4E50, 0x00555456, 0x005A595B, 0x005D5C5E, 0x00605F61, 0x00656466, 0x00686769, 0x006B6A6C, 0x006D6C6E, 0x00706F71, 0x00727173, 0x00747375, 0x00757476, 0x00777678, 0x0079787A, 0x007A797B, 0x007C7B7D, 0x007D7C7E, 
        0x007F7E80, 0x007F7E80, 0x00807F81, 0x00818082, 0x00828183, 0x00838284, 0x00848385, 0x00858486, 0x00858486, 0x00858486, 0x00868587, 0x00878688, 0x00878688, 0x00888789, 0x00888789, 0x0089888A, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008B8A8C, 
        0x008B8A8C, 0x008A8B8F, 0x008B8C90, 0x008B8C90, 0x008F9094, 0x0098999D, 0x009C9DA1, 0x009FA0A4, 0x00A4A5A9, 0x00A8A7AB, 0x00B1B0B4, 0x67C7C6C8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x836C6C6C, 0x00505050, 0x004C4B4D, 0x00474648, 0x00444345, 0x00424143, 0x006B6A6C, 0x00919092, 0x008F8E90, 0x008F8E90, 0x008F8E90, 0x008F8E90, 0x008F8E90, 
        0x008E8D8F, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 0x008C8B8D, 0x008B8A8C, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x0089888A, 0x00888789, 0x00888789, 0x00878688, 0x00868587, 0x00858486, 0x00858486, 0x00848385, 0x00838284, 0x00818082, 
        0x00807F81, 0x007E7D7F, 0x007D7C7E, 0x007B7A7C, 0x007A797B, 0x00787779, 0x00767577, 0x00747375, 0x00727173, 0x00717171, 0x006F6F6F, 0x006B6B6B, 0x00686868, 0x00656565, 0x00616161, 0x005C5C5C, 0x005A5A5A, 0x005B5B5B, 0x00656565, 0x00717171, 
        0x00808080, 0x00919191, 0x00A2A2A2, 0x00B7B7B7, 0x00CCCCCC, 0x00E6E6E6, 0x00FDFDFD, 0x00F7F7F7, 0x00DBDBDB, 0x00C7C7C7, 0x00B2B2B2, 0x00989799, 0x00868587, 0x00706F71, 0x00636264, 0x00555456, 0x00464547, 0x00373638, 0x002F2E30, 0x00323133, 
        0x00343335, 0x003E3D3F, 0x00434244, 0x004B4A4C, 0x00504F51, 0x00535254, 0x00575658, 0x005B5A5C, 0x005E5D5F, 0x00636264, 0x00656466, 0x00686769, 0x006A696B, 0x006D6C6E, 0x006F6E70, 0x00717072, 0x00727173, 0x00747375, 0x00757476, 0x00777678, 
        0x0079787A, 0x007A797B, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x00807F81, 0x00818082, 0x00828183, 0x00838284, 0x00848385, 0x00858486, 0x00868587, 0x00868587, 0x00868587, 0x00878688, 0x00888789, 0x0089888A, 0x0089888A, 
        0x0089888A, 0x0087888C, 0x0088898D, 0x00898A8E, 0x008D8E92, 0x0096979B, 0x00999A9E, 0x009B9CA0, 0x00A0A1A5, 0x00A4A3A7, 0x00B1B0B4, 0x83C9C8CA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xA1818181, 0x00555555, 0x00504F51, 0x004B4A4C, 0x0049484A, 0x00474648, 0x005F5E60, 0x008F8E90, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008D8C8E, 0x008C8B8D, 
        0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x008A898B, 0x008A898B, 0x0089888A, 0x0089888A, 0x00888789, 0x00878688, 0x00878688, 0x00868587, 0x00858486, 0x00858486, 0x00848385, 0x00838284, 0x00828183, 0x00818082, 0x00807F81, 0x007F7E80, 0x007D7C7E, 
        0x007C7B7D, 0x007B7A7C, 0x007A797B, 0x00787779, 0x00767577, 0x00747375, 0x00727173, 0x006F6E70, 0x006E6D6F, 0x006C6C6C, 0x00686868, 0x00646464, 0x00606060, 0x005D5D5D, 0x005A5A5A, 0x005A5A5A, 0x005B5B5B, 0x00666666, 0x00737373, 0x00818181, 
        0x008F8F8F, 0x009F9F9F, 0x00AFAFAF, 0x00C4C4C4, 0x00D8D8D8, 0x00F2F2F2, 0x00FFFFFF, 0x00F3F3F3, 0x00DADADA, 0x00C7C7C7, 0x00B4B4B4, 0x00A1A0A2, 0x00908F91, 0x007C7B7D, 0x006D6C6E, 0x005D5C5E, 0x00504F51, 0x00424143, 0x00383739, 0x00333234, 
        0x002D2C2E, 0x00343335, 0x0039383A, 0x00403F41, 0x00464547, 0x004B4A4C, 0x004F4E50, 0x00535254, 0x00575658, 0x005D5C5E, 0x005E5D5F, 0x00616062, 0x00646365, 0x00676668, 0x0069686A, 0x006C6B6D, 0x006D6C6E, 0x006F6E70, 0x00717072, 0x00737274, 
        0x00747375, 0x00767577, 0x00777678, 0x0079787A, 0x007A797B, 0x0079787A, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x00818082, 0x00828183, 0x00838284, 0x00838284, 0x00838284, 0x00848385, 0x00858486, 0x00868587, 0x00868587, 
        0x00868587, 0x00848589, 0x0086878B, 0x0086878B, 0x008B8C90, 0x00929397, 0x0095969A, 0x0098999D, 0x009D9EA2, 0x00A1A0A4, 0x00B2B1B5, 0xA1CCCBCD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xC2979797, 0x005B5B5B, 0x00565557, 0x00504F51, 0x004E4D4F, 0x004A494B, 0x00545355, 0x008B8A8C, 0x008A898B, 0x008A898B, 0x008A898B, 0x008A898B, 0x008A898B, 
        0x0089888A, 0x00888789, 0x00888789, 0x00878688, 0x00878688, 0x00868587, 0x00868587, 0x00858486, 0x00848385, 0x00838284, 0x00838284, 0x00828183, 0x00828183, 0x00807F81, 0x007F7E80, 0x007E7D7F, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 0x0079787A, 
        0x00787779, 0x00787779, 0x00767577, 0x00747375, 0x00727173, 0x00706F71, 0x006E6D6F, 0x006B6A6C, 0x0069686A, 0x00666666, 0x00626262, 0x005E5E5E, 0x005B5B5B, 0x00595959, 0x005B5B5B, 0x00616161, 0x00686868, 0x00747474, 0x00818181, 0x008F8F8F, 
        0x009C9C9C, 0x00ACACAC, 0x00BDBDBD, 0x00D1D1D1, 0x00E5E5E5, 0x00FAFAFA, 0x00FEFEFE, 0x00EDEDED, 0x00DADADA, 0x00C8C8C8, 0x00B6B6B6, 0x00A8A7A9, 0x00949395, 0x00858486, 0x00757476, 0x00656466, 0x0059585A, 0x004D4C4E, 0x00444345, 0x003A393B, 
        0x00313032, 0x00302F31, 0x00333234, 0x00373638, 0x003D3C3E, 0x00424143, 0x00484749, 0x004C4B4D, 0x004F4E50, 0x00565557, 0x00585759, 0x005B5A5C, 0x005E5D5F, 0x00616062, 0x00636264, 0x00666567, 0x00686769, 0x006A696B, 0x006C6B6D, 0x006E6D6F, 
        0x00706F71, 0x00727173, 0x00737274, 0x00757476, 0x00767577, 0x00757476, 0x00777678, 0x00787779, 0x0079787A, 0x007A797B, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x007F7E80, 0x00807F81, 0x00818082, 0x00828183, 0x00828183, 
        0x00838284, 0x00808185, 0x00838488, 0x00838488, 0x0088898D, 0x008F9094, 0x00919296, 0x00949599, 0x00999A9E, 0x009F9EA2, 0x00B3B2B6, 0xC2CFCED0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xE6A5A5A5, 0x0E5F5F5F, 0x005A595B, 0x00545355, 0x00515052, 0x004B4A4C, 0x004E4D4F, 0x0089888A, 0x00888789, 0x0089888A, 0x0089888A, 0x0089888A, 0x00888789, 
        0x00878688, 0x00878688, 0x00868587, 0x00858486, 0x00858486, 0x00848385, 0x00838284, 0x00838284, 0x00828183, 0x00818082, 0x00807F81, 0x007F7E80, 0x007F7E80, 0x007D7C7E, 0x007C7B7D, 0x007B7A7C, 0x007A797B, 0x0079787A, 0x00787779, 0x00767577, 
        0x00757476, 0x00737274, 0x00727173, 0x00706F71, 0x006D6C6E, 0x006B6A6C, 0x0069686A, 0x00666567, 0x00646365, 0x00626262, 0x005E5E5E, 0x005A5A5A, 0x00595959, 0x005A5A5A, 0x00606060, 0x006C6C6C, 0x00777777, 0x007E7E7E, 0x008A8A8A, 0x00989898, 
        0x00A6A6A6, 0x00B6B6B6, 0x00C7C7C7, 0x00DADADA, 0x00ECECEC, 0x00FFFFFF, 0x00FCFCFC, 0x00EBEBEB, 0x00DDDDDD, 0x00CBCBCB, 0x00B9B9B9, 0x00ACABAD, 0x00969597, 0x00888789, 0x007B7A7C, 0x006E6D6F, 0x00636264, 0x00555456, 0x004B4A4C, 0x00434244, 
        0x003A393B, 0x002E2D2F, 0x002F2E30, 0x00313032, 0x00353436, 0x003B3A3C, 0x00414042, 0x00464547, 0x0049484A, 0x004F4E50, 0x00515052, 0x00545355, 0x00575658, 0x005A595B, 0x005D5C5E, 0x00605F61, 0x00616062, 0x00656466, 0x00666567, 0x0069686A, 
        0x006B6A6C, 0x006C6B6D, 0x006E6D6F, 0x00706F71, 0x00717072, 0x00737274, 0x00747375, 0x00757476, 0x00767577, 0x00777678, 0x00777678, 0x0079787A, 0x007A797B, 0x007B7A7C, 0x007B7A7C, 0x007C7B7D, 0x007D7C7E, 0x007E7D7F, 0x007F7E80, 0x007F7E80, 
        0x007F7E80, 0x007E7F83, 0x00808185, 0x00818286, 0x0085868A, 0x008C8D91, 0x008F9094, 0x00919296, 0x0096979B, 0x009F9EA2, 0x0EB3B2B4, 0xE6D1D0D2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFBEBEBE, 0x38616161, 0x005B5A5C, 0x00616062, 0x00525153, 0x00545355, 0x004B4A4C, 0x007B7A7C, 0x00868587, 0x00878688, 0x00868686, 0x00858585, 0x00858585, 
        0x00848484, 0x00848484, 0x00838383, 0x00838383, 0x00828282, 0x00828282, 0x00818181, 0x00808080, 0x007F7F7F, 0x007E7E7E, 0x007D7D7D, 0x007C7C7C, 0x007B7B7B, 0x00797979, 0x00787878, 0x00777777, 0x00767676, 0x00757575, 0x00747474, 0x00727272, 
        0x00717171, 0x00707070, 0x006D6D6D, 0x006B6B6B, 0x006A6A6A, 0x00676767, 0x00636363, 0x00606060, 0x005F5F5F, 0x00595959, 0x00595959, 0x00585858, 0x005B5B5B, 0x00656565, 0x006E6E6E, 0x00767676, 0x00808080, 0x008B8B8B, 0x00949494, 0x00A3A3A3, 
        0x00B1B1B1, 0x00C0C0C0, 0x00D0D0D0, 0x00E3E3E3, 0x00F0F0F0, 0x00FFFFFF, 0x00F5F5F5, 0x00E8E8E8, 0x00DBDBDB, 0x00CACACA, 0x00BBBBBB, 0x00ACACAC, 0x009E9E9E, 0x008F8E90, 0x00828183, 0x00757476, 0x006B6A6C, 0x005E5D5F, 0x00545355, 0x004B4A4C, 
        0x00434244, 0x003B3A3C, 0x00343335, 0x002E2D2F, 0x002E2D2F, 0x00333234, 0x0039383A, 0x003F3E40, 0x00434244, 0x00474648, 0x004A494B, 0x004E4D4F, 0x00525153, 0x00555456, 0x00575658, 0x0059585A, 0x005A595B, 0x005F5E60, 0x00616062, 0x00646365, 
        0x00666567, 0x00676668, 0x0069686A, 0x006C6B6D, 0x006D6C6E, 0x006E6D6F, 0x006F6E70, 0x00717072, 0x00727173, 0x00727173, 0x00737274, 0x00757476, 0x00767577, 0x00777678, 0x00787779, 0x0079787A, 0x007A797B, 0x007A797B, 0x007B7A7C, 0x007C7B7D, 
        0x007D7C7E, 0x007C7B7D, 0x00818082, 0x007F7E80, 0x00828183, 0x00888789, 0x008C8B8D, 0x00908F91, 0x00908F91, 0x00989799, 0x38C2C2C2, 0xFFD5D5D5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFC4C4C4, 0x64717171, 0x00605F61, 0x00605F61, 0x00555456, 0x00545355, 0x00515052, 0x006E6D6F, 0x00838284, 0x00858486, 0x00848484, 0x00848484, 0x00838383, 
        0x00838383, 0x00828282, 0x00818181, 0x00818181, 0x00818181, 0x00808080, 0x007F7F7F, 0x007D7D7D, 0x007C7C7C, 0x007C7C7C, 0x007A7A7A, 0x00797979, 0x00787878, 0x00777777, 0x00767676, 0x00757575, 0x00737373, 0x00727272, 0x00717171, 0x006F6F6F, 
        0x006D6D6D, 0x006C6C6C, 0x00696969, 0x00686868, 0x00666666, 0x00636363, 0x005E5E5E, 0x005B5B5B, 0x005A5A5A, 0x00585858, 0x005B5B5B, 0x005D5D5D, 0x00636363, 0x006E6E6E, 0x00767676, 0x007F7F7F, 0x00898989, 0x00959595, 0x009E9E9E, 0x00ADADAD, 
        0x00BBBBBB, 0x00C8C8C8, 0x00D8D8D8, 0x00EAEAEA, 0x00F7F7F7, 0x00FFFFFF, 0x00F4F4F4, 0x00E7E7E7, 0x00DADADA, 0x00CBCBCB, 0x00BCBCBC, 0x00AEAEAE, 0x00A1A1A1, 0x00949395, 0x00878688, 0x007B7A7C, 0x00717072, 0x00646365, 0x005A595B, 0x00515052, 
        0x0049484A, 0x003F3E40, 0x0039383A, 0x00323133, 0x002F2E30, 0x00302F31, 0x00333234, 0x00383739, 0x003D3C3E, 0x00414042, 0x00444345, 0x00484749, 0x004C4B4D, 0x004F4E50, 0x00525153, 0x00555456, 0x00575658, 0x0059585A, 0x005C5B5D, 0x005F5E60, 
        0x00616062, 0x00626163, 0x00646365, 0x00666567, 0x00686769, 0x006B6A6C, 0x006C6B6D, 0x006D6C6E, 0x006F6E70, 0x00706F71, 0x00717072, 0x00727173, 0x00737274, 0x00757476, 0x00767577, 0x00777678, 0x00777678, 0x00787779, 0x00787779, 0x0079787A, 
        0x007A797B, 0x007D7C7E, 0x007D7C7E, 0x007D7C7E, 0x00818082, 0x00858486, 0x00888789, 0x008D8C8E, 0x00908F91, 0x009B9B9B, 0x64C5C5C5, 0xFFD8D8D8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFCACACA, 0x92898989, 0x00676668, 0x00616062, 0x005B5A5C, 0x00565557, 0x00585759, 0x00605F61, 0x007F7E80, 0x00838284, 0x00828282, 0x00818181, 0x00818181, 
        0x00808080, 0x007F7F7F, 0x007F7F7F, 0x007E7E7E, 0x007E7E7E, 0x007D7D7D, 0x007C7C7C, 0x007A7A7A, 0x00797979, 0x00787878, 0x00777777, 0x00767676, 0x00757575, 0x00747474, 0x00737373, 0x00717171, 0x00707070, 0x006E6E6E, 0x006C6C6C, 0x006A6A6A, 
        0x00686868, 0x00676767, 0x00656565, 0x00626262, 0x00616161, 0x005E5E5E, 0x005A5A5A, 0x00575757, 0x00575757, 0x005B5B5B, 0x00616161, 0x00676767, 0x006E6E6E, 0x00797979, 0x00808080, 0x00898989, 0x00949494, 0x009E9E9E, 0x00A9A9A9, 0x00B7B7B7, 
        0x00C3C3C3, 0x00CFCFCF, 0x00DFDFDF, 0x00F0F0F0, 0x00FDFDFD, 0x00FEFEFE, 0x00F2F2F2, 0x00E6E6E6, 0x00DADADA, 0x00CBCBCB, 0x00BEBEBE, 0x00B1B1B1, 0x00A5A5A5, 0x00989799, 0x008B8A8C, 0x00807F81, 0x00767577, 0x006A696B, 0x00605F61, 0x00575658, 
        0x004F4E50, 0x00464547, 0x00414042, 0x003A393B, 0x00343335, 0x002E2D2F, 0x002D2C2E, 0x00313032, 0x00363537, 0x003B3A3C, 0x003E3D3F, 0x00424143, 0x00464547, 0x00484749, 0x004B4A4C, 0x004F4E50, 0x00525153, 0x00555456, 0x00575658, 0x005A595B, 
        0x005D5C5E, 0x005E5D5F, 0x00605F61, 0x00626163, 0x00646365, 0x00666567, 0x00676668, 0x0069686A, 0x006A696B, 0x006B6A6C, 0x006D6C6E, 0x006F6E70, 0x00706F71, 0x00717072, 0x00727173, 0x00737274, 0x00747375, 0x00747375, 0x00757476, 0x00767577, 
        0x00777678, 0x007B7A7C, 0x00767577, 0x0079787A, 0x007F7E80, 0x00818082, 0x00838284, 0x008A898B, 0x008E8D8F, 0x00A2A2A2, 0x92C9C9C9, 0xFFDCDCDC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFCFCFCF, 0xC2A2A2A2, 0x0069686A, 0x00656466, 0x00626163, 0x005D5C5E, 0x005C5B5D, 0x0059585A, 0x007B7A7C, 0x00828183, 0x007F7F7F, 0x007F7F7F, 0x007E7E7E, 
        0x007D7D7D, 0x007D7D7D, 0x007C7C7C, 0x007B7B7B, 0x007B7B7B, 0x007A7A7A, 0x00797979, 0x00777777, 0x00767676, 0x00757575, 0x00747474, 0x00737373, 0x00727272, 0x00717171, 0x006F6F6F, 0x006E6E6E, 0x006C6C6C, 0x006B6B6B, 0x00696969, 0x00666666, 
        0x00656565, 0x00646464, 0x00606060, 0x005D5D5D, 0x005B5B5B, 0x00595959, 0x00585858, 0x00595959, 0x005B5B5B, 0x00626262, 0x006A6A6A, 0x00717171, 0x00787878, 0x00818181, 0x00888888, 0x00919191, 0x009C9C9C, 0x00A5A5A5, 0x00B0B0B0, 0x00BEBEBE, 
        0x00CACACA, 0x00D5D5D5, 0x00E4E4E4, 0x00F5F5F5, 0x00FFFFFF, 0x00FDFDFD, 0x00F1F1F1, 0x00E5E5E5, 0x00D9D9D9, 0x00CCCCCC, 0x00C0C0C0, 0x00B4B4B4, 0x00A9A9A9, 0x009C9B9D, 0x008F8E90, 0x00848385, 0x007B7A7C, 0x006F6E70, 0x00666567, 0x005E5D5F, 
        0x00565557, 0x004E4D4F, 0x0049484A, 0x00424143, 0x003A393B, 0x00333234, 0x002E2D2F, 0x002E2D2F, 0x00313032, 0x00353436, 0x0039383A, 0x003E3D3F, 0x00424143, 0x00434244, 0x00464547, 0x004A494B, 0x004D4C4E, 0x00515052, 0x00535254, 0x00565557, 
        0x0059585A, 0x005A595B, 0x005C5B5D, 0x005F5E60, 0x00605F61, 0x00616062, 0x00626163, 0x00646365, 0x00666567, 0x00686769, 0x0069686A, 0x006B6A6C, 0x006D6C6E, 0x006D6C6E, 0x006E6D6F, 0x006F6E70, 0x00706F71, 0x00717072, 0x00727173, 0x00737274, 
        0x00747375, 0x00777678, 0x00717072, 0x00777678, 0x007B7A7C, 0x007C7B7D, 0x00828183, 0x00868587, 0x0089888A, 0x00ADADAD, 0xC2CDCDCD, 0xFFDEDEDE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD5D5D5, 0xF5B8B8B8, 0x2B6E6D6F, 0x006A696B, 0x00666567, 0x00636264, 0x005B5A5C, 0x005A595B, 0x00767577, 0x007F7E80, 0x007D7D7D, 0x007C7C7C, 0x007C7C7C, 
        0x007B7B7B, 0x007A7A7A, 0x00797979, 0x00797979, 0x00787878, 0x00787878, 0x00777777, 0x00757575, 0x00747474, 0x00737373, 0x00727272, 0x00707070, 0x006F6F6F, 0x006D6D6D, 0x006C6C6C, 0x006A6A6A, 0x00696969, 0x00686868, 0x00666666, 0x00646464, 
        0x00626262, 0x00606060, 0x005D5D5D, 0x00595959, 0x00575757, 0x00575757, 0x00595959, 0x005E5E5E, 0x00646464, 0x006B6B6B, 0x00727272, 0x00787878, 0x007F7F7F, 0x00888888, 0x008E8E8E, 0x00979797, 0x00A3A3A3, 0x00ADADAD, 0x00B9B9B9, 0x00C7C7C7, 
        0x00D1D1D1, 0x00DDDDDD, 0x00EBEBEB, 0x00FAFAFA, 0x00FFFFFF, 0x00FBFBFB, 0x00F0F0F0, 0x00E4E4E4, 0x00D9D9D9, 0x00CCCCCC, 0x00C1C1C1, 0x00B6B6B6, 0x00ABABAB, 0x00A09FA1, 0x00939294, 0x0089888A, 0x00818082, 0x00767577, 0x006D6C6E, 0x00656466, 
        0x005D5C5E, 0x00555456, 0x004F4E50, 0x00474648, 0x00414042, 0x003A393B, 0x00343335, 0x00302F31, 0x002E2D2F, 0x002F2E30, 0x00333234, 0x00383739, 0x003D3C3E, 0x003F3E40, 0x00424143, 0x00464547, 0x00484749, 0x004B4A4C, 0x004E4D4F, 0x00515052, 
        0x00535254, 0x00555456, 0x00575658, 0x0059585A, 0x005B5A5C, 0x005D5C5E, 0x005E5D5F, 0x00605F61, 0x00626163, 0x00646365, 0x00666567, 0x00686769, 0x0069686A, 0x006A696B, 0x006B6A6C, 0x006C6B6D, 0x006D6C6E, 0x006E6D6F, 0x006F6E70, 0x00706F71, 
        0x00717072, 0x00737274, 0x006F6E70, 0x00767577, 0x00767577, 0x0079787A, 0x00818082, 0x00807F81, 0x00858486, 0x2BBBBBBB, 0xF5D2D2D2, 0xFFDEDEDE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD6D6D6, 0xFFC6C6C6, 0x637D7C7E, 0x006F6E70, 0x006A696B, 0x00686769, 0x005D5C5E, 0x005F5E60, 0x006D6C6E, 0x007A797B, 0x007A7A7A, 0x007A7A7A, 0x00797979, 
        0x00797979, 0x00787878, 0x00777777, 0x00767676, 0x00767676, 0x00757575, 0x00747474, 0x00737373, 0x00717171, 0x00707070, 0x006F6F6F, 0x006E6E6E, 0x006C6C6C, 0x006A6A6A, 0x00686868, 0x00676767, 0x00656565, 0x00646464, 0x00626262, 0x00606060, 
        0x005F5F5F, 0x005B5B5B, 0x00595959, 0x00575757, 0x00585858, 0x005A5A5A, 0x005E5E5E, 0x00666666, 0x006D6D6D, 0x00737373, 0x00797979, 0x007F7F7F, 0x00868686, 0x008F8F8F, 0x00969696, 0x00A0A0A0, 0x00ACACAC, 0x00B5B5B5, 0x00C0C0C0, 0x00CDCDCD, 
        0x00D7D7D7, 0x00E3E3E3, 0x00F1F1F1, 0x00FCFCFC, 0x00FFFFFF, 0x00F9F9F9, 0x00EEEEEE, 0x00E3E3E3, 0x00D8D8D8, 0x00CCCCCC, 0x00C2C2C2, 0x00B8B8B8, 0x00ADADAD, 0x00A2A1A3, 0x00969597, 0x008C8B8D, 0x00848385, 0x007A797B, 0x00717072, 0x0069686A, 
        0x00626163, 0x005A595B, 0x00535254, 0x004B4A4C, 0x00464547, 0x00414042, 0x003B3A3C, 0x00343335, 0x00302F31, 0x002C2B2D, 0x002E2D2F, 0x00323133, 0x00363537, 0x003A393B, 0x003E3D3F, 0x00414042, 0x00444345, 0x00474648, 0x004A494B, 0x004D4C4E, 
        0x004F4E50, 0x00515052, 0x00535254, 0x00555456, 0x00575658, 0x0059585A, 0x005A595B, 0x005C5B5D, 0x005E5D5F, 0x00605F61, 0x00626163, 0x00646365, 0x00656466, 0x00666567, 0x00676668, 0x0069686A, 0x006A696B, 0x006B6A6C, 0x006C6B6D, 0x006D6C6E, 
        0x006F6E70, 0x006F6E70, 0x006E6D6F, 0x00737274, 0x00717072, 0x00777678, 0x007D7C7E, 0x007B7A7C, 0x008B8A8C, 0x63C6C6C6, 0xFFD7D7D7, 0xFFE0E0E0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD7D7D7, 0xFFCECECE, 0x9D989799, 0x00757476, 0x006F6E70, 0x006B6A6C, 0x00656466, 0x00636264, 0x00666567, 0x00767577, 0x00787878, 0x00787878, 0x00777777, 
        0x00767676, 0x00757575, 0x00747474, 0x00737373, 0x00737373, 0x00727272, 0x00717171, 0x006F6F6F, 0x006E6E6E, 0x006D6D6D, 0x006C6C6C, 0x006A6A6A, 0x00696969, 0x00676767, 0x00656565, 0x00646464, 0x00626262, 0x00606060, 0x005E5E5E, 0x005C5C5C, 
        0x005A5A5A, 0x00585858, 0x00585858, 0x005A5A5A, 0x005E5E5E, 0x00616161, 0x00666666, 0x006D6D6D, 0x00747474, 0x007B7B7B, 0x00818181, 0x00868686, 0x008E8E8E, 0x00989898, 0x009F9F9F, 0x00A9A9A9, 0x00B4B4B4, 0x00BCBCBC, 0x00C6C6C6, 0x00D2D2D2, 
        0x00DCDCDC, 0x00E8E8E8, 0x00F5F5F5, 0x00FDFDFD, 0x00FFFFFF, 0x00F7F7F7, 0x00ECECEC, 0x00E2E2E2, 0x00D8D8D8, 0x00CDCDCD, 0x00C3C3C3, 0x00B9B9B9, 0x00AEAEAE, 0x00A4A3A5, 0x0099989A, 0x008F8E90, 0x00888789, 0x007E7D7F, 0x00767577, 0x006E6D6F, 
        0x00666567, 0x00605F61, 0x0059585A, 0x00504F51, 0x004B4A4C, 0x00474648, 0x00403F41, 0x003A393B, 0x00363537, 0x002F2E30, 0x002E2D2F, 0x002D2C2E, 0x002F2E30, 0x00343335, 0x00383739, 0x003C3B3D, 0x003E3D3F, 0x00434244, 0x00454446, 0x0049484A, 
        0x004B4A4C, 0x004D4C4E, 0x004F4E50, 0x00515052, 0x00535254, 0x00555456, 0x00565557, 0x00585759, 0x005A595B, 0x005C5B5D, 0x005D5C5E, 0x005F5E60, 0x00616062, 0x00626163, 0x00646365, 0x00656466, 0x00666567, 0x00676668, 0x0069686A, 0x006A696B, 
        0x006B6A6C, 0x006B6A6C, 0x0069686A, 0x006E6D6F, 0x006D6C6E, 0x00757476, 0x00777678, 0x007A797B, 0x009D9C9E, 0x9DCDCDCD, 0xFFDBDBDB, 0xFFE4E4E4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDADADA, 0xFFD4D4D4, 0xD8AEADAF, 0x177A797B, 0x00747375, 0x006D6C6E, 0x006E6D6F, 0x00666567, 0x00626163, 0x00737274, 0x00767676, 0x00767676, 0x00757575, 
        0x00747474, 0x00737373, 0x00727272, 0x00727272, 0x00717171, 0x00707070, 0x006F6F6F, 0x006D6D6D, 0x006C6C6C, 0x006B6B6B, 0x00696969, 0x00686868, 0x00666666, 0x00656565, 0x00636363, 0x00616161, 0x005F5F5F, 0x005D5D5D, 0x005B5B5B, 0x00585858, 
        0x00565656, 0x00565656, 0x00595959, 0x005E5E5E, 0x00646464, 0x00686868, 0x006D6D6D, 0x00737373, 0x00787878, 0x00818181, 0x00868686, 0x008C8C8C, 0x00949494, 0x009E9E9E, 0x00A5A5A5, 0x00AEAEAE, 0x00B8B8B8, 0x00C2C2C2, 0x00CCCCCC, 0x00D7D7D7, 
        0x00E1E1E1, 0x00EDEDED, 0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00F5F5F5, 0x00EAEAEA, 0x00E1E1E1, 0x00D8D8D8, 0x00CDCDCD, 0x00C4C4C4, 0x00BABABA, 0x00AFAFAF, 0x00A8A7A9, 0x009D9C9E, 0x00949395, 0x008D8C8E, 0x00838284, 0x007B7A7C, 0x00737274, 
        0x006B6A6C, 0x00656466, 0x005E5D5F, 0x00555456, 0x004F4E50, 0x004A494B, 0x00444345, 0x003F3E40, 0x003C3B3D, 0x00343335, 0x00313032, 0x002D2C2E, 0x002C2B2D, 0x00302F31, 0x00343335, 0x00383739, 0x0039383A, 0x003E3D3F, 0x00403F41, 0x00434244, 
        0x00464547, 0x00484749, 0x004A494B, 0x004C4B4D, 0x004E4D4F, 0x00525153, 0x00545355, 0x00565557, 0x00575658, 0x0059585A, 0x005A595B, 0x005C5B5D, 0x005E5D5F, 0x00605F61, 0x00616062, 0x00626163, 0x00646365, 0x00656466, 0x00666567, 0x00686769, 
        0x0069686A, 0x00686769, 0x00646365, 0x0069686A, 0x006A696B, 0x00747375, 0x00737274, 0x007A797B, 0x17AEADAF, 0xD8D0D0D0, 0xFFDDDDDD, 0xFFE7E7E7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDFDFDF, 0xFFD6D6D6, 0xFFC7C6C8, 0x57838284, 0x00787779, 0x00717072, 0x00706F71, 0x006D6C6E, 0x00666567, 0x0069686A, 0x00777777, 0x00757575, 0x00747474, 
        0x00737373, 0x00737373, 0x00727272, 0x00707070, 0x006F6F6F, 0x006C6C6C, 0x006C6C6C, 0x006B6B6B, 0x006A6A6A, 0x00686868, 0x00676767, 0x00656565, 0x00646464, 0x00626262, 0x00616161, 0x00606060, 0x005D5D5D, 0x005A5A5A, 0x00575757, 0x00565656, 
        0x00565656, 0x005B5B5B, 0x005F5F5F, 0x00646464, 0x006A6A6A, 0x006F6F6F, 0x00757575, 0x007B7B7B, 0x00808080, 0x00878787, 0x008C8C8C, 0x00949494, 0x009B9B9B, 0x00A3A3A3, 0x00ADADAD, 0x00B7B7B7, 0x00BDBDBD, 0x00C7C7C7, 0x00D2D2D2, 0x00DEDEDE, 
        0x00E7E7E7, 0x00F2F2F2, 0x00FDFDFD, 0x00FFFFFF, 0x00FDFDFD, 0x00F2F2F2, 0x00EBEBEB, 0x00E1E1E1, 0x00D7D7D7, 0x00CFCFCF, 0x00C5C5C5, 0x00BBBBBB, 0x00B3B3B3, 0x00A9A8AA, 0x00A09FA1, 0x00979698, 0x008F8E90, 0x00868587, 0x007F7E80, 0x00787779, 
        0x006F6E70, 0x00686769, 0x00636264, 0x005C5B5D, 0x00555456, 0x004F4E50, 0x004A494B, 0x00444345, 0x00403F41, 0x0039383A, 0x00353436, 0x00302F31, 0x002C2B2D, 0x002B2A2C, 0x002E2D2F, 0x00333234, 0x00363537, 0x0039383A, 0x003C3B3D, 0x003F3E40, 
        0x00424143, 0x00434244, 0x00464547, 0x0049484A, 0x004B4A4C, 0x004E4D4F, 0x004F4E50, 0x00515052, 0x00535254, 0x00545355, 0x00565557, 0x00585759, 0x0059585A, 0x0059585A, 0x005E5D5F, 0x00605F61, 0x005B5A5C, 0x00666567, 0x00616062, 0x00636264, 
        0x00676668, 0x005E5D5F, 0x00636264, 0x00656466, 0x0069686A, 0x006B6A6C, 0x00706F71, 0x00818082, 0x57C2C1C3, 0xFFD5D5D5, 0xFFDFDFDF, 0xFFEAEAEA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE2E2E2, 0xFFDADADA, 0xFFCDCCCE, 0x999C9B9D, 0x007C7B7D, 0x0079787A, 0x00757476, 0x00706F71, 0x006B6A6C, 0x0069686A, 0x00727272, 0x00727272, 0x00727272, 
        0x00717171, 0x006F6F6F, 0x006D6D6D, 0x006D6D6D, 0x006C6C6C, 0x006C6C6C, 0x006B6B6B, 0x00696969, 0x00676767, 0x00666666, 0x00646464, 0x00636363, 0x00626262, 0x005F5F5F, 0x005E5E5E, 0x005C5C5C, 0x005A5A5A, 0x00585858, 0x00575757, 0x00585858, 
        0x005A5A5A, 0x00616161, 0x00656565, 0x006A6A6A, 0x006F6F6F, 0x00747474, 0x007A7A7A, 0x00818181, 0x00868686, 0x008D8D8D, 0x00929292, 0x009A9A9A, 0x00A2A2A2, 0x00A9A9A9, 0x00B3B3B3, 0x00BCBCBC, 0x00C3C3C3, 0x00CCCCCC, 0x00D6D6D6, 0x00E1E1E1, 
        0x00EAEAEA, 0x00F5F5F5, 0x00FFFFFF, 0x00FFFFFF, 0x00FBFBFB, 0x00F1F1F1, 0x00EAEAEA, 0x00E0E0E0, 0x00D7D7D7, 0x00CFCFCF, 0x00C6C6C6, 0x00BCBCBC, 0x00B5B5B5, 0x00ABAAAC, 0x00A1A0A2, 0x0099989A, 0x00919092, 0x00888789, 0x00818082, 0x007A797B, 
        0x00717072, 0x006B6A6C, 0x00666567, 0x005F5E60, 0x00585759, 0x00535254, 0x004D4C4E, 0x00474648, 0x00434244, 0x003D3C3E, 0x003A393B, 0x00353436, 0x00313032, 0x002E2D2F, 0x002D2C2E, 0x002F2E30, 0x00313032, 0x00353436, 0x00383739, 0x003C3B3D, 
        0x003F3E40, 0x00414042, 0x00434244, 0x00464547, 0x00484749, 0x004B4A4C, 0x004C4B4D, 0x004E4D4F, 0x00504F51, 0x00525153, 0x00545355, 0x00565557, 0x00575658, 0x00575658, 0x005C5B5D, 0x005B5A5C, 0x005C5B5D, 0x00605F61, 0x00605F61, 0x005D5C5E, 
        0x00636264, 0x005E5D5F, 0x005F5E60, 0x005F5E60, 0x00646365, 0x006B6A6C, 0x00686769, 0x00969597, 0x99CBCACC, 0xFFD9D9D9, 0xFFE2E2E2, 0xFFEDEDED, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE6E6E6, 0xFFDFDFDF, 0xFFD1D0D2, 0xDCB7B6B8, 0x23828183, 0x007E7D7F, 0x00787779, 0x00737274, 0x00706F71, 0x0069686A, 0x006D6D6D, 0x006F6F6F, 0x00707070, 
        0x006E6E6E, 0x006C6C6C, 0x006A6A6A, 0x00696969, 0x006A6A6A, 0x00696969, 0x00686868, 0x00666666, 0x00646464, 0x00626262, 0x00616161, 0x00606060, 0x00606060, 0x005B5B5B, 0x005A5A5A, 0x00585858, 0x00575757, 0x00575757, 0x005A5A5A, 0x005E5E5E, 
        0x00606060, 0x00666666, 0x006A6A6A, 0x00707070, 0x00757575, 0x007A7A7A, 0x00808080, 0x00868686, 0x008B8B8B, 0x00929292, 0x00989898, 0x00A0A0A0, 0x00A7A7A7, 0x00AFAFAF, 0x00B8B8B8, 0x00C2C2C2, 0x00C8C8C8, 0x00D2D2D2, 0x00DBDBDB, 0x00E5E5E5, 
        0x00EEEEEE, 0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00F8F8F8, 0x00F0F0F0, 0x00E9E9E9, 0x00DFDFDF, 0x00D7D7D7, 0x00CFCFCF, 0x00C6C6C6, 0x00BDBDBD, 0x00B6B6B6, 0x00ADACAE, 0x00A4A3A5, 0x009C9B9D, 0x00949395, 0x008B8A8C, 0x00848385, 0x007E7D7F, 
        0x00757476, 0x006F6E70, 0x006A696B, 0x00636264, 0x005D5C5E, 0x00575658, 0x00525153, 0x004C4B4D, 0x00484749, 0x00424143, 0x00403F41, 0x003B3A3C, 0x00363537, 0x00323133, 0x002F2E30, 0x002D2C2E, 0x002C2B2D, 0x00313032, 0x00333234, 0x00373638, 
        0x003A393B, 0x003C3B3D, 0x003F3E40, 0x00424143, 0x00444345, 0x00464547, 0x00484749, 0x004A494B, 0x004C4B4D, 0x004E4D4F, 0x00504F51, 0x00535254, 0x00545355, 0x00545355, 0x0059585A, 0x00555456, 0x005C5B5D, 0x005A595B, 0x005D5C5E, 0x0059585A, 
        0x00626163, 0x005F5E60, 0x005C5B5D, 0x005B5A5C, 0x00616062, 0x00676668, 0x00686769, 0x23B1B0B2, 0xDCD3D2D4, 0xFFDEDEDE, 0xFFE6E6E6, 0xFFF0F0F0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFD5D4D6, 0xFFC7C6C8, 0x6B919092, 0x00807F81, 0x007C7B7D, 0x00777678, 0x00767577, 0x006D6C6E, 0x006D6D6D, 0x006D6D6D, 0x006D6D6D, 
        0x006C6C6C, 0x006B6B6B, 0x00696969, 0x00686868, 0x00686868, 0x00656565, 0x00646464, 0x00636363, 0x00626262, 0x00606060, 0x005F5F5F, 0x005E5E5E, 0x005D5D5D, 0x00585858, 0x00575757, 0x00575757, 0x00575757, 0x005A5A5A, 0x005E5E5E, 0x00646464, 
        0x00686868, 0x006C6C6C, 0x006F6F6F, 0x00757575, 0x007A7A7A, 0x007F7F7F, 0x00858585, 0x008C8C8C, 0x00909090, 0x00989898, 0x009E9E9E, 0x00A5A5A5, 0x00ADADAD, 0x00B5B5B5, 0x00BDBDBD, 0x00C6C6C6, 0x00CDCDCD, 0x00D8D8D8, 0x00E0E0E0, 0x00E9E9E9, 
        0x00F2F2F2, 0x00FCFCFC, 0x00FFFFFF, 0x00FEFEFE, 0x00F6F6F6, 0x00EFEFEF, 0x00E8E8E8, 0x00DFDFDF, 0x00D6D6D6, 0x00CFCFCF, 0x00C7C7C7, 0x00BEBEBE, 0x00B7B7B7, 0x00AFAEB0, 0x00A6A5A7, 0x009F9EA0, 0x00979698, 0x008E8D8F, 0x00888789, 0x00818082, 
        0x0079787A, 0x00737274, 0x006E6D6F, 0x00676668, 0x00616062, 0x005C5B5D, 0x00565557, 0x00504F51, 0x004C4B4D, 0x00464547, 0x00434244, 0x003F3E40, 0x003A393B, 0x00363537, 0x00323133, 0x002F2E30, 0x002D2C2E, 0x002D2C2E, 0x002F2E30, 0x00323133, 
        0x00353436, 0x00383739, 0x003B3A3C, 0x003E3D3F, 0x00403F41, 0x00434244, 0x00444345, 0x00464547, 0x0049484A, 0x004B4A4C, 0x004D4C4E, 0x004F4E50, 0x00515052, 0x00525153, 0x00545355, 0x00545355, 0x0059585A, 0x00565557, 0x0059585A, 0x005C5B5D, 
        0x00656466, 0x00626163, 0x00605F61, 0x005B5A5C, 0x00605F61, 0x005E5D5F, 0x007E7D7F, 0x6BC6C5C7, 0xFFD5D4D6, 0xFFE2E2E2, 0xFFEAEAEA, 0xFFF2F2F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEDEDED, 0xFFE6E6E6, 0xFFDBDADC, 0xFFCFCED0, 0xB4A9A8AA, 0x00858486, 0x00828183, 0x007D7C7E, 0x007A797B, 0x00757476, 0x006F6F6F, 0x006D6D6D, 0x006A6A6A, 
        0x00696969, 0x00696969, 0x00696969, 0x00676767, 0x00656565, 0x00626262, 0x00626262, 0x00616161, 0x00606060, 0x005E5E5E, 0x005C5C5C, 0x005A5A5A, 0x00595959, 0x00565656, 0x00575757, 0x00585858, 0x005B5B5B, 0x005F5F5F, 0x00646464, 0x00696969, 
        0x006D6D6D, 0x00727272, 0x00767676, 0x007B7B7B, 0x00818181, 0x00868686, 0x008C8C8C, 0x00929292, 0x00979797, 0x009F9F9F, 0x00A4A4A4, 0x00ACACAC, 0x00B4B4B4, 0x00BBBBBB, 0x00C3C3C3, 0x00CCCCCC, 0x00D2D2D2, 0x00DDDDDD, 0x00E3E3E3, 0x00ECECEC, 
        0x00F6F6F6, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F4F4F4, 0x00EEEEEE, 0x00E8E8E8, 0x00DEDEDE, 0x00D6D6D6, 0x00CFCFCF, 0x00C7C7C7, 0x00BEBEBE, 0x00B8B8B8, 0x00B0AFB1, 0x00A8A7A9, 0x00A1A0A2, 0x009A999B, 0x00919092, 0x008A898B, 0x00848385, 
        0x007D7C7E, 0x00767577, 0x00717072, 0x006A696B, 0x00646365, 0x005F5E60, 0x005A595B, 0x00545355, 0x00504F51, 0x004A494B, 0x00474648, 0x00424143, 0x003D3C3E, 0x0039383A, 0x00363537, 0x00323133, 0x00302F31, 0x002C2B2D, 0x002D2C2E, 0x002F2E30, 
        0x00323133, 0x00353436, 0x00383739, 0x003B3A3C, 0x003D3C3E, 0x00403F41, 0x00424143, 0x00444345, 0x00464547, 0x00474648, 0x0049484A, 0x004B4A4C, 0x004D4C4E, 0x004F4E50, 0x004F4E50, 0x00555456, 0x00525153, 0x00545355, 0x00565557, 0x00636264, 
        0x006A696B, 0x00656466, 0x00666567, 0x005C5B5D, 0x005D5C5E, 0x0059585A, 0x00A09FA1, 0xB4D0CFD1, 0xFFD8D7D9, 0xFFE5E5E5, 0xFFEDEDED, 0xFFF4F4F4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEFEFEF, 0xFFE9E9E9, 0xFFE1E0E2, 0xFFD3D2D4, 0xFFBFBEC0, 0x4D939294, 0x00868587, 0x00807F81, 0x007C7B7D, 0x00787779, 0x00747474, 0x006F6F6F, 0x00696969, 
        0x00666666, 0x00666666, 0x00666666, 0x00646464, 0x00626262, 0x00616161, 0x00616161, 0x005F5F5F, 0x005E5E5E, 0x005B5B5B, 0x00595959, 0x00575757, 0x00565656, 0x00575757, 0x00595959, 0x005C5C5C, 0x00606060, 0x00646464, 0x00696969, 0x006E6E6E, 
        0x00717171, 0x00777777, 0x007B7B7B, 0x00808080, 0x00858585, 0x008A8A8A, 0x00909090, 0x00979797, 0x009B9B9B, 0x00A3A3A3, 0x00A9A9A9, 0x00B1B1B1, 0x00B8B8B8, 0x00BFBFBF, 0x00C7C7C7, 0x00D0D0D0, 0x00D6D6D6, 0x00E0E0E0, 0x00E7E7E7, 0x00F0F0F0, 
        0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00FBFBFB, 0x00F3F3F3, 0x00EDEDED, 0x00E7E7E7, 0x00DEDEDE, 0x00D6D6D6, 0x00D0D0D0, 0x00C8C8C8, 0x00BFBFBF, 0x00B9B9B9, 0x00B1B0B2, 0x00AAA9AB, 0x00A4A3A5, 0x009D9C9E, 0x00939294, 0x008D8C8E, 0x00888789, 
        0x00818082, 0x0079787A, 0x00747375, 0x006E6D6F, 0x00686769, 0x00636264, 0x005E5D5F, 0x00585759, 0x00545355, 0x004F4E50, 0x004B4A4C, 0x00464547, 0x00414042, 0x003D3C3E, 0x003A393B, 0x00363537, 0x00343335, 0x002F2E30, 0x002E2D2F, 0x002E2D2F, 
        0x002F2E30, 0x00313032, 0x00343335, 0x00373638, 0x0039383A, 0x003D3C3E, 0x003E3D3F, 0x00403F41, 0x00424143, 0x00444345, 0x00464547, 0x00484749, 0x0049484A, 0x004D4C4E, 0x004B4A4C, 0x00535254, 0x004D4C4E, 0x00535254, 0x0059585A, 0x006B6A6C, 
        0x006D6C6E, 0x006A696B, 0x0069686A, 0x005E5D5F, 0x005C5B5D, 0x006B6A6C, 0x4DBEBDBF, 0xFFD7D6D8, 0xFFDEDDDF, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF6F6F6, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE4E3E5, 0xFFD8D7D9, 0xFFCDCCCE, 0x9CAAA9AB, 0x008A898B, 0x00838284, 0x00818082, 0x007B7A7C, 0x00797979, 0x00737373, 0x006C6C6C, 
        0x00666666, 0x00636363, 0x00626262, 0x00616161, 0x00606060, 0x005F5F5F, 0x005E5E5E, 0x005C5C5C, 0x005A5A5A, 0x00585858, 0x00575757, 0x00575757, 0x00575757, 0x005C5C5C, 0x005E5E5E, 0x00626262, 0x00666666, 0x006A6A6A, 0x006F6F6F, 0x00737373, 
        0x00757575, 0x007B7B7B, 0x007F7F7F, 0x00858585, 0x008A8A8A, 0x008F8F8F, 0x00959595, 0x009B9B9B, 0x00A0A0A0, 0x00A7A7A7, 0x00ADADAD, 0x00B5B5B5, 0x00BCBCBC, 0x00C3C3C3, 0x00CBCBCB, 0x00D3D3D3, 0x00D9D9D9, 0x00E4E4E4, 0x00EAEAEA, 0x00F3F3F3, 
        0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F9F9, 0x00F3F3F3, 0x00ECECEC, 0x00E6E6E6, 0x00DDDDDD, 0x00D6D6D6, 0x00D0D0D0, 0x00C9C9C9, 0x00C0C0C0, 0x00BABABA, 0x00B3B2B4, 0x00ACABAD, 0x00A6A5A7, 0x009F9EA0, 0x00959496, 0x008F8E90, 0x008A898B, 
        0x00848385, 0x007D7C7E, 0x00787779, 0x00717072, 0x006C6B6D, 0x00676668, 0x00616062, 0x005C5B5D, 0x00585759, 0x00535254, 0x004F4E50, 0x004A494B, 0x00454446, 0x00424143, 0x003E3D3F, 0x003A393B, 0x00383739, 0x00333234, 0x00313032, 0x002F2E30, 
        0x002D2C2E, 0x002E2D2F, 0x00313032, 0x00333234, 0x00353436, 0x00383739, 0x003A393B, 0x003C3B3D, 0x003E3D3F, 0x00403F41, 0x00424143, 0x00454446, 0x00464547, 0x0049484A, 0x0049484A, 0x004D4C4E, 0x004C4B4D, 0x00535254, 0x00656466, 0x00747375, 
        0x00727173, 0x006F6E70, 0x006A696B, 0x00656466, 0x00656466, 0x00949395, 0x9CCECDCF, 0xFFDBDADC, 0xFFE4E3E5, 0xFFEDEDED, 0xFFF3F3F3, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFE7E6E8, 0xFFDFDEE0, 0xFFD5D4D6, 0xECBEBDBF, 0x40908F91, 0x00888789, 0x00888789, 0x007F7E80, 0x007D7D7D, 0x00787878, 0x006F6F6F, 
        0x00676767, 0x00626262, 0x00606060, 0x00606060, 0x00616161, 0x005D5D5D, 0x005B5B5B, 0x00585858, 0x00565656, 0x00565656, 0x00575757, 0x00585858, 0x00595959, 0x00626262, 0x00646464, 0x00676767, 0x006B6B6B, 0x006F6F6F, 0x00737373, 0x00777777, 
        0x007A7A7A, 0x00818181, 0x00848484, 0x008A8A8A, 0x008F8F8F, 0x00949494, 0x009A9A9A, 0x00A1A1A1, 0x00A5A5A5, 0x00ACACAC, 0x00B2B2B2, 0x00BABABA, 0x00C2C2C2, 0x00C8C8C8, 0x00D0D0D0, 0x00D8D8D8, 0x00DDDDDD, 0x00E6E6E6, 0x00EDEDED, 0x00F6F6F6, 
        0x00FDFDFD, 0x00FFFFFF, 0x00FEFEFE, 0x00F8F8F8, 0x00F3F3F3, 0x00EAEAEA, 0x00E4E4E4, 0x00DCDCDC, 0x00D6D6D6, 0x00D0D0D0, 0x00C9C9C9, 0x00C1C1C1, 0x00BBBBBB, 0x00B4B3B5, 0x00ADACAE, 0x00A7A6A8, 0x00A09FA1, 0x00979698, 0x00919092, 0x008C8B8D, 
        0x00868587, 0x007F7E80, 0x007A797B, 0x00747375, 0x006E6D6F, 0x0069686A, 0x00646365, 0x005F5E60, 0x005B5A5C, 0x00555456, 0x00515052, 0x004C4B4D, 0x00484749, 0x00454446, 0x00424143, 0x003E3D3F, 0x003B3A3C, 0x00363537, 0x00333234, 0x002F2E30, 
        0x002D2C2E, 0x002C2B2D, 0x002E2D2F, 0x00302F31, 0x00323133, 0x00353436, 0x00363537, 0x0039383A, 0x003B3A3C, 0x003E3D3F, 0x00403F41, 0x00434244, 0x00444345, 0x00464547, 0x00474648, 0x00474648, 0x004F4E50, 0x00545355, 0x00727173, 0x007C7B7D, 
        0x00777678, 0x00727173, 0x0069686A, 0x006E6D6F, 0x00706F71, 0x40BAB9BB, 0xECD3D2D4, 0xFFDEDDDF, 0xFFE6E5E7, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF5F5F5, 0xFFF2F2F2, 0xFFECECEC, 0xFFE0E0E0, 0xFFDADADA, 0xFFCBCBCB, 0x94A8A8A8, 0x008E8E8E, 0x00878787, 0x00858585, 0x00828183, 0x007B7A7C, 0x0079787A, 
        0x006F6E70, 0x005E5D5F, 0x005C5B5D, 0x00605F61, 0x005A595B, 0x005C5C5C, 0x00595959, 0x00565656, 0x00575757, 0x00595959, 0x005B5B5B, 0x005E5F5D, 0x00616260, 0x00646464, 0x00676767, 0x006B6B6B, 0x006F6F6F, 0x00737373, 0x00787878, 0x007C7C7C, 
        0x007F7F7F, 0x00858585, 0x00898989, 0x008F8F8F, 0x00949494, 0x00999999, 0x009F9F9F, 0x00A5A5A5, 0x00AAAAAA, 0x00B1B1B1, 0x00B7B7B7, 0x00BEBEBE, 0x00C5C5C5, 0x00CBCBCB, 0x00D3D3D3, 0x00DBDBDB, 0x00E1E1E1, 0x00E8E8E8, 0x00F1F1F1, 0x00FBFBFB, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F6F6F6, 0x00F1F1F1, 0x00E9E9E9, 0x00E4E4E4, 0x00DCDCDC, 0x00D5D5D5, 0x00D0D0D0, 0x00C9C9C9, 0x00C1C1C1, 0x00BCBCBC, 0x00B4B4B4, 0x00AFAFAF, 0x00A8A8A8, 0x00A1A1A1, 0x009B9B9B, 0x00949494, 0x008D8D8D, 
        0x00888888, 0x00818082, 0x007D7C7E, 0x00777678, 0x00717072, 0x006C6B6D, 0x00676668, 0x00626163, 0x005E5D5F, 0x0059585A, 0x00555456, 0x00515052, 0x004C4B4D, 0x0049484A, 0x00454446, 0x00414042, 0x003E3D3F, 0x003A393B, 0x00383739, 0x00353436, 
        0x00313032, 0x002E2D2F, 0x002C2B2D, 0x002C2B2D, 0x002C2B2D, 0x00333234, 0x00343335, 0x00353436, 0x0039383A, 0x003D3C3E, 0x003C3B3D, 0x003C3B3D, 0x00414042, 0x00464547, 0x00464547, 0x00454446, 0x00474648, 0x006F6E70, 0x00858486, 0x00777678, 
        0x0079787A, 0x00757476, 0x006D6C6E, 0x00706F71, 0x00989799, 0x94CFCED0, 0xFFD2D1D3, 0xFFECEBED, 0xFFE6E5E7, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFEEEEEE, 0xFFE7E7E7, 0xFFDDDDDD, 0xFFD1D1D1, 0xEAB9B9B9, 0x429B9B9B, 0x008A8A8A, 0x008A8A8A, 0x00888789, 0x00818082, 0x007E7D7F, 
        0x00777678, 0x00656466, 0x005B5A5C, 0x005A595B, 0x00585759, 0x00585858, 0x00565656, 0x00565656, 0x00585858, 0x005B5B5B, 0x005D5D5D, 0x00616260, 0x00656664, 0x00676767, 0x006A6A6A, 0x006E6E6E, 0x00727272, 0x00767676, 0x007B7B7B, 0x00808080, 
        0x00838383, 0x00888888, 0x008C8C8C, 0x00929292, 0x00979797, 0x009C9C9C, 0x00A2A2A2, 0x00A8A8A8, 0x00ADADAD, 0x00B4B4B4, 0x00BABABA, 0x00C1C1C1, 0x00C8C8C8, 0x00CECECE, 0x00D6D6D6, 0x00DEDEDE, 0x00E3E3E3, 0x00EBEBEB, 0x00F3F3F3, 0x00FCFCFC, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F5F5F5, 0x00F0F0F0, 0x00E9E9E9, 0x00E3E3E3, 0x00DCDCDC, 0x00D5D5D5, 0x00D0D0D0, 0x00C9C9C9, 0x00C2C2C2, 0x00BCBCBC, 0x00B5B5B5, 0x00B0B0B0, 0x00A9A9A9, 0x00A2A2A2, 0x009C9C9C, 0x00959595, 0x008F8F8F, 
        0x008A8A8A, 0x00838284, 0x007F7E80, 0x0079787A, 0x00747375, 0x006F6E70, 0x006A696B, 0x00646365, 0x00616062, 0x005B5A5C, 0x00585759, 0x00545355, 0x004F4E50, 0x004B4A4C, 0x00474648, 0x00434244, 0x00414042, 0x003D3C3E, 0x003B3A3C, 0x00383739, 
        0x00333234, 0x00302F31, 0x002D2C2E, 0x002D2C2E, 0x002C2B2D, 0x00313032, 0x00323133, 0x00323133, 0x00323133, 0x00373638, 0x003E3D3F, 0x00403F41, 0x003F3E40, 0x00403F41, 0x00414042, 0x00484749, 0x00504F51, 0x008E8D8F, 0x007F7E80, 0x00888789, 
        0x007C7B7D, 0x007C7B7D, 0x00737274, 0x007D7C7E, 0x42BDBCBE, 0xEACDCCCE, 0xFFE2E1E3, 0xFFE4E3E5, 0xFFF2F1F3, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF2F2F2, 0xFFEEEEEE, 0xFFE2E2E2, 0xFFD8D8D8, 0xFFCDCDCD, 0x9CAEAEAE, 0x00929292, 0x008F8F8F, 0x008A898B, 0x00848385, 0x00818082, 
        0x007D7C7E, 0x00706F71, 0x005F5E60, 0x00575658, 0x00575658, 0x00565656, 0x00565656, 0x00595959, 0x005C5C5C, 0x005F5F5F, 0x00616161, 0x00656565, 0x006A6A6A, 0x006C6C6C, 0x006F6F6F, 0x00737373, 0x00777777, 0x007B7B7B, 0x00808080, 0x00848484, 
        0x00888888, 0x008D8D8D, 0x00919191, 0x00979797, 0x009C9C9C, 0x00A1A1A1, 0x00A7A7A7, 0x00ADADAD, 0x00B2B2B2, 0x00B9B9B9, 0x00BEBEBE, 0x00C6C6C6, 0x00CCCCCC, 0x00D2D2D2, 0x00DADADA, 0x00E1E1E1, 0x00E7E7E7, 0x00EFEFEF, 0x00F6F6F6, 0x00FEFEFE, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FAFAFA, 0x00F4F4F4, 0x00EEEEEE, 0x00E8E8E8, 0x00E3E3E3, 0x00DCDCDC, 0x00D5D5D5, 0x00D0D0D0, 0x00C9C9C9, 0x00C2C2C2, 0x00BDBDBD, 0x00B6B6B6, 0x00B1B1B1, 0x00AAAAAA, 0x00A4A4A4, 0x009E9E9E, 0x00989898, 0x00919191, 
        0x008C8C8C, 0x00878688, 0x00828183, 0x007C7B7D, 0x00777678, 0x00727173, 0x006D6C6E, 0x00686769, 0x00646365, 0x005F5E60, 0x005C5B5D, 0x00575658, 0x00535254, 0x004F4E50, 0x004B4A4C, 0x00474648, 0x00454446, 0x00414042, 0x003F3E40, 0x003B3A3C, 
        0x00373638, 0x00333234, 0x00302F31, 0x002E2D2F, 0x002D2C2E, 0x002C2B2D, 0x002C2B2D, 0x00302F31, 0x00333234, 0x00343335, 0x00383739, 0x003B3A3C, 0x0039383A, 0x003C3B3D, 0x00403F41, 0x00454446, 0x00807F81, 0x008A898B, 0x008E8D8F, 0x00848385, 
        0x00828183, 0x007F7E80, 0x00787779, 0x00A4A3A5, 0x9CCECDCF, 0xFFD7D6D8, 0xFFE6E5E7, 0xFFE7E6E8, 0xFFF5F4F6, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFF1F1F1, 0xFFE7E7E7, 0xFFDEDEDE, 0xFFD6D6D6, 0xF6BFBFBF, 0x54A1A1A1, 0x00909090, 0x008D8C8E, 0x008A898B, 0x00858486, 
        0x00828183, 0x007B7A7C, 0x0069686A, 0x0059585A, 0x00545355, 0x00585858, 0x005A5A5A, 0x005E5E5E, 0x00626262, 0x00646464, 0x00656565, 0x00696969, 0x006E6E6E, 0x00717171, 0x00747474, 0x00787878, 0x007C7C7C, 0x00808080, 0x00848484, 0x00898989, 
        0x008C8C8C, 0x00919191, 0x00959595, 0x009B9B9B, 0x00A1A1A1, 0x00A6A6A6, 0x00ABABAB, 0x00B2B2B2, 0x00B6B6B6, 0x00BDBDBD, 0x00C2C2C2, 0x00CACACA, 0x00D0D0D0, 0x00D6D6D6, 0x00DDDDDD, 0x00E5E5E5, 0x00EAEAEA, 0x00F2F2F2, 0x00F9F9F9, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FEFEFE, 0x00F9F9F9, 0x00F3F3F3, 0x00EEEEEE, 0x00E7E7E7, 0x00E2E2E2, 0x00DBDBDB, 0x00D5D5D5, 0x00D0D0D0, 0x00CACACA, 0x00C3C3C3, 0x00BEBEBE, 0x00B7B7B7, 0x00B2B2B2, 0x00ACACAC, 0x00A5A5A5, 0x00A0A0A0, 0x009A9A9A, 0x00939393, 
        0x008F8F8F, 0x0089888A, 0x00858486, 0x007F7E80, 0x007A797B, 0x00757476, 0x00706F71, 0x006B6A6C, 0x00676668, 0x00626163, 0x005F5E60, 0x005B5A5C, 0x00565557, 0x00535254, 0x004F4E50, 0x004B4A4C, 0x00484749, 0x00444345, 0x00424143, 0x003F3E40, 
        0x003B3A3C, 0x00373638, 0x00343335, 0x00313032, 0x002F2E30, 0x002C2B2D, 0x00282729, 0x002E2D2F, 0x00363537, 0x00333234, 0x00302F31, 0x00353436, 0x003A393B, 0x003C3B3D, 0x00383739, 0x006A696B, 0x00989799, 0x008D8C8E, 0x00908F91, 0x00888789, 
        0x00858486, 0x007E7D7F, 0x008C8B8D, 0x54C8C7C9, 0xF6CECDCF, 0xFFE1E0E2, 0xFFE6E5E7, 0xFFF0EFF1, 0xFFF2F1F3, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE3E3E3, 0xFFD8D8D8, 0xFFCDCDCD, 0xB2B5B5B5, 0x12979797, 0x00949395, 0x00919092, 0x008B8A8C, 
        0x00878688, 0x00838284, 0x00767577, 0x00626262, 0x00555555, 0x005C5C5C, 0x005E5E5E, 0x00626262, 0x00666666, 0x00686868, 0x00696969, 0x006D6D6D, 0x00717171, 0x00757575, 0x00787878, 0x007C7C7C, 0x00808080, 0x00848484, 0x00888888, 0x008D8D8D, 
        0x00909090, 0x00959595, 0x00999999, 0x009F9F9F, 0x00A4A4A4, 0x00A9A9A9, 0x00AFAFAF, 0x00B5B5B5, 0x00BABABA, 0x00C1C1C1, 0x00C6C6C6, 0x00CDCDCD, 0x00D3D3D3, 0x00D9D9D9, 0x00E0E0E0, 0x00E7E7E7, 0x00EDEDED, 0x00F5F5F5, 0x00FAFAFA, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FDFDFD, 0x00F8F8F8, 0x00F3F3F3, 0x00EEEEEE, 0x00E7E7E7, 0x00E2E2E2, 0x00DBDBDB, 0x00D5D5D5, 0x00D0D0D0, 0x00CACACA, 0x00C3C3C3, 0x00BEBEBE, 0x00B7B7B7, 0x00B3B3B3, 0x00ADADAD, 0x00A7A7A7, 0x00A1A1A1, 0x009B9B9B, 0x00959595, 
        0x00919191, 0x008A898B, 0x00868587, 0x00807F81, 0x007B7A7C, 0x00777678, 0x00727173, 0x006D6C6E, 0x0069686A, 0x00656466, 0x00626163, 0x005D5C5E, 0x0059585A, 0x00555456, 0x00515052, 0x004E4D4F, 0x004B4A4C, 0x00464547, 0x00444345, 0x00414042, 
        0x003E3D3F, 0x003B3A3C, 0x00373638, 0x00343335, 0x00323133, 0x00302F31, 0x002C2B2D, 0x002C2B2D, 0x002E2D2F, 0x002F2E30, 0x00313032, 0x00363537, 0x003A393B, 0x00353436, 0x00515052, 0x00969597, 0x00989799, 0x00989799, 0x008E8D8F, 0x00939294, 
        0x00888789, 0x00868587, 0x12B1B0B2, 0xB2D1D0D2, 0xFFDBDADC, 0xFFE2E1E3, 0xFFEFEEF0, 0xFFF1F0F2, 0xFFF8F7F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF4F4F4, 0xFFF2F2F2, 0xFFE9E9E9, 0xFFDCDCDC, 0xFFD7D7D7, 0xFFC6C6C6, 0x73A8A8A8, 0x00989799, 0x00929193, 0x008C8B8D, 
        0x00888789, 0x00878688, 0x00818082, 0x00727272, 0x00616161, 0x00606060, 0x00616161, 0x00646464, 0x00686868, 0x006B6B6B, 0x006D6D6D, 0x00717171, 0x00757575, 0x00797979, 0x007C7C7C, 0x00808080, 0x00848484, 0x00888888, 0x008C8C8C, 0x00919191, 
        0x00949494, 0x00999999, 0x009D9D9D, 0x00A3A3A3, 0x00A8A8A8, 0x00ADADAD, 0x00B3B3B3, 0x00B9B9B9, 0x00BEBEBE, 0x00C4C4C4, 0x00C9C9C9, 0x00D0D0D0, 0x00D6D6D6, 0x00DCDCDC, 0x00E2E2E2, 0x00EAEAEA, 0x00EFEFEF, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FCFCFC, 0x00F7F7F7, 0x00F2F2F2, 0x00EEEEEE, 0x00E6E6E6, 0x00E1E1E1, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C4C4C4, 0x00BFBFBF, 0x00B8B8B8, 0x00B4B4B4, 0x00AEAEAE, 0x00A8A8A8, 0x00A3A3A3, 0x009D9D9D, 0x00979797, 
        0x00939393, 0x008C8B8D, 0x00888789, 0x00828183, 0x007D7C7E, 0x0079787A, 0x00757476, 0x00706F71, 0x006C6B6D, 0x00676668, 0x00646365, 0x00605F61, 0x005C5B5D, 0x00585759, 0x00545355, 0x00504F51, 0x004E4D4F, 0x004A494B, 0x00474648, 0x00434244, 
        0x00403F41, 0x003E3D3F, 0x003B3A3C, 0x00373638, 0x00353436, 0x00302F31, 0x00333234, 0x002D2C2E, 0x00282729, 0x002E2D2F, 0x00323133, 0x002F2E30, 0x002C2B2D, 0x00403F41, 0x008D8C8E, 0x00A2A1A3, 0x009E9D9F, 0x00979698, 0x00979698, 0x00919092, 
        0x008B8A8C, 0x009F9EA0, 0x73C8C7C9, 0xFFD2D1D3, 0xFFE3E2E4, 0xFFEAE9EB, 0xFFF0EFF1, 0xFFF1F0F2, 0xFFFDFCFE, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFEDEDED, 0xFFE5E5E5, 0xFFDEDEDE, 0xFFD0D0D0, 0xD6BFBFBF, 0x3BA1A0A2, 0x00959496, 0x008E8D8F, 
        0x008D8C8E, 0x008A8A8A, 0x00878787, 0x00818181, 0x00747474, 0x00666666, 0x00666666, 0x00676767, 0x006B6B6B, 0x006F6F6F, 0x00727272, 0x00767676, 0x00797979, 0x007D7D7D, 0x00808080, 0x00848484, 0x00888888, 0x008C8C8C, 0x00909090, 0x00959595, 
        0x00989898, 0x009D9D9D, 0x00A1A1A1, 0x00A7A7A7, 0x00ACACAC, 0x00B1B1B1, 0x00B7B7B7, 0x00BDBDBD, 0x00C2C2C2, 0x00C8C8C8, 0x00CDCDCD, 0x00D4D4D4, 0x00DADADA, 0x00DFDFDF, 0x00E5E5E5, 0x00EDEDED, 0x00F2F2F2, 0x00F9F9F9, 0x00FDFDFD, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FBFBFB, 0x00F6F6F6, 0x00F1F1F1, 0x00EDEDED, 0x00E5E5E5, 0x00E1E1E1, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C4C4C4, 0x00C0C0C0, 0x00B9B9B9, 0x00B5B5B5, 0x00AFAFAF, 0x00AAAAAA, 0x00A5A5A5, 0x009F9F9F, 0x00999999, 
        0x00959595, 0x008E8D8F, 0x008A898B, 0x00858486, 0x00807F81, 0x007C7B7D, 0x00777678, 0x00727173, 0x006F6E70, 0x006A696B, 0x00676668, 0x00636264, 0x005F5E60, 0x005B5A5C, 0x00575658, 0x00545355, 0x00515052, 0x004D4C4E, 0x004A494B, 0x00464547, 
        0x00434244, 0x00414042, 0x003E3D3F, 0x003A393B, 0x00383739, 0x00313032, 0x00363537, 0x00302F31, 0x002C2B2D, 0x00313032, 0x002C2B2D, 0x002B2A2C, 0x0039383A, 0x0079787A, 0x00AAA9AB, 0x00A9A8AA, 0x009F9EA0, 0x009C9B9D, 0x00969597, 0x00959496, 
        0x009A999B, 0x3BBDBCBE, 0xD6CFCED0, 0xFFDAD9DB, 0xFFE4E3E5, 0xFFF3F2F4, 0xFFEFEEF0, 0xFFF6F5F7, 0xFFFAF9FB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFFCFCFC, 0xFFF4F4F4, 0xFFEEEEEE, 0xFFEDEDED, 0xFFE1E1E1, 0xFFD2D2D2, 0xFFD0D0D0, 0xA1B2B1B3, 0x089E9D9F, 0x00979698, 
        0x00969597, 0x008D8D8D, 0x00898989, 0x00888888, 0x00818181, 0x006D6D6D, 0x006B6B6B, 0x006B6B6B, 0x006E6E6E, 0x00727272, 0x00757575, 0x00797979, 0x007B7B7B, 0x007F7F7F, 0x00828282, 0x00868686, 0x008B8B8B, 0x008E8E8E, 0x00939393, 0x00989898, 
        0x009B9B9B, 0x00A0A0A0, 0x00A4A4A4, 0x00A9A9A9, 0x00AFAFAF, 0x00B4B4B4, 0x00BABABA, 0x00C0C0C0, 0x00C4C4C4, 0x00CBCBCB, 0x00D0D0D0, 0x00D6D6D6, 0x00DCDCDC, 0x00E1E1E1, 0x00E8E8E8, 0x00EFEFEF, 0x00F4F4F4, 0x00FBFBFB, 0x00FEFEFE, 0x00FFFFFF, 
        0x00FEFEFE, 0x00FAFAFA, 0x00F5F5F5, 0x00F0F0F0, 0x00ECECEC, 0x00E5E5E5, 0x00E0E0E0, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C5C5C5, 0x00C0C0C0, 0x00BABABA, 0x00B6B6B6, 0x00B0B0B0, 0x00ABABAB, 0x00A6A6A6, 0x00A1A1A1, 0x009B9B9B, 
        0x00979797, 0x00908F91, 0x008C8B8D, 0x00878688, 0x00828183, 0x007E7D7F, 0x0079787A, 0x00747375, 0x00717072, 0x006C6B6D, 0x0069686A, 0x00656466, 0x00616062, 0x005D5C5E, 0x005A595B, 0x00565557, 0x00535254, 0x00504F51, 0x004D4C4E, 0x00484749, 
        0x00454446, 0x00424143, 0x003F3E40, 0x003C3B3D, 0x0039383A, 0x00363537, 0x00373638, 0x002F2E30, 0x00302F31, 0x00323133, 0x00242325, 0x00323133, 0x00616062, 0x00B5B4B6, 0x00A9A8AA, 0x00A7A6A8, 0x00ACABAD, 0x009A999B, 0x009F9EA0, 0x009B9A9C, 
        0x08B2B1B3, 0xA1D0CFD1, 0xFFD5D4D6, 0xFFE0DFE1, 0xFFE9E8EA, 0xFFF1F0F2, 0xFFF8F7F9, 0xFFFAF9FB, 0xFFF7F6F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF0F0F0, 0xFFE9E9E9, 0xFFDEDEDE, 0xFFD6D6D6, 0xFFC5C5C5, 0x72AFAFAF, 0x009A9A9A, 
        0x00949494, 0x00939393, 0x008F8F8F, 0x008A8A8A, 0x00888888, 0x00808080, 0x00757575, 0x006F6F6F, 0x00737373, 0x00787779, 0x007A797B, 0x007D7C7E, 0x00818082, 0x00858585, 0x00878787, 0x008A8A8A, 0x008E8E8E, 0x00929292, 0x00979797, 0x009C9C9C, 
        0x009F9F9F, 0x00A4A4A4, 0x00A8A8A8, 0x00AEAEAE, 0x00B3B3B3, 0x00B8B8B8, 0x00BDBDBD, 0x00C4C4C4, 0x00C8C8C8, 0x00CDCDCD, 0x00D2D2D2, 0x00D9D9D9, 0x00DFDFDF, 0x00E5E5E5, 0x00EBEBEB, 0x00F0F0F0, 0x00F4F4F4, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FDFDFD, 0x00F9F9F9, 0x00F5F5F5, 0x00EFEFEF, 0x00EAEAEA, 0x00E4E4E4, 0x00E0E0E0, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C5C5C5, 0x00C1C1C1, 0x00BBBBBB, 0x00B7B7B7, 0x00B1B1B1, 0x00ACACAC, 0x00A7A7A7, 0x00A2A2A2, 0x009C9C9C, 
        0x00989898, 0x00939294, 0x008F8E90, 0x0089888A, 0x00848385, 0x00807F81, 0x007C7B7D, 0x00777678, 0x00737274, 0x00706F71, 0x006D6C6E, 0x00686769, 0x00646365, 0x00605F61, 0x005D5C5E, 0x0059585A, 0x00565557, 0x00535254, 0x004F4E50, 0x0049484A, 
        0x00464547, 0x00464547, 0x00414042, 0x003D3C3E, 0x003F3E40, 0x003D3C3E, 0x00363537, 0x00363537, 0x00363537, 0x002D2C2E, 0x002D2C2E, 0x00565557, 0x00B8B7B9, 0x00B5B5B5, 0x00AFAFAF, 0x00ACACAC, 0x00AAAAAA, 0x00A2A2A2, 0x009E9E9E, 0x00B0B0B0, 
        0x72C8C8C8, 0xFFD6D6D6, 0xFFDEDEDE, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE3E3E3, 0xFFDBDBDB, 0xFFD1D1D1, 0xDCC0C0C0, 0x49AAAAAA, 
        0x009C9C9C, 0x00969696, 0x00939393, 0x008F8F8F, 0x008C8C8C, 0x00868686, 0x007F7F7F, 0x00777777, 0x00747474, 0x00787779, 0x007C7B7D, 0x00807F81, 0x00828183, 0x00868686, 0x00898989, 0x008D8D8D, 0x00919191, 0x00969696, 0x009A9A9A, 0x009E9E9E, 
        0x00A1A1A1, 0x00A7A7A7, 0x00ABABAB, 0x00B1B1B1, 0x00B6B6B6, 0x00BBBBBB, 0x00C0C0C0, 0x00C6C6C6, 0x00CBCBCB, 0x00D0D0D0, 0x00D4D4D4, 0x00DBDBDB, 0x00E1E1E1, 0x00E7E7E7, 0x00ECECEC, 0x00F3F3F3, 0x00F7F7F7, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FDFDFD, 0x00F9F9F9, 0x00F4F4F4, 0x00EEEEEE, 0x00EAEAEA, 0x00E4E4E4, 0x00E0E0E0, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C5C5C5, 0x00C1C1C1, 0x00BCBCBC, 0x00B8B8B8, 0x00B2B2B2, 0x00ADADAD, 0x00A8A8A8, 0x00A3A3A3, 0x009D9D9D, 
        0x00999999, 0x00949395, 0x00908F91, 0x008A898B, 0x00868587, 0x00828183, 0x007D7C7E, 0x00787779, 0x00757476, 0x00717072, 0x006E6D6F, 0x006A696B, 0x00656466, 0x00626163, 0x005E5D5F, 0x005A595B, 0x00585759, 0x00535254, 0x00545355, 0x00515052, 
        0x004A494B, 0x00454446, 0x00444345, 0x00444345, 0x00434244, 0x003C3B3D, 0x003E3D3F, 0x00373638, 0x00313032, 0x00333234, 0x00504F51, 0x00B6B5B7, 0x00BCBBBD, 0x00BABABA, 0x00B6B6B6, 0x00B1B1B1, 0x00ABABAB, 0x00A6A6A6, 0x00ACACAC, 0x49BFBFBF, 
        0xDCD2D2D2, 0xFFDBDBDB, 0xFFE3E3E3, 0xFFEDEDED, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF1F1F1, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFDADADA, 0xFFCFCFCF, 0xB6BCBCBC, 
        0x26A7A7A7, 0x009A9A9A, 0x00969696, 0x00939393, 0x00909090, 0x008C8C8C, 0x00888888, 0x00818082, 0x007A797B, 0x007B7A7C, 0x00807F81, 0x00848385, 0x00858486, 0x00898989, 0x008C8C8C, 0x00919191, 0x00959595, 0x00999999, 0x009E9E9E, 0x00A2A2A2, 
        0x00A5A5A5, 0x00ABABAB, 0x00AFAFAF, 0x00B5B5B5, 0x00BABABA, 0x00BEBEBE, 0x00C4C4C4, 0x00CACACA, 0x00CECECE, 0x00D4D4D4, 0x00D8D8D8, 0x00DEDEDE, 0x00E4E4E4, 0x00E9E9E9, 0x00EFEFEF, 0x00F6F6F6, 0x00FAFAFA, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FCFCFC, 0x00F8F8F8, 0x00F3F3F3, 0x00EEEEEE, 0x00E9E9E9, 0x00E3E3E3, 0x00DFDFDF, 0x00DADADA, 0x00D5D5D5, 0x00D0D0D0, 0x00CBCBCB, 0x00C6C6C6, 0x00C2C2C2, 0x00BDBDBD, 0x00B9B9B9, 0x00B3B3B3, 0x00AEAEAE, 0x00AAAAAA, 0x00A5A5A5, 0x009F9F9F, 
        0x009B9B9B, 0x00969597, 0x00929193, 0x008C8B8D, 0x00888789, 0x00848385, 0x007F7E80, 0x007B7A7C, 0x00777678, 0x00737274, 0x00706F71, 0x006C6B6D, 0x00686769, 0x00646365, 0x00616062, 0x005D5C5E, 0x005A595B, 0x00575658, 0x00525153, 0x00504F51, 
        0x004F4E50, 0x004B4A4C, 0x0049484A, 0x00454446, 0x003D3C3E, 0x00444345, 0x00353436, 0x003E3D3F, 0x003C3B3D, 0x0049484A, 0x00BCBBBD, 0x00CAC9CB, 0x00C2C1C3, 0x00BDBDBD, 0x00BBBBBB, 0x00B5B5B5, 0x00ADADAD, 0x00AFAFAF, 0x26BDBDBD, 0xB6CECECE, 
        0xFFDADADA, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFF1F1F1, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF0F0F0, 0xFFEAEAEA, 0xFFDFDFDF, 0xFFD8D8D8, 0xFFC9C9C9, 
        0x96B5B5B5, 0x08A4A4A4, 0x009A9A9A, 0x00969696, 0x00959595, 0x00909090, 0x008D8D8D, 0x00888789, 0x00838284, 0x00818082, 0x00838284, 0x00878688, 0x00888789, 0x008D8D8D, 0x00919191, 0x00959595, 0x00999999, 0x009C9C9C, 0x00A0A0A0, 0x00A5A5A5, 
        0x00A9A9A9, 0x00AFAFAF, 0x00B3B3B3, 0x00B8B8B8, 0x00BDBDBD, 0x00C2C2C2, 0x00C7C7C7, 0x00CDCDCD, 0x00D1D1D1, 0x00D8D8D8, 0x00DCDCDC, 0x00E1E1E1, 0x00E6E6E6, 0x00ECECEC, 0x00F2F2F2, 0x00F8F8F8, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FBFBFB, 0x00F7F7F7, 0x00F2F2F2, 0x00EDEDED, 0x00E9E9E9, 0x00E3E3E3, 0x00DFDFDF, 0x00D9D9D9, 0x00D5D5D5, 0x00D0D0D0, 0x00CCCCCC, 0x00C6C6C6, 0x00C2C2C2, 0x00BDBDBD, 0x00B9B9B9, 0x00B4B4B4, 0x00AFAFAF, 0x00ABABAB, 0x00A6A6A6, 0x00A0A0A0, 
        0x009C9C9C, 0x00979698, 0x00939294, 0x008E8D8F, 0x0089888A, 0x00868587, 0x00818082, 0x007D7C7E, 0x0079787A, 0x00757476, 0x00727173, 0x006E6D6F, 0x006A696B, 0x00666567, 0x00636264, 0x005F5E60, 0x005C5B5D, 0x005C5B5D, 0x00515052, 0x004F4E50, 
        0x00535254, 0x004F4E50, 0x0049484A, 0x00464547, 0x00434244, 0x00414042, 0x003F3E40, 0x00383739, 0x00555456, 0x00C0BFC1, 0x00CAC9CB, 0x00CDCCCE, 0x00BDBCBE, 0x00C0C0C0, 0x00BDBDBD, 0x00B8B8B8, 0x00B6B6B6, 0x08BCBCBC, 0x96CBCBCB, 0xFFD8D8D8, 
        0xFFDFDFDF, 0xFFEAEAEA, 0xFFF0F0F0, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF3F3F3, 0xFFEFEFEF, 0xFFE6E6E6, 0xFFE0E0E0, 0xFFD5D5D5, 
        0xFFC7C7C7, 0x7CB4B4B4, 0x00A3A3A3, 0x00999999, 0x00979797, 0x00959496, 0x008F8E90, 0x008A898B, 0x0089888A, 0x00868587, 0x00848385, 0x00888789, 0x008E8D8F, 0x00929292, 0x00959595, 0x00999999, 0x009C9C9C, 0x009F9F9F, 0x00A3A3A3, 0x00A8A8A8, 
        0x00ADADAD, 0x00B2B2B2, 0x00B6B6B6, 0x00BBBBBB, 0x00C0C0C0, 0x00C4C4C4, 0x00C9C9C9, 0x00CFCFCF, 0x00D3D3D3, 0x00DADADA, 0x00DEDEDE, 0x00E4E4E4, 0x00E9E9E9, 0x00EEEEEE, 0x00F3F3F3, 0x00FAFAFA, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 
        0x00FAFAFA, 0x00F5F5F5, 0x00F1F1F1, 0x00ECECEC, 0x00E8E8E8, 0x00E3E3E3, 0x00DFDFDF, 0x00D9D9D9, 0x00D5D5D5, 0x00D0D0D0, 0x00CCCCCC, 0x00C6C6C6, 0x00C2C2C2, 0x00BDBDBD, 0x00B9B9B9, 0x00B4B4B4, 0x00AFAFAF, 0x00ABABAB, 0x00A7A7A7, 0x00A1A1A1, 
        0x009D9D9D, 0x00989799, 0x00959496, 0x008F8E90, 0x008B8A8C, 0x00878688, 0x00838284, 0x007F7E80, 0x007B7A7C, 0x00777678, 0x00747375, 0x00706F71, 0x006C6B6D, 0x0069686A, 0x00656466, 0x00616062, 0x005F5E60, 0x005D5C5E, 0x00585759, 0x00555456, 
        0x00535254, 0x004E4D4F, 0x004A494B, 0x004B4A4C, 0x004C4B4D, 0x00403F41, 0x00424143, 0x0059585A, 0x00C0BFC1, 0x00D1D0D2, 0x00D6D5D7, 0x00C9C8CA, 0x00C9C8CA, 0x00C7C7C7, 0x00C0C0C0, 0x00BCBCBC, 0x00C0C0C0, 0x7CCACACA, 0xFFD5D5D5, 0xFFDFDFDF, 
        0xFFE7E7E7, 0xFFEFEFEF, 0xFFF3F3F3, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFEDEDED, 0xFFE7E7E7, 0xFFDFDFDF, 
        0xFFD4D4D4, 0xF0C4C4C4, 0x68AFAFAF, 0x009F9F9F, 0x00989898, 0x009B9A9C, 0x00939294, 0x008D8C8E, 0x008B8A8C, 0x00888789, 0x00848385, 0x00888789, 0x00919092, 0x00949494, 0x00989898, 0x009C9C9C, 0x00A0A0A0, 0x00A2A2A2, 0x00A6A6A6, 0x00ACACAC, 
        0x00B0B0B0, 0x00B5B5B5, 0x00B9B9B9, 0x00BEBEBE, 0x00C3C3C3, 0x00C7C7C7, 0x00CCCCCC, 0x00D2D2D2, 0x00D6D6D6, 0x00DCDCDC, 0x00E0E0E0, 0x00E6E6E6, 0x00EBEBEB, 0x00F0F0F0, 0x00F5F5F5, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 
        0x00F9F9F9, 0x00F4F4F4, 0x00F0F0F0, 0x00ECECEC, 0x00E8E8E8, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D4D4D4, 0x00D1D1D1, 0x00CCCCCC, 0x00C7C7C7, 0x00C3C3C3, 0x00BDBDBD, 0x00BABABA, 0x00B4B4B4, 0x00B0B0B0, 0x00ACACAC, 0x00A8A8A8, 0x00A2A2A2, 
        0x009F9F9F, 0x009A999B, 0x00969597, 0x00919092, 0x008D8C8E, 0x0089888A, 0x00858486, 0x00818082, 0x007D7C7E, 0x0079787A, 0x00767577, 0x00727173, 0x006E6D6F, 0x006B6A6C, 0x00676668, 0x00646365, 0x00616062, 0x005B5A5C, 0x005E5D5F, 0x00575658, 
        0x00515052, 0x00535254, 0x00525153, 0x00484749, 0x00414042, 0x004A494B, 0x00605F61, 0x00D2D1D3, 0x00DCDBDD, 0x00D7D6D8, 0x00D1D0D2, 0x00D2D1D3, 0x00CDCCCE, 0x00CBCBCB, 0x00C2C2C2, 0x00BFBFBF, 0x68C8C8C8, 0xF0D3D3D3, 0xFFDBDBDB, 0xFFE4E4E4, 
        0xFFEEEEEE, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF2F3F1, 0xFFEDEEEC, 0xFFE5E5E5, 
        0xFFDDDDDD, 0xFFD2D2D2, 0xDFC2C2C2, 0x5AAFAFAF, 0x00A0A0A0, 0x009E9D9F, 0x0099989A, 0x00949395, 0x008F8E90, 0x008A898B, 0x00878688, 0x00888789, 0x008B8A8C, 0x00949494, 0x00999999, 0x009F9F9F, 0x00A4A4A4, 0x00A6A6A6, 0x00AAAAAA, 0x00AFAFAF, 
        0x00B3B3B3, 0x00B8B8B8, 0x00BCBCBC, 0x00C1C1C1, 0x00C6C6C6, 0x00CACACA, 0x00CFCFCF, 0x00D4D4D4, 0x00D8D8D8, 0x00DEDEDE, 0x00E2E2E2, 0x00E8E8E8, 0x00EDEDED, 0x00F2F2F2, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 
        0x00F8F8F8, 0x00F3F3F3, 0x00EFEFEF, 0x00EBEBEB, 0x00E7E7E7, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D4D4D4, 0x00D1D1D1, 0x00CCCCCC, 0x00C7C7C7, 0x00C3C3C3, 0x00BEBEBE, 0x00BBBBBB, 0x00B5B5B5, 0x00B1B1B1, 0x00ADADAD, 0x00A9A9A9, 0x00A4A4A4, 
        0x00A0A0A0, 0x009C9B9D, 0x00989799, 0x00939294, 0x008F8E90, 0x008B8A8C, 0x00878688, 0x00838284, 0x00807F81, 0x007B7A7C, 0x00787779, 0x00747375, 0x00706F71, 0x006D6C6E, 0x006A696B, 0x00666567, 0x00636264, 0x005C5B5D, 0x005E5D5F, 0x00555456, 
        0x00525153, 0x0059585A, 0x00535254, 0x004C4B4D, 0x00545355, 0x00767577, 0x00E1E0E2, 0x00E0DFE1, 0x00E4E3E5, 0x00E0DFE1, 0x00D5D4D6, 0x00D0CFD1, 0x00D1D0D2, 0x00CBCBCB, 0x00C5C5C5, 0x5AC6C6C6, 0xDFD1D1D1, 0xFFDCDCDC, 0xFFE3E3E3, 0xFFEBEBEB, 
        0xFFF2F2F2, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF4F5F3, 0xFFF2F3F1, 0xFFEBEBEB, 
        0xFFE2E2E2, 0xFFDCDCDC, 0xFFD4D4D4, 0xD4C0C0C0, 0x51ABABAB, 0x009E9D9F, 0x009E9D9F, 0x009B9A9C, 0x00949395, 0x008E8D8F, 0x008A898B, 0x00878688, 0x00838284, 0x00939393, 0x00999999, 0x00A1A1A1, 0x00A7A7A7, 0x00AAAAAA, 0x00ADADAD, 0x00B1B1B1, 
        0x00B5B5B5, 0x00BBBBBB, 0x00BEBEBE, 0x00C3C3C3, 0x00C8C8C8, 0x00CCCCCC, 0x00D1D1D1, 0x00D6D6D6, 0x00DBDBDB, 0x00DFDFDF, 0x00E3E3E3, 0x00E9E9E9, 0x00EFEFEF, 0x00F3F3F3, 0x00F8F8F8, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 
        0x00F7F7F7, 0x00F3F3F3, 0x00EFEFEF, 0x00EBEBEB, 0x00E7E7E7, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D4D4D4, 0x00D1D1D1, 0x00CCCCCC, 0x00C7C7C7, 0x00C3C3C3, 0x00BFBFBF, 0x00BBBBBB, 0x00B6B6B6, 0x00B2B2B2, 0x00AEAEAE, 0x00AAAAAA, 0x00A5A5A5, 
        0x00A1A1A1, 0x009D9C9E, 0x0099989A, 0x00949395, 0x00908F91, 0x008D8C8E, 0x0089888A, 0x00848385, 0x00818082, 0x007D7C7E, 0x007A797B, 0x00767577, 0x00727173, 0x006F6E70, 0x006B6A6C, 0x00686769, 0x00656466, 0x00605F61, 0x00616062, 0x00585759, 
        0x00575658, 0x00575658, 0x004A494B, 0x005C5B5D, 0x008D8C8E, 0x00EEEDEF, 0x00E7E6E8, 0x00EDECEE, 0x00DEDDDF, 0x00E0DFE1, 0x00DFDEE0, 0x00D5D4D6, 0x00D8D7D9, 0x00C9C9C9, 0x51C9C9C9, 0xD4CECECE, 0xFFDADADA, 0xFFE5E5E5, 0xFFECECEC, 0xFFF1F1F1, 
        0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFEFEFEF, 
        0xFFE9E9E9, 0xFFE3E3E3, 0xFFDBDBDB, 0xFFD0D0D0, 0xCEC6C6C6, 0x4EA9A9A9, 0x00A2A2A2, 0x009C9C9C, 0x00969696, 0x00919191, 0x00919191, 0x008E8E8E, 0x00868686, 0x00818181, 0x00909090, 0x00A1A1A1, 0x00AAAAAA, 0x00ACACAC, 0x00AEAEAE, 0x00B5B5B5, 
        0x00BBBBBB, 0x00C0C0C0, 0x00C0C0C0, 0x00C4C4C4, 0x00CBCBCB, 0x00D1D1D1, 0x00D4D4D4, 0x00D7D7D7, 0x00DBDBDB, 0x00E2E2E2, 0x00E6E6E6, 0x00EBEBEB, 0x00EFEFEF, 0x00F5F5F5, 0x00FBFBFB, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FBFBFB, 
        0x00F7F7F7, 0x00F3F3F3, 0x00EEEEEE, 0x00E9E9E9, 0x00E7E7E7, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D5D5D5, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C4C4C4, 0x00BFBFBF, 0x00BCBCBC, 0x00B7B7B7, 0x00B3B3B3, 0x00AFAFAF, 0x00ABABAB, 0x00A7A7A7, 
        0x00A4A4A4, 0x009D9C9E, 0x009A999B, 0x00969597, 0x00919092, 0x008D8C8E, 0x0089888A, 0x00858486, 0x00828183, 0x007E7D7F, 0x007C7B7D, 0x0079787A, 0x00757476, 0x00717072, 0x006E6D6F, 0x006A696B, 0x00676668, 0x00636363, 0x005E5E5E, 0x00626262, 
        0x00535353, 0x00585858, 0x00616161, 0x00BBBBBB, 0x00F5F5F5, 0x00EFEFEF, 0x00EFEFEF, 0x00EBEBEB, 0x00E5E5E5, 0x00E3E3E3, 0x00E1E1E1, 0x00DADADA, 0x00D0D0D0, 0x4EC8C8C8, 0xCED1D1D1, 0xFFDCDCDC, 0xFFE4E4E4, 0xFFEAEAEA, 0xFFF1F1F1, 0xFFF6F6F6, 
        0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF5F5F5, 
        0xFFEFEFEF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFD9D9D9, 0xFFD0D0D0, 0xCEC3C3C3, 0x51ADADAD, 0x009E9E9E, 0x009D9D9D, 0x00999999, 0x00929292, 0x008F8F8F, 0x008E8E8E, 0x008B8B8B, 0x00818181, 0x00878787, 0x009F9F9F, 0x00B3B3B3, 0x00B7B7B7, 0x00B6B6B6, 
        0x00B8B8B8, 0x00C2C2C2, 0x00C3C3C3, 0x00C8C8C8, 0x00CECECE, 0x00D2D2D2, 0x00D4D4D4, 0x00DCDCDC, 0x00E4E4E4, 0x00E3E3E3, 0x00E7E7E7, 0x00ECECEC, 0x00F1F1F1, 0x00F7F7F7, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FBFBFB, 
        0x00F7F7F7, 0x00F2F2F2, 0x00EDEDED, 0x00E9E9E9, 0x00E7E7E7, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D5D5D5, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C4C4C4, 0x00BFBFBF, 0x00BCBCBC, 0x00B8B8B8, 0x00B4B4B4, 0x00B0B0B0, 0x00ACACAC, 0x00A7A7A7, 
        0x00A4A4A4, 0x009F9EA0, 0x009B9A9C, 0x00979698, 0x00929193, 0x008F8E90, 0x008B8A8C, 0x00878688, 0x00848385, 0x00818082, 0x007B7A7C, 0x00747375, 0x00727173, 0x00737274, 0x00727173, 0x006C6B6D, 0x00676668, 0x00696969, 0x00646464, 0x005A5A5A, 
        0x00616161, 0x00757575, 0x00E8E8E8, 0x00F6F6F6, 0x00FFFFFF, 0x00F8F8F8, 0x00F5F5F5, 0x00F0F0F0, 0x00ECECEC, 0x00E8E8E8, 0x00E1E1E1, 0x00D3D3D3, 0x51C7C7C7, 0xCED0D0D0, 0xFFD9D9D9, 0xFFE2E2E2, 0xFFE9E9E9, 0xFFEFEFEF, 0xFFF4F4F4, 0xFFF8F8F8, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF7F7F7, 
        0xFFF4F4F4, 0xFFF0F0F0, 0xFFEBEBEB, 0xFFE2E2E2, 0xFFDADADA, 0xFFD2D2D2, 0xD4C1C1C1, 0x5AAFAFAF, 0x00A2A2A2, 0x00999999, 0x00989898, 0x00959595, 0x00909090, 0x008B8B8B, 0x00838383, 0x007F7F7F, 0x00888888, 0x00999999, 0x00ACACAC, 0x00BBBBBB, 
        0x00C3C3C3, 0x00C0C0C0, 0x00C7C7C7, 0x00CCCCCC, 0x00CCCCCC, 0x00D1D1D1, 0x00D9D9D9, 0x00DCDCDC, 0x00D9D9D9, 0x00E5E5E5, 0x00EAEAEA, 0x00EFEFEF, 0x00F4F4F4, 0x00F9F9F9, 0x00FEFEFE, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00FAFAFA, 
        0x00F6F6F6, 0x00F2F2F2, 0x00EDEDED, 0x00E9E9E9, 0x00E6E6E6, 0x00E1E1E1, 0x00DEDEDE, 0x00D9D9D9, 0x00D5D5D5, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C5C5C5, 0x00BFBFBF, 0x00BCBCBC, 0x00B8B8B8, 0x00B4B4B4, 0x00B0B0B0, 0x00ACACAC, 0x00A8A8A8, 
        0x00A5A5A5, 0x00A09FA1, 0x009D9C9E, 0x00989799, 0x00949395, 0x00908F91, 0x008C8B8D, 0x00888789, 0x00858486, 0x007D7C7E, 0x007E7D7F, 0x007E7D7F, 0x007A797B, 0x00737274, 0x006E6D6F, 0x006D6C6E, 0x006E6D6F, 0x00646464, 0x00666666, 0x00636363, 
        0x00AAAAAA, 0x00F9F9F9, 0x00FBFBFB, 0x00FFFFFF, 0x00F9F9F9, 0x00FCFCFC, 0x00F5F5F5, 0x00F3F3F3, 0x00F4F4F4, 0x00E9E9E9, 0x00D4D4D4, 0x5ACBCBCB, 0xD4CFCFCF, 0xFFDBDBDB, 0xFFE2E2E2, 0xFFEAEAEA, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 
        0xFFF6F6F6, 0xFFF4F4F4, 0xFFF0F0F0, 0xFFE9E9E9, 0xFFE2E2E2, 0xFFD8D8D8, 0xFFD2D2D2, 0xDFC5C5C5, 0x68B1B1B1, 0x00A1A1A1, 0x009C9C9C, 0x009A9A9A, 0x00919191, 0x008D8D8D, 0x008E8E8E, 0x00898989, 0x007F7F7F, 0x007E7E7E, 0x008F8F8F, 0x00AAAAAA, 
        0x00BEBEBE, 0x00C8C8C8, 0x00C5C5C5, 0x00CCCCCC, 0x00D7D7D7, 0x00D8D8D8, 0x00D5D5D5, 0x00DDDDDD, 0x00EBEBEB, 0x00E7E7E7, 0x00ECECEC, 0x00F2F2F2, 0x00F6F6F6, 0x00FBFBFB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FCFCFC, 0x00F9F9F9, 
        0x00F5F5F5, 0x00F1F1F1, 0x00EDEDED, 0x00E8E8E8, 0x00E5E5E5, 0x00E1E1E1, 0x00DDDDDD, 0x00D8D8D8, 0x00D5D5D5, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C5C5C5, 0x00C0C0C0, 0x00BDBDBD, 0x00B9B9B9, 0x00B5B5B5, 0x00B1B1B1, 0x00ADADAD, 0x00A9A9A9, 
        0x00A6A6A6, 0x00A1A0A2, 0x009E9D9F, 0x0099989A, 0x00959496, 0x00929193, 0x008E8D8F, 0x008A898B, 0x00878688, 0x00858486, 0x00807F81, 0x007A797B, 0x0079787A, 0x00787779, 0x00747375, 0x006C6B6D, 0x00666567, 0x006A6A6A, 0x00838383, 0x00CECECE, 
        0x00E3E3E3, 0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FDFDFD, 0x00FCFCFC, 0x00F8F8F8, 0x00ECECEC, 0x00D8D8D8, 0x68CACACA, 0xDFCFCFCF, 0xFFDCDCDC, 0xFFE3E3E3, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE5E5E5, 0xFFDADADA, 0xFFD3D3D3, 0xF0CACACA, 0x7CB8B8B8, 0x08A5A5A5, 0x009C9C9C, 0x00989898, 0x00979797, 0x008F8F8F, 0x008B8B8B, 0x008A8A8A, 0x00828282, 0x007D7D7D, 0x00878787, 
        0x00989898, 0x00C0C0C0, 0x00C7C7C7, 0x00CFCFCF, 0x00D3D3D3, 0x00D9D9D9, 0x00DFDFDF, 0x00E2E2E2, 0x00E2E2E2, 0x00E9E9E9, 0x00EEEEEE, 0x00F3F3F3, 0x00F8F8F8, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FFFFFF, 0x00FCFCFC, 0x00F7F7F7, 
        0x00F4F4F4, 0x00F0F0F0, 0x00ECECEC, 0x00E7E7E7, 0x00E4E4E4, 0x00E1E1E1, 0x00DDDDDD, 0x00D8D8D8, 0x00D4D4D4, 0x00D1D1D1, 0x00CDCDCD, 0x00C9C9C9, 0x00C5C5C5, 0x00C1C1C1, 0x00BEBEBE, 0x00BABABA, 0x00B6B6B6, 0x00B2B2B2, 0x00AEAEAE, 0x00AAAAAA, 
        0x00A7A7A7, 0x00A2A1A3, 0x009F9EA0, 0x009A999B, 0x00969597, 0x00939294, 0x008F8E90, 0x008B8A8C, 0x00888789, 0x00878688, 0x00818082, 0x007B7A7C, 0x00777678, 0x00747375, 0x00737274, 0x00767577, 0x007A797B, 0x009D9D9D, 0x00D0D0D0, 0x00DDDDDD, 
        0x00E9E9E9, 0x00EFEFEF, 0x00F3F3F3, 0x00F5F5F5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F0F0F0, 0x08D5D5D5, 0x7CC8C8C8, 0xF0D2D2D2, 0xFFDEDEDE, 0xFFE0E0E0, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFF0F0F0, 0xFFECECEC, 0xFFE4E4E4, 0xFFDEDEDE, 0xFFD7D7D7, 0xFFCACACA, 0x96BBBBBB, 0x26ABABAB, 0x009C9C9C, 0x00999999, 0x00939393, 0x008E8E8E, 0x008E8E8E, 0x008A8A8A, 0x00818181, 0x007B7B7B, 
        0x007B7B7B, 0x00828282, 0x00A9A9A9, 0x00CDCDCD, 0x00D7D7D7, 0x00D8D8D8, 0x00DFDFDF, 0x00E5E5E5, 0x00E4E4E4, 0x00ECECEC, 0x00F0F0F0, 0x00F5F5F5, 0x00F9F9F9, 0x00FCFCFC, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FEFEFE, 0x00FBFBFB, 0x00F6F6F6, 
        0x00F2F2F2, 0x00EFEFEF, 0x00ECECEC, 0x00E7E7E7, 0x00E3E3E3, 0x00E0E0E0, 0x00DDDDDD, 0x00D8D8D8, 0x00D4D4D4, 0x00D1D1D1, 0x00CECECE, 0x00C9C9C9, 0x00C6C6C6, 0x00C1C1C1, 0x00BEBEBE, 0x00BABABA, 0x00B6B6B6, 0x00B3B3B3, 0x00AFAFAF, 0x00ABABAB, 
        0x00A8A8A8, 0x00A3A2A4, 0x00A09FA1, 0x009C9B9D, 0x00989799, 0x00949395, 0x00908F91, 0x008C8B8D, 0x008A898B, 0x00818082, 0x00848385, 0x00848385, 0x007D7C7E, 0x00767577, 0x007C7B7D, 0x00949395, 0x00ACABAD, 0x00CACACA, 0x00CECECE, 0x00D7D7D7, 
        0x00DDDDDD, 0x00E4E4E4, 0x00F0F0F0, 0x00FCFCFC, 0x00F1F1F1, 0x00FEFEFE, 0x00E9E9E9, 0x26D2D2D2, 0x96CACACA, 0xFFD1D1D1, 0xFFDDDDDD, 0xFFE5E5E5, 0xFFE8E8E8, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF4F4F4, 0xFFEFEFEF, 0xFFEEEEEE, 0xFFE9E9E9, 0xFFDEDEDE, 0xFFD5D5D5, 0xFFD1D1D1, 0xB6C2C2C2, 0x49ADADAD, 0x009E9E9E, 0x009C9C9C, 0x00969696, 0x008D8D8D, 0x008A8A8A, 0x00898989, 0x00848484, 
        0x007E7E7E, 0x007A7A7A, 0x00747474, 0x00858585, 0x00B0B0B0, 0x00D4D4D4, 0x00E0E0E0, 0x00E5E5E5, 0x00EDEDED, 0x00EEEEEE, 0x00F2F2F2, 0x00F6F6F6, 0x00FAFAFA, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FEFEFE, 0x00FAFAFA, 0x00F5F5F5, 
        0x00F1F1F1, 0x00EFEFEF, 0x00EBEBEB, 0x00E6E6E6, 0x00E3E3E3, 0x00E0E0E0, 0x00DCDCDC, 0x00D8D8D8, 0x00D4D4D4, 0x00D1D1D1, 0x00CECECE, 0x00C9C9C9, 0x00C6C6C6, 0x00C2C2C2, 0x00BFBFBF, 0x00BBBBBB, 0x00B7B7B7, 0x00B3B3B3, 0x00B0B0B0, 0x00ABABAB, 
        0x00A8A8A8, 0x00A5A4A6, 0x00A2A1A3, 0x009D9C9E, 0x0099989A, 0x00969597, 0x00929193, 0x008E8D8F, 0x008B8A8C, 0x008A898B, 0x00838284, 0x007E7D7F, 0x00828183, 0x008B8A8C, 0x0099989A, 0x00ABAAAC, 0x00BAB9BB, 0x00BDBDBD, 0x00C2C2C2, 0x00CBCBCB, 
        0x00D8D8D8, 0x00DBDBDB, 0x00E8E8E8, 0x00EAEAEA, 0x00FFFFFF, 0x00E5E5E5, 0x49CFCFCF, 0xB6C7C7C7, 0xFFD5D5D5, 0xFFE3E3E3, 0xFFE5E5E5, 0xFFE9E9E9, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF0F0F0, 0xFFEDEDED, 0xFFEAEAEA, 0xFFE0E0E0, 0xFFD7D7D7, 0xFFD0D0D0, 0xDCCACACA, 0x72B0B0B0, 0x08A2A2A2, 0x00969696, 0x00959595, 0x00929292, 0x008A8A8A, 0x00868686, 
        0x00888888, 0x007E7E7E, 0x007E7E7E, 0x00747474, 0x006C6C6C, 0x007E7E7E, 0x00ABABAB, 0x00D7D7D7, 0x00ECECEC, 0x00F0F0F0, 0x00F3F3F3, 0x00F7F7F7, 0x00FAFAFA, 0x00FDFDFD, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FEFEFE, 0x00FAFAFA, 0x00F5F5F5, 
        0x00F1F1F1, 0x00EEEEEE, 0x00EBEBEB, 0x00E6E6E6, 0x00E2E2E2, 0x00E0E0E0, 0x00DCDCDC, 0x00D8D8D8, 0x00D4D4D4, 0x00D1D1D1, 0x00CECECE, 0x00C9C9C9, 0x00C6C6C6, 0x00C2C2C2, 0x00BFBFBF, 0x00BBBBBB, 0x00B7B7B7, 0x00B4B4B4, 0x00B0B0B0, 0x00ACACAC, 
        0x00A9A9A9, 0x00A6A5A7, 0x00A3A2A4, 0x009E9D9F, 0x009A999B, 0x00979698, 0x00939294, 0x008F8E90, 0x008D8C8E, 0x008A898B, 0x00848385, 0x00838284, 0x0089888A, 0x00929193, 0x009B9A9C, 0x00A5A4A6, 0x00AEADAF, 0x00B6B6B6, 0x00BCBCBC, 0x00C7C7C7, 
        0x00CACACA, 0x00D4D4D4, 0x00DDDDDD, 0x00E2E2E2, 0x08C9C9C9, 0x72C6C6C6, 0xDCCFCFCF, 0xFFDADADA, 0xFFE2E2E2, 0xFFE8E8E8, 0xFFEDEDED, 0xFFF2F2F2, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF2F2F2, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFDBDBDB, 0xFFD6D6D6, 0xFFCFCFCF, 0xA1BFBFBF, 0x3BAAAAAA, 0x00999999, 0x00939393, 0x00919191, 0x008D8D8D, 
        0x00878787, 0x00868686, 0x00838383, 0x00787878, 0x00767676, 0x00777777, 0x006A6A6A, 0x00717171, 0x00909090, 0x00CFCED0, 0x00E7E6E8, 0x00FEFDFF, 0x00FFFEFF, 0x00FEFDFF, 0x00FDFCFE, 0x00FFFEFF, 0x00FFFEFF, 0x00FBFAFC, 0x00F8F7F9, 0x00F4F3F5, 
        0x00F1F0F2, 0x00EFEEF0, 0x00ECEBED, 0x00E8E7E9, 0x00E5E4E6, 0x00E2E2E2, 0x00DEDEDE, 0x00D9D9D9, 0x00D5D5D5, 0x00D1D1D1, 0x00CECECE, 0x00CBCBCB, 0x00C9C9C9, 0x00C3C3C3, 0x00C0C0C0, 0x00BCBCBC, 0x00B8B8B8, 0x00B5B5B5, 0x00B2B2B2, 0x00ADADAD, 
        0x00AAAAAA, 0x00A5A5A5, 0x00A4A4A4, 0x00A0A0A0, 0x009B9B9B, 0x00999999, 0x00979797, 0x008D8D8D, 0x00828282, 0x00737373, 0x00737373, 0x00787878, 0x00858585, 0x00909090, 0x00939393, 0x00999999, 0x00A4A4A4, 0x00AEAEAE, 0x00B4B4B4, 0x00BCBCBC, 
        0x00C6C6C6, 0x00CDCDCD, 0x00CACACA, 0x3BC6C6C6, 0xA1CACACA, 0xFFD6D6D6, 0xFFDBDBDB, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 
        0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFEFEFEF, 0xFFEAEAEA, 0xFFE3E3E3, 0xFFDEDEDE, 0xFFD4D4D4, 0xFFD1D1D1, 0xD6C7C7C7, 0x73B6B6B6, 0x12A3A3A3, 0x00969696, 0x008E8E8E, 
        0x008B8B8B, 0x00808080, 0x00858585, 0x007F7F7F, 0x00797979, 0x00797979, 0x00727272, 0x006B6B6B, 0x00707070, 0x00626163, 0x00717072, 0x009B9A9C, 0x00D4D3D5, 0x00FCFBFD, 0x00FFFEFF, 0x00FDFCFE, 0x00F9F8FA, 0x00FDFCFE, 0x00FBFAFC, 0x00F8F7F9, 
        0x00F3F2F4, 0x00ECEBED, 0x00E7E6E8, 0x00E4E3E5, 0x00E3E2E4, 0x00DCDCDC, 0x00DADADA, 0x00D7D7D7, 0x00D4D4D4, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C5C5C5, 0x00C5C5C5, 0x00C0C0C0, 0x00BABABA, 0x00B6B6B6, 0x00B5B5B5, 0x00B2B2B2, 0x00AEAEAE, 
        0x00AAAAAA, 0x00A3A3A3, 0x00A8A8A8, 0x00A6A6A6, 0x00979797, 0x007D7D7D, 0x00656565, 0x00595959, 0x00575757, 0x00606060, 0x006C6C6C, 0x00747474, 0x00797979, 0x00818181, 0x008C8C8C, 0x00979797, 0x00A0A0A0, 0x00A4A4A4, 0x00ACACAC, 0x00B3B3B3, 
        0x00BBBBBB, 0x12C4C4C4, 0x73CACACA, 0xD6D1D1D1, 0xFFDADADA, 0xFFDEDEDE, 0xFFE3E3E3, 0xFFEAEAEA, 0xFFEFEFEF, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFEDEDED, 0xFFE9E9E9, 0xFFE2E2E2, 0xFFDFDFDF, 0xFFD7D7D7, 0xFFCCCCCC, 0xB2BEBEBE, 0x54AFAFAF, 0x009E9E9E, 
        0x00929292, 0x008C8C8C, 0x008C8C8C, 0x00858585, 0x007D7D7D, 0x007B7B7B, 0x007A7A7A, 0x00757575, 0x006E6E6E, 0x006C6B6D, 0x00686769, 0x00626163, 0x00605F61, 0x00676668, 0x00848385, 0x00B5B4B6, 0x00DDDCDE, 0x00F4F3F5, 0x00F5F4F6, 0x00F5F4F6, 
        0x00F0EFF1, 0x00EAE9EB, 0x00E6E5E7, 0x00E6E5E7, 0x00E7E6E8, 0x00E2E2E2, 0x00DEDEDE, 0x00DADADA, 0x00D6D6D6, 0x00D3D3D3, 0x00D0D0D0, 0x00CDCDCD, 0x00CBCBCB, 0x00C3C3C3, 0x00BFBFBF, 0x00BCBCBC, 0x00BABABA, 0x00B9B9B9, 0x00B3B3B3, 0x00AAAAAA, 
        0x00A2A2A2, 0x008B8B8B, 0x00696969, 0x00454545, 0x00363636, 0x003A3A3A, 0x00434343, 0x004B4B4B, 0x00515151, 0x00585858, 0x00626262, 0x00696969, 0x006F6F6F, 0x007A7A7A, 0x00858585, 0x008B8B8B, 0x008F8F8F, 0x009C9C9C, 0x00ABABAB, 0x00B8B8B8, 
        0x54C1C1C1, 0xB2CBCBCB, 0xFFD2D2D2, 0xFFDBDBDB, 0xFFE3E3E3, 0xFFE9E9E9, 0xFFEDEDED, 0xFFF1F1F1, 0xFFF5F5F5, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF3F3F3, 0xFFF0F0F0, 0xFFEDEDED, 0xFFE5E5E5, 0xFFDBDBDB, 0xFFD6D6D6, 0xFFD5D5D5, 0xF6CDCDCD, 0x9CBBBBBB, 
        0x42ABABAB, 0x00979797, 0x008C8C8C, 0x00888888, 0x00878787, 0x007E7E7E, 0x00777777, 0x00777777, 0x00767676, 0x006D6C6E, 0x0069686A, 0x00636264, 0x005E5D5F, 0x005C5B5D, 0x005C5B5D, 0x0059585A, 0x00545355, 0x00575658, 0x006A696B, 0x00888789, 
        0x00A6A5A7, 0x00BDBCBE, 0x00CECDCF, 0x00D8D7D9, 0x00DEDDDF, 0x00DDDDDD, 0x00DBDBDB, 0x00D8D8D8, 0x00D5D5D5, 0x00D1D1D1, 0x00CDCDCD, 0x00C8C8C8, 0x00C4C4C4, 0x00C0C0C0, 0x00B2B2B2, 0x009C9C9C, 0x00808080, 0x00616161, 0x00414141, 0x00242424, 
        0x00131313, 0x000E0E0E, 0x00161616, 0x00222222, 0x002C2C2C, 0x002F2F2F, 0x00333333, 0x003F3F3F, 0x004B4B4B, 0x00545454, 0x005A5A5A, 0x00636363, 0x006C6C6C, 0x00737373, 0x00767676, 0x00828282, 0x00929292, 0x00ABABAB, 0x42BCBCBC, 0x9CCACACA, 
        0xF6D2D2D2, 0xFFDBDBDB, 0xFFE0E0E0, 0xFFE4E4E4, 0xFFE8E8E8, 0xFFF0F0F0, 0xFFF3F3F3, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF5F5F5, 0xFFEFEFEF, 0xFFEDEDED, 0xFFE8E8E8, 0xFFE3E3E3, 0xFFDFDFDF, 0xFFDBDBDB, 0xFFD3D3D3, 
        0xEACCCCCC, 0x94C2C2C2, 0x40A4A4A4, 0x00909090, 0x008D8D8D, 0x00868686, 0x00808080, 0x007B7B7B, 0x00737373, 0x00767577, 0x00727173, 0x006E6D6F, 0x006B6A6C, 0x00636264, 0x00585759, 0x00555456, 0x00585759, 0x00525153, 0x004E4D4F, 0x00484749, 
        0x00424143, 0x003D3C3E, 0x003A393B, 0x003A393B, 0x003A393B, 0x00444444, 0x00454545, 0x00464646, 0x00464646, 0x00424242, 0x00393939, 0x002F2F2F, 0x00282828, 0x00121212, 0x000E0E0E, 0x00070707, 0x00020202, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x000B0B0B, 0x00111111, 0x00191919, 0x00212121, 0x00292929, 0x00313131, 0x00393939, 0x003E3E3E, 0x004B4B4B, 0x00515151, 0x00555555, 0x005C5C5C, 0x00696969, 0x007E7E7E, 0x00A0A0A0, 0x40C0C0C0, 0x94C8C8C8, 0xEAD3D3D3, 0xFFD9D9D9, 
        0xFFDDDDDD, 0xFFE4E4E4, 0xFFEBEBEB, 0xFFEEEEEE, 0xFFF2F2F2, 0xFFF5F5F5, 0xFFF6F6F6, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFF4F4F4, 0xFFF2F2F2, 0xFFEDEDED, 0xFFE7E7E7, 0xFFE2E2E2, 0xFFDEDEDE, 
        0xFFDADADA, 0xFFD3D3D3, 0xECCDCDCD, 0x9CC5C5C5, 0x4DB1B1B1, 0x00949494, 0x00858585, 0x00838383, 0x007F7F7F, 0x00767577, 0x00737274, 0x006E6D6F, 0x0069686A, 0x00676668, 0x00656466, 0x00616062, 0x005D5C5E, 0x00555456, 0x00525153, 0x004F4E50, 
        0x004B4A4C, 0x00484749, 0x00434244, 0x003C3B3D, 0x00383739, 0x00323232, 0x00303030, 0x002E2E2E, 0x002A2A2A, 0x00262626, 0x00202020, 0x00191919, 0x00151515, 0x00141414, 0x00111111, 0x000B0B0B, 0x00050505, 0x00000000, 0x00000000, 0x00000000, 
        0x00020202, 0x00000000, 0x00060606, 0x000E0E0E, 0x00151515, 0x001D1D1D, 0x00282828, 0x00313131, 0x00373737, 0x003E3E3E, 0x00484848, 0x00565656, 0x00727272, 0x009E9E9E, 0x4DC2C2C2, 0x9CCECECE, 0xECCECECE, 0xFFD9D9D9, 0xFFDFDFDF, 0xFFE2E2E2, 
        0xFFE5E5E5, 0xFFEDEDED, 0xFFF2F2F2, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFEFEFEF, 0xFFEDEDED, 0xFFE6E6E6, 
        0xFFE0E0E0, 0xFFDEDEDE, 0xFFD8D8D8, 0xFFD3D3D3, 0xFFCDCDCD, 0xB4C6C6C6, 0x6BBABABA, 0x23A1A1A1, 0x00848484, 0x00787779, 0x0079787A, 0x00757476, 0x006D6C6E, 0x006B6A6C, 0x006B6A6C, 0x00646365, 0x005A595B, 0x005B5A5C, 0x00575658, 0x00504F51, 
        0x004B4A4C, 0x00484749, 0x00454446, 0x00424143, 0x003F3E40, 0x003D3D3D, 0x00393939, 0x00323232, 0x002C2C2C, 0x00272727, 0x00242424, 0x00222222, 0x00202020, 0x00151515, 0x00131313, 0x00101010, 0x000C0C0C, 0x00090909, 0x00050505, 0x00010101, 
        0x00000000, 0x00000000, 0x00020202, 0x000C0C0C, 0x00151515, 0x001A1A1A, 0x001F1F1F, 0x00292929, 0x00323232, 0x00484848, 0x007C7C7C, 0x23B1B1B1, 0x6BC9C9C9, 0xB4CECECE, 0xFFD1D1D1, 0xFFD9D9D9, 0xFFE3E3E3, 0xFFE1E1E1, 0xFFE6E6E6, 0xFFEBEBEB, 
        0xFFF0F0F0, 0xFFF6F6F6, 0xFFF5F5F5, 0xFFF4F4F4, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF4F4F4, 0xFFF3F3F3, 0xFFF0F0F0, 
        0xFFEDEDED, 0xFFE3E3E3, 0xFFE3E3E3, 0xFFE1E1E1, 0xFFDCDCDC, 0xFFD6D6D6, 0xFFD1D1D1, 0xDCCCCCCC, 0x99C6C6C6, 0x57B7B6B8, 0x179A999B, 0x007F7E80, 0x00757476, 0x00717072, 0x0069686A, 0x00646365, 0x00666567, 0x005F5E60, 0x005C5B5D, 0x00585759, 
        0x00535254, 0x004E4D4F, 0x0049484A, 0x00444345, 0x00414042, 0x003A3A3A, 0x00383838, 0x00353535, 0x00313131, 0x002D2D2D, 0x00282828, 0x00222222, 0x001E1E1E, 0x001D1D1D, 0x00191919, 0x00131313, 0x000E0E0E, 0x000B0B0B, 0x00080808, 0x00030303, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030303, 0x000E0E0E, 0x002E2E2E, 0x00696969, 0x179C9C9C, 0x57C7C7C7, 0x99CBCBCB, 0xDCCFCFCF, 0xFFD5D5D5, 0xFFDCDCDC, 0xFFDEDEDE, 0xFFE1E1E1, 0xFFE7E7E7, 0xFFEDEDED, 0xFFEFEFEF, 0xFFF1F1F1, 
        0xFFF5F5F5, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF5F5F5, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF8F8F8, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF6F6F6, 0xFFF4F4F4, 
        0xFFF3F3F3, 0xFFF0F0F0, 0xFFEDEDED, 0xFFE9E9E9, 0xFFE5E5E5, 0xFFE1E1E1, 0xFFDDDDDD, 0xFFD8D8D8, 0xFFD4D4D4, 0xFFD2D2D2, 0xD8CDCDCD, 0x9DC4C4C4, 0x63B6B6B6, 0x2BA3A3A3, 0x008B8B8B, 0x00757575, 0x00676767, 0x00636363, 0x00606060, 0x005B5B5B, 
        0x00565656, 0x00515151, 0x004D4D4D, 0x00494949, 0x00464646, 0x00414141, 0x003E3E3E, 0x003A3A3A, 0x00363636, 0x00323232, 0x002D2D2D, 0x00272727, 0x00232323, 0x00202020, 0x001A1A1A, 0x00151515, 0x00141414, 0x00111111, 0x000B0B0B, 0x00050505, 
        0x00030303, 0x00000000, 0x00171717, 0x00404040, 0x00757575, 0x2BA9A9A9, 0x63C6C6C6, 0x9DCDCDCD, 0xD8CDCDCD, 0xFFD6D6D6, 0xFFD9D9D9, 0xFFDEDEDE, 0xFFE2E2E2, 0xFFE5E5E5, 0xFFE9E9E9, 0xFFEDEDED, 0xFFF1F1F1, 0xFFF4F4F4, 0xFFF5F5F5, 0xFFF7F7F7, 
        0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 
        0xFFF6F6F6, 0xFFF7F7F7, 0xFFF4F4F4, 0xFFF0F0F0, 0xFFEDEDED, 0xFFEBEBEB, 0xFFE7E7E7, 0xFFE3E3E3, 0xFFE0E0E0, 0xFFDDDDDD, 0xFFDBDBDB, 0xFFD8D8D8, 0xFFD4D4D4, 0xF5D0D0D0, 0xC2CACACA, 0x92C3C3C3, 0x64BFBFBF, 0x38A5A5A5, 0x0E989898, 0x00848484, 
        0x00707070, 0x00616161, 0x00565656, 0x004E4E4E, 0x004A4A4A, 0x00494949, 0x00444444, 0x003D3D3D, 0x00373737, 0x00343434, 0x00313131, 0x002E2E2E, 0x002C2C2C, 0x00222222, 0x00202020, 0x00212121, 0x00272727, 0x00373737, 0x00525252, 0x00737373, 
        0x0E8C8C8C, 0x38B5B5B5, 0x64C1C1C1, 0x92CBCBCB, 0xC2D0D0D0, 0xF5D4D4D4, 0xFFD5D5D5, 0xFFD8D8D8, 0xFFE0E0E0, 0xFFE0E0E0, 0xFFE3E3E3, 0xFFE7E7E7, 0xFFEAEAEA, 0xFFEDEDED, 0xFFF0F0F0, 0xFFF4F4F4, 0xFFF7F7F7, 0xFFF7F7F7, 0xFFF8F8F8, 0xFFF9F9F9, 
        0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF9F9F9, 
        0xFFF9F9F9, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF5F5F5, 0xFFF3F3F3, 0xFFF2F2F2, 0xFFEFEFEF, 0xFFECECEC, 0xFFEAEAEA, 0xFFE5E5E5, 0xFFE2E2E2, 0xFFDEDEDE, 0xFFDBDBDB, 0xFFDADADA, 0xFFD8D8D8, 0xFFD6D6D6, 0xFFD5D5D5, 0xFFD0D0D0, 0xE6CECECE, 0xC2CBCBCB, 
        0xA1CACACA, 0x83C8C8C8, 0x67C2C2C2, 0x4FB9B9B9, 0x39B1B1B1, 0x27A3A3A3, 0x189F9F9F, 0x0C999999, 0x04969696, 0x00959595, 0x04959595, 0x0C969696, 0x18969696, 0x27A5A5A5, 0x39B1B1B1, 0x4FC2C2C2, 0x67CCCCCC, 0x83CDCDCD, 0xA1CBCBCB, 0xC2CDCDCD, 
        0xE6D1D1D1, 0xFFD5D5D5, 0xFFDADADA, 0xFFDBDBDB, 0xFFDADADA, 0xFFDCDCDC, 0xFFDEDEDE, 0xFFE2E2E2, 0xFFEAEAEA, 0xFFE9E9E9, 0xFFEBEBEB, 0xFFEFEFEF, 0xFFF1F1F1, 0xFFF3F3F3, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

GUI_CONST_STORAGE GUI_BITMAP bmknob_gray_trans_140x140 = {
  140, // xSize
  140, // ySize
  560, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acknob_gray_trans_140x140,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Knob 70x70
*/
static GUI_CONST_STORAGE unsigned long _acknob_gray_trans_70x70[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF5F5F5, 
        0xFFF1F1F1, 0xFFEBEBEB, 0xFFE5E5E5, 0xFFDDDDDD, 0xFFD5D5D5, 0xFFCBCBCB, 0xEDBBBABC, 0xBDB1B0B2, 0x8BAFAEB2, 0x59B0AFB3, 0x3BB4B3B7, 0x22B9B7BC, 0x10C1C0C4, 0x04C6C5C9, 0x01C7C6CA, 0x09C4C3C7, 0x18C2C1C5, 0x2EC0BFC3, 0x49BEBDC1, 0x6EBDBCBF, 
        0xA7BEBEBF, 0xD5C3C3C3, 0xFDCBCBCB, 0xFFD4D4D4, 0xFFDDDDDD, 0xFFE4E4E4, 0xFFEBEBEB, 0xFFF2F2F2, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF5F5F5, 0xFFF0F0F0, 0xFFE9E9E9, 
        0xFFE0E0E0, 0xFFD7D7D7, 0xFFC9C9C9, 0xDDACACAC, 0x91959496, 0x408B8A8C, 0x0B919092, 0x00969597, 0x009F9EA2, 0x00A5A4A8, 0x00ABA9AF, 0x00B2B1B6, 0x00BAB9BD, 0x00C0BFC3, 0x00C7C6CA, 0x00C7C6CA, 0x00C4C3C7, 0x00C1C0C4, 0x00BFBEC2, 0x00BBBABE, 
        0x00B9B8BA, 0x00B6B5B7, 0x24B0AFB1, 0x63B5B4B6, 0xBCBDBCBE, 0xF6CBCACC, 0xFFD7D6D8, 0xFFE2E1E3, 0xFFE9E9E9, 0xFFF1F1F1, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF3F3F3, 0xFFEBEBEB, 0xFFE1E1E1, 0xFFD4D4D4, 
        0xFABCBCBC, 0xBA8C8C8C, 0x48717171, 0x09737373, 0x0079787A, 0x00818082, 0x00888789, 0x008F8E90, 0x00959498, 0x009E9DA1, 0x00A6A5A9, 0x00ACABAE, 0x00B4B3B5, 0x00BBBABC, 0x00C2C1C3, 0x00C9C8CA, 0x00C8C7C9, 0x00C4C3C5, 0x00C1C0C2, 0x00BFBEC0, 
        0x00BCBBBD, 0x00B9B8BA, 0x00B5B4B6, 0x00B2B1B3, 0x00ADACAE, 0x24ACABAD, 0x80B4B3B5, 0xE2C4C3C5, 0xFFD4D4D4, 0xFFE0E0E0, 0xFFEAEAEA, 0xFFF2F2F2, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF5F5F5, 0xFFEEEEEE, 0xFFE3E3E3, 0xFFD7D7D7, 0xFDC1C1C1, 0xB28A8A8A, 
        0x35626262, 0x005E5E5E, 0x00646464, 0x006B6B6B, 0x00747375, 0x007A797B, 0x00858486, 0x00929193, 0x00A1A0A2, 0x00ACABAD, 0x00B8B7B9, 0x00C1C0C2, 0x00C9C9C9, 0x00D0D0D0, 0x00D6D6D6, 0x00DFDFDF, 0x00E4E4E4, 0x00E8E8E8, 0x00E6E6E6, 0x00E0E0E0, 
        0x00D4D3D5, 0x00C3C2C4, 0x00BAB9BB, 0x00B5B4B6, 0x00B0AFB1, 0x00B0AFB1, 0x00AAA9AB, 0x10A9A8AA, 0x70B1B1B1, 0xE4C5C5C5, 0xFFD6D6D6, 0xFFE4E4E4, 0xFFEEEEEE, 0xFFF5F5F5, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF3F3F3, 0xFFEAEAEA, 0xFFDDDDDD, 0xFFCDCDCD, 0xD2A4A4A4, 0x46777777, 0x006E6E6E, 
        0x00676767, 0x00616161, 0x005E5E5E, 0x006A696A, 0x007D7C7F, 0x008F8E92, 0x009D9C9E, 0x00A6A5A7, 0x00ACACAC, 0x00B3B3B3, 0x00B9B9B9, 0x00C1C1C0, 0x00C9C9C9, 0x00CFCFCF, 0x00D6D6D6, 0x00DDDDDD, 0x00E5E5E5, 0x00EBEBEB, 0x00F2F2F2, 0x00FBFBFB, 
        0x00FFFEFF, 0x00FEFDFE, 0x00EFEEF0, 0x00D2D1D3, 0x00BBBABC, 0x00B0AFB1, 0x00AFAEB0, 0x00ACABAD, 0x00A8A8A8, 0x15A6A6A6, 0x8EB5B5B5, 0xF5CDCDCD, 0xFFDDDDDD, 0xFFEAEAEA, 0xFFF3F3F3, 0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF7F7F7, 0xFFF1F1F1, 0xFFE6E6E6, 0xFFD8D8D8, 0xF6C0C0C0, 0x8799989A, 0x0F858486, 0x007E7D7F, 0x00757476, 
        0x006E6D6F, 0x0069686A, 0x00737274, 0x00858486, 0x008D8C8E, 0x00959496, 0x009C9B9D, 0x00A4A3A5, 0x00AAAAAA, 0x00B2B2B2, 0x00B9B9B9, 0x00C1C1C1, 0x00C8C8C8, 0x00D0D0D0, 0x00D6D6D6, 0x00DEDEDE, 0x00E5E5E5, 0x00EDEDED, 0x00F4F4F4, 0x00FDFDFD, 
        0x00FFFFFF, 0x00FEFEFE, 0x00F9F9F9, 0x00F1F1F1, 0x00E7E7E7, 0x00CECECE, 0x00B9B9B9, 0x00ADADAD, 0x00ABAAAC, 0x00AAA9AB, 0x00A4A3A5, 0x39A9A8AA, 0xD3C2C2C2, 0xFFD8D8D8, 0xFFE7E7E7, 0xFFF2F3F1, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF7F7F7, 0xFFF0F0F0, 0xFFE4E4E4, 0xFFD4D4D4, 0xE5B9B9B9, 0x499F9F9F, 0x00959496, 0x008D8C8E, 0x00878688, 0x007C7B7D, 
        0x00727173, 0x00777678, 0x007E7D7F, 0x00848385, 0x008B8A8C, 0x00929193, 0x009A999B, 0x00A1A0A2, 0x00A9A9A9, 0x00B1B1B1, 0x00B8B8B8, 0x00C0C0C0, 0x00C7C7C7, 0x00CFCFCF, 0x00D6D6D6, 0x00DFDFDF, 0x00E6E6E6, 0x00EFEFEF, 0x00F6F6F6, 0x00FEFEFE, 
        0x00FFFFFF, 0x00FEFEFE, 0x00F7F7F7, 0x00EDEDED, 0x00E3E3E3, 0x00DBDBDB, 0x00D1D1D1, 0x00C3C3C3, 0x00B0AFB1, 0x00ABAAAC, 0x00A8A7A9, 0x00A4A3A5, 0x12A3A3A3, 0x9CB9B9B9, 0xFFD4D4D4, 0xFFE3E3E3, 0xFFF0F0F0, 0xFFF8F8F8, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFF7F7F7, 0xFFF0F0F0, 0xFFE3E3E3, 0xFFD0D0D0, 0xCEBDBDBD, 0x21AAAAAA, 0x00A4A4A4, 0x009D9C9E, 0x00949395, 0x00787779, 0x00686769, 
        0x006E6D6F, 0x00747375, 0x007B7A7C, 0x00828183, 0x00888789, 0x00908F91, 0x00989799, 0x00A09FA1, 0x00A7A7A7, 0x00AFAFAF, 0x00B7B7B7, 0x00BEBEBE, 0x00C7C7C7, 0x00CFCFCF, 0x00D7D7D7, 0x00DFDFDF, 0x00E7E7E7, 0x00EFEFEF, 0x00F8F8F8, 0x00FEFEFE, 
        0x00FFFFFF, 0x00FCFCFC, 0x00F3F3F3, 0x00E9E9E9, 0x00E1E1E1, 0x00D7D7D7, 0x00CFCFCF, 0x00C6C6C6, 0x00BDBCBE, 0x00B1B0B2, 0x00ACABAD, 0x00A8A8A8, 0x00A6A6A6, 0x02A2A2A2, 0x75B2B2B2, 0xF7D0D0D0, 0xFFE2E2E2, 0xFFEFEFEF, 0xFFF7F7F7, 0xFFF9F9F9, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF0F0F0, 0xFFE2E2E2, 0xFFD1D1D1, 0xBDC3C3C3, 0x17BDBDBD, 0x00B3B3B3, 0x00ACACAC, 0x009D9C9E, 0x006B6A6C, 0x005C5B5D, 0x00656466, 
        0x0069686A, 0x00717072, 0x00767577, 0x007C7B7D, 0x00858486, 0x008D8C8E, 0x00959496, 0x009D9C9E, 0x00A6A6A6, 0x00AEAEAE, 0x00B6B6B6, 0x00BEBEBE, 0x00C6C6C6, 0x00CFCFCF, 0x00D7D7D7, 0x00E0E0E0, 0x00E9E9E9, 0x00F1F1F1, 0x00FAFAFA, 0x00FFFFFF, 
        0x00FFFFFF, 0x00F8F8F8, 0x00EEEEEE, 0x00E4E4E4, 0x00DBDBDB, 0x00D1D1D1, 0x00C9C9C9, 0x00C0C0C0, 0x00B8B7B9, 0x00B0AFB1, 0x00A9A9A9, 0x00ABABAB, 0x00A9A9A9, 0x00A7A7A7, 0x00A1A1A1, 0x60B0B0B0, 0xF3D0D0D0, 0xFFE3E3E3, 0xFFEFEFEF, 0xFFF7F7F7, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF1F1F1, 0xFFE4E4E4, 0xFFD0D0D0, 0xBDCDCDCD, 0x14CBCBCB, 0x00C4C4C4, 0x00BDBDBD, 0x009E9E9E, 0x005A595B, 0x00525153, 0x0059585A, 0x005F5E60, 
        0x00656466, 0x006C6B6D, 0x00737274, 0x007A797B, 0x00828183, 0x008A898B, 0x00929193, 0x009B9A9C, 0x00A4A4A4, 0x00ADADAD, 0x00B5B5B5, 0x00BEBEBE, 0x00C5C5C5, 0x00CFCFCF, 0x00D7D7D7, 0x00E0E0E0, 0x00E9E9E9, 0x00F1F1F1, 0x00FAFAFA, 0x00FFFFFF, 
        0x00FEFEFE, 0x00F5F5F5, 0x00EBEBEB, 0x00E1E1E1, 0x00D7D7D7, 0x00CDCDCD, 0x00C4C4C4, 0x00BABABA, 0x00B3B3B3, 0x00A9A9A9, 0x00A2A2A2, 0x009D9D9D, 0x00A6A6A6, 0x00A9A9A9, 0x00A7A6A8, 0x00A2A1A3, 0x5BAFAFAF, 0xF4D0D0D0, 0xFFE3E3E3, 0xFFF0F0F0, 
        0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF2F2F2, 0xFFE6E6E6, 0xFFD2D2D2, 0xCED1D1D1, 0x17DBDBDB, 0x00D3D3D3, 0x00CDCDCD, 0x00A0A0A0, 0x004A4A4A, 0x0049484A, 0x00504F51, 0x00555456, 0x005A595B, 
        0x00626163, 0x00686769, 0x006F6E70, 0x00777678, 0x007E7D7F, 0x00868587, 0x008E8D8F, 0x00979698, 0x00A1A1A1, 0x00AAAAAA, 0x00B3B3B3, 0x00BCBCBC, 0x00C5C5C5, 0x00CECECE, 0x00D7D7D7, 0x00E1E1E1, 0x00EAEAEA, 0x00F3F3F3, 0x00FCFCFC, 0x00FFFFFF, 
        0x00FCFCFC, 0x00F2F2F2, 0x00E7E7E7, 0x00DDDDDD, 0x00D2D2D2, 0x00C8C8C8, 0x00BFBFBF, 0x00B5B5B5, 0x00ACACAC, 0x00A4A4A4, 0x009C9C9C, 0x00949494, 0x008F8F8F, 0x00A2A1A3, 0x00A9A8AA, 0x00A5A4A6, 0x00A1A1A1, 0x68B3B3B3, 0xFBD3D3D3, 0xFFE7E7E7, 
        0xFFF2F2F2, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF5F5F5, 0xFFEAEAEA, 0xFFD5D5D5, 0xE5D5D5D5, 0x21E9E9E9, 0x00E3E3E3, 0x00DBDBDB, 0x00ABABAB, 0x00414141, 0x00404040, 0x00444345, 0x0049484A, 0x00504F51, 0x00565557, 
        0x005D5C5E, 0x00646365, 0x006B6A6C, 0x00737274, 0x007A797B, 0x00838284, 0x008B8A8C, 0x00959496, 0x009E9E9E, 0x00A8A8A8, 0x00B1B1B1, 0x00BCBCBC, 0x00C4C4C4, 0x00CECECE, 0x00D7D7D7, 0x00E1E1E1, 0x00ECECEC, 0x00F6F6F6, 0x00FEFEFE, 0x00FFFFFF, 
        0x00F9F9F9, 0x00EDEDED, 0x00E3E3E3, 0x00D7D7D7, 0x00CDCDCD, 0x00C3C3C3, 0x00B9B9B9, 0x00AFAFAF, 0x00A5A5A5, 0x009D9D9D, 0x00969696, 0x008E8E8E, 0x00888789, 0x00818082, 0x009E9D9F, 0x00AAA9AB, 0x00A6A6A6, 0x00A1A1A1, 0x86B8B8B8, 0xFFD8D8D8, 
        0xFFEAEAEA, 0xFFF5F5F5, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF7F7F7, 0xFFEEEEEE, 0xFFDDDDDD, 0xF6D2D2D2, 0x49F5F5F5, 0x00F2F2F2, 0x00EAEAEA, 0x00BDBDBD, 0x00383838, 0x00343434, 0x003C3C3C, 0x003F3E40, 0x00464547, 0x004B4A4C, 0x00525153, 
        0x00585759, 0x005F5E60, 0x00666567, 0x006F6E70, 0x00767577, 0x007F7E80, 0x00878688, 0x00929193, 0x009B9B9B, 0x00A5A5A5, 0x00AFAFAF, 0x00BABABA, 0x00C3C3C3, 0x00CECECE, 0x00D8D8D8, 0x00E2E2E2, 0x00ECECEC, 0x00F7F7F7, 0x00FEFEFE, 0x00FEFEFE, 
        0x00F4F4F4, 0x00E9E9E9, 0x00DDDDDD, 0x00D2D2D2, 0x00C7C7C7, 0x00BCBCBC, 0x00B2B2B2, 0x00A8A8A8, 0x00A0A19F, 0x00979797, 0x008E8E8E, 0x00868686, 0x007F7E80, 0x0079787A, 0x00767577, 0x009E9D9F, 0x00A9A9A9, 0x00A6A6A6, 0x0AA4A4A4, 0xB7C1C1C1, 
        0xFFDDDDDD, 0xFFEEEEEE, 0xFFF7F7F7, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF4F4F4, 0xFFE3E3E3, 0xFFD0D0D0, 0x87F0F0F0, 0x00FDFDFD, 0x00FAFAFA, 0x00E0DFE1, 0x00414042, 0x002C2B2D, 0x002F2E30, 0x00353436, 0x003A393B, 0x00403F41, 0x00464547, 0x004D4C4E, 
        0x00545355, 0x005A595B, 0x00626163, 0x006A696B, 0x00727173, 0x007B7A7C, 0x00838284, 0x008D8C8E, 0x0099989A, 0x00A3A3A3, 0x00AEAEAE, 0x00B8B8B8, 0x00C2C2C2, 0x00CECECE, 0x00D8D8D8, 0x00E3E3E3, 0x00EEEEEE, 0x00F8F8F8, 0x00FFFFFF, 0x00FBFBFB, 
        0x00F0F0F0, 0x00E3E3E3, 0x00D8D8D8, 0x00CCCCCC, 0x00C2C2C2, 0x00B6B6B6, 0x00ABABAB, 0x00A1A1A1, 0x00989898, 0x008F8F8F, 0x00888888, 0x00808080, 0x00777777, 0x00727272, 0x006A6A6A, 0x006E6E6E, 0x00A5A5A5, 0x00AAAAAA, 0x00A5A5A5, 0x1FA9A9A9, 
        0xE8CCCCCC, 0xFFE4E4E4, 0xFFF1F1F1, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF6F6F6, 0xFFECECEC, 0xFFD5D5D5, 0xD2D1D1D1, 0x0FEEEEEE, 0x00FBFBFB, 0x00FCFCFC, 0x0069686A, 0x00333234, 0x00302F31, 0x002E2D2F, 0x002F2E30, 0x00353436, 0x003B3A3C, 0x00414042, 0x00474648, 
        0x004E4D4F, 0x00555456, 0x005D5C5E, 0x00656466, 0x006D6C6E, 0x00767577, 0x007F7E80, 0x0089888A, 0x00949395, 0x00A0A0A0, 0x00ABABAB, 0x00B6B6B6, 0x00C1C1C1, 0x00CDCDCD, 0x00D8D8D8, 0x00E4E4E4, 0x00F0F0F0, 0x00FBFBFB, 0x00FFFFFF, 0x00F8F8F8, 
        0x00EBEBEB, 0x00DDDDDD, 0x00D1D1D1, 0x00C5C5C5, 0x00BABABA, 0x00AEAEAE, 0x00A4A4A4, 0x00999999, 0x00919191, 0x00888888, 0x00808080, 0x00797979, 0x00717171, 0x006B6B6B, 0x00656565, 0x005D5D5D, 0x00707070, 0x00A9A9A9, 0x00AAAAAA, 0x00A6A6A6, 
        0x61B5B5B5, 0xFFD8D8D8, 0xFFE9E9E9, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF9F9F9, 0xFFF0F0F0, 0xFFDFDFDF, 0xFDC9C9C9, 0x46CDCDCD, 0x00DEDEDE, 0x00EFEFEF, 0x00A9A9A9, 0x003E3D3F, 0x0039383A, 0x00363537, 0x00302F31, 0x002C2B2D, 0x002F2E30, 0x00343335, 0x003B3A3C, 0x00424143, 
        0x00484749, 0x004F4E50, 0x00575658, 0x005F5E60, 0x00686769, 0x00727173, 0x007B7A7C, 0x00858486, 0x00908F91, 0x009C9C9C, 0x00A8A8A8, 0x00B5B5B5, 0x00C0C0C0, 0x00CDCDCD, 0x00D8D8D8, 0x00E5E5E5, 0x00F1F1F1, 0x00FCFCFC, 0x00FFFFFF, 0x00F4F4F4, 
        0x00E6E6E6, 0x00D8D8D8, 0x00CBCBCB, 0x00BEBEBE, 0x00B3B3B3, 0x00A7A7A7, 0x009C9C9C, 0x00929292, 0x00888888, 0x00808080, 0x00787878, 0x00707070, 0x00686868, 0x00626262, 0x005B5B5B, 0x00585858, 0x00575757, 0x008B8B8B, 0x00ACACAC, 0x00A9A9A9, 
        0x05A8A8A8, 0xBFC4C4C4, 0xFFE2E2E2, 0xFFF0F0F0, 0xFFF9F9F9, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF5F5F5, 0xFFEAEAEA, 0xFFD4D4D4, 0xB2B6B6B6, 0x00BEBEBE, 0x00CECECE, 0x00CDCDCD, 0x004D4D4D, 0x00424143, 0x003E3D3F, 0x0039383A, 0x00353436, 0x00323133, 0x002C2B2D, 0x002E2D2F, 0x00343335, 0x003B3A3C, 
        0x00414042, 0x00484749, 0x00504F51, 0x00585759, 0x00626163, 0x006C6B6D, 0x00757476, 0x00807F81, 0x008C8B8D, 0x00999999, 0x00A5A5A5, 0x00B2B2B2, 0x00BFBFBF, 0x00CDCDCD, 0x00D9D9D9, 0x00E6E6E6, 0x00F4F4F4, 0x00FEFEFE, 0x00FDFDFD, 0x00EEEEEE, 
        0x00DFDFDF, 0x00D0D0D0, 0x00C3C3C3, 0x00B5B5B5, 0x00AAAAAA, 0x009E9E9E, 0x00939393, 0x00898989, 0x007F7F7F, 0x00777777, 0x006F6F6F, 0x00686868, 0x00616161, 0x005A5A5A, 0x00575757, 0x00585858, 0x005B5B5B, 0x00636363, 0x00A4A4A4, 0x00ADADAD, 
        0x00A9A9A9, 0x38B3B3B3, 0xFAD5D5D5, 0xFFE9E9E9, 0xFFF6F6F6, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF0F0F0, 0xFFE2E2E2, 0xFAC0C0C0, 0x359D9D9D, 0x00ADADAD, 0x00BEBEBE, 0x007A7A7A, 0x004C4C4C, 0x00484749, 0x00454446, 0x00403F41, 0x003C3B3D, 0x00383739, 0x00333234, 0x002E2D2F, 0x002E2D2F, 0x00333234, 
        0x003B3A3C, 0x00424143, 0x0049484A, 0x00525153, 0x005C5B5D, 0x00666567, 0x00706F71, 0x007C7B7D, 0x00888789, 0x00959595, 0x00A2A2A2, 0x00B0B0B0, 0x00BEBEBE, 0x00CCCCCC, 0x00DADADA, 0x00E8E8E8, 0x00F6F6F6, 0x00FFFFFF, 0x00F8F8F8, 0x00E8E8E8, 
        0x00D8D8D8, 0x00CACACA, 0x00BABABA, 0x00ADADAD, 0x00A0A0A0, 0x00949494, 0x008A8A8A, 0x00808080, 0x00777777, 0x006F6F6F, 0x00676767, 0x00606060, 0x00585858, 0x00575757, 0x005A5A5A, 0x005E5E5E, 0x00606060, 0x00606060, 0x00808080, 0x00B0B0B0, 
        0x00ADADAD, 0x00A8A8A8, 0xB0C5C5C5, 0xFFE1E1E1, 0xFFF1F1F1, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEBEBEB, 0xFFD7D7D7, 0xBA9B9B9B, 0x008C8C8C, 0x009D9D9D, 0x009E9E9E, 0x00545454, 0x00535353, 0x004C4B4D, 0x004B4A4C, 0x00474648, 0x00434244, 0x003E3D3F, 0x003A393B, 0x00353436, 0x00302F31, 0x002E2D2F, 
        0x00333234, 0x003A393B, 0x00424143, 0x004B4A4C, 0x00555456, 0x005F5E60, 0x006A696B, 0x00767577, 0x00828183, 0x008F8F8F, 0x009D9D9D, 0x00ADADAD, 0x00BCBCBC, 0x00CBCBCB, 0x00DBDBDB, 0x00EAEAEA, 0x00F8F8F8, 0x00FFFFFF, 0x00F3F3F3, 0x00E2E2E2, 
        0x00D0D0D0, 0x00C2C2C2, 0x00B1B1B1, 0x00A4A4A4, 0x00969696, 0x008B8B8B, 0x00808080, 0x00767676, 0x006D6D6D, 0x00646464, 0x005C5C5C, 0x00565656, 0x00585858, 0x005C5C5C, 0x00606060, 0x00626262, 0x00656565, 0x00686868, 0x00686868, 0x00A7A7A7, 
        0x00AFAFAF, 0x00ACACAC, 0x3AB5B5B5, 0xFFD7D7D7, 0xFFEBEBEB, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE4E4E4, 0xFFC7C7C7, 0x48707070, 0x007B7B7B, 0x008B8B8B, 0x00717171, 0x005B5B5B, 0x00575757, 0x00545355, 0x00525153, 0x004E4D4F, 0x004A494B, 0x00464547, 0x00414042, 0x003C3B3D, 0x00363537, 0x00302F31, 
        0x002D2C2E, 0x00323133, 0x003B3A3C, 0x00434244, 0x004D4C4E, 0x00575658, 0x00636264, 0x006F6E70, 0x007C7B7D, 0x008B8B8B, 0x009A9A9A, 0x00AAAAAA, 0x00BBBBBB, 0x00CBCBCB, 0x00DCDCDC, 0x00EBEBEB, 0x00FBFBFB, 0x00FDFDFD, 0x00ECECEC, 0x00D9D9D9, 
        0x00C7C7C7, 0x00B7B7B7, 0x00A6A6A6, 0x00989898, 0x008B8B8B, 0x007F7F7F, 0x00757575, 0x006B6B6B, 0x00636363, 0x005B5B5B, 0x00575757, 0x00595959, 0x005F5F5F, 0x00616161, 0x00636363, 0x00666666, 0x00696969, 0x006B6B6B, 0x006E6E6E, 0x00888888, 
        0x00B3B3B3, 0x00AEAEAE, 0x00AEAEAE, 0xC7CBCBCB, 0xFFE4E4E4, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDCDCDC, 0xDD9B9B9B, 0x09585858, 0x006A6A6A, 0x00787878, 0x00646464, 0x00606060, 0x005E5E5E, 0x005B5A5C, 0x00585759, 0x00545355, 0x00504F51, 0x004D4C4E, 0x0049484A, 0x00434244, 0x003F3E40, 0x0039383A, 
        0x00323133, 0x002D2C2E, 0x00313032, 0x0039383A, 0x00444345, 0x004F4E50, 0x005B5A5C, 0x00676668, 0x00747375, 0x00848484, 0x00959595, 0x00A6A6A6, 0x00B9B9B9, 0x00CACACA, 0x00DCDCDC, 0x00EDEDED, 0x00FEFEFE, 0x00F9F9F9, 0x00E4E4E4, 0x00CFCFCF, 
        0x00BDBDBD, 0x00ABABAB, 0x009A9A9A, 0x008C8C8C, 0x00808080, 0x00747474, 0x006A6A6A, 0x00606060, 0x00585858, 0x00585858, 0x005D5D5D, 0x00606060, 0x00636363, 0x00676767, 0x00686868, 0x006B6B6B, 0x006D6D6D, 0x00707070, 0x00707070, 0x00777777, 
        0x00B1B1B1, 0x00B4B4B4, 0x00AEAEAF, 0x66BEBDBE, 0xFFDCDCDC, 0xFFF5F5F5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD3D3D3, 0x91646464, 0x00494949, 0x005A5A5A, 0x00686868, 0x0069686A, 0x00676668, 0x00646365, 0x00616062, 0x005F5E60, 0x005C5B5D, 0x00585759, 0x00545355, 0x004F4E50, 0x004B4A4C, 0x00474648, 0x00424143, 
        0x003B3A3C, 0x00343335, 0x002D2C2E, 0x00313032, 0x003A393B, 0x00464547, 0x00515052, 0x005F5E60, 0x006D6C6E, 0x007D7C7E, 0x008E8D8F, 0x00A09FA1, 0x00B4B4B4, 0x00C8C8C8, 0x00DCDCDC, 0x00F0F0F0, 0x00FFFFFF, 0x00F2F2F2, 0x00DBDBDB, 0x00C4C4C4, 
        0x00B0B0B0, 0x009E9E9E, 0x008E8E8E, 0x00808080, 0x00737373, 0x00676767, 0x005F5F5F, 0x00585858, 0x005A5A5A, 0x005E5E5E, 0x00626262, 0x00656565, 0x00696969, 0x006C6C6C, 0x006E6E6E, 0x00717171, 0x00737373, 0x00747375, 0x00777678, 0x00787779, 
        0x009E9D9F, 0x00B6B5B8, 0x00B3B2B5, 0x1CB6B5B8, 0xF5D5D5D5, 0xFFF4F4F4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFC8C8C8, 0x402E2E2E, 0x00383838, 0x00484848, 0x006C6C6C, 0x006F6E70, 0x006D6C6E, 0x006B6A6C, 0x00686769, 0x00666567, 0x00636264, 0x00605F61, 0x005C5B5D, 0x00585759, 0x00545355, 0x00504F51, 0x004B4A4C, 
        0x00454446, 0x003E3D3F, 0x00373638, 0x002F2E30, 0x00302F31, 0x003B3A3C, 0x00474648, 0x00545355, 0x00636264, 0x00747375, 0x00878688, 0x009C9B9D, 0x00B2B2B2, 0x00C7C7C7, 0x00DDDDDD, 0x00F4F4F4, 0x00FDFDFD, 0x00E7E7E7, 0x00CFCFCF, 0x00B7B7B7, 
        0x00A2A2A2, 0x008F8F8F, 0x00818181, 0x00727272, 0x00656565, 0x005A5A5A, 0x00585858, 0x005C5C5C, 0x00616161, 0x00656565, 0x00696969, 0x006C6C6C, 0x006F6F6F, 0x00717171, 0x00747474, 0x00767676, 0x00777777, 0x0079787A, 0x007B7A7C, 0x007C7B7D, 
        0x008B8A8C, 0x00BBBABE, 0x00B7B6BA, 0x00B4B3B6, 0xC0CCCCCD, 0xFFF0F0F0, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xED949494, 0x0B161616, 0x00282828, 0x003C3C3C, 0x00777777, 0x00757476, 0x00737274, 0x00727173, 0x006F6E70, 0x006D6C6E, 0x006A696B, 0x00686769, 0x00656466, 0x00605F61, 0x005D5C5E, 0x00585759, 0x00545355, 
        0x004E4D4F, 0x00474648, 0x00424143, 0x003A393B, 0x00313032, 0x002F2E30, 0x003B3A3C, 0x00484749, 0x00585759, 0x0069686A, 0x007D7C7E, 0x00949395, 0x00AEAEAE, 0x00C6C6C6, 0x00DFDFDF, 0x00F7F7F7, 0x00F8F8F8, 0x00DADADA, 0x00C0C0C0, 0x00A7A7A7, 
        0x00929292, 0x00808080, 0x00707070, 0x00616161, 0x00595959, 0x005A5A5A, 0x005F5F5F, 0x00646464, 0x00696969, 0x006C6C6C, 0x006F6F6F, 0x00727272, 0x00747474, 0x00767676, 0x00787878, 0x007B7B7B, 0x007C7C7C, 0x007D7C7E, 0x007F7E80, 0x00807F81, 
        0x00848385, 0x00B8B7BB, 0x00BBBABE, 0x00B6B5B8, 0x79C4C4C5, 0xFFEDEDED, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xBD656565, 0x00080808, 0x00161616, 0x00464646, 0x007C7C7C, 0x007C7B7D, 0x007A797B, 0x0079787A, 0x00767577, 0x00747375, 0x00727173, 0x00706F71, 0x006D6C6E, 0x006A696B, 0x00666567, 0x00626163, 0x005E5D5F, 
        0x00585759, 0x00535254, 0x004D4C4E, 0x00464547, 0x003E3D3F, 0x00343335, 0x00302F31, 0x003A393B, 0x004B4A4C, 0x005D5C5E, 0x00747375, 0x008C8B8D, 0x00A7A7A7, 0x00C4C4C4, 0x00E1E1E1, 0x00FAFAFA, 0x00EEEEEE, 0x00CCCCCC, 0x00AFAFAF, 0x00959595, 
        0x00808080, 0x006E6E6E, 0x005E5E5E, 0x00595959, 0x005D5D5D, 0x00636363, 0x00696969, 0x006D6D6D, 0x00707070, 0x00737373, 0x00767676, 0x00787878, 0x007A7A7A, 0x007C7C7C, 0x007E7E7E, 0x00808080, 0x00818181, 0x00838284, 0x00848385, 0x00858486, 
        0x00868587, 0x00ACABAF, 0x00BEBDC1, 0x00BBBABD, 0x3EBFBFC0, 0xFFEBEBEB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x8B3D3D3D, 0x00000000, 0x00080808, 0x00515151, 0x00838383, 0x00818082, 0x00807F81, 0x007E7D7F, 0x007D7C7E, 0x007B7A7C, 0x0079787A, 0x00777678, 0x00757476, 0x00737274, 0x00706F71, 0x006D6C6E, 0x00686769, 
        0x00646365, 0x005F5E60, 0x0059585A, 0x00545355, 0x004B4A4C, 0x00424143, 0x00373638, 0x00302F31, 0x0039383A, 0x004C4B4D, 0x00656466, 0x00807F81, 0x009F9F9F, 0x00C0C0C0, 0x00E5E5E5, 0x00FCFCFC, 0x00E0E0E0, 0x00B9B9B9, 0x00999999, 0x00808080, 
        0x006B6B6B, 0x005C5C5C, 0x005B5B5B, 0x00626262, 0x00686868, 0x006C6C6C, 0x00717171, 0x00747474, 0x00777678, 0x007A797B, 0x007C7B7D, 0x007E7D7F, 0x00818082, 0x00828183, 0x00848385, 0x00858486, 0x00868686, 0x00878688, 0x0089888A, 0x008A898B, 
        0x008A898B, 0x00A3A2A6, 0x00C1C0C4, 0x00BDBCBF, 0x12C0BFC0, 0xF9E7E7E7, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x59212121, 0x00020202, 0x00010101, 0x00676767, 0x00898989, 0x00888789, 0x00878688, 0x00868587, 0x00858486, 0x00838284, 0x00818082, 0x007F7E80, 0x007C7B7D, 0x007B7A7C, 0x0079787A, 0x00767577, 0x00727173, 
        0x006F6E70, 0x006B6A6C, 0x00666567, 0x00616062, 0x0059585A, 0x00515052, 0x00484749, 0x003C3B3D, 0x00313032, 0x00383739, 0x00525153, 0x006F6E70, 0x00939393, 0x00BFBFBF, 0x00E8E8E8, 0x00F5F5F5, 0x00C8C8C8, 0x00A0A0A0, 0x007F7F7F, 0x00666666, 
        0x005B5B5B, 0x005F5F5F, 0x00666666, 0x006D6D6D, 0x00717171, 0x00757575, 0x00797979, 0x007C7C7C, 0x007E7D7F, 0x00818082, 0x00838284, 0x00868587, 0x00878688, 0x00888789, 0x0089888A, 0x008A898B, 0x008B8B8B, 0x008C8B8D, 0x008D8C8E, 0x008E8D8F, 
        0x008F8E90, 0x009E9DA1, 0x00C3C2C6, 0x00C0BFC2, 0x00BFBFC0, 0xD8E5E5E5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x3B141414, 0x00070707, 0x00020202, 0x007D7D7D, 0x008D8D8D, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x00878688, 0x00878688, 0x00868587, 0x00848385, 0x00828183, 0x00807F81, 0x007E7D7F, 
        0x007B7A7C, 0x00777678, 0x00747375, 0x00706F71, 0x006B6A6C, 0x00636264, 0x005C5B5D, 0x00515052, 0x00434244, 0x00333234, 0x0039383A, 0x0059585A, 0x00828282, 0x00B7B7B7, 0x00EDEDED, 0x00E3E3E3, 0x00ABABAB, 0x007E7E7E, 0x00616161, 0x005D5D5D, 
        0x00666666, 0x006E6E6E, 0x00737373, 0x00787878, 0x007C7C7C, 0x00808080, 0x00828282, 0x00858585, 0x00878688, 0x00888789, 0x0089888A, 0x008B8A8C, 0x008C8B8D, 0x008D8C8E, 0x008E8D8F, 0x008F8E90, 0x00919191, 0x00919092, 0x00929193, 0x00939294, 
        0x00929193, 0x009C9B9F, 0x00C7C6CA, 0x00C3C2C5, 0x00C1C0C1, 0xBAE3E3E3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x22191919, 0x00101010, 0x000B0B0B, 0x00949494, 0x00949494, 0x00949395, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 0x008F8E90, 0x008F8E90, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x00888789, 
        0x00868587, 0x00838284, 0x00818082, 0x007E7D7F, 0x007A797B, 0x00767577, 0x006F6E70, 0x00676668, 0x005D5C5E, 0x004E4D4F, 0x003C3B3D, 0x003B3A3C, 0x00676767, 0x00ABABAB, 0x00EFEFEF, 0x00C0C0C0, 0x007F7F7F, 0x00616161, 0x00646464, 0x006F6F6F, 
        0x00777777, 0x007D7D7D, 0x00828282, 0x00858585, 0x00878787, 0x008A8A8A, 0x008B8B8B, 0x008D8D8D, 0x008E8D8F, 0x008F8E90, 0x00908F91, 0x00929193, 0x00929193, 0x00939294, 0x00949395, 0x00959496, 0x00959595, 0x00969597, 0x00979698, 0x00979698, 
        0x00979698, 0x009A999D, 0x00C8C7CB, 0x00C7C6CA, 0x00C3C2C3, 0xA2E3E3E3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x10242424, 0x001A191B, 0x001B1A1C, 0x0099989A, 0x009A999B, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00989799, 0x00979698, 0x00979698, 0x00969597, 0x00959496, 0x00949395, 0x00939294, 0x00939294, 
        0x00919092, 0x00908F91, 0x008E8D8F, 0x008D8C8E, 0x008A898B, 0x00878688, 0x00838284, 0x007F7E80, 0x0079787A, 0x00706F71, 0x00605F61, 0x00484749, 0x00434343, 0x00949494, 0x00DFDFDF, 0x00838284, 0x00656466, 0x00717072, 0x007D7C7E, 0x00838284, 
        0x00878688, 0x008B8A8C, 0x008E8D8F, 0x00919092, 0x00929193, 0x00939294, 0x00959496, 0x00969597, 0x00969597, 0x00979698, 0x00979698, 0x00989799, 0x0099989A, 0x0099989A, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009B9A9C, 
        0x00999A9E, 0x009A9B9F, 0x00BDBEC2, 0x00C6C7CB, 0x00C8C7CB, 0x8FE4E3E4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x042D2D2D, 0x00232224, 0x00262527, 0x009F9EA0, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009D9C9E, 0x009C9B9D, 0x009C9B9D, 0x009C9B9D, 
        0x009C9B9D, 0x009C9B9D, 0x009B9A9C, 0x009B9A9C, 0x0099989A, 0x00989799, 0x00979698, 0x00969597, 0x00949395, 0x00908F91, 0x008D8C8E, 0x00858486, 0x006E6E6E, 0x006B6B6B, 0x00A0A0A0, 0x007C7B7D, 0x008A898B, 0x00929193, 0x00959496, 0x00989799, 
        0x00989799, 0x009A999B, 0x009A999B, 0x009B9A9C, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x00A09FA1, 
        0x009E9FA3, 0x009D9EA2, 0x00B7B8BC, 0x00C0C1C5, 0x00C7C6CA, 0x84E4E4E5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x01343434, 0x002B2A2C, 0x002E2D2F, 0x00A09FA1, 0x009F9EA0, 0x00A09FA1, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 
        0x009E9D9F, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009B9A9C, 0x009A999B, 0x009A999B, 0x00989799, 0x00989799, 0x00959496, 0x00919092, 0x0089888A, 0x007C7C7C, 0x00A1A1A1, 0x006B6B6B, 0x006D6C6E, 0x00838284, 0x008C8B8D, 0x00908F91, 0x00949395, 
        0x00969597, 0x00979698, 0x00989799, 0x0099989A, 0x009A999B, 0x009B9A9C, 0x009B9A9C, 0x009C9B9D, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009E9D9F, 0x009F9EA0, 0x009F9EA0, 0x009F9EA0, 
        0x009D9EA2, 0x009C9DA1, 0x00B1B2B6, 0x00B9BABE, 0x00C2C1C5, 0x81E3E3E4, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x093D3D3D, 0x00333234, 0x00323133, 0x009C9B9D, 0x009B9A9C, 0x009B9A9C, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x009A999B, 0x0099989A, 0x0099989A, 0x00989799, 0x00989799, 0x00979698, 0x00969597, 
        0x00959496, 0x00949395, 0x00939294, 0x00919092, 0x00919092, 0x008E8D8F, 0x008B8A8C, 0x00878688, 0x00838284, 0x007C7B7D, 0x00717072, 0x00656466, 0x00848484, 0x00E0E0E0, 0x00939393, 0x00424143, 0x00484749, 0x00605F61, 0x00706F71, 0x0079787A, 
        0x007F7E80, 0x00848385, 0x00878688, 0x008A898B, 0x008C8B8D, 0x008D8C8E, 0x00908F91, 0x00919092, 0x00929193, 0x00939294, 0x00949395, 0x00949395, 0x00969597, 0x00979698, 0x00979698, 0x00989799, 0x00989799, 0x00989799, 0x0099989A, 0x0099989A, 
        0x0098999D, 0x0096979B, 0x00ABACB0, 0x00B0B1B5, 0x00BBBABE, 0x89E2E1E2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x18444444, 0x003B3A3C, 0x00343335, 0x00969597, 0x00979698, 0x00979698, 0x00979698, 0x00969597, 0x00959496, 0x00959496, 0x00949395, 0x00939294, 0x00929193, 0x00929193, 0x00919092, 0x00919092, 0x008E8D8F, 
        0x008D8C8E, 0x008B8A8C, 0x008A898B, 0x00878688, 0x00858585, 0x00828282, 0x007D7D7D, 0x00777777, 0x00707070, 0x00636363, 0x00606060, 0x00808080, 0x00C1C1C1, 0x00EFEFEF, 0x00ABABAB, 0x00686769, 0x003C3B3D, 0x003C3B3D, 0x004D4C4E, 0x005C5B5D, 
        0x00676668, 0x006F6E70, 0x00767577, 0x007A797B, 0x007E7D7F, 0x00818082, 0x00838284, 0x00868587, 0x00888789, 0x008A898B, 0x008B8A8C, 0x008C8B8D, 0x008D8C8E, 0x008F8E90, 0x008F8E90, 0x00919092, 0x00929193, 0x00929193, 0x00939294, 0x00949395, 
        0x00929397, 0x00949599, 0x00A3A4A8, 0x00AAABAF, 0x00B3B2B6, 0x98E2E1E2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x2E515151, 0x00454446, 0x003B3A3C, 0x0089888A, 0x00929193, 0x00939294, 0x00929193, 0x00919092, 0x00919092, 0x008F8E90, 0x008E8D8F, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x00878688, 
        0x00858486, 0x00828183, 0x007F7E80, 0x007C7B7D, 0x00787878, 0x00737373, 0x006E6E6E, 0x00666666, 0x005D5D5D, 0x00626262, 0x007E7E7E, 0x00ADADAD, 0x00E3E3E3, 0x00ECECEC, 0x00B8B8B8, 0x00828183, 0x005A595B, 0x0039383A, 0x00333234, 0x00434244, 
        0x00515052, 0x005C5B5D, 0x00636264, 0x006B6A6C, 0x00706F71, 0x00747375, 0x00777678, 0x007B7A7C, 0x007E7D7F, 0x00807F81, 0x00828183, 0x00848385, 0x00868587, 0x00878688, 0x00878688, 0x0089888A, 0x008A898B, 0x008B8A8C, 0x008C8B8D, 0x008D8C8E, 
        0x008C8D91, 0x008E8F93, 0x009C9DA1, 0x00A3A4A8, 0x00AEADB1, 0xADE3E2E3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x49656565, 0x004C4B4D, 0x00464547, 0x007B7A7C, 0x008E8D8F, 0x008E8D8F, 0x008D8C8E, 0x008C8B8D, 0x008B8A8C, 0x008A898B, 0x0089888A, 0x00888789, 0x00878688, 0x00858486, 0x00838284, 0x00828183, 0x007F7E80, 
        0x007C7B7D, 0x0079787A, 0x00757476, 0x00717072, 0x006D6D6D, 0x00666666, 0x005F5F5F, 0x005B5B5B, 0x00666666, 0x00808080, 0x00A0A0A0, 0x00C8C8C8, 0x00F5F5F5, 0x00E8E8E8, 0x00BDBDBD, 0x00949395, 0x006F6E70, 0x00525153, 0x00383739, 0x00323133, 
        0x003C3B3D, 0x00484749, 0x00515052, 0x0059585A, 0x00616062, 0x00666567, 0x006B6A6C, 0x006F6E70, 0x00727173, 0x00767577, 0x0079787A, 0x007B7A7C, 0x007C7B7D, 0x007F7E80, 0x00818082, 0x00838284, 0x00858486, 0x00858486, 0x00878688, 0x00888789, 
        0x0086878B, 0x008A8B8F, 0x0096979B, 0x009C9DA1, 0x00AAA9AD, 0xC9E5E4E5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x6E7E7E7E, 0x00555456, 0x004D4C4E, 0x006E6D6F, 0x0089888A, 0x008A898B, 0x0089888A, 0x00878688, 0x00868587, 0x00858486, 0x00848385, 0x00828183, 0x00818082, 0x007E7D7F, 0x007C7B7D, 0x007A797B, 0x00777678, 
        0x00757476, 0x00717072, 0x006D6C6E, 0x00686769, 0x00626262, 0x005B5B5B, 0x005C5C5C, 0x006B6B6B, 0x007F7F7F, 0x009A9A9A, 0x00BABABA, 0x00DFDFDF, 0x00FDFDFD, 0x00E4E4E4, 0x00C1C1C1, 0x00A09FA1, 0x007F7E80, 0x00646365, 0x004C4B4D, 0x003A393B, 
        0x00302F31, 0x00373638, 0x00424143, 0x004B4A4C, 0x00545355, 0x0059585A, 0x005F5E60, 0x00646365, 0x00686769, 0x006D6C6E, 0x00706F71, 0x00737274, 0x00757476, 0x00777678, 0x0079787A, 0x007B7A7C, 0x007D7C7E, 0x007E7D7F, 0x00807F81, 0x00818082, 
        0x00808185, 0x00848589, 0x008F9094, 0x0095969A, 0x04A9A8AC, 0xEAE8E7E8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xA7959595, 0x005F5E60, 0x00545355, 0x00616062, 0x00858486, 0x00858585, 0x00848484, 0x00838383, 0x00828282, 0x00818181, 0x007E7E7E, 0x007C7C7C, 0x007A7A7A, 0x00787878, 0x00757575, 0x00737373, 0x00707070, 
        0x006D6D6D, 0x00696969, 0x00636363, 0x005D5D5D, 0x00595959, 0x005D5D5D, 0x006E6E6E, 0x00808080, 0x00959595, 0x00AFAFAF, 0x00CCCCCC, 0x00EDEDED, 0x00FAFAFA, 0x00E1E1E1, 0x00C3C3C3, 0x00A6A6A6, 0x008B8A8C, 0x00737274, 0x005C5B5D, 0x004A494B, 
        0x003A393B, 0x002F2E30, 0x00343335, 0x003E3D3F, 0x00464547, 0x004D4C4E, 0x00535254, 0x00585759, 0x005D5C5E, 0x00636264, 0x00666567, 0x006A696B, 0x006D6C6E, 0x00706F71, 0x00727173, 0x00747375, 0x00777678, 0x00787779, 0x0079787A, 0x007B7A7C, 
        0x007E7D7F, 0x00807F81, 0x00888789, 0x008F8E90, 0x27AFAEAF, 0xFFEBEBEB, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xD5B1B1B1, 0x00666567, 0x005C5B5D, 0x005B5A5C, 0x00807F81, 0x00808080, 0x007F7F7F, 0x007E7E7E, 0x007D7D7D, 0x007B7B7B, 0x00787878, 0x00767676, 0x00747474, 0x00727272, 0x006F6F6F, 0x006C6C6C, 0x00676767, 
        0x00646464, 0x005F5F5F, 0x005A5A5A, 0x00595959, 0x00626262, 0x00707070, 0x00818181, 0x00939393, 0x00A7A7A7, 0x00C1C1C1, 0x00DADADA, 0x00F8F8F8, 0x00F8F8F8, 0x00E0E0E0, 0x00C5C5C5, 0x00ADADAD, 0x00949395, 0x007D7C7E, 0x00686769, 0x00575658, 
        0x00484749, 0x003B3A3C, 0x002F2E30, 0x00323133, 0x003A393B, 0x00424143, 0x00474648, 0x004E4D4F, 0x00545355, 0x005A595B, 0x005D5C5E, 0x00616062, 0x00646365, 0x00676668, 0x006A696B, 0x006E6D6F, 0x00706F71, 0x00727173, 0x00737274, 0x00757476, 
        0x00767577, 0x007B7A7C, 0x00818082, 0x008A898B, 0x55B9B9B9, 0xFFEEEEEE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFDCACACA, 0x24717072, 0x00676668, 0x005C5B5D, 0x00777678, 0x007B7B7B, 0x007A7A7A, 0x00797979, 0x00777777, 0x00767676, 0x00737373, 0x00717171, 0x006E6E6E, 0x006B6B6B, 0x00686868, 0x00656565, 0x00616161, 
        0x005C5C5C, 0x00585858, 0x005A5A5A, 0x00656565, 0x00727272, 0x007F7F7F, 0x008F8F8F, 0x00A2A2A2, 0x00B7B7B7, 0x00CFCFCF, 0x00E7E7E7, 0x00FDFDFD, 0x00F5F5F5, 0x00DEDEDE, 0x00C7C7C7, 0x00B2B2B2, 0x009B9A9C, 0x00878688, 0x00747375, 0x00636264, 
        0x00545355, 0x00464547, 0x003B3A3C, 0x00313032, 0x002F2E30, 0x00373638, 0x003E3D3F, 0x00454446, 0x004B4A4C, 0x00504F51, 0x00545355, 0x00585759, 0x005C5B5D, 0x005F5E60, 0x00636264, 0x00676668, 0x0069686A, 0x006B6A6C, 0x006D6C6E, 0x006F6E70, 
        0x00706F71, 0x00747375, 0x007C7B7D, 0x00838284, 0xA1CBCBCB, 0xFFEFEFEF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFD5D5D5, 0x638D8C8E, 0x006F6E70, 0x00676668, 0x006C6B6D, 0x00777777, 0x00767676, 0x00747474, 0x00727272, 0x00717171, 0x006E6E6E, 0x006B6B6B, 0x00686868, 0x00656565, 0x00626262, 0x005E5E5E, 0x00595959, 
        0x00585858, 0x005F5F5F, 0x00676767, 0x00737373, 0x00818181, 0x008D8D8D, 0x009F9F9F, 0x00B1B1B1, 0x00C4C4C4, 0x00DADADA, 0x00F1F1F1, 0x00FFFFFF, 0x00F1F1F1, 0x00DDDDDD, 0x00C8C8C8, 0x00B4B4B4, 0x00A1A0A2, 0x008E8D8F, 0x007D7C7E, 0x006D6C6E, 
        0x005F5E60, 0x00504F51, 0x00454446, 0x003B3A3C, 0x00313032, 0x002D2C2E, 0x00343335, 0x003B3A3C, 0x00424143, 0x00474648, 0x004C4B4D, 0x00504F51, 0x00545355, 0x00585759, 0x005B5A5C, 0x005F5E60, 0x00626163, 0x00646365, 0x00676668, 0x006A696B, 
        0x00686769, 0x006C6B6D, 0x00757476, 0x06908F91, 0xDDD5D5D5, 0xFFF2F2F2, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFDCDCDC, 0xBCADACAE, 0x00787779, 0x00717072, 0x0069686A, 0x00747474, 0x00737373, 0x00707070, 0x006E6E6E, 0x006C6C6C, 0x00696969, 0x00666666, 0x00646464, 0x00606060, 0x005D5D5D, 0x00585858, 0x00585858, 
        0x00606060, 0x006A6A6A, 0x00757575, 0x00818181, 0x008D8D8D, 0x009B9B9B, 0x00ABABAB, 0x00BDBDBD, 0x00CFCFCF, 0x00E4E4E4, 0x00F9F9F9, 0x00FEFEFE, 0x00EEEEEE, 0x00DCDCDC, 0x00CACACA, 0x00B8B8B8, 0x00A5A4A6, 0x00949395, 0x00848385, 0x00757476, 
        0x00676668, 0x005A595B, 0x004E4D4F, 0x00444345, 0x0039383A, 0x00313032, 0x002D2C2E, 0x00323133, 0x0039383A, 0x003F3E40, 0x00434244, 0x0049484A, 0x004D4C4E, 0x00515052, 0x00545355, 0x00585759, 0x005B5A5C, 0x005D5C5E, 0x00626163, 0x00636264, 
        0x00605F61, 0x00646365, 0x006C6B6D, 0x3CA9A8AA, 0xFFDCDCDC, 0xFFF5F5F5, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFE5E5E5, 0xF6C9C8CA, 0x24848385, 0x00787779, 0x006F6E70, 0x006E6E6E, 0x006E6E6E, 0x006B6B6B, 0x00696969, 0x00676767, 0x00646464, 0x00616161, 0x005F5F5F, 0x00595959, 0x00575757, 0x005A5A5A, 0x00636363, 
        0x006B6B6B, 0x00757575, 0x00808080, 0x008B8B8B, 0x00989898, 0x00A6A6A6, 0x00B6B6B6, 0x00C7C7C7, 0x00D9D9D9, 0x00ECECEC, 0x00FDFDFD, 0x00FBFBFB, 0x00ECECEC, 0x00DBDBDB, 0x00CBCBCB, 0x00BABABA, 0x00AAA9AB, 0x009A999B, 0x0089888A, 0x007B7A7C, 
        0x006F6E70, 0x00626163, 0x00575658, 0x004C4B4D, 0x00434244, 0x003B3A3C, 0x00323133, 0x002D2C2E, 0x00302F31, 0x00363537, 0x003C3B3D, 0x00414042, 0x00454446, 0x0049484A, 0x004E4D4F, 0x00525153, 0x00555456, 0x00585759, 0x005A595B, 0x005F5E60, 
        0x005F5E60, 0x005E5D5F, 0x006B6A6C, 0x9AC8C7C9, 0xFFE4E4E4, 0xFFF8F8F8, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFEBEBEB, 0xFFD8D7D9, 0x80A09FA1, 0x00818082, 0x0079787A, 0x00707070, 0x00696969, 0x00686868, 0x00656565, 0x00626262, 0x00606060, 0x005C5C5C, 0x00585858, 0x00575757, 0x005C5C5C, 0x00646464, 0x006D6D6D, 
        0x00777777, 0x00808080, 0x008B8B8B, 0x00979797, 0x00A4A4A4, 0x00B2B2B2, 0x00C1C1C1, 0x00D1D1D1, 0x00E2E2E2, 0x00F3F3F3, 0x00FFFFFF, 0x00F8F8F8, 0x00EBEBEB, 0x00DADADA, 0x00CCCCCC, 0x00BCBCBC, 0x00ADACAE, 0x009F9EA0, 0x008F8E90, 0x00838284, 
        0x00757476, 0x0069686A, 0x005F5E60, 0x00545355, 0x004B4A4C, 0x00424143, 0x003A393B, 0x00333234, 0x002E2D2F, 0x00302F31, 0x00353436, 0x003A393B, 0x003F3E40, 0x00434244, 0x00474648, 0x004A494B, 0x004E4D4F, 0x00525153, 0x00565557, 0x0069686A, 
        0x00686769, 0x005D5C5E, 0x1389888A, 0xECD7D6D8, 0xFFEBEBEB, 0xFFFAFAFA, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF1F1F1, 0xFFE1E0E2, 0xE2C3C2C4, 0x1089888A, 0x00818082, 0x00787878, 0x006A6A6A, 0x00626262, 0x00616161, 0x005D5D5D, 0x00595959, 0x00575757, 0x00585858, 0x00606060, 0x00676767, 0x006F6F6F, 0x00767676, 
        0x00808080, 0x008A8A8A, 0x00959595, 0x00A0A0A0, 0x00ADADAD, 0x00BBBBBB, 0x00CACACA, 0x00D8D8D8, 0x00E8E8E8, 0x00F8F8F8, 0x00FFFFFF, 0x00F6F6F6, 0x00E8E8E8, 0x00D9D9D9, 0x00CDCDCD, 0x00BEBEBE, 0x00B0AFB1, 0x00A3A2A4, 0x00939294, 0x00888789, 
        0x007C7B7D, 0x00706F71, 0x00656466, 0x005C5B5D, 0x00525153, 0x0049484A, 0x00424143, 0x003B3A3C, 0x00333234, 0x002E2D2F, 0x002E2D2F, 0x00333234, 0x00373638, 0x003C3B3D, 0x00403F41, 0x00454446, 0x00484749, 0x004C4B4D, 0x00605F61, 0x00767577, 
        0x006D6C6E, 0x006A696B, 0x72BCBBBD, 0xFFE1E0E2, 0xFFF1F1F1, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF5F5F5, 0xFFE8E8E8, 0xFFD5D5D5, 0x70A3A3A3, 0x00888888, 0x00828183, 0x00777678, 0x005F5E60, 0x005B5A5C, 0x00595959, 0x00575757, 0x005B5B5B, 0x00616260, 0x00676767, 0x006F6F6F, 0x00777777, 0x00808080, 
        0x00898989, 0x00939393, 0x009E9E9E, 0x00A9A9A9, 0x00B6B6B6, 0x00C3C3C3, 0x00D1D1D1, 0x00DFDFDF, 0x00EEEEEE, 0x00FDFDFD, 0x00FEFEFE, 0x00F3F3F3, 0x00E6E6E6, 0x00D9D9D9, 0x00CDCDCD, 0x00BFBFBF, 0x00B2B2B2, 0x00A5A5A5, 0x00989898, 0x008C8C8C, 
        0x00807F81, 0x00757476, 0x006B6A6C, 0x00616062, 0x00585759, 0x00504F51, 0x00484749, 0x00414042, 0x003B3A3C, 0x00343335, 0x002E2D2F, 0x002C2B2D, 0x00333234, 0x00353436, 0x003C3B3D, 0x003F3E40, 0x00434244, 0x0049484A, 0x00807F81, 0x007D7C7E, 
        0x00747375, 0x11919092, 0xDFD4D3D5, 0xFFEAE9EB, 0xFFF6F6F6, 0xFFFCFCFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFF8F8F8, 0xFFF1F1F1, 0xFFE0E0E0, 0xE4C4C4C4, 0x15959595, 0x0089888A, 0x00818082, 0x006D6C6E, 0x00575658, 0x00585858, 0x005D5D5D, 0x00626262, 0x006A6A6A, 0x00707070, 0x00787878, 0x00808080, 0x00888888, 
        0x00919191, 0x009C9C9C, 0x00A6A6A6, 0x00B2B2B2, 0x00BEBEBE, 0x00CBCBCB, 0x00D8D8D8, 0x00E6E6E6, 0x00F4F4F4, 0x00FFFFFF, 0x00FCFCFC, 0x00F1F1F1, 0x00E5E5E5, 0x00D8D8D8, 0x00CDCDCD, 0x00C0C0C0, 0x00B4B4B4, 0x00A8A8A8, 0x009C9C9C, 0x00909090, 
        0x00868587, 0x007B7A7C, 0x00717072, 0x00686769, 0x005F5E60, 0x00575658, 0x004F4E50, 0x00484749, 0x00424143, 0x003B3A3C, 0x00343335, 0x002F2E30, 0x002B2A2C, 0x00323133, 0x00343335, 0x0039383A, 0x003C3B3D, 0x00727173, 0x008D8C8E, 0x00858486, 
        0x00807F81, 0x7AC2C1C3, 0xFFE1E0E2, 0xFFF0EFF1, 0xFFF8F8F8, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF6F6F6, 0xFFEBEBEB, 0xFFD6D6D6, 0x8EAFAFAF, 0x00949395, 0x008A898B, 0x00807F81, 0x00636363, 0x005F5F5F, 0x00656565, 0x006A6A6A, 0x00717171, 0x00797979, 0x00808080, 0x00888888, 0x00919191, 
        0x00999999, 0x00A4A4A4, 0x00AEAEAE, 0x00BABABA, 0x00C5C5C5, 0x00D2D2D2, 0x00DEDEDE, 0x00EBEBEB, 0x00F9F9F9, 0x00FFFFFF, 0x00FAFAFA, 0x00F0F0F0, 0x00E4E4E4, 0x00D8D8D8, 0x00CDCDCD, 0x00C1C1C1, 0x00B6B6B6, 0x00ABABAB, 0x009F9F9F, 0x00949494, 
        0x0089888A, 0x007F7E80, 0x00767577, 0x006D6C6E, 0x00656466, 0x005D5C5E, 0x00555456, 0x004E4D4F, 0x00474648, 0x00414042, 0x003B3A3C, 0x00353436, 0x00302F31, 0x002C2B2D, 0x00302F31, 0x00333234, 0x00555456, 0x009C9B9D, 0x00959496, 0x008E8D8F, 
        0x21A8A7A9, 0xECD8D7D9, 0xFFEBEAEC, 0xFFF6F5F7, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF1F1F1, 0xFFE4E4E4, 0xF5CCCCCC, 0x39A2A1A3, 0x00929193, 0x008A8A8A, 0x00808080, 0x00696969, 0x006B6B6B, 0x00727272, 0x00797979, 0x00808080, 0x00878787, 0x008F8F8F, 0x00989898, 
        0x00A1A1A1, 0x00ABABAB, 0x00B6B6B6, 0x00C1C1C1, 0x00CCCCCC, 0x00D8D8D8, 0x00E3E3E3, 0x00F1F1F1, 0x00FCFCFC, 0x00FFFFFF, 0x00F8F8F8, 0x00EFEFEF, 0x00E3E3E3, 0x00D8D8D8, 0x00CECECE, 0x00C2C2C2, 0x00B8B8B8, 0x00ADADAD, 0x00A3A3A3, 0x00989898, 
        0x008D8C8E, 0x00848385, 0x007B7A7C, 0x00727173, 0x006A696B, 0x00626163, 0x005A595B, 0x00545355, 0x004D4C4E, 0x00464547, 0x00403F41, 0x003A393B, 0x00353436, 0x002F2E30, 0x002D2C2E, 0x003E3D3F, 0x00A09FA1, 0x00A7A6A8, 0x009B9A9C, 0x029F9EA0, 
        0xACCCCBCD, 0xFFE2E1E3, 0xFFF3F2F4, 0xFFF8F7F9, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFF7F7F7, 0xFFEEEEEE, 0xFFDDDDDD, 0xD3C1C1C1, 0x129D9D9D, 0x00939393, 0x008B8B8B, 0x007F7F7F, 0x00737373, 0x007A797B, 0x00807F81, 0x00878787, 0x008E8E8E, 0x00969696, 0x009F9F9F, 
        0x00A8A8A8, 0x00B2B2B2, 0x00BCBCBC, 0x00C7C7C7, 0x00D1D1D1, 0x00DDDDDD, 0x00E9E9E9, 0x00F4F4F4, 0x00FFFFFF, 0x00FEFEFE, 0x00F7F7F7, 0x00ECECEC, 0x00E2E2E2, 0x00D8D8D8, 0x00CECECE, 0x00C3C3C3, 0x00BABABA, 0x00AFAFAF, 0x00A5A5A5, 0x009B9B9B, 
        0x00929193, 0x00878688, 0x007F7E80, 0x00767577, 0x006F6E70, 0x00676668, 0x005F5E60, 0x00585759, 0x00525153, 0x004B4A4C, 0x00444345, 0x00414042, 0x003B3A3C, 0x00353436, 0x00373638, 0x00A09FA1, 0x00B5B5B5, 0x00ADADAD, 0x00A5A5A5, 0x66C2C2C2, 
        0xFFDDDDDD, 0xFFEEEEEE, 0xFFF7F7F7, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF5F5F5, 0xFFEAEAEA, 0xFFD8D8D8, 0x9CB8B8B8, 0x029C9C9C, 0x00949494, 0x008C8C8C, 0x00828183, 0x00807F81, 0x00868587, 0x008D8D8D, 0x00959595, 0x009D9D9D, 0x00A5A5A5, 
        0x00AFAFAF, 0x00B9B9B9, 0x00C3C3C3, 0x00CECECE, 0x00D8D8D8, 0x00E2E2E2, 0x00EEEEEE, 0x00F9F9F9, 0x00FFFFFF, 0x00FDFDFD, 0x00F5F5F5, 0x00EBEBEB, 0x00E1E1E1, 0x00D7D7D7, 0x00CECECE, 0x00C4C4C4, 0x00BBBBBB, 0x00B1B1B1, 0x00A8A8A8, 0x009E9E9E, 
        0x00959496, 0x008B8A8C, 0x00838284, 0x007A797B, 0x00737274, 0x006B6A6C, 0x00646365, 0x005D5C5E, 0x00565557, 0x00504F51, 0x004B4A4C, 0x00434244, 0x003E3D3F, 0x00424143, 0x00A4A3A5, 0x00C6C5C7, 0x00BDBDBD, 0x00B4B4B4, 0x31BDBDBD, 0xEDD8D8D8, 
        0xFFEAEAEA, 0xFFF5F5F5, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF3F3F3, 0xFFE7E7E7, 0xFFD4D4D4, 0x75B3B3B3, 0x009A9A9A, 0x00959496, 0x008B8A8C, 0x00868587, 0x008C8B8D, 0x00959595, 0x009C9C9C, 0x00A3A3A3, 0x00ACACAC, 
        0x00B6B6B6, 0x00BFBFBF, 0x00C8C8C8, 0x00D3D3D3, 0x00DDDDDD, 0x00E8E8E8, 0x00F2F2F2, 0x00FDFDFD, 0x00FFFFFF, 0x00FCFCFC, 0x00F3F3F3, 0x00EAEAEA, 0x00E1E1E1, 0x00D7D7D7, 0x00CECECE, 0x00C5C5C5, 0x00BBBBBB, 0x00B2B2B2, 0x00AAAAAA, 0x00A0A0A0, 
        0x00979698, 0x008E8D8F, 0x00868587, 0x007E7D7F, 0x00777678, 0x006F6E70, 0x00686769, 0x00616062, 0x005C5B5D, 0x00545355, 0x004F4E50, 0x00484749, 0x004B4A4C, 0x00B2B1B3, 0x00D4D3D5, 0x00CCCBCD, 0x00C5C5C5, 0x1AC1C1C1, 0xDBD3D3D3, 0xFFE6E6E6, 
        0xFFF3F3F3, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF1F2F0, 0xFFE4E4E4, 0xF7D1D1D1, 0x60AFAFAF, 0x009D9C9E, 0x00959496, 0x008A898B, 0x00878688, 0x00969696, 0x00A3A3A3, 0x00AAAAAA, 0x00B2B2B2, 
        0x00BBBBBB, 0x00C5C5C5, 0x00CECECE, 0x00D7D7D7, 0x00E1E1E1, 0x00EBEBEB, 0x00F5F5F5, 0x00FEFEFE, 0x00FFFFFF, 0x00FAFAFA, 0x00F1F1F1, 0x00E9E9E9, 0x00E0E0E0, 0x00D7D7D7, 0x00CFCFCF, 0x00C5C5C5, 0x00BDBDBD, 0x00B4B4B4, 0x00ACACAC, 0x00A3A3A3, 
        0x009B9A9C, 0x00929193, 0x008A898B, 0x00828183, 0x007B7A7C, 0x00737274, 0x006C6B6D, 0x00666567, 0x005F5E60, 0x00565557, 0x00535254, 0x00626163, 0x00CBCACC, 0x00E4E3E5, 0x00DDDCDE, 0x00D4D3D5, 0x14C9C9C9, 0xC3D0D0D0, 0xFFE4E4E4, 0xFFF1F1F1, 
        0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFEFEFEF, 0xFFE3E3E3, 0xF3D0D0D0, 0x5BAFAFAF, 0x009B9B9B, 0x00939393, 0x008C8C8C, 0x00878787, 0x009C9C9C, 0x00B1B1B1, 0x00B8B8B8, 
        0x00C1C1C1, 0x00C9C9C9, 0x00D3D3D3, 0x00DDDDDD, 0x00E5E5E5, 0x00EEEEEE, 0x00F9F9F9, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F9F9, 0x00F0F0F0, 0x00E8E8E8, 0x00E0E0E0, 0x00D7D7D7, 0x00CFCFCF, 0x00C6C6C6, 0x00BEBEBE, 0x00B6B6B6, 0x00AEAEAE, 0x00A6A6A6, 
        0x009C9B9D, 0x00949395, 0x008C8B8D, 0x00858486, 0x007E7D7F, 0x00757476, 0x00717072, 0x0069686A, 0x00646464, 0x005C5C5C, 0x00868686, 0x00E9E9E9, 0x00F3F3F3, 0x00EBEBEB, 0x00E3E3E3, 0x14D1D1D1, 0xBAD1D1D1, 0xFFE3E3E3, 0xFFF0F0F0, 0xFFF8F8F8, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF6F6F6, 0xFFF0F0F0, 0xFFE2E2E2, 0xF4CFCFCF, 0x68B2B2B2, 0x009C9C9C, 0x00949494, 0x008A8A8A, 0x00848484, 0x00959595, 0x00BABABA, 
        0x00C5C5C5, 0x00CFCFCF, 0x00D6D6D6, 0x00DFDFDF, 0x00E9E9E9, 0x00F3F3F3, 0x00FCFCFC, 0x00FFFFFF, 0x00FEFEFE, 0x00F8F8F8, 0x00EFEFEF, 0x00E7E7E7, 0x00DFDFDF, 0x00D7D7D7, 0x00CFCFCF, 0x00C7C7C7, 0x00BEBEBE, 0x00B7B7B7, 0x00AFAFAF, 0x00A7A7A7, 
        0x009F9EA0, 0x00979698, 0x008F8E90, 0x00888789, 0x00807F81, 0x007B7A7C, 0x00737274, 0x006B6A6C, 0x006E6E6E, 0x00B0B0B0, 0x00FBFBFB, 0x00FEFEFE, 0x00FBFBFB, 0x00F3F3F3, 0x1AD8D8D8, 0xC3D1D1D1, 0xFFE2E2E2, 0xFFF0F0F0, 0xFFF7F7F7, 0xFFFAFAFA, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFEFEFEF, 0xFFE4E4E4, 0xFBD5D5D5, 0x86B9B9B9, 0x0A9F9F9F, 0x00959595, 0x008C8C8C, 0x00838383, 0x00858585, 
        0x00ADADAD, 0x00D2D2D2, 0x00DCDCDC, 0x00E3E3E3, 0x00EDEDED, 0x00F6F6F6, 0x00FEFEFE, 0x00FFFFFF, 0x00FDFDFD, 0x00F5F5F5, 0x00EEEEEE, 0x00E5E5E5, 0x00DFDFDF, 0x00D6D6D6, 0x00CFCFCF, 0x00C7C7C7, 0x00C0C0C0, 0x00B8B8B8, 0x00B1B1B1, 0x00A9A9A9, 
        0x00A1A0A2, 0x0099989A, 0x00929193, 0x008A898B, 0x00838284, 0x007D7C7E, 0x00767577, 0x008C8B8D, 0x00C1C1C1, 0x00DFDFDF, 0x00EEEEEE, 0x00F8F8F8, 0x00F9F9F9, 0x31D8D8D8, 0xDBD2D2D2, 0xFFE3E3E3, 0xFFEFEFEF, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF1F1F1, 0xFFE8E8E8, 0xFFD7D7D7, 0xB7C2C2C2, 0x1FA3A3A3, 0x00949494, 0x008C8C8C, 0x00848484, 
        0x007B7B7B, 0x00858585, 0x00B7B7B7, 0x00E5E5E5, 0x00F1F1F1, 0x00F8F8F8, 0x00FEFEFE, 0x00FFFFFF, 0x00FCFCFC, 0x00F3F3F3, 0x00EDEDED, 0x00E4E4E4, 0x00DEDEDE, 0x00D6D6D6, 0x00D0D0D0, 0x00C8C8C8, 0x00C1C1C1, 0x00B9B9B9, 0x00B2B2B2, 0x00AAAAAA, 
        0x00A4A3A5, 0x009C9B9D, 0x00959496, 0x008D8C8E, 0x00878688, 0x00838284, 0x00949395, 0x00AEADAF, 0x00BCBCBC, 0x00CDCDCD, 0x00DDDDDD, 0x02E5E5E5, 0x66D2D2D2, 0xEDD6D6D6, 0xFFE7E7E7, 0xFFF1F1F1, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF3F3F3, 0xFFEAEAEA, 0xFFDDDDDD, 0xE8CDCDCD, 0x61B0B0B0, 0x05979797, 0x008B8B8B, 
        0x00848484, 0x007A7A7A, 0x00737373, 0x00777777, 0x00A2A1A3, 0x00DBDADC, 0x00FEFDFE, 0x00FDFCFE, 0x00FBFAFC, 0x00F4F3F5, 0x00ECEBED, 0x00E5E4E6, 0x00DEDEDE, 0x00D6D6D6, 0x00CFCFCF, 0x00C8C8C8, 0x00C2C2C2, 0x00B9B9B9, 0x00B4B4B4, 0x00ACACAC, 
        0x00A5A5A5, 0x009E9E9E, 0x00858585, 0x00707070, 0x006D6D6D, 0x007B7B7B, 0x008C8C8C, 0x009D9D9D, 0x00ADADAD, 0x00BCBCBC, 0x21C9C9C9, 0xACCFCFCF, 0xFFDDDDDD, 0xFFEAEAEA, 0xFFF3F3F3, 0xFFF8F8F8, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 
        0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFF9F9F9, 0xFFF5F5F5, 0xFFEEEEEE, 0xFFE5E5E5, 0xFFD5D5D5, 0xBFC4C4C4, 0x38A6A6A6, 
        0x008F8F8F, 0x00848484, 0x007B7B7B, 0x00747474, 0x006B6A6C, 0x00616062, 0x0069686A, 0x00908F91, 0x00ABAAAC, 0x00C5C4C6, 0x00D7D6D8, 0x00E1E0E2, 0x00DEDEDE, 0x00D7D7D7, 0x00D0D0D0, 0x00C9C9C9, 0x00BDBDBD, 0x00A5A5A5, 0x00848484, 0x00616161, 
        0x00464646, 0x00323232, 0x00383838, 0x004A4A4A, 0x005A5A5A, 0x006A6A6A, 0x007A7A7A, 0x008C8C8C, 0x11ACACAC, 0x7AC5C5C5, 0xECD6D6D6, 0xFFE3E3E3, 0xFFEEEEEE, 0xFFF5F5F5, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 
        0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFCFCFC, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF7F7F7, 0xFFF1F1F1, 0xFFEBEBEB, 0xFFE1E1E1, 0xFAD6D6D6, 
        0xB0C2C2C2, 0x3AA5A5A5, 0x00888888, 0x007C7C7C, 0x00747375, 0x006C6B6D, 0x00626163, 0x005B5A5C, 0x00525153, 0x0049484A, 0x00414042, 0x003A393B, 0x003B3B3B, 0x00393939, 0x00303030, 0x00212121, 0x00111111, 0x00060606, 0x00000000, 0x00010101, 
        0x00090909, 0x00171717, 0x00282828, 0x00383838, 0x00494949, 0x005E5E5E, 0x13929292, 0x72BFBFBF, 0xDFD5D5D5, 0xFFDFDFDF, 0xFFECECEC, 0xFFF3F3F3, 0xFFF7F7F7, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFF6F6F6, 0xFFF1F1F1, 0xFFE9E9E9, 
        0xFFDFDFDF, 0xFFD7D7D7, 0xC7CACACA, 0x66AEAEAE, 0x1C919092, 0x00767577, 0x006C6B6D, 0x00626163, 0x005B5A5C, 0x00525153, 0x0049484A, 0x00424143, 0x003A3A3A, 0x00313131, 0x00282828, 0x00212121, 0x00181818, 0x000F0F0F, 0x00080808, 0x00010101, 
        0x00010101, 0x00090909, 0x001D1D1D, 0x06585858, 0x3C969696, 0x9AC8C8C8, 0xECD6D6D6, 0xFFE1E1E1, 0xFFE9E9E9, 0xFFF0F0F0, 0xFFF6F6F6, 0xFFF7F7F7, 0xFFFAFAFA, 0xFFF9F9F9, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 
        0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFAFAFA, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFAFAFA, 0xFFFBFBFB, 0xFFF8F8F8, 0xFFF5F5F5, 
        0xFFF2F2F2, 0xFFEBEBEB, 0xFFE4E4E4, 0xFFDCDCDC, 0xF5D6D6D6, 0xC0CACACA, 0x79B2B2B2, 0x3E989898, 0x12808080, 0x00696969, 0x00555555, 0x004A4A4A, 0x00434343, 0x00393939, 0x00313131, 0x00292929, 0x001F1F1F, 0x001C1C1C, 0x00292929, 0x04424242, 
        0x27636363, 0x55949494, 0xA1C6C6C6, 0xDDD5D5D5, 0xFFDDDDDD, 0xFFE4E4E4, 0xFFEBEBEB, 0xFFF2F2F2, 0xFFF6F6F6, 0xFFF9F9F9, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 
        0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFBFBFB, 0xFFFDFDFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFCFCFC, 
        0xFFFCFCFC, 0xFFFAFAFA, 0xFFF8F8F8, 0xFFF5F5F5, 0xFFF1F1F1, 0xFFEEEEEE, 0xFFECECEC, 0xFFEAEAEA, 0xF9E7E7E7, 0xD8E5E5E5, 0xBAE2E2E2, 0xA2DADADA, 0x8FD0D0D0, 0x84CBCBCB, 0x81CACACA, 0x89CBCBCB, 0x98D5D5D5, 0xADE3E3E3, 0xC9E6E6E6, 0xEAE7E7E7, 
        0xFFEBEBEB, 0xFFEDEDED, 0xFFEEEEEE, 0xFFF3F3F3, 0xFFF5F5F5, 0xFFF8F8F8, 0xFFFAFAFA, 0xFFFCFCFC, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 
        0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFDFDFD, 0xFFFEFEFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

GUI_CONST_STORAGE GUI_BITMAP bmknob_gray_trans_70x70 = {
  70, // xSize
  70, // ySize
  280, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acknob_gray_trans_70x70,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Backgound 480x272
*/
static GUI_CONST_STORAGE GUI_COLOR _ColorsBackGround_480x272[] = {
  0x000000, 0xE1DCDD, 0xDDD9D9, 0xE5E1E1,
  0xD9D5D5, 0xD6D1D1, 0xE9E5E5, 0xB5ADAD,
  0xB1A9A9, 0xE4DEE0, 0xE0DADC, 0xADA5A5,
  0xA9A1A1, 0xA19999, 0xA59D9D, 0xCEC8C8,
  0xBEB9B8, 0xCECAC8, 0xCCC8C6, 0xD0CCCA,
  0xCAC6C4, 0xCCC6C6, 0xE8E2E4, 0xD2CCCC,
  0xCAC4C4, 0xC4BEBE, 0xD0CACA, 0xD2CECC,
  0x9D9595, 0xD4CECE, 0xC8C2C2, 0xD4D0CE,
  0xC8C4C2, 0xC6C2C0, 0xC6C0C0, 0xDCD6D8,
  0xC5C0BE, 0xC0BABA, 0xC2BCBC, 0xB8B0B0,
  0xC2BEBC, 0xC1BCBA, 0x89807D, 0xBAB5B4,
  0xBAB2B2, 0x9A9191, 0xD8D4D2, 0x8D8481,
  0x867D7A, 0xD2CECE, 0x827875, 0x918886,
  0xBCB6B6, 0x7E7471, 0xBCB4B4, 0xD8D2D2,
  0xBDB8B6, 0x796E6C, 0xBEB6B6, 0x766A68,
  0x958C8A, 0xD8D2D4, 0x786C6A, 0x968D8C,
  0x746866, 0xB8B2B2, 0xD0CCCC, 0x7D7270,
  0xC0B8B8, 0x7C716E, 0x7A706D, 0x726664,
  0x908684, 0xB6B0B0, 0x807674, 0x948A89,
  0x706462, 0x8C8280, 0xB9B4B2, 0x887E7C,
  0x99908E, 0xEAE8E8, 0xECE9E9, 0x847A78,
  0x988E8D, 0xDCD6D6, 0x928988, 0x9C9492,
  0x6E6260, 0xC0BAB8, 0xBCB6B4, 0xE6E2E4,
  0x9C9292, 0x6C605E, 0xC2BABA, 0xDCD8D6,
  0xE6E4E4, 0xB8B2B0, 0xEAE6E8, 0xCECACA,
  0x766C69, 0xB6B0AE, 0xD4CED0, 0x807572,
  0x6A5E5C, 0xC4BEBC, 0xA09696, 0xA09896,
  0xE0DADA, 0xB2ACAC, 0x8E8584, 0xCCC8C8,
  0xECE6E8, 0xC4BCBC, 0x665A58, 0xD2CDCE,
  0xB2ACAA, 0xA49C9A, 0x726865, 0xD0CAC9,
  0xCBC6C6, 0xC3BEBE, 0x8A8180, 0xAEA8A8,
  0x685C5A, 0xC5C0C0, 0x9E9896, 0xC8C2C0,
  0xCAC4C3, 0x847976, 0xE8E2E2, 0x645856,
  0xD7D4D2, 0xE3DEE0, 0xD2CCCB, 0xC1BCBC,
  0xA49A9A, 0xDBD6D8, 0xAEA8A7, 0xC6BEBE,
  0xDFDADC, 0xAAA4A4, 0xC9C4C4, 0xA8A09E,
  0xC7C2C2, 0xCEC8C7, 0xE4DEDF, 0xA39C9A,
  0xB8AFAF, 0xCCC6C5, 0xBAB1B1, 0xE0DCDB,
  0xD7D2D4, 0x887E7B, 0x6E6461, 0xD0CBCC,
  0xD6D0CF, 0xD3D0CE, 0x625654, 0xA7A09E,
  0xB0A8A7, 0x877E7C, 0x908683, 0xDBD8D6,
  0x7F7674, 0x8C827F, 0x9F9898, 0xABA4A2,
  0xACA4A3, 0xB8AFB0, 0xBCB3B3, 0xBAB3B4,
  0xBCB5B6, 0xC0B9BA, 0xD1CECC, 0x605452,
  0x7C6F6D, 0xA39C9C, 0xABA3A4, 0xB0A7A7,
  0x837A78, 0x948A87, 0x97908D, 0x9B9492,
  0xA09798, 0xACA3A2, 0xACA3A4, 0xB4ABAB,
  0xBEB5B5, 0x746765, 0x998F90, 0x9F9798,
  0xA39B9C, 0xB4ABAC, 0xBAB1B2, 0x7B7270,
  0x988E8B, 0x9C9394, 0xA89E9E, 0xBCB3B4,
  0xBEB5B6, 0xC2B9BA, 0xE3E0E0, 0xA7A0A0,
  0xB6AFB0, 0xC8C1C0, 0xCEC9CA, 0xA49B9C,
  0xB8B0AE, 0xBAB2B1, 0xB8B1B2, 0xBEB7B8,
  0xC0B7B7, 0xC2B9B9, 0xE9E8E7, 0x786B69,
  0xA89FA0, 0x706361, 0xB4ACAB, 0xCAC2C2,
  0xD3CED0, 0xB2ABAC, 0xCCC7C8, 0xDBD8D8,
  0x958B8C, 0x9B9494, 0xA79FA0, 0xB0A7A8,
  0xBCB4B3, 0xCFCCCB, 0xE6E4E3, 0xECE6E7,
  0x6C5F5E, 0x807372, 0x938C89, 0x9B9394,
  0xBEB6B5, 0xC0B8B7, 0xC2BAB9, 0xC4BCBB,
  0xC1BBBC, 0xCDCAC9, 0xDFDCDB, 0xDFDCDC,
  0x5F5351, 0x8F8885, 0x918788, 0x979090,
  0xAFA7A8, 0xC0B7B8, 0xC1BEBD, 0xC5C2C0,
  0xCBC5C6, 0xD3D0D0, 0xD7D4D4, 0xE4E0DF
};

static GUI_CONST_STORAGE GUI_LOGPALETTE _PalBackGround_480x272 = {
  256,  // Number of entries
  0,    // No transparency
  &_ColorsBackGround_480x272[0]
};

static GUI_CONST_STORAGE unsigned char _acBackGround_480x272[] = {
  0xAA, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0xD4, 0xD4, 0x44, 0xD5, 0xAD, 0x25, 0x25, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 
        0x12, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x1D, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x1D, 
        0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x17, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1B, 
        0x31, 0x9D, 0x1B, 0xAE, 0xAE, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 
        0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0xED, 0x3A, 0x3A, 0xBC, 0x36, 0x36, 0xAA, 0xAA, 0x2C, 0xD1, 0xD1, 0x96, 0x27, 0x94, 0x07, 0x07, 0x07, 0xC1, 0x07, 0x07, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xB2, 
        0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0xC6, 0x75, 0x93, 0x0D, 0x6B, 0x6B, 0x6B, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0xB7, 0x2D, 0x2D, 0x5C, 0x5C, 0x2D, 0x57, 0x57, 0xB7, 0x57, 0x57, 0x2D, 0x5C, 0x5C, 0x57, 0x57, 0x2D, 0x2D, 0x50, 0x2D, 
        0x2D, 0x2D, 0x50, 0x2D, 0x50, 0xB6, 0xF7, 0xF7, 0xB6, 0x54, 0x3F, 0x3F, 0x54, 0x3F, 0xE0, 0x3C, 0x4B, 0x56, 0x56, 0x33, 0x33, 0x33, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x4F, 0x99, 0x30, 0x53, 0xB4, 0x32, 0x32, 0xA4, 0x35, 0x35, 0x43, 0xC3, 0x46, 
        0x46, 0xB0, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0x46, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 
        0x45, 0x45, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x3E, 0x39, 0x3E, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3B, 0x3B, 0xD7, 0xD7, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x3B, 0x40, 0x40, 0x40, 0xBD, 0x40, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
  0x36, 0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0xD4, 0x44, 0x10, 0xAD, 0xAD, 0x25, 0xF0, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x22, 0x21, 0x21, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x8E, 0x8E, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x13, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 
        0x1B, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0xAE, 0x42, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x11, 0x77, 0x0F, 0x0F, 0x0F, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 
        0x24, 0x24, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0xED, 0x10, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0xBC, 0xEC, 0xAC, 0x36, 0x2B, 0xAB, 0xAA, 0xAB, 0xAB, 0x2C, 0x2C, 0x96, 0x27, 0x94, 0x07, 0x07, 
        0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x8A, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x9F, 0x9F, 0x9F, 0x0E, 0x75, 0x75, 0x93, 0x0D, 0x6B, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x5C, 0x2D, 0x50, 0x50, 0xC4, 0xC4, 
        0x3C, 0x3C, 0x4B, 0xB5, 0xB5, 0x33, 0x33, 0xF5, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0xB4, 0x53, 0x53, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 
        0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x67, 0x67, 0x35, 0x35, 0x43, 0x43, 0x45, 0x46, 0x46, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 
        0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0x58, 0x9A, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0xD9, 0x4C, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 0x58, 
        0x58, 0x58, 0x58, 0x5D, 0x5D, 0x68, 0x68, 0x68, 0x68, 0x68, 0x7C, 0x7C, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x83, 0x83, 0x83, 0x83, 0x83, 0x83, 0x83,
  0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0xD5, 0xD5, 0xD5, 0xC9, 0xC9, 0xC9, 0xEF, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x24, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0xCD, 0xCD, 0x7F, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 
        0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x3D, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 
        0x21, 0x22, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0x2C, 0x96, 0x96, 0x96, 0x27, 0x94, 0x94, 0x94, 0x07, 0x07, 
        0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0x0B, 0x0B, 0x0B, 0x0B, 0xB2, 0x0C, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0x93, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x57, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 
        0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0xB5, 0x56, 0x56, 0x33, 0x33, 0x33, 0xF5, 0x6E, 0x6E, 0x2F, 0x2F, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x53, 0x30, 
        0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0xB4, 0xB4, 0x32, 0x32, 0x4A, 0xA4, 0x67, 0x35, 0x35, 0x43, 0x43, 0x45, 0x45, 0xB0, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x3E, 0x3E, 0x3E, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x76, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 
        0x58, 0x58, 0x5D, 0x58, 0x58, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x7C, 0x7C, 0x7C, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72,
  0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0x44, 0x44, 0xAD, 0xD5, 0x25, 0x25, 0x5E, 0x5E, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x22, 0x22, 0x22, 0x22, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 
        0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x84, 0x05, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0xAE, 0x17, 0x86, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 
        0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x29, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x34, 0x34, 0xAC, 0x2B, 0xAB, 0x2C, 0x2C, 0x2C, 0x96, 0x27, 0x27, 0xCC, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x93, 0x0D, 0x0D, 0xA6, 0x6B, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0x50, 
        0x54, 0xC4, 0x3C, 0x3C, 0x4B, 0x56, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 
        0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0x53, 0x32, 0x32, 0x32, 0x32, 0x67, 0x35, 0x35, 0x43, 0x45, 0xB0, 0xB0, 0x39, 0x3E, 0x3E, 
        0xD7, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x40, 0x3B, 0x3B, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xBD, 0x40, 0x40, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9,
  0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0xAD, 0xD5, 0xD5, 0xD5, 0xAD, 0xAD, 0x25, 0x29, 0x26, 0x26, 0xEF, 0x26, 0x26, 0x26, 
        0x19, 0x19, 0x19, 0x8B, 0x22, 0x22, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 
        0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x1D, 0x1B, 0x9D, 0x1D, 0x1B, 0x9D, 0x1D, 0x1B, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 
        0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x9D, 0x1D, 0x1B, 0x1B, 0x17, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x21, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 
        0x26, 0x29, 0x25, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x44, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0xD3, 0x3A, 0x34, 0x34, 0x3A, 0x34, 0x34, 0x34, 0x38, 0xEC, 0x34, 0x34, 0xAC, 0x2B, 0x36, 0x36, 0xAA, 0xAB, 0xAB, 0x2C, 0x96, 0x96, 
        0x96, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x9F, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x93, 0xC0, 0x93, 0x88, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0xB8, 0xB8, 0xB8, 0x7E, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x5C, 0x2D, 0x50, 0x50, 0x54, 0x54, 0xC4, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 
        0x2A, 0x2A, 0x99, 0x99, 0x30, 0x30, 0x53, 0x32, 0x32, 0x32, 0xA4, 0x35, 0x35, 0x45, 0x45, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0xD7, 0x64, 0xD7, 0x64, 0x64, 0x64, 0x64, 0x64, 0x64, 0x64, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0x47, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 
        0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47,
  0x44, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0x44, 0x44, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0x5E, 0x5E, 0xC9, 0xD5, 0x5E, 0x5E, 0xD5, 0x5E, 0x5E, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0x10, 0xD5, 0xD5, 0xD5, 0x5E, 0x5E, 0x5E, 0x5E, 0x29, 
        0x29, 0x29, 0xF0, 0xF0, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x79, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0xAE, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0x17, 0x17, 0x1B, 0x17, 0x1B, 0x1B, 
        0x9D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x05, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x17, 0x17, 0x17, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 
        0x26, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0xD4, 0x3A, 0x38, 0x34, 0xBC, 0xAC, 0xAC, 0x36, 0x36, 0xAC, 0x2B, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0xE4, 0xAA, 
        0xAA, 0x96, 0x96, 0x2C, 0x96, 0x27, 0x27, 0x27, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0x9F, 0x0E, 0xB1, 0x93, 0x0D, 0x0D, 0x6B, 0x6A, 0x1C, 0xEB, 0x2D, 
        0x2D, 0x50, 0x54, 0x3F, 0x3C, 0x3C, 0x4B, 0x4B, 0xEA, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x6E, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 
        0x2A, 0x2A, 0x2A, 0xA1, 0x30, 0x30, 0x30, 0xB4, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x46, 0x45, 0x45, 0x46, 0x46, 0xB0, 0x46, 0xB0, 0xB0, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x43, 0x35, 
        0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0xBD, 0xBD, 0xBD, 
        0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0x5D, 0x68, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x58,
  0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x44, 0xD5, 0xD5, 0xAD, 0x5E, 0x26, 0x26, 0x5E, 0x5E, 0x5E, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x5E, 0x5E, 0x25, 0x25, 0x5E, 0x26, 0x5E, 0x25, 0x25, 0x5E, 0x26, 0x26, 0xEF, 0x26, 
        0x26, 0xEF, 0xEF, 0xEF, 0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x22, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 
        0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x9D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1F, 0x1F, 0x9D, 0x1F, 0x1F, 
        0x1F, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x9D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x90, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 
        0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0xEF, 0x29, 0x25, 0xAD, 0xAD, 0x44, 0x44, 0xD3, 0x34, 0x2B, 0xAA, 0xAA, 0x2C, 0x96, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 
        0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x75, 0xC0, 0x0D, 0xA6, 0xA6, 0x7E, 0x1C, 0x57, 0x57, 0x2D, 0x50, 0x50, 0xB6, 0x3F, 0x3C, 0x3C, 
        0x4B, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0xA2, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 
        0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0xA4, 0xA4, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x43, 0x43, 0x43, 
        0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0x4A, 0x4A, 0xA4, 0xA4, 0xA4, 0x35, 0x67, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x43, 0x45, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x3E, 
        0x3E, 0xD7, 0xD7, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x4C, 0x4C, 0xD9, 0x58, 0x58, 0x58, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x7C, 0x7C, 0x7C, 0x72, 0x72, 0x72,
  0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0xD3, 0xD4, 0xD3, 0x10, 0x10, 0xAD, 0x25, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 
        0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x22, 0x22, 0x7D, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1F, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 
        0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x18, 0x14, 
        0x80, 0x8E, 0x80, 0x20, 0x20, 0x1E, 0x80, 0x80, 0x90, 0x90, 0x90, 0x21, 0x21, 0xCD, 0x22, 0x22, 0x22, 0x24, 0x19, 0x19, 0x69, 0x69, 0x26, 0xEF, 0x26, 0x5E, 0xEE, 0xD5, 0xAD, 0x10, 0x44, 0xD3, 0xD3, 0x38, 0x34, 0x34, 0xAC, 0x2B, 0xAB, 0x4E, 0x41, 
        0x41, 0xD2, 0x27, 0x49, 0xCC, 0x07, 0x07, 0x6D, 0x6D, 0xDA, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0x9F, 0x9F, 0x0E, 0x0E, 0x0E, 0xB1, 0x93, 0x93, 0x93, 0x93, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 
        0x57, 0x57, 0x57, 0x57, 0x57, 0x2D, 0x50, 0x50, 0x50, 0x54, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0x33, 0x33, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x53, 0xB4, 0xB4, 
        0x32, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0xC3, 0x43, 0x43, 0x43, 0x45, 0x45, 0x43, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 
        0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0x46, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x76, 0xBD, 0xBD, 0xBD, 0x76, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 
        0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD,
  0xAD, 0xAD, 0xAD, 0xAD, 0x10, 0x44, 0x44, 0x10, 0x44, 0xD4, 0x44, 0x44, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x44, 0xD5, 0xD5, 0xEE, 0x5E, 0x5E, 0x5E, 0x29, 0x87, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x79, 0x24, 0x24, 0x21, 0x21, 
        0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 
        0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x5F, 0x23, 0x23, 0x5F, 0xDF, 0x23, 
        0xDF, 0x5F, 0x5F, 0xA3, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0xFD, 0x1F, 0x9C, 0x1F, 0x1F, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 
        0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x10, 0x10, 0x44, 0x10, 0xD3, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x36, 0xE4, 0xE4, 
        0x2C, 0xAB, 0x2C, 0x2C, 0x2C, 0xD1, 0xD2, 0xD2, 0xD2, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x74, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xD8, 0xE2, 0x0E, 0x0E, 0x0E, 0xC0, 0x0D, 0x0D, 0x6B, 0x7E, 
        0x1C, 0x1C, 0xC5, 0x57, 0x5C, 0x2D, 0x50, 0x54, 0xB6, 0xC4, 0x3F, 0x3C, 0x3C, 0xEA, 0xEA, 0x4B, 0x4B, 0xEA, 0xB5, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x2F, 0x2F, 0x2F, 0x4D, 
        0xA5, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0x35, 0x35, 0x35, 0x43, 0x43, 0xC3, 0x45, 0x45, 0x45, 0x46, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 
        0x3E, 0x64, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0x76, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 
        0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0x68, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68,
  0x2B, 0x2B, 0xBC, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x25, 0x25, 0x25, 0x5E, 0x25, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x77, 0x77, 0x77, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 
        0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x05, 0x05, 0x84, 0x05, 0x05, 0x2E, 0x2E, 0x2E, 0x05, 0x05, 0x05, 0x84, 0x84, 0x37, 0x37, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x9D, 0x1D, 0x1D, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x59, 0x10, 0x10, 0x10, 0x38, 0x34, 0xBC, 0x36, 
        0xAA, 0xAA, 0x2C, 0x96, 0x96, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0x6D, 0x6D, 0xDD, 0x08, 0x08, 0x08, 0x7B, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8D, 0xA7, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xD8, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 
        0xC0, 0x0D, 0x0D, 0x0D, 0x6A, 0x1C, 0x1C, 0xC5, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x54, 0x54, 0x3F, 0x3F, 0x3C, 0xEA, 0xB5, 0x56, 0x33, 0x33, 0x48, 0xA2, 0x6E, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 
        0x99, 0x30, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0x53, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x43, 0x45, 0x45, 0x46, 
        0x39, 0x39, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 
        0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0xD9, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x9A, 0x9A, 0x4C, 0x4C, 0x4C, 0x4C,
  0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0x36, 0x36, 0x36, 0x3A, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0x10, 0x10, 0x44, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 
        0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x73, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x1D, 
        0x1F, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x9C, 0x9C, 0x1F, 0x1D, 0x9C, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x2E, 0xFE, 0x3D, 0x3D, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x37, 0x05, 0x05, 0x05, 0x1D, 0x9D, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x79, 0x26, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0xAD, 0x44, 0x44, 0x10, 
        0x3A, 0xBC, 0x36, 0x36, 0x2B, 0xAB, 0x96, 0x27, 0x27, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0x9F, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0xBF, 0x6A, 0x7E, 
        0x1C, 0x1C, 0x1C, 0xC5, 0xB7, 0xEB, 0xEB, 0xB7, 0xEB, 0xB7, 0xB7, 0xB7, 0xB7, 0xB7, 0x5C, 0xB7, 0xB7, 0x2D, 0x5C, 0x2D, 0x5C, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x50, 0xBE, 0x50, 0x3F, 0x3F, 0x3C, 0x3C, 0x4B, 0x56, 0x33, 0x33, 0x6E, 0x2F, 0x2F, 0x4D, 
        0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0x53, 0x53, 0x81, 0x81, 0x32, 0x32, 0x4A, 0x4A, 0x67, 0x67, 0x35, 0x35, 0x35, 0x43, 0x45, 0x45, 0x45, 0x46, 0x46, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x76, 0xBD, 0xBD, 0xBD, 0x47, 
        0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x46, 0xB0, 0x46, 0x46, 0xB0, 0x46, 0x46, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0xD7, 0xD7, 0x3B, 
        0x3B, 0x3B, 0x40, 0xBD, 0x47, 0x47, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x68, 0x68, 0x68, 0x7C, 0x68, 0x7C, 0x68, 0x68, 0x7C,
  0xC1, 0x07, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x2C, 0x2C, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x3A, 0x10, 0x10, 0x10, 0xAD, 0xAD, 0xAD, 0x29, 0x29, 0xEF, 
        0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 
        0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x9D, 0x9D, 0x1D, 0x9C, 0x1D, 0x1D, 0x9C, 0x1D, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 
        0x1D, 0x1D, 0x1F, 0x1D, 0x1F, 0x1F, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x84, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x9C, 0x1F, 0x1F, 0x1D, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 
        0x90, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x79, 0x79, 0x26, 0x26, 0x29, 0x29, 0x29, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0xD5, 0xAD, 0x25, 0x10, 0x44, 0x10, 0x44, 0x10, 0xED, 0xD4, 0xD4, 0xD3, 0xD3, 
        0x34, 0xAC, 0xAC, 0x36, 0xE4, 0xE4, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x94, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 
        0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0xB8, 0x6A, 0x6A, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0xC5, 0xC5, 0x57, 0x5C, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x54, 0x3F, 0x3F, 0x3C, 0x4B, 0x4B, 0x56, 0x33, 0x48, 0x6E, 0x6E, 0x2F, 0x4D, 0xA5, 
        0x7A, 0x2A, 0x99, 0x30, 0x53, 0xB4, 0x81, 0x32, 0x32, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0xC3, 0x43, 0x43, 0xC3, 
        0x43, 0x43, 0x43, 0x45, 0x45, 0xC3, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0xC3, 0xC3, 0x45, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x40, 0xBD, 0xBD, 0x47, 0x47, 
        0x4C, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0xE8,
  0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0xD4, 0x44, 0x44, 0x44, 0xD5, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x69, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 
        0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 
        0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 
        0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x04, 0xA3, 0xA3, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 
        0x90, 0x90, 0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xAD, 0xAD, 0xAD, 0xAD, 0xAD, 0x25, 0x25, 0xAD, 0xAD, 0xAD, 0x10, 0xAD, 0x10, 0x10, 0x10, 0xD3, 0x34, 0x34, 
        0xAC, 0xAC, 0xAC, 0x36, 0x2B, 0x4E, 0x96, 0x27, 0x94, 0xCC, 0x07, 0x07, 0x6D, 0xBB, 0xDD, 0x08, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0xBA, 0xB2, 0xB9, 0x0C, 0x0C, 0x0C, 0xCB, 0xD8, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x75, 0x75, 0xB1, 0x75, 0x93, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0x2D, 0x2D, 0x50, 0x50, 0x3F, 0x3F, 0x3C, 0xB5, 0x33, 0x48, 0xA2, 
        0x2F, 0x4D, 0xA5, 0x2A, 0x99, 0x30, 0x53, 0x53, 0x81, 0x32, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x64, 
        0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0xD7, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x40, 0x40, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47,
  0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0xCD, 0xCD, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x21, 0x21, 0x21, 
        0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x22, 0x24, 0x22, 0x22, 0x24, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x91, 0x91, 0x91, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 
        0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x84, 
        0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 
        0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x22, 0x8B, 0x19, 0x19, 0x19, 0x26, 0x26, 0x29, 0x25, 0x25, 0x10, 0x10, 0x34, 0x34, 0x5A, 0x36, 0xE4, 0x4E, 
        0xC2, 0x96, 0x27, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x08, 0xA0, 0x8A, 0x8A, 0x08, 0xA0, 0xA0, 0x8A, 0x8A, 0x7B, 0x7B, 0x8A, 0x8A, 0x8A, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0xA7, 
        0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0x93, 0x0D, 0x0D, 0xA6, 0x6A, 0x1C, 0x1C, 0x57, 0xB7, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x54, 0x54, 0x54, 0xC4, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x4D, 0x4D, 
        0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x45, 
        0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 
        0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0,
  0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0x44, 0x44, 0xAD, 0xEE, 0xEE, 0xD5, 0x25, 0x25, 0x25, 0x25, 0x5E, 0x5E, 0x26, 0x26, 0x26, 0xEF, 0xEF, 0xEF, 0xEF, 0xEF, 0x71, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 
        0x19, 0x24, 0x22, 0x24, 0x7D, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x91, 
        0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 
        0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x9D, 0x9C, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x9C, 0x1F, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 
        0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0xFE, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x98, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x9C, 0x1D, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x77, 0x0F, 0x0F, 0x12, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0xAD, 0x10, 0x10, 0x10, 0x38, 0xD3, 0x34, 0x34, 0x34, 0x34, 0xBC, 0xAC, 0x2B, 
        0x36, 0x36, 0xAA, 0x2C, 0x2C, 0x27, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0x6D, 0xBB, 0xBB, 0xDD, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x7B, 0x8A, 0xB3, 0xF8, 0x0B, 0x8A, 0xB3, 0x0B, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 
        0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0xC0, 0x0D, 0xA6, 0xA6, 0x6A, 0x1C, 0x1C, 0xC5, 0xEB, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x54, 0xC4, 0xC4, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0xA2, 0xA2, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0xB4, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0xC3, 0x46, 0x46, 0x39, 0x39, 0x3E, 0x64, 0x3B, 
        0x3B, 0x3B, 0xBD, 0xBD, 0x47, 0x47, 0x4C, 0x9A, 0x4C, 0x4C, 0x4C, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35,
  0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0xD4, 0x10, 0x44, 0x44, 0xD5, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x24, 0x24, 
        0x19, 0x24, 0x8B, 0x8B, 0x8B, 0x8B, 0x24, 0x24, 0x22, 0x24, 0x7D, 0x7D, 0x21, 0xCD, 0x90, 0xCD, 0x90, 0x90, 0x1E, 0x1E, 0xDB, 0x80, 0x20, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0xAE, 0xAE, 0x17, 0x86, 0x17, 0x86, 0xAE, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x9C, 0x9C, 0x1F, 0x1D, 0x1B, 0x9D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x9B, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0xCE, 0x0F, 0x91, 0x12, 0xDE, 0x12, 0x12, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0xAD, 0xAD, 0x44, 
        0xED, 0xD3, 0x3A, 0xEC, 0x36, 0x36, 0xAB, 0x2C, 0xD2, 0xD2, 0x27, 0x94, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 
        0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0xB1, 0xC0, 0xC0, 0x0D, 0xB8, 0x6A, 0x1C, 0x1C, 0xB7, 0x2D, 0x2D, 0x50, 0xB6, 0xC4, 0x3C, 0x3C, 0x3C, 0x4B, 0xB5, 0x56, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 
        0x53, 0x53, 0x81, 0x32, 0x32, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0xC3, 0x46, 0x46, 0xB0, 0x46, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x76, 0x76, 0xBD, 0x76, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 
        0x9A, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0xE8, 0x68, 0x68, 0x68, 0x68, 0x7C, 0x7C, 0x7C, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72,
  0xBC, 0x3A, 0x34, 0x34, 0x3A, 0xD4, 0xD3, 0xD3, 0xD4, 0xD4, 0xD4, 0x44, 0xED, 0x10, 0xAD, 0xAD, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0xAD, 0x44, 0x44, 0x10, 0xED, 0xED, 0xD3, 0xD4, 0x10, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0xD4, 0xD4, 0x44, 
        0x44, 0x44, 0xD5, 0xAD, 0xAD, 0xD5, 0x25, 0x25, 0x5E, 0x29, 0x87, 0x26, 0x26, 0x71, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x22, 0xCD, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x55, 0x04, 0xA3, 0xA3, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 
        0x91, 0x91, 0x12, 0x78, 0x14, 0x14, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x22, 0x22, 0x24, 0x24, 0x19, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x38, 0x34, 0x36, 
        0x36, 0x2B, 0xE4, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x07, 0x07, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 
        0xA8, 0xB2, 0xB2, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x75, 0xC0, 0x0D, 0x0D, 0xA6, 0x6A, 0x1C, 0x57, 0x5C, 0x2D, 0x50, 0xC4, 0xC4, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x81, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 
        0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0xB0, 0xB0, 0x46, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0xB0, 0x46, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0xD9, 0x58, 0x58, 0x58,
  0xAA, 0xAA, 0x2B, 0x2B, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2B, 0xBC, 0x36, 0x2B, 0x34, 0x34, 0xAC, 0x34, 0x34, 0xD3, 0xD3, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0xD5, 0xEE, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0xD5, 0xD5, 0x5E, 
        0xC9, 0xD5, 0x5E, 0x5E, 0xD5, 0xD5, 0x25, 0x25, 0xAD, 0x25, 0x25, 0x29, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x84, 0x2E, 0x2E, 0x37, 0x37, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x05, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 
        0x1F, 0x05, 0x05, 0x9C, 0x05, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1B, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x22, 0x22, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x79, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0xD3, 0xD3, 
        0x38, 0x34, 0xAC, 0xAC, 0x2B, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0xE4, 0xE4, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 
        0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xB8, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0xB7, 0xB7, 0xB7, 0xB7, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 
        0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0xB6, 0x3F, 0xE0, 0x3C, 0xEA, 0x56, 0x56, 0x33, 0x33, 0x48, 0x6E, 0x6E, 0x4D, 0x4D, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x53, 0x32, 0x32, 0x32, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0x45, 0x45, 0x45, 0x45, 0x46, 
        0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3E, 0x3E, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 
        0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x5D,
  0x08, 0x08, 0x08, 0xBB, 0xBB, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0xA9, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0x36, 0xBC, 0xBC, 0x3A, 0xD3, 0xD4, 0x44, 0x10, 0xAD, 0x25, 0x29, 0xF0, 0xF0, 0xF0, 0x26, 0x26, 0x69, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x22, 0x22, 0x21, 0xCD, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x14, 0x14, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 
        0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x17, 0x86, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0xAE, 
        0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x1D, 0x1F, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x3D, 0x2E, 0x2E, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x55, 0x04, 0x89, 0x89, 0xA3, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x11, 0xF1, 0x0F, 0x91, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 
        0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x22, 0x22, 0x22, 0x22, 0x24, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0xEE, 0x44, 0x44, 0x38, 0x34, 0xAC, 0xAA, 0x2C, 0x2C, 0x96, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xB3, 0x0B, 0x0B, 0xA8, 0x0C, 0x0C, 0x0C, 
        0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x75, 0x75, 0xCF, 0xC0, 0x88, 0x88, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0x50, 0x54, 0x3F, 0x3C, 0x3C, 0xEA, 0x56, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 
        0x33, 0x33, 0x56, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x56, 0x56, 0x33, 0x33, 0x33, 0x48, 0x6E, 0x2F, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x53, 0x53, 0x32, 0x32, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x43, 0x43, 
        0x43, 0x45, 0x46, 0x46, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x64, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 
        0x46, 0xB0, 0x46, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x40, 0xBD, 0x47, 0x47, 0x4C, 0xD9, 0x58, 0x58, 0x58, 0x5D, 0xE8, 0xE8, 0xE8, 0x68,
  0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 0xBC, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0xD5, 0xD5, 0x5E, 0x26, 0xEF, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x80, 
        0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0xFC, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 
        0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x84, 0x84, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x9C, 0x1F, 0x9C, 
        0x1D, 0x1D, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 
        0x84, 0x84, 0x84, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x9D, 0x1F, 0x1F, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x17, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x21, 0x24, 0x19, 0x19, 0x19, 0x19, 0x28, 0x26, 
        0x26, 0x26, 0x26, 0x25, 0xD5, 0x44, 0x44, 0x44, 0xD4, 0x3A, 0xEC, 0xBC, 0x36, 0xAA, 0x2C, 0x2C, 0xD2, 0x27, 0x94, 0x94, 0x65, 0x07, 0x07, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 
        0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0x9F, 0x9F, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x75, 0x88, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0xB8, 0x7E, 0x1C, 0x1C, 0x1C, 0x57, 0xC5, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0xB6, 0x54, 0x54, 0xC4, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0xEA, 
        0x56, 0x33, 0x33, 0x33, 0x48, 0xA2, 0x6E, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x43, 
        0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x43, 0x45, 0x43, 0x43, 0x45, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 
        0x64, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xBD, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0x40,
  0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x36, 0x36, 0x36, 0xBC, 0x3A, 0x3A, 0x3A, 0x10, 0x44, 0x44, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x24, 0x7D, 0x21, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x20, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x1A, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x9D, 0x1B, 0x9D, 0x1D, 0x9D, 0x9D, 0x1D, 0x9D, 0x1B, 0x1D, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x84, 0x84, 0x84, 0x84, 
        0x05, 0x05, 0x05, 0x9C, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x9D, 0x1D, 0x9D, 0x9D, 0x9D, 0x31, 0x1B, 0x1B, 0xAE, 0xAE, 0x1B, 0xAE, 0xAE, 
        0x1B, 0x17, 0xAE, 0xAE, 0xAE, 0xAE, 0xAE, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x19, 0x19, 0x24, 0x19, 0x79, 0x79, 0x29, 0x29, 0x25, 0x25, 0x25, 
        0x25, 0x59, 0x10, 0x44, 0xED, 0xED, 0xD3, 0x34, 0x34, 0xEC, 0xEC, 0x36, 0x36, 0x36, 0xAA, 0x2C, 0x2C, 0xD1, 0xD2, 0x27, 0x27, 0x49, 0xCC, 0xCC, 0x07, 0x07, 0x07, 0x6D, 0x6D, 0xDD, 0xDD, 0xDD, 0x08, 0x08, 0x08, 0x08, 0x7B, 0x7B, 0xB3, 0xB3, 0xB3, 
        0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0x8D, 0x8D, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0x8F, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x75, 0x88, 0x0D, 0x6B, 0x6A, 0x6A, 0x1C, 0xC5, 0x2D, 
        0x50, 0x50, 0x54, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x48, 0x2F, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x53, 0x53, 0xB4, 0x81, 0x32, 0x32, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x35, 0x43, 0x45, 0xB0, 0xB0, 0xB0, 0x39, 0x3E, 0x3E, 0x3E, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x46, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 
        0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x47,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0x36, 0xBC, 0x3A, 0xD4, 0x44, 0x25, 0x25, 0x26, 0x26, 0x69, 0x19, 0x24, 0x22, 0xCD, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x21, 0x22, 0x21, 0x7D, 0x24, 0x22, 0x22, 0x22, 0x24, 0x22, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 
        0x86, 0x86, 0xAE, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x3D, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x55, 0xA3, 0xA3, 0x23, 0x5F, 0x5F, 0xDF, 0xDF, 0x23, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xA3, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x77, 
        0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 
        0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x87, 0x29, 0xF0, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x2C, 0xD2, 0x27, 0x49, 0x65, 0x07, 0x07, 0x6D, 0x6D, 0xDD, 0x08, 0xA0, 0xB3, 
        0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xB9, 0xB9, 0x0C, 0x0C, 0x8F, 0x8F, 0xC6, 0x0E, 0x0E, 0x75, 0x93, 0x88, 0x0D, 0x6B, 0x7E, 0x1C, 0x57, 0x2D, 0x2D, 0x50, 0xB6, 0x3F, 0x3C, 0xEA, 0x56, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x7A, 0x2A, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0xB4, 0x81, 0x32, 0x32, 0x4A, 0x4A, 0x35, 0x35, 0x43, 0x43, 0x45, 
        0x45, 0x45, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0xB0, 0xB0, 0x39, 0xB0, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0xB0, 0x39, 
        0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x47, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
  0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 0x36, 0xC8, 0x3A, 0x3A, 0xD3, 0x44, 0xAD, 0xAD, 0x25, 0x5E, 0x5E, 0x26, 0x69, 0x19, 
        0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0xFC, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 
        0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0x73, 
        0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 0x37, 0x37, 0x05, 0x37, 0x37, 
        0x05, 0x37, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1F, 0x1F, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 
        0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x14, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 
        0x1E, 0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x44, 0xD4, 0xD3, 0x34, 0xBC, 0x36, 0xE4, 0x2B, 0xAB, 0xD1, 0xD1, 0xD2, 0x49, 0x49, 0x65, 0x07, 0x6D, 0xDA, 0x74, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 
        0xA8, 0xB2, 0xB9, 0x0C, 0x0C, 0x0C, 0xE2, 0xC6, 0x0E, 0x0E, 0x75, 0x75, 0x75, 0x88, 0x88, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0xB6, 0x3F, 0x3F, 0xC4, 0x3C, 0x3C, 0x3C, 
        0x4B, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x4A, 0xA4, 0x35, 0x35, 0x35, 
        0xC3, 0x45, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 
        0x46, 0x45, 0x45, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x40, 0xBD, 0xBD, 0x47, 0x4C, 0xD9, 0xD9, 0x58, 0x58, 0x5D,
  0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x3A, 0x3A, 0x3A, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xED, 0xED, 0x44, 0xD5, 0xEE, 
        0xEE, 0x25, 0x29, 0x29, 0x87, 0x26, 0x19, 0x19, 0x19, 0x79, 0x79, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 
        0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 
        0x77, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x05, 0x05, 0x84, 
        0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0xFE, 0xFE, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x87, 0x26, 
        0x26, 0xF0, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0xAD, 0x44, 0x10, 0x10, 0x10, 0x10, 0xD3, 0x10, 0x10, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x38, 0x34, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x34, 0x2B, 0x2B, 0xAB, 0x2C, 0x2C, 0x27, 0x27, 
        0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0xA0, 0xB3, 0xF8, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0xE2, 0x9F, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0xBF, 0x6A, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0xB7, 
        0x2D, 0x2D, 0xBE, 0x50, 0x50, 0x50, 0x50, 0x54, 0x54, 0xC4, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x3C, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x56, 0x33, 0x33, 0x33, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x4F, 0x99, 
        0x99, 0x30, 0x30, 0x53, 0x81, 0x32, 0x32, 0x4A, 0x67, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x76, 0x76, 0x76, 0x76, 0x76, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x64, 0x64, 0x64, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x40, 0xBD, 0x47, 0x47, 0x4C, 0x4C, 0xD9, 0x58,
  0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x96, 0x96, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xD4, 0xD4, 0xD4, 0xD5, 0x25, 0x25, 0x25, 0x26, 0xEF, 0x26, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x71, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x22, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x8E, 0x14, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 
        0x17, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x1F, 0x1D, 0x9C, 0x9C, 0x05, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 
        0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x84, 0x05, 0x84, 0x37, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 
        0xA3, 0xA3, 0xA3, 0xA3, 0x55, 0x04, 0x89, 0xA3, 0x04, 0x55, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 
        0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 
        0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0xAA, 0xC2, 0x96, 
        0x94, 0x94, 0x07, 0xC1, 0xBB, 0x74, 0x08, 0xA0, 0xA0, 0x0B, 0x0B, 0x0B, 0xA8, 0xA7, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xB8, 0x6A, 0x6A, 0x1C, 0x1C, 0x5C, 0x2D, 0x2D, 0x50, 0xB6, 0x3F, 0x3F, 0x3C, 0x3C, 
        0x4B, 0x4B, 0x56, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x30, 0x30, 0x30, 0x53, 0x53, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 
        0x53, 0x53, 0xB4, 0xB4, 0xB4, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0xD7, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B,
  0x36, 0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0xAA, 0xAA, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0xD4, 0xD4, 0xED, 0x44, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x29, 0x5E, 0x25, 0xEE, 0xEE, 0x25, 0x25, 0xEE, 0xEE, 
        0xAD, 0x44, 0x10, 0xAD, 0xAD, 0x44, 0x10, 0x10, 0x44, 0x44, 0xAD, 0xAD, 0x44, 0x25, 0xEE, 0x5E, 0x5E, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 
        0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x20, 0x20, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 
        0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x9D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x2E, 0x84, 0x98, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1B, 0x1B, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x80, 0x80, 0x80, 
        0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x2B, 0xE4, 0x2C, 0xD2, 0x94, 0x07, 0xC1, 0xBB, 0x08, 0xA0, 0xB3, 0x0B, 
        0xA8, 0xB2, 0x0C, 0xCB, 0x9F, 0x9F, 0x9F, 0x0E, 0x0E, 0x75, 0x75, 0x75, 0x75, 0x75, 0x93, 0xC0, 0x75, 0x75, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0xA6, 0x6B, 0x6A, 0x7E, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0xB7, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 
        0x50, 0xBE, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x54, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x4B, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0xA5, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0xB4, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x35, 
        0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0xB0, 0x46, 0x46, 0x46, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x3E, 0xD7, 0xD7, 0xD7, 0xD7, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D,
  0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0xEC, 0xEC, 0x38, 0x38, 0x10, 0x10, 0xD3, 0x10, 0x10, 0x10, 0xAD, 0xAD, 0x25, 0x25, 0x29, 0x29, 0xF0, 
        0xF0, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x80, 0x14, 0x14, 0x80, 0x18, 0x18, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0xAE, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x9D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 
        0x89, 0x89, 0x89, 0xA3, 0xA3, 0x89, 0x5F, 0x89, 0x89, 0xDF, 0x5F, 0xDF, 0x23, 0x5F, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x23, 0xA3, 0x55, 0x89, 0x89, 0xA3, 0xA3, 0xA3, 0xA3, 0x55, 0x55, 0x55, 0x55, 0xA3, 0xA3, 0xA3, 0xA3, 0x55, 0x04, 0x04, 0xA3, 0xA3, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x11, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0xFC, 0xFC, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x79, 0x79, 0x79, 0x26, 0x29, 0x25, 0x25, 0x25, 0x10, 0x34, 0x34, 0x34, 0x2B, 0xAB, 0x2C, 0x2C, 0x27, 0x27, 0x65, 0x07, 0x6D, 0x74, 0x08, 
        0x08, 0x7B, 0x8A, 0x0B, 0x0B, 0xA8, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0xC6, 0x0E, 0x0E, 0xB1, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0x6B, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x5C, 0x2D, 0x2D, 0x2D, 0x50, 
        0x50, 0x54, 0xC4, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0xB5, 0x56, 0x56, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x4A, 0xA4, 0x35, 0x43, 0x43, 0x45, 0x46, 0x39, 0x3E, 0x64, 0x3B, 0x40, 0x76, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 
        0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0xE8, 0x68,
  0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0xD3, 0x10, 0x10, 0x44, 0x25, 0x29, 0x5E, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x24, 
        0x24, 0x24, 0x22, 0x22, 0x22, 0xCD, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x5F, 0xA3, 0x5F, 0x23, 0xDF, 0x5F, 0x5F, 0xDF, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x02, 0x23, 0x23, 0x89, 0x89, 
        0x89, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0xAE, 0xAE, 0x17, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x77, 0x77, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x79, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x3A, 0x38, 0x34, 
        0x34, 0x36, 0x2B, 0xAB, 0xAA, 0x2C, 0x96, 0x27, 0x27, 0x27, 0x07, 0x07, 0x07, 0x6D, 0xBB, 0xDD, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xB8, 0x6A, 0x1C, 0xC5, 0x5C, 0xBE, 
        0x50, 0x54, 0x3F, 0xE0, 0x3C, 0x4B, 0x56, 0x33, 0x48, 0xA2, 0x6E, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x81, 0x81, 0x32, 
        0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x64, 0x64, 0x64, 0xD7, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B,
  0x2C, 0x2C, 0xAB, 0x36, 0x36, 0xAA, 0xAA, 0xBC, 0xBC, 0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0x3A, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0x44, 0xEE, 0xEE, 0x25, 0x25, 0x5E, 0x26, 0x29, 0x26, 0xEF, 0x26, 0x79, 0x79, 
        0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x22, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x90, 0x90, 0x1E, 0x80, 0x80, 
        0x14, 0x14, 0x14, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x1F, 0x9C, 0x1D, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 
        0xA3, 0xA3, 0xA3, 0x55, 0x55, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1D, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x90, 0x21, 0x21, 0x21, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0xD4, 0x10, 0x38, 0x38, 0x10, 0xD3, 0xD3, 0x3A, 0x3A, 0xBC, 0xBC, 0xBC, 0xAC, 
        0x36, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0x27, 0x27, 0x27, 0xCC, 0x07, 0x07, 0x6D, 0xDD, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x9F, 0x9F, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 
        0xA6, 0x6B, 0x6A, 0x1C, 0x1C, 0x57, 0xB7, 0x5C, 0x5C, 0x2D, 0xB6, 0x54, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x4B, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x4A, 
        0x4A, 0x35, 0x43, 0x45, 0x46, 0x39, 0x3E, 0x64, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x76, 0x47, 0x47, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x47, 0x47, 0x47, 0x76, 0x76, 0x76, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x47,
  0x2C, 0xAB, 0xAB, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x96, 0x2C, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xC7, 0x36, 0x36, 0xBC, 0x3A, 0xD3, 0x44, 0xAD, 0xD5, 0xEE, 0x29, 0x26, 0x26, 0x28, 0x28, 
        0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x19, 0x79, 0x79, 0x19, 0x69, 0x26, 0x28, 0x71, 0x26, 0x69, 0x69, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x21, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x91, 0x0F, 0x0F, 
        0x0F, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1B, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x84, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 
        0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x55, 0x04, 0x89, 0xA3, 0x55, 0x55, 0xA3, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x5F, 0x23, 0xDF, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x02, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0xA3, 0x55, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 
        0x05, 0x1F, 0x1F, 0x1F, 0x1D, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 
        0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x79, 0x79, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x36, 0xC7, 0x36, 0x36, 0x2B, 0xAB, 0xAB, 0xAB, 
        0x2C, 0x2C, 0x41, 0x96, 0x27, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0xA6, 
        0x7E, 0x1C, 0x57, 0xC5, 0x2D, 0x2D, 0x50, 0x50, 0xC4, 0x3C, 0x3C, 0xEA, 0xB5, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x53, 0x53, 0x81, 0x32, 0x32, 0x32, 0x4A, 0xA4, 0xA4, 
        0x67, 0x35, 0x35, 0x35, 0x43, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x67, 0xA4, 0xA4, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0x67, 0x35, 
        0x35, 0x35, 0x43, 0x43, 0x45, 0x45, 0x46, 0x39, 0x39, 0x39, 0x3E, 0xD7, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x4C, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58,
  0x07, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0xBC, 0xBC, 0xBC, 0x3A, 0xD3, 0xD4, 0x44, 0x44, 0xD5, 0x25, 0x25, 0x29, 0x25, 0xF0, 0x26, 0x26, 0x26, 0x87, 0x87, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 
        0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x05, 0x05, 0x9C, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x9C, 
        0x05, 0x05, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x89, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x89, 0x55, 0x55, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0x84, 0x84, 
        0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0xAE, 0x17, 0xAE, 0x17, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x77, 0x13, 0x13, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x95, 0x78, 0x78, 0x14, 0x1E, 0x1E, 
        0x1E, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x4E, 0x2C, 0x2C, 
        0x96, 0x27, 0x27, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 
        0x7E, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x50, 0x50, 0x50, 0x50, 0xC4, 0x3C, 0x3C, 0xB5, 0xB5, 0x33, 0x48, 0xA2, 0xA2, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x99, 0x99, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 
        0xA4, 0x35, 0x67, 0x67, 0x67, 0x67, 0x35, 0x67, 0x67, 0x67, 0x67, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0xB4, 
        0x32, 0x32, 0x32, 0x4A, 0xA4, 0xA4, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x46, 0x46, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40,
  0x08, 0x08, 0xBB, 0xDA, 0xDA, 0x07, 0x07, 0x65, 0x27, 0x27, 0x27, 0x2C, 0x2C, 0xAA, 0x36, 0xBC, 0xBC, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0xD5, 0xD5, 0xAD, 0xAD, 0xAD, 0xAD, 0x25, 0xD5, 0xD5, 0xD5, 0xD5, 0x44, 0x25, 0xD5, 0x5E, 0x5E, 0xD5, 0xAD, 0xAD, 0x25, 
        0x25, 0x25, 0x25, 0x29, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x69, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x24, 0x24, 0x24, 0x22, 0x22, 0x21, 0x21, 0x90, 0x90, 0x80, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 
        0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x86, 
        0x17, 0x17, 0x1B, 0x9D, 0x1D, 0x1D, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 
        0x55, 0x55, 0x55, 0x55, 0x89, 0x23, 0x89, 0x23, 0x23, 0x89, 0x23, 0xDF, 0xDF, 0xDF, 0xDF, 0x5F, 0xDF, 0x5F, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x23, 0x23, 0x5F, 0x5F, 0x89, 0x55, 0x55, 0x89, 0x23, 0x89, 0x89, 0x55, 0x55, 0x55, 
        0x55, 0x04, 0x55, 0x55, 0x55, 0x04, 0x04, 0x55, 0x55, 0x55, 0x55, 0xA3, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x5F, 0xDF, 0xDF, 0xDF, 0x5F, 0x23, 0xDF, 0xDF, 0xDF, 0x89, 0xA3, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x78, 0x14, 0x14, 0x80, 0x80, 0x90, 
        0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0xAB, 0x4E, 0x2C, 
        0x96, 0x96, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xC6, 0x0E, 0x0E, 0x0E, 0xCF, 0xCF, 0xCF, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0x50, 0x3F, 0x3F, 0x3C, 0x4B, 0x56, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x81, 
        0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0xA4, 0x4A, 0x4A, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x32, 
        0x32, 0x32, 0x32, 0x32, 0xA4, 0xA4, 0xA4, 0x35, 0x35, 0x35, 0x35, 0xC3, 0x45, 0x45, 0x46, 0x39, 0x39, 0x3E, 0x64, 0x64, 0x64, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x76, 0x47,
  0x27, 0x27, 0x27, 0x27, 0xD2, 0xD1, 0xD1, 0x4E, 0xAB, 0xAA, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0xD5, 0xD5, 0x5E, 0x5E, 0x25, 0x25, 0x29, 0x29, 0x25, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0x26, 0x5E, 0x5E, 0x5E, 0x29, 0x29, 0x5E, 0xEF, 
        0xEF, 0x26, 0xEF, 0xEF, 0xEF, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x22, 0x22, 0x22, 0x22, 0xCD, 0xCD, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 
        0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 0x55, 0x55, 
        0x55, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x55, 0x55, 0xA3, 0xA3, 0x55, 0x55, 0x55, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x3D, 0x3D, 0x2E, 0xFE, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0xFE, 0x3D, 0x3D, 0x2E, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x66, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0xAE, 0xAE, 0x13, 0x13, 0x77, 0x11, 
        0x11, 0x0F, 0x91, 0x91, 0x91, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x90, 0x90, 0x90, 0x21, 0x24, 0x19, 0x19, 0x79, 0x29, 0x26, 0x26, 0x25, 0x10, 0x10, 0x10, 0xD3, 0x34, 0x34, 0x34, 0x36, 0xAC, 0x2B, 0x2B, 0x2B, 0x2B, 0xAA, 0xAA, 0xAA, 0xAA, 
        0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x6D, 0x74, 0x08, 0xA0, 0x0B, 0x0B, 0xA8, 0x8D, 0xA7, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0x75, 0x75, 0x88, 0x0D, 0x0D, 0x0D, 0x6B, 0x6A, 0x6A, 0x6A, 
        0x6A, 0x1C, 0x57, 0x57, 0xB7, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0xB6, 0xB6, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0xEA, 0x4B, 0x4B, 0xEA, 0xEA, 0x4B, 0x4B, 0x4B, 0xB5, 0xB5, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 
        0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0x7A, 0x2A, 0x4F, 0x30, 0x30, 0x53, 0x32, 0x32, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0xC3, 0x45, 0x46, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x64, 0x64, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x76, 0x76, 
        0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x9A, 0x9A, 0x9A, 0x9A, 0x9A, 0x9A, 0x9A, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x76, 0xBD, 0x40, 0x3B, 0x3B, 0x64, 0xD7, 0x3E, 0x39, 0x39,
  0xBC, 0xBC, 0xC8, 0xC8, 0xBC, 0xBC, 0xBC, 0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0xD2, 0x96, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xC7, 0x36, 0x36, 0x34, 0xD3, 0xED, 0x10, 
        0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x87, 0x26, 0x26, 0x28, 0x79, 0x19, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x22, 0x22, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 
        0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x13, 0xAE, 0x86, 0xAE, 0xAE, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x1F, 0x9D, 0x1D, 0x9C, 0x1F, 0x1F, 0x1F, 0x1D, 0x1F, 
        0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x89, 0x89, 0x23, 0x23, 0x5F, 0x02, 0xDF, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 
        0x89, 0x89, 0x89, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0xDF, 0xDF, 0x23, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x6C, 0x8C, 
        0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x5F, 0x23, 0x23, 0xA3, 0xA3, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 
        0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0xAE, 0x86, 0x86, 0x86, 
        0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x78, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x21, 0x22, 0x24, 0x24, 0x19, 0x19, 0x19, 0x26, 0x26, 0x26, 0x25, 0x25, 0x25, 0x25, 0xAD, 0xAD, 0x10, 0x10, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x10, 0x3A, 0x3A, 0x34, 0x34, 0xAC, 0x36, 0xAA, 0x2C, 0x96, 0x96, 0x27, 0x07, 0x07, 0x07, 0x6D, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xE2, 0x0E, 0x0E, 0xB1, 0x75, 0x0D, 0x0D, 0x6B, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x5C, 
        0x2D, 0x50, 0x54, 0x3C, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x48, 0xF5, 0x33, 0x33, 0x33, 0x33, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 
        0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0x53, 0x81, 0x32, 0x4A, 0x4A, 0xA4, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0xB0, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x4A, 0x4A,
  0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x07, 0x07, 0x94, 0x07, 0x07, 0x07, 0x07, 0x94, 0xCC, 0x94, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x96, 0x2C, 0xAB, 0xAA, 0xAA, 0x36, 0xBC, 0x34, 0x34, 0xD3, 0xED, 0x44, 0xAD, 
        0x25, 0x5E, 0x5E, 0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0xCD, 0x1E, 0x1E, 0x90, 0x90, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x80, 0x14, 0x14, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 
        0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x1F, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x5F, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x5F, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x9C, 0x9C, 0x1B, 0x1B, 0x1D, 0x1B, 0x17, 0x17, 0xAE, 0x17, 0x9B, 0x9B, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x24, 0x24, 0x19, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0xD3, 0x3A, 0xEC, 0x36, 0x36, 0xAB, 0x2C, 0x96, 0x96, 0x94, 0x94, 
        0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x74, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xE2, 0x0E, 0x0E, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xCF, 0xCF, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0x5C, 0x2D, 0xBE, 0x54, 0x3F, 0x3C, 0xEA, 0xB5, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 
        0x99, 0x30, 0x30, 0x30, 0x53, 0x32, 0x32, 0x32, 0x32, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x45, 0xB0, 0x45, 
        0x45, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A,
  0xAA, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0x10, 0x10, 0x10, 0x10, 0x10, 0x59, 0x25, 0x29, 0xF0, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x19, 0x19, 
        0x19, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x20, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 
        0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x89, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x55, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0xA3, 0x04, 0x04, 0xA3, 0x04, 0x04, 0xA3, 0x04, 0x04, 0x04, 0x89, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 
        0x1F, 0x66, 0x1D, 0x1F, 0x1F, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x21, 0x24, 0x19, 0x79, 0x26, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x2B, 0xAA, 0xAB, 0x2C, 
        0x2C, 0x61, 0x27, 0x27, 0x49, 0x27, 0x27, 0xCC, 0xCC, 0x49, 0x65, 0x49, 0x49, 0xCC, 0x65, 0x65, 0xCC, 0xCC, 0xCC, 0x65, 0x07, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xDA, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xA8, 
        0xB2, 0x8D, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0x93, 0x93, 0x0D, 0x6B, 0xA6, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0xB6, 0xB6, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0xEA, 0xEA, 0x4B, 0xB5, 0xB5, 0xB5, 0xB5, 0xB5, 0x56, 0x33, 
        0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x53, 0xB4, 0x32, 0x4A, 0xA4, 0x35, 0x43, 0x43, 0x45, 0x45, 0x46, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x9A, 0x9A, 0x9A, 0x9A,
  0x36, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x2C, 0x2C, 0x96, 0x2C, 0x96, 0x96, 0xAA, 0xAA, 0x2C, 0xAB, 0x2B, 0x36, 0x36, 0xAC, 0x34, 0x3A, 0xD3, 0xD3, 0xD3, 0x44, 0x44, 0x44, 0xD5, 0x44, 0x44, 0x44, 0xAD, 0xD5, 0xD5, 0xEE, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x2E, 0x3D, 0xFE, 0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0x04, 0x55, 0xA3, 
        0x23, 0x23, 0x23, 0x89, 0xDF, 0x23, 0x5F, 0x5F, 0x5F, 0x5F, 0xDF, 0xDF, 0x23, 0xA3, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0xFE, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x04, 0xFE, 0xFE, 0x2E, 0xFE, 0xFE, 0xFE, 
        0xFE, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0xFE, 0x2E, 0xFE, 0xFE, 0x04, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0x84, 0x84, 0x84, 0x84, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x31, 0x9D, 0x1B, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 
        0x17, 0xAE, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 
        0x79, 0x79, 0xFA, 0x87, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0xAB, 0x41, 0x27, 0x27, 0x49, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0xA8, 0xA7, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0xB7, 0x50, 0x50, 0x54, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0xEA, 0x4B, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 
        0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0xB4, 0x32, 0x4A, 0xA4, 0x35, 0x43, 0x43, 0x45, 0x46, 0x39, 0x3E, 0x3E, 0x64, 0x64, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x64, 
        0x64, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x64, 0x64, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x64, 0x64, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x64,
  0x07, 0x07, 0x07, 0x94, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x27, 0x94, 0x94, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xC7, 0x36, 0x36, 0xBC, 0x36, 0xC8, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0x10, 0xD4, 0xED, 0x10, 0x10, 0x10, 0xAD, 0xAD, 
        0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x5E, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x22, 0x22, 0x21, 0xCD, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x98, 0x84, 0x84, 0x84, 0x2E, 0x84, 
        0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x1F, 0x9C, 0x1F, 0x1F, 0x9C, 0x9C, 0x1F, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0x23, 0x23, 0x02, 0x02, 0x23, 0xDF, 0x5F, 0xDF, 0xDF, 0xDF, 0xDF, 0x02, 0xDF, 0x02, 0x02, 0xDF, 0xDF, 0x23, 0xDF, 0x5F, 0x02, 0x23, 0xDF, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0xA3, 0x89, 0x89, 0x89, 
        0x55, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x89, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x9D, 0x1B, 0x17, 0xAE, 0xAE, 0xAE, 0x86, 0x13, 0x13, 
        0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x44, 0x10, 0x10, 0xD3, 0xD3, 0x38, 0x34, 0xAC, 0xAC, 
        0xAC, 0x36, 0x2B, 0xE4, 0xE4, 0x4E, 0x2C, 0x2C, 0x27, 0x27, 0x27, 0x49, 0x65, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0x6D, 0x6D, 0x6D, 0xBB, 0xDD, 0x74, 0x08, 0xA0, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 
        0xCB, 0xD8, 0xC6, 0x0E, 0x0E, 0xB1, 0x88, 0x0D, 0x0D, 0xA6, 0xBF, 0x1C, 0x1C, 0xC5, 0xB7, 0x2D, 0x50, 0xB6, 0x54, 0x54, 0x3F, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0xA2, 
        0xA2, 0xA2, 0x48, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA5, 0xA5, 0xA5, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x4A, 0xA4, 0x67, 0x35, 0x35, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0x46, 0xB0, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39,
  0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0xD3, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x25, 0xF0, 
        0x29, 0x29, 0x28, 0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x8E, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x78, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x0F, 0x0F, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 
        0xFE, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x2E, 0x37, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1F, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x2E, 0x2E, 
        0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x23, 0x55, 0x89, 0x23, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x8E, 0x20, 0x1E, 0x1E, 0xCD, 0xCD, 0x90, 0xCD, 0xCD, 0xCD, 0x22, 
        0x22, 0x24, 0x24, 0x24, 0x19, 0x79, 0x26, 0x26, 0x26, 0x26, 0xF0, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x34, 0x34, 0x2B, 0xE4, 0x2C, 0xD2, 0x27, 0x27, 0x65, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0xA7, 0xB2, 0x0C, 0x0C, 0x0C, 
        0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0x75, 0xC0, 0x0D, 0x0D, 0x0D, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x2D, 0x50, 0x50, 0x54, 0x3F, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x48, 0xA2, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0xC3, 0x45, 0x45, 0xB0, 0xB0, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0xD9, 0x58,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0xC7, 0x36, 0xBC, 0xBC, 0x34, 0x38, 0x10, 0x10, 0x10, 0xAD, 0x25, 0xF0, 0x29, 
        0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 
        0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x89, 0x23, 
        0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0x02, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x5F, 0x02, 0x23, 0x23, 0xDF, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x98, 0x37, 0x84, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x9D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x73, 0x1B, 0xAE, 0x17, 0x17, 0x86, 
        0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x21, 0xFB, 0x7D, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 
        0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0xF0, 0xF0, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x38, 0x34, 0x3A, 0xBC, 0xBC, 0x36, 0xAA, 0xAA, 0x2C, 0x96, 0x96, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 
        0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xD8, 0x9F, 0x9F, 0x0E, 0x75, 0x93, 0x93, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0x2D, 0x50, 0x50, 0xB6, 0xB6, 0xC4, 0x3C, 0x3C, 0xEA, 0xEA, 0x33, 0x33, 0x33, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 
        0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x7A, 0x7A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x4A, 
        0x4A, 0xA4, 0xA4, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B,
  0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0x36, 0xBC, 0xBC, 0x3A, 0x10, 0x44, 0x25, 0x26, 0xEF, 0x71, 0x19, 0x79, 0x19, 0x24, 
        0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0xDE, 0x91, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x98, 0x98, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 
        0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x55, 0x89, 0x89, 0xA3, 0x23, 0x23, 0x5F, 0x89, 0x23, 
        0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x55, 0x55, 0x89, 0x55, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x98, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x05, 0x05, 
        0x1F, 0x1F, 0x9D, 0x1D, 0x1B, 0xAE, 0x86, 0x86, 0x13, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x90, 0x90, 0x90, 0x21, 0x22, 0x19, 0x19, 0x24, 0x19, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 
        0x26, 0x29, 0x29, 0x26, 0x26, 0x5E, 0x5E, 0x25, 0x25, 0xAD, 0xAD, 0x44, 0x44, 0xED, 0x38, 0xD3, 0x34, 0x34, 0x34, 0xAC, 0xAC, 0x2B, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0x96, 0x96, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 
        0x0B, 0x0B, 0xBA, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xC0, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0xA6, 0xA6, 0xA6, 0xA6, 0x6B, 0x6B, 0x6A, 0x7E, 0x7E, 0x6A, 0x1C, 0x57, 0x57, 0x57, 0x2D, 0x50, 0x50, 0xB6, 0x3F, 0x3C, 0x4B, 
        0x4B, 0x56, 0x33, 0x48, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x7A, 0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x99, 0xA1, 0x30, 0x30, 0x30, 0x30, 0xB4, 0xB4, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x43, 0x43, 0x46, 0x46, 0x46, 0xB0, 
        0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x36, 0x36, 0x36, 0xBC, 0x3A, 0xD4, 0xD4, 0x44, 0x5E, 0xEF, 0xEF, 0x71, 0x26, 0x19, 0x24, 0x22, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 
        0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x86, 0x17, 0x1B, 0x17, 
        0x17, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x73, 0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x2E, 0x2E, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x02, 0x23, 0xDF, 0x5F, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x89, 0x89, 0x89, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0xFE, 0x2E, 0x3D, 0xFE, 0x3D, 0x2E, 0x2E, 0x3D, 0x2E, 0x2E, 0x3D, 0xFE, 0xFE, 0x3D, 0x2E, 0x84, 0x84, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x31, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x9B, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 
        0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0xED, 0x10, 0xD3, 0x34, 0x34, 0x36, 0x36, 0xAB, 0x2C, 0x61, 0x27, 0x49, 0x65, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0xE2, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0xB7, 0x2D, 0x50, 0x50, 0xB6, 0x3F, 
        0x3F, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x53, 0xB4, 0x32, 
        0x4A, 0x67, 0x35, 0x43, 0x45, 0x46, 0x39, 0x3E, 0xD7, 0x3B, 0x40, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0x58, 0x58, 0x58, 0x58, 0x5D, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x68, 0x68,
  0x07, 0x07, 0x07, 0x94, 0x94, 0x07, 0x94, 0x94, 0x94, 0x27, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD3, 0x10, 0x44, 0xAD, 0xEE, 0x25, 0x25, 0x26, 0xEF, 0x26, 0x79, 0x79, 0x19, 
        0x19, 0x24, 0x24, 0x7D, 0x21, 0xCD, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0xAE, 0x17, 0x1B, 0x17, 0x17, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 
        0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x97, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0xF2, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x89, 0x89, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0xFD, 0xFD, 0x9C, 0xFD, 0xFD, 0x9C, 0x1F, 0xFD, 0xFD, 0x9C, 0xFD, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x98, 0x37, 0x37, 0x37, 0x37, 0x84, 0x2E, 0x2E, 0x98, 0x98, 0x84, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x73, 0x17, 0x86, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x29, 
        0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x34, 0x34, 0x34, 0x2B, 0x36, 0xE4, 0xAB, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0xA9, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0xB3, 0x0B, 
        0x0B, 0xB2, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xC0, 0xC0, 0x0D, 0x0D, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x54, 0xB6, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0xEA, 0xEA, 0xB5, 0xB5, 0x33, 0x33, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 
        0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x4F, 
        0x99, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0x67, 0x35, 0x43, 0x43, 0x45, 0x45, 0x45, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40,
  0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0x2C, 0xAA, 0x2C, 0x2C, 0xAA, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0xAD, 0x25, 0x5E, 0x5E, 
        0xF0, 0x26, 0x28, 0x19, 0x19, 0x24, 0x22, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x5F, 0xDF, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0xA3, 0x55, 0x55, 0x04, 0x55, 0x55, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x55, 0x04, 0x55, 0x89, 0x89, 0x89, 0x23, 0x5F, 0x5F, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0xF2, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0xF2, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 
        0xDF, 0x23, 0x23, 0xDF, 0x5F, 0xA3, 0x23, 0x23, 0xA3, 0xA3, 0xA3, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0xFE, 0xFE, 0x2E, 0x2E, 
        0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x21, 0x21, 0x24, 0x19, 0x19, 
        0x19, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x4E, 0x2B, 0x4E, 0x2C, 0x2C, 0x96, 0x94, 0x27, 0x27, 0x07, 0x07, 0xC1, 0xBB, 
        0x08, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0x75, 0x75, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0xB6, 0x54, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0xB5, 0xB5, 
        0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0xA2, 0x48, 0x48, 0x6E, 0x6E, 0x6E, 0x2F, 0x2F, 0x4D, 0xA5, 0x7A, 0x7A, 0x7A, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0x30, 
        0x53, 0x53, 0x53, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0xC3, 0x46, 0x46, 0x46, 0x39, 0x64, 0x64, 0x64, 0x64, 0x64, 0x3B,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0xA9, 0xA9, 0x27, 0x27, 0xD2, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0xEC, 0x34, 0x34, 0x3A, 0xD3, 0xD3, 0xD3, 0xD3, 0xD3, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0xD5, 0xEE, 0x25, 0x5E, 
        0x5E, 0xEF, 0x26, 0x26, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x80, 0x80, 0x8E, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x77, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x17, 0x17, 0xAE, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x17, 
        0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x98, 0x84, 0x84, 0x84, 0x84, 0x37, 0x84, 0x84, 0x37, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 
        0x2E, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0xDF, 0xDF, 0x02, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x02, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x02, 0xDF, 0x23, 0x23, 0x89, 0xA3, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1D, 0x1B, 0x1B, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 
        0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x29, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x4E, 0x4E, 0x96, 0x96, 0x27, 0x94, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x74, 0x08, 0xA0, 0xA0, 0xB3, 
        0x8A, 0x8A, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xB8, 0x6A, 0x6A, 0x1C, 0x1C, 0xC5, 0x57, 0x2D, 0x50, 0x50, 0x50, 0x54, 0x54, 0xC4, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 
        0x4B, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x33, 0xF5, 0x48, 0x48, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x99, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x30, 
        0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0xC3, 0x43, 0x45, 0x45, 0x46, 0x46, 0x39, 0x39,
  0x34, 0x38, 0x38, 0xD3, 0xD3, 0x38, 0x10, 0x10, 0xD3, 0x44, 0x44, 0x44, 0x10, 0x44, 0x44, 0xAD, 0xAD, 0xAD, 0xAD, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xEE, 0x29, 0x29, 
        0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0xF0, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x22, 0x22, 0x22, 0x22, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 
        0x14, 0x78, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0xFE, 0xFE, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x5F, 0xA3, 0x5F, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x02, 
        0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x97, 0x97, 0x97, 0x0A, 0x97, 0xF2, 0xF2, 0x97, 0x97, 0x97, 0x97, 0xF2, 0xF2, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0xDF, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x5F, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x37, 0x84, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x9D, 0x1F, 0x1F, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 
        0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x19, 0x19, 0x79, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0xAC, 0x36, 0xAB, 0xD1, 0xD2, 0x27, 0x49, 0x65, 0x07, 0x6D, 0xDD, 0xDD, 0x08, 0x08, 0x08, 0xA0, 
        0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xBA, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0xA6, 0xA6, 0x7E, 0x1C, 0x1C, 0x57, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x54, 
        0x54, 0x54, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x2A, 0x2A, 0x2A, 0x2A, 0x99, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x4A, 0xA4, 0x67, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0xB0,
  0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0xD3, 0x10, 0xD4, 0xD4, 0x3A, 0x3A, 0x3A, 0x3A, 0x38, 0x38, 0xD3, 0x34, 0x34, 0x38, 0x38, 0x34, 0x34, 0x38, 0x38, 0xD3, 0xD3, 
        0xD3, 0xD3, 0xD3, 0x44, 0x44, 0x44, 0x10, 0x44, 0x44, 0x25, 0x25, 0x25, 0x5E, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x22, 0x22, 0xCD, 0xCD, 0xCD, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x11, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x13, 0x86, 0xAE, 0x17, 0x17, 0xAE, 0x17, 0x1B, 
        0x1B, 0x1B, 0x9D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x37, 0x84, 0x84, 0x84, 0x37, 0x37, 0x84, 0x84, 0x84, 
        0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0x55, 0x23, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x89, 0xA3, 0x89, 0x89, 0x55, 0x89, 0x04, 0xA3, 0x55, 0x89, 0x89, 
        0x55, 0x55, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x98, 0x84, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0xAE, 0xAE, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 
        0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0x2C, 0x96, 0x96, 
        0xD2, 0x27, 0x27, 0x27, 0x94, 0xCC, 0x94, 0xCC, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0xCB, 0xE2, 0x0E, 0xB1, 0xC0, 0x0D, 0xA6, 0x6A, 0x1C, 
        0xB7, 0x2D, 0x50, 0x50, 0x3F, 0x3C, 0x3C, 0x4B, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0xA5, 0xA5, 0x2A, 0x2A, 0x99, 0x99, 0x30, 0x53, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0xA4, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0xC3, 0xC3, 
        0xC3, 0x43, 0x43, 0x43, 0xC3, 0xC3, 0xC3, 0xC3, 0xC3, 0xC3, 0x45, 0x45, 0xC3, 0x43, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35,
  0x96, 0x96, 0x2C, 0x2C, 0xAB, 0xAB, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x28, 0x79, 0x19, 0x19, 0x79, 0x24, 
        0x24, 0x22, 0x22, 0x22, 0x21, 0x7D, 0x7D, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x8E, 0x8E, 0x8E, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x13, 0x42, 
        0x17, 0x17, 0x1B, 0x1B, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 
        0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x3D, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x23, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0xF2, 0xF2, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x97, 0x97, 0x8C, 0xF2, 0x97, 0xF2, 
        0x8C, 0x02, 0x02, 0x02, 0x6C, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x2E, 
        0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 
        0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x14, 0x14, 0x1E, 0x1E, 0x90, 0x24, 0x24, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x41, 0x4E, 0x2C, 0x96, 0x96, 
        0xA9, 0x65, 0x07, 0x07, 0x07, 0x6D, 0xDD, 0x08, 0x7B, 0xB3, 0x0B, 0x0B, 0x8D, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xCF, 0x0D, 0x0D, 0x0D, 0xB8, 0x6A, 0xB8, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xC5, 0x5C, 0x5C, 0x5C, 0x5C, 0x2D, 
        0x50, 0xB6, 0xB6, 0x54, 0x3F, 0x3C, 0x3C, 0x4B, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 0x30, 0x53, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0xA4, 0xA4, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 
        0x46, 0x45, 0x46, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x64, 0x64, 0x3B, 0x3B, 0x40, 0x3B, 0x40, 0xBD, 0x40, 0x40, 0x40, 0x40, 0xBD, 0x76, 0x40, 0x40, 0x40, 0x40, 0x76, 0x76,
  0xAA, 0x36, 0x36, 0x36, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0x44, 0x44, 0xD5, 0xD5, 0x25, 0x25, 0xD5, 0xD5, 0xD5, 0xEE, 0xD5, 0x5E, 0x25, 0x25, 0xF0, 0x26, 0x26, 0xEF, 0xEF, 0xEF, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 
        0x24, 0x24, 0x24, 0x22, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x21, 0x21, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0xAE, 0x17, 0xAE, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 
        0x98, 0x2E, 0x3D, 0x2E, 0x04, 0x2E, 0xFE, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x04, 0x89, 0x55, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x89, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x5F, 0x23, 0x02, 0x5F, 
        0x5F, 0x23, 0xDF, 0x5F, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x5F, 0xDF, 0x23, 0xDF, 0x5F, 0x5F, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x8C, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0xFD, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x9C, 0x1D, 0x9D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 
        0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 
        0x10, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x41, 0x41, 0x41, 0x27, 0x49, 0x07, 0x07, 0xC1, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x8D, 0xB2, 0xB9, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xA6, 0x6A, 0x1C, 0xC5, 
        0xEB, 0x2D, 0xBE, 0x54, 0x3C, 0x4B, 0x56, 0x33, 0xA2, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x30, 0x30, 0x30, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x32, 0x81, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 
        0xA4, 0x67, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0xB0, 0xB0, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x39, 0x39, 0x39, 0x39,
  0x94, 0x27, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x3A, 0x38, 0x38, 0x38, 0x38, 0x10, 0x44, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x87, 0x26, 0x28, 0x79, 0x79, 0x19, 0x19, 
        0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 
        0x18, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x17, 0x17, 0x17, 0x73, 
        0x1D, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x55, 0x55, 0x89, 0x23, 0x5F, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 
        0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x97, 0x97, 
        0x97, 0x0A, 0x0A, 0xF2, 0xF2, 0x0A, 0x97, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1D, 0x9D, 0x1B, 0x1B, 0xAE, 0x17, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x12, 0x12, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x95, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x10, 0x44, 0x38, 0x38, 0x3A, 0x34, 0x34, 0x36, 0x36, 0xAB, 
        0x2C, 0xD2, 0xD2, 0xD2, 0x27, 0xCC, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0xB2, 0xA7, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 
        0xC0, 0x0D, 0x0D, 0x0D, 0xBF, 0x1C, 0x1C, 0xC5, 0x5C, 0x2D, 0xBE, 0x54, 0x3F, 0x3F, 0x3C, 0x3C, 0xB5, 0xB5, 0x33, 0x33, 0xA2, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x4A, 
        0x4A, 0xA4, 0xA4, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67,
  0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x96, 0x96, 0x2C, 0x2C, 0xAA, 0x36, 0xBC, 0xBC, 0xD4, 0x44, 0x44, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x28, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x80, 0x14, 0x14, 
        0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 
        0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x92, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x04, 0x89, 0x89, 0x89, 0x5F, 0x5F, 0x23, 0x89, 0x23, 0xDF, 0xDF, 0xDF, 0xDF, 
        0x23, 0x02, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1F, 0x9D, 0x9D, 0x1B, 0x73, 0x17, 0x17, 0x17, 0x86, 0x17, 0x9B, 0x13, 0x13, 0x13, 0x13, 0x1A, 0x77, 0x77, 0x77, 0x0F, 0x11, 
        0x11, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x19, 0x26, 0x29, 0x29, 0x25, 0x25, 0x44, 0xD3, 0x34, 0x34, 0x36, 0x2B, 0x2B, 0x2C, 0x2C, 0x41, 0x27, 0x27, 0x49, 0x65, 0x07, 0x07, 0x6D, 0xDD, 
        0x74, 0x74, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x8D, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0xCB, 0xE2, 0xE2, 0x0E, 0xE2, 0xE2, 0x0E, 
        0x0E, 0x0E, 0x75, 0xC0, 0xC0, 0xC0, 0x0D, 0x6B, 0x6A, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x5C, 0x50, 0x50, 0x54, 0xC4, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x53, 
        0x53, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x67,
  0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x36, 0xBC, 0xBC, 0xBC, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0x34, 0x3A, 0x3A, 0xD4, 0xD4, 0x44, 0x10, 0x44, 0x25, 0x25, 0x29, 0x29, 
        0x79, 0x19, 0x19, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 0x17, 
        0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x1D, 0x05, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x05, 0x05, 0x84, 0x37, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 
        0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x97, 0xF2, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x97, 0x0A, 0x8C, 0x8C, 0x6C, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x6C, 0x6C, 0x8C, 0x6C, 0x6C, 0x02, 0x6C, 0x6C, 0x02, 0x6C, 0x6C, 0x02, 
        0x02, 0x02, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x6C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x84, 0x98, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x77, 0x0F, 
        0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0xEE, 0xAD, 0x44, 0x10, 0xD3, 0xD3, 0x38, 0x38, 0x34, 0xAC, 0xAC, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0xAC, 
        0x2B, 0x2B, 0xE4, 0x2B, 0x36, 0x36, 0x4E, 0x4E, 0x2C, 0x41, 0x49, 0x49, 0xCC, 0x07, 0x6D, 0x74, 0x08, 0xA0, 0x8A, 0x0B, 0xB2, 0x0C, 0x0C, 0xD8, 0x0E, 0x0E, 0x0E, 0xCF, 0x88, 0x0D, 0x0D, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 
        0x57, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0x50, 0x54, 0xC4, 0xC4, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 
        0x99, 0x99, 0x30, 0x30, 0x53, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x43, 0x43,
  0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0xAC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0xD3, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 
        0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1F, 0x1F, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x98, 0x2E, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x04, 0x04, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x23, 0x23, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0xF2, 0x6C, 0x8C, 0x0A, 0x0A, 0x97, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x5F, 0x5F, 0x89, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x3D, 
        0x3D, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x84, 0x98, 0x37, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x13, 0x13, 0x77, 
        0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x26, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x10, 0x38, 0x38, 0xEC, 0x36, 0x2C, 0x2C, 0x27, 0x27, 0x07, 0x6D, 0x74, 0x08, 0xB3, 0x0B, 0xBA, 0x0C, 0xCB, 0x0E, 0x0E, 0x0D, 0x0D, 0xA6, 0x1C, 0x1C, 0xC5, 0xC5, 
        0x5C, 0x2D, 0x50, 0x54, 0x3F, 0x3C, 0xB5, 0x33, 0xF5, 0x48, 0x2F, 0x2F, 0x2F, 0x4D, 0x7A, 0x2A, 0x4F, 0x99, 0x99, 0x30, 0x30, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x4A, 0xA4, 0xA4, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 
        0x45, 0x46, 0x46, 0x46, 0x46, 0xB0, 0x46, 0x46, 0x46, 0x46, 0xB0, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45,
  0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xAC, 0xAC, 0x34, 0x34, 0xEC, 0xEC, 0x38, 0xD4, 0x10, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x17, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x1F, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x23, 0x5F, 0x5F, 0x23, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x02, 0x5F, 0x23, 0xDF, 0x5F, 0x23, 0x89, 0x89, 0x89, 0xA3, 0x55, 0x55, 0x55, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x1D, 0x73, 0x17, 0x17, 0x86, 0x13, 
        0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x7D, 0x7D, 0x24, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x25, 0x25, 0x25, 0xAD, 0xED, 0xD4, 0x38, 0x38, 0xAC, 0xBC, 0xAC, 0xAC, 
        0x36, 0x36, 0xE4, 0x36, 0xAB, 0xE4, 0xAA, 0x36, 0x36, 0x2B, 0x2B, 0xAA, 0xAA, 0xAA, 0xAB, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x27, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0xA0, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x75, 0x93, 0x0D, 
        0xA6, 0xB8, 0x7E, 0x1C, 0x1C, 0x57, 0xB7, 0x2D, 0x2D, 0x2D, 0x50, 0xB6, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x33, 0x33, 0x33, 0xA2, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x99, 0x30, 0x30, 0x53, 0x53, 0x53, 0x81, 0x81, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35,
  0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0xAC, 0xBC, 0xBC, 0xBC, 0xD4, 0xD4, 0xD4, 0x10, 0x25, 0xAD, 0x25, 0xF0, 0x29, 0x26, 0x26, 0x26, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 
        0x90, 0x90, 0x90, 0x1E, 0x90, 0x90, 0x21, 0x90, 0x90, 0x21, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x22, 0x22, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0xCD, 0xCD, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 
        0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x55, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0x5F, 0x23, 0x23, 0x89, 0x89, 0xA3, 0x89, 0xA3, 0x89, 0x04, 0x04, 0xA3, 0x55, 0x55, 0xA3, 0x04, 0x55, 0x89, 0x55, 0x55, 0x89, 0x89, 
        0x89, 0x23, 0x23, 0x23, 0xDF, 0x5F, 0x23, 0x5F, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x92, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0xF2, 0xF2, 0xF2, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0xA3, 0x55, 0x04, 0x04, 0x04, 0x2E, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x9D, 0x1B, 0x73, 0x42, 0x9B, 0x77, 0x11, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x22, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 
        0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x4E, 0x41, 0x41, 0x41, 0x96, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 
        0xB1, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x6B, 0x6B, 0x6B, 0x7E, 0x7E, 0x6A, 0x57, 0x57, 0x57, 0x57, 0xB7, 0x2D, 0x50, 0xB6, 0x54, 0x3F, 0x3F, 0xE0, 0x4B, 0x4B, 0x33, 0xF5, 0x48, 0x48, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x30, 
        0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32,
  0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x27, 0x96, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0x3A, 0xD4, 0x44, 0xAD, 0x25, 0x29, 0xF0, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x22, 0x22, 0x22, 
        0x22, 0x22, 0x21, 0x21, 0xCD, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0xAE, 0xAE, 0x73, 0x1B, 0x73, 0x1B, 0x73, 
        0x73, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0xDC, 0x1F, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x9C, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x1F, 0x1F, 0x9D, 0x1F, 0x1F, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0xAE, 0xAE, 
        0x86, 0xAE, 0x42, 0x86, 0x86, 0x42, 0xAE, 0x86, 0xAE, 0x17, 0xAE, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x37, 0x84, 0x84, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x23, 0x23, 0x5F, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x5F, 0x23, 0x5F, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0xF2, 0xF2, 0x8C, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 
        0x02, 0x02, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0xA3, 0xA3, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1B, 
        0x1B, 0x17, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x13, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x15, 0x78, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0xCD, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 
        0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x2C, 0x2C, 0xD1, 0x41, 0x27, 0x27, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x6D, 0xC1, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 
        0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x6B, 0xBF, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xEB, 0x57, 0x5C, 0xB7, 0x5C, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x54, 0xC4, 0x3F, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0xB5, 
        0x33, 0x33, 0x33, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A,
  0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x96, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD1, 
        0x2C, 0x2C, 0xE4, 0xE4, 0x36, 0x34, 0x38, 0xD3, 0x44, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x22, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x12, 0x91, 0x11, 0x11, 0x11, 0x1A, 0x13, 0x9B, 0x86, 0x17, 
        0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x98, 0x98, 0x84, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0xA3, 0x89, 0x89, 0x89, 0x5F, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0xFE, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 0x98, 0x2E, 0x2E, 0x37, 0x37, 0x37, 0x37, 0x37, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x78, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 
        0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x3A, 0xBC, 0x36, 0x36, 0x36, 0x36, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0xD2, 0xD2, 0x27, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 
        0xB2, 0x0C, 0xCB, 0xD8, 0xE2, 0x0E, 0x0E, 0x75, 0xC0, 0x93, 0x0D, 0xA6, 0xB8, 0x6A, 0x6A, 0x1C, 0x57, 0x1C, 0x57, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x50, 0x54, 0xC4, 0xC4, 0x3F, 0x3C, 0x3C, 0x4B, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x48, 0x48, 
        0xA2, 0xA2, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53,
  0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0x44, 0xD5, 0xD5, 0xAD, 0x25, 0x29, 
        0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x22, 0x22, 0x21, 0x21, 0x21, 0x21, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x22, 0x22, 0x24, 0x24, 0x24, 0x22, 0xCD, 0x7D, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x20, 0x80, 0x14, 0x14, 
        0x14, 0x12, 0x12, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0x77, 0x77, 0x1A, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x17, 0x1B, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x37, 0x05, 0x37, 0x84, 0x84, 0x84, 0x98, 0x37, 0x2E, 0x84, 0x2E, 0xFE, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 
        0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0xDF, 0xA3, 0x04, 0x04, 0x04, 0x84, 0x84, 0x05, 0x05, 0x1F, 0x9D, 0x31, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x21, 0x21, 0x21, 0x7D, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x87, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x34, 0x5A, 0x2B, 0x2B, 0x2B, 0x4E, 0x2C, 0x96, 0x96, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0xBB, 0x08, 0x08, 0x08, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 
        0xB1, 0x0D, 0xA6, 0xBF, 0x1C, 0x1C, 0xC5, 0xB7, 0x2D, 0x2D, 0x50, 0xBE, 0x54, 0x54, 0x54, 0xC4, 0xC4, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0xC4, 0xC4, 0x3F, 0x54, 0x3F, 0xC4, 0xC4, 0xC4, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0x33, 0x33, 0xF5, 
        0x48, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x4F, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4,
  0xCC, 0xCC, 0xA9, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0xD4, 0xD3, 0x10, 0x25, 0x25, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x22, 0xCD, 0xCD, 0xCD, 0xCD, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 
        0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x22, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 
        0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x84, 0x84, 0x98, 0x37, 0x98, 0x98, 0x98, 0x37, 0x98, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 
        0xA3, 0xA3, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 0x89, 0x89, 0x04, 0x89, 
        0x89, 0x89, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x5F, 0x55, 0x04, 0x04, 0x04, 0x04, 
        0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x66, 0x9C, 0x1F, 0x1D, 0xDC, 0x1D, 0x1D, 0x1F, 0x9D, 
        0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x15, 0x15, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x21, 0x21, 0x22, 0x24, 0x19, 0x79, 0x26, 0x26, 0x25, 0x25, 0x25, 0x25, 
        0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x2C, 0x96, 0x27, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0xB3, 
        0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xD8, 0xE2, 0x0E, 0x0E, 0x93, 0x0D, 0x0D, 0x7E, 0x1C, 0x57, 0x57, 0x2D, 0xBE, 0x3F, 0x3F, 0x4B, 0x56, 0x48, 0x6E, 0x2F, 0x4D, 0x2A, 0x2A, 0x99, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 
        0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A,
  0x25, 0x25, 0xEE, 0x25, 0x29, 0x25, 0x25, 0x5E, 0xD5, 0xD5, 0xD5, 0xD5, 0x44, 0x44, 0x44, 0x44, 0xD4, 0xD4, 0xD4, 0xD4, 0x3A, 0x3A, 0xD4, 0x3A, 0x3A, 0x3A, 0x3A, 0x44, 0x44, 0x10, 0x10, 0x10, 0x25, 0x29, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x12, 
        0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0xCE, 0xCE, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 
        0x05, 0x37, 0x37, 0x84, 0x84, 0x37, 0x3D, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x55, 0xA3, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x84, 0x2E, 0x2E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0xCE, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 
        0x90, 0x21, 0x21, 0x21, 0x24, 0x79, 0x79, 0x26, 0x87, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34, 0x2B, 0x2B, 0x2B, 0x41, 0x96, 0x27, 0x94, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0xCB, 
        0x0E, 0x0E, 0x0E, 0x0E, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x54, 
        0x3F, 0x3F, 0x3C, 0xB5, 0x33, 0x33, 0x33, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F,
  0x07, 0x07, 0x07, 0xCC, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0x34, 0x34, 0x38, 0xD3, 0xD3, 0x10, 0xEE, 0x25, 0x5E, 0x26, 0x26, 0x26, 0x19, 0x19, 0x24, 0x22, 0xCD, 0x90, 0x90, 0x90, 0x1E, 0x80, 
        0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x17, 0x17, 0x73, 0x1B, 0x9D, 0x9D, 0x1D, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0xF2, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 
        0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x21, 0x21, 
        0x24, 0x19, 0x79, 0x26, 0x29, 0x29, 0x25, 0x10, 0x10, 0x3A, 0x34, 0x2B, 0x2B, 0x2B, 0xAB, 0x4E, 0x41, 0x27, 0x27, 0x94, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 
        0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0xB1, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xBF, 0x0D, 0x0D, 0xB8, 0xB8, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0xB7, 0xB7, 0x2D, 0x2D, 0x50, 0xB6, 
        0xC4, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x48, 0x48, 0x2F, 0x2F, 0x4D, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0xA4, 0xA4, 0x67, 0x35, 0x35,
  0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0xEC, 0x38, 0xD3, 0x10, 0x25, 0xEE, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x18, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x9D, 0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x9D, 0x1F, 0x1F, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0xA3, 0xA3, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0xF2, 0x97, 0x97, 0xF2, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x85, 0x01, 0x01, 0x0A, 0x0A, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x3D, 0x2E, 0x98, 0x37, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 
        0x1F, 0x1D, 0x1B, 0x1B, 0x73, 0xAE, 0xAE, 0x17, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x12, 0x12, 0x12, 0x78, 0x14, 0x80, 0x80, 0x1E, 0x90, 
        0x21, 0x21, 0x19, 0x19, 0x19, 0x79, 0x26, 0x29, 0xF0, 0x26, 0x5E, 0x25, 0x25, 0xAD, 0x10, 0x10, 0x10, 0x34, 0xEC, 0x2B, 0x2B, 0x36, 0x2B, 0x4E, 0x2C, 0xD2, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x6B, 0x7E, 0x1C, 0x1C, 0x57, 0x2D, 0x50, 0x50, 0xB6, 0x3F, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0x56, 0x33, 0x48, 
        0x48, 0x48, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x99, 0x99, 0x30, 0x99, 0x99, 0x30, 0x30, 0x30,
  0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0xAB, 0xAB, 0xAA, 0xAA, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x10, 0xED, 0xED, 0x44, 0xAD, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x87, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x28, 0x28, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 
        0x9D, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0xA3, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0xA3, 0xA3, 
        0x89, 0xA3, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 
        0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x92, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 
        0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0xFE, 0x3D, 0x3D, 0x2E, 0x2E, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x98, 0x98, 0x84, 0x98, 0x84, 0x37, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x13, 0x77, 0x0F, 0x12, 0x78, 0x78, 0x14, 0x1E, 0x1E, 0x21, 0x24, 0x24, 0x19, 
        0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x36, 0xAB, 0x4E, 0x4E, 0x4E, 0x41, 0x96, 0x27, 0x27, 0x94, 0x94, 0x65, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 
        0xB2, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0x0E, 0xC0, 0x93, 0x0D, 0x0D, 0x6B, 0x0D, 0x6B, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x50, 0xB6, 0xB6, 0x3F, 0xC4, 0x3F, 0xC4, 0xC4, 0x3C, 0x3C, 0x3F, 0x3C, 0x3C, 0x3C, 
        0x4B, 0x4B, 0x4B, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x48,
  0xBC, 0x34, 0x38, 0xD3, 0xED, 0xED, 0x44, 0xAD, 0xEE, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x5E, 0x29, 0xF0, 0xF0, 0x29, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0xD5, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x9B, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0xDF, 0xDF, 
        0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x97, 0x0A, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x97, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x04, 0x89, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x3D, 0x2E, 0x84, 0x98, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x66, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x29, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x2B, 0xE4, 0xAA, 0xAB, 0xD1, 0x96, 0x27, 0x94, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 
        0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xB8, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0xB7, 0x50, 0x50, 0x50, 0x50, 0xB6, 0x54, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 
        0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0x48, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A,
  0x2B, 0x2B, 0xAC, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0xD3, 0xD3, 0xD3, 0x10, 0x10, 0x10, 0x38, 0x3A, 0x3A, 0x3A, 0xD3, 0xD3, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0xAD, 0xAD, 0xAD, 0xD5, 0x29, 0x25, 
        0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x0F, 0x0F, 0x77, 0x77, 0x86, 0x86, 0xAE, 
        0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x2E, 0x84, 0x3D, 0x3D, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 
        0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x1D, 0x1F, 0xFD, 0x9C, 0x05, 0x05, 0x84, 0x98, 0x98, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0xA3, 0x89, 0x89, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0xA3, 0x89, 0x89, 0xA3, 0x55, 0x04, 0x55, 0x55, 0x04, 0x55, 
        0xA3, 0xA3, 0xA3, 0x55, 0x89, 0x89, 0x89, 0x5F, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x0A, 0x01, 0x01, 0x97, 0x97, 0x0A, 0x0A, 0x0A, 0x97, 0x8C, 0x8C, 0x97, 0x0A, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x92, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x5F, 0x5F, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x55, 0x55, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0xFE, 0xFE, 0x98, 0x98, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1F, 0x1D, 0x1B, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x79, 0x26, 0x87, 0x29, 0x25, 0x25, 0x38, 0x34, 0x2B, 0xE4, 0x96, 0x27, 0x94, 0x07, 0xBB, 0x08, 0x08, 0xB3, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 
        0x0C, 0xCB, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0x75, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0xB7, 0xB7, 0xB7, 0xB7, 0x2D, 0x2D, 0x50, 0x50, 0x50, 
        0x50, 0x50, 0xBE, 0xBE, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0xBE, 0x50, 0x54, 0x54, 0x3F, 0x3F, 0x3C, 0x3C, 0x4B, 0xB5, 0x33, 0x33, 0x48, 0xA2, 0x2F, 0x2F, 0x2F, 0xA5,
  0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x3A, 0x3A, 0xD4, 0xD4, 0x3A, 0x3A, 0x3A, 0x34, 0x34, 0x3A, 0x34, 0x34, 0xAC, 0xAC, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0xAC, 0x34, 0x34, 0x34, 0x34, 0xD3, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 
        0x29, 0x29, 0x26, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 
        0x77, 0x77, 0x77, 0x13, 0x86, 0xAE, 0x17, 0x17, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x84, 0x84, 0x2E, 0xFE, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x89, 0x04, 0x04, 0x89, 0x89, 0x04, 0x55, 0x55, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x89, 0x23, 0x23, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0xF2, 0x0A, 0x97, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x92, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x92, 0x85, 0x85, 0x01, 0x01, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0xFE, 0xFE, 0xFE, 0x2E, 0x2E, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x37, 0x37, 0x2E, 0x2E, 0x84, 0x37, 0x05, 0x37, 0x37, 0x05, 0x05, 0x9C, 0x1D, 0x9D, 0x17, 0x17, 0x86, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x14, 0x80, 
        0x1E, 0x90, 0x90, 0x19, 0x79, 0x79, 0x79, 0x29, 0x25, 0x25, 0x10, 0x10, 0x38, 0x34, 0xEC, 0x2B, 0x2B, 0x2B, 0x2B, 0x2C, 0xD2, 0xD2, 0xD2, 0x27, 0x49, 0xCC, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0x9F, 0x9F, 0xC6, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0xA6, 0x6B, 0x6B, 0x7E, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x2D, 0x2D, 0x2D, 0x50, 
        0x50, 0x50, 0x54, 0x54, 0xC4, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x4F,
  0x36, 0x36, 0xAC, 0xAC, 0xEC, 0xEC, 0xEC, 0x34, 0x34, 0x3A, 0xD4, 0xD4, 0xD4, 0x38, 0x3A, 0x44, 0x44, 0x10, 0x10, 0x10, 0xAD, 0xAD, 0xAD, 0xD5, 0x25, 0x25, 0x29, 0x29, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x21, 
        0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x11, 0x11, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x66, 0x9C, 0x9C, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 
        0x05, 0x05, 0x1F, 0x9C, 0x05, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x98, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x97, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0xF2, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x98, 0x37, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x9D, 0x1D, 0x1B, 0x73, 0xAE, 0x17, 0x9B, 0x9B, 0x13, 0x11, 0x11, 0xCE, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x1E, 
        0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x19, 0x26, 0x26, 0x19, 0x79, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0xF0, 0x25, 0x25, 0x25, 0x10, 0x10, 0x34, 0x34, 0x36, 0xAA, 0x2C, 0x27, 
        0x94, 0x07, 0xC1, 0x08, 0x08, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0xA6, 0xA6, 0xBF, 0x1C, 0x6A, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0x5C, 0x2D, 0x5C, 0x2D, 0x2D, 0x2D, 0xBE, 0x50, 0x50, 0xBE, 0x50, 0x50, 0x50, 
        0x54, 0x54, 0x54, 0xC4, 0xC4, 0xC4, 0x3F, 0x3F, 0x3C, 0x3C, 0xEA, 0xEA, 0xEA, 0xB5, 0x33, 0x33, 0x48, 0x48, 0x6E, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x99, 0x99,
  0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xC7, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD3, 0xD3, 0xD3, 0xD3, 0xED, 0xED, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0xAD, 
        0xAD, 0xEE, 0x25, 0x29, 0x26, 0xEF, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x77, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0xFD, 0xFD, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 
        0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x02, 0x02, 0x8C, 
        0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x5F, 0x89, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x37, 0x37, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x19, 0x19, 0x79, 0x26, 0x87, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x34, 0x34, 0x2B, 0xAB, 0xAB, 0x2C, 0x2C, 0x96, 
        0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x6D, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x75, 0x88, 0x88, 0x88, 0x0D, 0x0D, 
        0x0D, 0x6B, 0x6B, 0x6A, 0x6A, 0x1C, 0x1C, 0x57, 0xB7, 0xB7, 0x2D, 0x50, 0x50, 0x50, 0x54, 0x3F, 0x3C, 0x3C, 0x4B, 0x4B, 0x56, 0xF6, 0x33, 0x48, 0x48, 0xA2, 0x6E, 0x6E,
  0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0xD1, 0xD1, 0x2C, 0x2C, 0x2C, 0xAA, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x44, 0xAD, 0x29, 0x29, 0x26, 
        0x26, 0x79, 0x24, 0x22, 0x22, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 
        0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x1B, 0x9D, 0x9D, 0x9D, 0xFD, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x98, 0x84, 0x2E, 0x3D, 0x3D, 0x2E, 0xFE, 0x3D, 0x2E, 0x84, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x23, 0xDF, 0xDF, 0x02, 0x02, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0xCA, 0xCA, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0xFD, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 
        0x78, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x79, 0x79, 0x79, 0x26, 0x29, 0x29, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 
        0x34, 0x2B, 0x2B, 0x4E, 0x41, 0xD2, 0x49, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0x7B, 0x0B, 0x0B, 0xA8, 0x8D, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0xB1, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xBF, 0xB8, 0xB8, 0xBF, 0x6A, 
        0x6A, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0x5C, 0x2D, 0xBE, 0xBE, 0xB6, 0x3F, 0x3C, 0x3C, 0x3C, 0xEA, 0x4B, 0x56, 0x56, 0x33, 0xF5, 0x48, 0xA2, 0x6E, 0x2F,
  0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x3A, 0xED, 0x44, 0xAD, 0xEE, 0xEE, 0x5E, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x24, 0x22, 0xCD, 0xCD, 
        0xCD, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x86, 
        0xAE, 0xAE, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0xDC, 0x1D, 0x1D, 0x1D, 0x66, 0x66, 0x9C, 0x9C, 0x05, 0x05, 0x84, 0x84, 0x98, 0x2E, 0x2E, 0x3D, 0xFE, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x89, 0x55, 0x5F, 0x5F, 0x5F, 
        0xDF, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0xF2, 0xF2, 0x6C, 0x6C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 
        0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x5B, 0x16, 0xE6, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x03, 
        0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0xF2, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 
        0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1B, 0x1B, 0x1B, 0xAE, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x11, 0x11, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x12, 0x12, 0x91, 0x12, 0x12, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x38, 0x34, 0x2B, 0xE4, 
        0x4E, 0x41, 0x94, 0xCC, 0x07, 0x6D, 0x74, 0x08, 0x08, 0x7B, 0x8A, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xC0, 0xC0, 0x0D, 0xA6, 0xBF, 0xBF, 0x6A, 
        0x1C, 0x1C, 0xEB, 0x5C, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0xB6, 0x54, 0x54, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0xEA, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0x56, 0x33, 0x33,
  0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x27, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x36, 0x2B, 0x34, 0x38, 0xD3, 0x10, 0x25, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x7D, 0x7D, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 
        0x12, 0x12, 0x12, 0x91, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0xF1, 0xCE, 0x11, 0x11, 0x11, 0x77, 0x1A, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 
        0x2E, 0x84, 0x2E, 0x3D, 0x3D, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x2E, 0x2E, 0xFE, 0x3D, 0x3D, 0x3D, 0x2E, 0xFE, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 
        0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 
        0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x23, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x91, 0x12, 0x78, 0x78, 0x14, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x10, 
        0x38, 0x34, 0x2B, 0x2B, 0x36, 0x4E, 0x4E, 0x96, 0xD2, 0x27, 0x49, 0xCC, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x88, 
        0x88, 0x88, 0x0D, 0x0D, 0xB8, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x54, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xEA, 0xEA, 0xB5, 0xB5,
  0xAB, 0xAB, 0x2B, 0x36, 0x36, 0x36, 0x36, 0xAC, 0xAC, 0xBC, 0xBC, 0x34, 0x3A, 0xD4, 0xD3, 0xD3, 0xED, 0x44, 0xD3, 0x44, 0x44, 0x44, 0x44, 0xD4, 0x44, 0xD5, 0xD5, 0xD5, 0xEE, 0x25, 0x29, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 
        0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x86, 0xAE, 0x1B, 0x1B, 0x1B, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0xFD, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x98, 0x84, 0x2E, 0x3D, 0x2E, 0x3D, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0xDF, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 
        0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x92, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0xF2, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x84, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1B, 0x1B, 0x73, 0x17, 0xAE, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 
        0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 
        0x10, 0x38, 0x34, 0x2B, 0x2B, 0xAB, 0x41, 0x27, 0xA9, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xB8, 0x6A, 
        0x6A, 0x1C, 0x1C, 0xC5, 0x2D, 0x2D, 0x50, 0x54, 0x54, 0x3F, 0x3C, 0xEA, 0xEA, 0xEA, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3C,
  0x2B, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x36, 0xC7, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0x34, 0x3A, 0xD3, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x24, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0x13, 0x13, 0x17, 0x17, 0xAE, 
        0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x84, 
        0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0x55, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x5F, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x23, 0x89, 0x89, 0x89, 0x89, 0xA3, 0x89, 0x89, 0x55, 
        0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x9C, 0x66, 0x1D, 0x1D, 
        0x1D, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24, 0x19, 0x79, 0x79, 0x29, 0x29, 0x29, 0x25, 0xAD, 0xED, 0xD3, 0x3A, 0x34, 0xAC, 
        0x36, 0x2B, 0xAB, 0xC2, 0x27, 0x27, 0x94, 0xCC, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0x1C, 0x1C, 
        0x57, 0xC5, 0x57, 0x57, 0x5C, 0x2D, 0x2D, 0x50, 0x50, 0xBE, 0x50, 0x54, 0x54, 0x3F, 0xC4, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0xB5, 0x33, 0x33,
  0x07, 0x07, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0xE4, 0x36, 0x36, 0x36, 0xAC, 0xBC, 0xEC, 0x34, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD3, 0x44, 0x44, 0x44, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 
        0x24, 0x24, 0x21, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x86, 0x13, 0x86, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x9D, 0x1D, 0x66, 0x66, 0x66, 0x66, 0x1F, 
        0x9C, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 
        0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x92, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x92, 0x92, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x97, 0x0A, 0x97, 
        0x02, 0x02, 0x02, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x1F, 
        0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x19, 0x79, 0x19, 0x19, 0x79, 0x79, 0x29, 0x29, 0x29, 0x25, 0x25, 
        0x10, 0x10, 0x38, 0xEC, 0x36, 0xAB, 0x2C, 0xD1, 0x96, 0x27, 0x27, 0xCC, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB9, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x8F, 0x8F, 0x9F, 
        0x0E, 0x0E, 0x75, 0x93, 0x88, 0x0D, 0x6B, 0x6A, 0x1C, 0x1C, 0x57, 0x2D, 0x2D, 0x50, 0x3F, 0xC4, 0x3C, 0x4B, 0x33, 0x33, 0x48, 0x2F, 0x2F, 0xA5, 0xA5, 0x2A, 0x4F, 0x99,
  0x38, 0xD3, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0xDE, 0xDE, 0x12, 0xDE, 0xDE, 0x12, 0x91, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x11, 0x11, 0x1A, 0x77, 0x13, 0x9B, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0xFE, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0xFE, 0xFE, 0x3D, 0x3D, 0xFE, 0xFE, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x55, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x82, 0x82, 0x16, 0x5B, 0x03, 0x16, 0x16, 
        0x16, 0xE6, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x5B, 0x16, 0x16, 0x16, 0x60, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 
        0xFE, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x2E, 0x98, 0x84, 0x98, 0x98, 0x3D, 0xFE, 0xFE, 0xFE, 0x3D, 0x04, 0x2E, 0xFE, 0xFE, 0xFE, 0x3D, 0x04, 0x04, 0x84, 0x84, 0x2E, 
        0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 
        0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x34, 0x34, 0x2B, 0x2B, 0x41, 0x41, 0xCC, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xE2, 0x0E, 0x0E, 0x75, 0x93, 0x93, 0x0D, 0x0D, 0x6B, 0x6A, 0x6A, 0x1C, 0x57, 0x57, 0x2D, 0x2D, 0x2D, 
        0x50, 0x54, 0xB6, 0x3F, 0x3F, 0x3C, 0x3C, 0x4B, 0x4B, 0x56, 0x56, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F,
  0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0xC2, 0x2C, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0x3A, 0x3A, 0xD4, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x87, 0x26, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x9B, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 
        0x1F, 0x05, 0x05, 0x05, 0x37, 0x05, 0x37, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x55, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0xFE, 0x2E, 0x2E, 0x84, 0x84, 
        0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x37, 0x37, 0x37, 0x37, 0x37, 0x05, 0x37, 0x84, 0x84, 0x98, 0x37, 0x84, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0xF2, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x5B, 0x5B, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x51, 0x62, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 0x51, 0x51, 
        0x62, 0x62, 0x51, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x16, 0x16, 0xE6, 0xE6, 0xE6, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x97, 0x97, 0x97, 0xF2, 0x6C, 0x6C, 
        0x6C, 0x6C, 0x02, 0x02, 0xF2, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0xFE, 0x3D, 0x2E, 0x2E, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0xFD, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 
        0x9D, 0x1D, 0x1B, 0x1B, 0x73, 0x73, 0x17, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 
        0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x4E, 0x4E, 0x96, 0x27, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0xB3, 0x0B, 0xB3, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x8D, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0xC6, 0x0E, 0x0E, 0x75, 0x93, 0x75, 0x93, 0x88, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0x6B,
  0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x96, 0xAA, 0xAA, 0x36, 0x3A, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x8E, 0x18, 0x18, 0x18, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 
        0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x9B, 0x9B, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x17, 0x17, 0x73, 0x73, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 
        0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x98, 0x2E, 0x2E, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x97, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 
        0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x5B, 0xE6, 0x16, 0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x60, 0x60, 0xE6, 0xE6, 0x16, 0xE6, 0xE6, 
        0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x03, 0x09, 0xCA, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0x03, 0x03, 0xCA, 0xCA, 0xFF, 
        0x92, 0x09, 0x92, 0x09, 0x85, 0x85, 0x85, 0x85, 0x92, 0x92, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x55, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 
        0x2E, 0x2E, 0x84, 0x37, 0x37, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x13, 0x0F, 0x0F, 0x91, 0x78, 0x78, 0x14, 0x1E, 0x1E, 0x90, 0x90, 0x24, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x38, 
        0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x36, 0xBC, 0xBC, 0xBC, 0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x96, 0x27, 0x27, 0x94, 0x07, 0x07, 0xC1, 0xDD, 0x08, 
        0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x75, 0x75, 0x93, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0xB7, 0xB7, 0x2D, 0x2D, 0x2D,
  0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xD0, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x36, 0x36, 0xEC, 0xD3, 0xD4, 0x44, 0x25, 0x29, 0x26, 0x26, 0x19, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x80, 
        0x80, 0x80, 0x78, 0x14, 0x14, 0x78, 0x14, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x24, 0x22, 0x22, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 
        0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x73, 0x73, 0x1D, 0x9D, 0x9D, 0x05, 0x05, 0x37, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x55, 0x55, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 
        0x6C, 0x8C, 0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x2E, 0xFE, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 
        0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x89, 0x89, 
        0x04, 0x04, 0x2E, 0x05, 0x05, 0x05, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x13, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 
        0x19, 0x79, 0x26, 0x29, 0x29, 0x25, 0xAD, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x2B, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0xDA, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 
        0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x5C, 0x2D, 0x2D, 0xBE, 0x50, 0xB6, 0x54, 0x54, 0x54, 0x3F,
  0x8A, 0xA0, 0xA0, 0x08, 0x08, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x74, 0x74, 0x74, 0x74, 0x08, 0x08, 0x74, 0xBB, 0x74, 0x74, 0x74, 0xDA, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x96, 0x2C, 0xAA, 0x36, 0x34, 0x38, 0x38, 0x10, 0x25, 
        0x29, 0x26, 0x19, 0x19, 0x21, 0x90, 0x1E, 0x80, 0x14, 0x78, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 
        0x91, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x1F, 0x1F, 0x1F, 0x1F, 0x9C, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x89, 0x55, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x55, 0x55, 
        0x04, 0x89, 0x89, 0xA3, 0x55, 0xA3, 0xA3, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x09, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 
        0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x98, 0x05, 0x05, 0xFD, 0x9D, 0x1D, 0x73, 0x17, 0x86, 0x1A, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x15, 0xFC, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x90, 0x22, 
        0x24, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x87, 0xF0, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x34, 0xBC, 0x36, 0xAB, 0xAB, 0x2C, 0x2C, 0xD1, 0x96, 0x27, 0x94, 0xCC, 0x07, 0x07, 0xC1, 0x08, 0x08, 0x08, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 
        0xB2, 0x0C, 0x0C, 0xCB, 0xCB, 0xC6, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0xA6, 0xA6, 0x6A, 0x6A, 0x1C, 0x57, 0xB7, 0xB7, 0x50, 0x50, 0x50, 0x50, 0x50, 0x54, 0xB6, 0x3F, 0x3F,
  0xA7, 0xA8, 0x0B, 0xB3, 0xA0, 0x08, 0x74, 0x07, 0x07, 0x65, 0x27, 0x2C, 0x2C, 0x2B, 0x34, 0x38, 0x10, 0x10, 0xEE, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x22, 
        0x22, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 
        0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0x9D, 0x9D, 0x9D, 0x9D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x98, 0x98, 
        0x3D, 0x3D, 0xFE, 0xFE, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0xFE, 0x3D, 0xFE, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0x89, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x92, 0x09, 0x09, 0xCA, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x2E, 0x3D, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x1D, 0x1B, 0x73, 0x17, 0x86, 0x9B, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x12, 0x12, 0x12, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0xCD, 0x90, 0x90, 0x21, 0x21, 0x7D, 0x24, 0x24, 0x19, 0x19, 0x79, 0x28, 0x26, 0x25, 0x25, 0x25, 0x38, 0x34, 0x34, 0xE4, 0x4E, 0x61, 0x49, 0x07, 0x6D, 0x74, 0x08, 0xB3, 0x0B, 0x0B, 0xB2, 0x0C, 0xCB, 0x0E, 0x0E, 
        0xB1, 0xC0, 0x93, 0x0D, 0xA6, 0x6B, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C,
  0x07, 0x07, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0xAA, 0x2B, 0x2B, 0x34, 0x38, 0xD3, 0x10, 0x25, 0x25, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 
        0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x73, 0x1D, 0x9D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x98, 0xFE, 0x04, 0x04, 0x04, 0x55, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 
        0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 
        0x70, 0x70, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0xF2, 0x8C, 0x6C, 0xF2, 0xF2, 0xF2, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x98, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0x1D, 0x1D, 0x17, 0x86, 0x86, 0x86, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 
        0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x44, 0x38, 0x34, 0xAC, 0x2B, 0xAB, 0x96, 0x27, 0x07, 0x07, 0x07, 0xBB, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 
        0xE2, 0x0E, 0x0E, 0xB1, 0xC0, 0x93, 0x0D, 0x6B, 0x6A, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x54, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0xEA, 0x4B,
  0xD2, 0xD1, 0xD1, 0x2C, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x44, 0x10, 0x10, 0xAD, 0x25, 0xEE, 0x29, 0x29, 0x25, 0xF0, 0x26, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 
        0x24, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x29, 0x29, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x77, 
        0x13, 0x86, 0x86, 0xAE, 0x1B, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x31, 0x9D, 0x9D, 0x1D, 0xDC, 0x1D, 0x9D, 0x1D, 0x9D, 0x9D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0xCA, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0xCA, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 
        0x97, 0x8C, 0xF2, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 
        0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x98, 0x05, 0x05, 0x9C, 0x66, 0x1D, 0x9D, 0x1B, 0x1B, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x87, 0x29, 0x25, 0x25, 0x10, 0x38, 0x34, 0x2B, 0xAB, 0x41, 0x27, 0x94, 0x07, 0x07, 0xDA, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0xA8, 0xA8, 0xB9, 0x0C, 0xCB, 0xCB, 0xE2, 0xC6, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0x6B, 0x6A, 0x1C, 0x6A, 0x1C, 0x57, 0x57,
  0xAA, 0x36, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x3A, 0x3A, 0x3A, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x29, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x0F, 0x77, 0x11, 0x11, 0x77, 0x13, 0x13, 0x13, 0x86, 0xAE, 0xAE, 0x1B, 0x1D, 0x9D, 0x1F, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 
        0x23, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x55, 0xA3, 0x89, 0x55, 0x55, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x89, 0x89, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x8C, 0x0A, 0x97, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 
        0x16, 0xE6, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x62, 0xD6, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 
        0x55, 0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x1F, 0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 
        0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2C, 0x2C, 0xC2, 0x27, 0x27, 0x94, 0x94, 0x65, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0x7B, 0xB3, 
        0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xC6, 0x0E, 0x0E, 0x93, 0x93, 0x0D, 0x0D, 0xA6, 0x6A, 0x1C, 0x1C, 0x57, 0xC5, 0x57, 0x5C, 0x2D, 0x2D, 0x50, 0x50,
  0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x19, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, 0x0F, 0x77, 0x13, 0x13, 0x9B, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 
        0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x23, 0xA3, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x05, 0x05, 0x9C, 0x1F, 0x9D, 0x1D, 0x73, 0x17, 
        0x17, 0x86, 0x13, 0x77, 0x11, 0x11, 0x11, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x21, 
        0x21, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0xAB, 0xAB, 0x2C, 0x2C, 0xD2, 0xD2, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x27, 0x94, 0xCC, 0x65, 0x65, 0x07, 
        0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xE2, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0xA6, 0xBF, 0x1C, 0x1C, 0x57,
  0x27, 0x41, 0x4E, 0x4E, 0x2B, 0x2B, 0x34, 0xD3, 0x10, 0x25, 0x25, 0x26, 0x26, 0x19, 0x24, 0x7D, 0x21, 0x90, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 
        0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 
        0x0F, 0x77, 0x13, 0x13, 0x13, 0x86, 0xAE, 0xAE, 0xAE, 0x73, 0x73, 0x1B, 0x1D, 0x1D, 0x9D, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x55, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0xF2, 
        0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x92, 0x85, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 
        0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x55, 0x04, 0x04, 
        0x04, 0xFE, 0x84, 0x84, 0x37, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 
        0x12, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0xF0, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x2C, 0x41, 
        0x27, 0x94, 0x94, 0x07, 0xBB, 0x08, 0x08, 0xA0, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0x8F, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E,
  0xBB, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x2C, 0xAA, 0xAA, 0xAB, 0x36, 0x36, 0x34, 0x38, 0xD3, 0xD3, 0xD3, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x80, 0x80, 0x80, 
        0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x12, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x11, 0x77, 0x13, 0x13, 0xAE, 0xAE, 0xAE, 0x73, 0x1B, 0x31, 0xDC, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1F, 
        0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0xA3, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x02, 0x02, 0x23, 
        0x23, 0x02, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x70, 0x51, 0x70, 0x51, 0x51, 0x51, 0x51, 0x51, 
        0x70, 0x70, 0x51, 0x51, 0xE7, 0x70, 0xE7, 0x51, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 
        0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 
        0x89, 0x04, 0x04, 0x04, 0x84, 0x84, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 
        0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x10, 0x10, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x4E, 0x4E, 0x2C, 0xD2, 0x27, 0x27, 0x49, 0xCC, 0x65, 0xCC, 0xCC, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x6D, 0x6D, 0x74, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0xB1, 0x0D, 0x0D, 0xA6, 0xB8,
  0x07, 0x07, 0x65, 0xCC, 0x94, 0x27, 0x27, 0x41, 0xD1, 0x4E, 0x4E, 0x36, 0x2B, 0x5A, 0xEC, 0x34, 0x10, 0x10, 0x10, 0xAD, 0x29, 0xF0, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x26, 0x26, 0x79, 0x79, 0x79, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 
        0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x90, 0x90, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 
        0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 
        0xFE, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x02, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x02, 0x6C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x5B, 0x5B, 0x5B, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0xE7, 0xE7, 0xE7, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 
        0x02, 0xDF, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x1D, 0x1F, 0x1F, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x12, 0x12, 0x12, 0x78, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 
        0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x38, 0x38, 0x34, 0x38, 0xAC, 0x2B, 0x2B, 0x2C, 0x2C, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x6D, 0xBB, 0xBB, 0x08, 0x08, 0x08, 
        0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E,
  0x07, 0x07, 0x07, 0x07, 0xCC, 0x27, 0x27, 0x61, 0xD1, 0xD1, 0x2C, 0xE4, 0x36, 0x2B, 0x2B, 0xAC, 0xEC, 0x38, 0xD3, 0x10, 0x44, 0x44, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x26, 
        0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 
        0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0xAE, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9C, 0x66, 0x1D, 0x9C, 0x9C, 0x9C, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x98, 0x84, 0x2E, 0xFE, 
        0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 
        0x5B, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x1F, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 
        0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0xBC, 0x36, 0x36, 0xAA, 0x2C, 0x2C, 0x96, 0x27, 0x27, 
        0x94, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0x08, 0xA0, 0xA0, 0x0B, 0x0B, 0xA8, 0xB2, 0x0C, 0x0C, 0xCB, 0x0E, 0x0E, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x6A, 0x6A, 0x1C, 0x57,
  0x44, 0x10, 0x10, 0x10, 0xD3, 0xD4, 0xED, 0xED, 0xD3, 0x3A, 0x3A, 0xD4, 0x3A, 0x3A, 0x3A, 0x3A, 0x38, 0x38, 0x38, 0x38, 0xD3, 0xD4, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1B, 0x1B, 0x73, 0x73, 0x17, 0x17, 0x17, 
        0x86, 0xAE, 0xAE, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0xE5, 0xE5, 0x13, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x66, 0x9C, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 0x37, 
        0x2E, 0x98, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x89, 
        0x89, 0xA3, 0xA3, 0x89, 0x04, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x51, 0x51, 0x51, 0x51, 
        0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x62, 0x62, 0x06, 0x06, 0x60, 0x60, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0xE7, 0xE7, 0x62, 0x62, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 0x51, 0xD6, 0x51, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0xD6, 0xD6, 0x62, 0x62, 0xD6, 0xD6, 0x51, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x23, 0x89, 0x55, 0x04, 0x04, 0x2E, 0x84, 0x05, 0x9C, 0x9D, 0x17, 0x17, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x14, 0x14, 0x1E, 0x90, 
        0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x5A, 0x36, 0xAB, 0xD1, 0xD2, 0x27, 0x65, 0x07, 0x07, 0xC1, 0xC1, 
        0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0xA6,
  0x27, 0x27, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0xD2, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x79, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x73, 0x73, 0x17, 0x73, 0x17, 0xAE, 0xAE, 0x17, 
        0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 0x37, 0x2E, 0x37, 0x37, 0x37, 
        0x2E, 0x2E, 0x98, 0x98, 0x2E, 0xFE, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 
        0x23, 0x23, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x92, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x16, 0xE6, 0x16, 0x16, 0xE6, 0x5B, 0x5B, 0x5B, 0x16, 0x5B, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x60, 0xE6, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0x09, 0x09, 0x09, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0xDF, 0xA3, 0x04, 0x04, 0x04, 0x84, 0x05, 0x05, 0x9D, 0x1B, 0x17, 0x86, 0x13, 0x0F, 0x0F, 0x12, 0x12, 0x78, 0x14, 0x14, 0x80, 
        0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x41, 0x41, 0x27, 0x27, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 
        0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x8A, 0xF8, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2,
  0x7B, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2B, 0xAC, 0x38, 0xD3, 0x10, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x14, 0x8E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x80, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x9B, 0x9B, 0x17, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x1D, 0xDC, 0x9C, 0x9C, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0xDF, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 
        0xE6, 0x5B, 0x60, 0x16, 0x16, 0x06, 0x06, 0x06, 0x62, 0x62, 0x62, 0xE7, 0xD6, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x70, 0x70, 0x52, 0x70, 0x70, 0x51, 0xE7, 0x62, 0x62, 0xE7, 0xE7, 
        0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x23, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x98, 0x98, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x9C, 0x9C, 0x1D, 0x1F, 0x9D, 0xDC, 0xDC, 0x1D, 0x1B, 0x73, 0x1B, 0x1B, 0x1B, 0x17, 
        0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x14, 0x14, 0x8E, 0x8E, 0x80, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x44, 0x10, 0xD3, 0x34, 0x34, 0x2B, 0x2B, 
        0x2B, 0x4E, 0x41, 0x27, 0x27, 0x49, 0xCC, 0x07, 0x6D, 0x6D, 0xDD, 0x74, 0x08, 0x08, 0x7B, 0x7B, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA7, 0xA7, 0x8D, 0x8D, 0x0C,
  0x0B, 0x0B, 0xB3, 0xB3, 0x8A, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x27, 0x27, 0x96, 0x2C, 0xAB, 0x36, 0xAC, 0x34, 0x34, 0x3A, 0x44, 0xAD, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x22, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 
        0x8E, 0x78, 0x78, 0x95, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0xCE, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 
        0x91, 0x12, 0x12, 0x91, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x13, 0x13, 0x13, 0x13, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 
        0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 
        0xE7, 0x06, 0x06, 0x06, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0xF2, 0x97, 0x8C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0xFE, 0x84, 0x98, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0xFD, 0xFD, 0x1F, 0xDC, 0x9D, 0x9D, 0x1D, 0x31, 0xDC, 0x1D, 0x73, 0x1B, 0x1B, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x79, 
        0x28, 0x26, 0x29, 0x25, 0x25, 0x10, 0x38, 0x34, 0xE4, 0x2C, 0x27, 0x65, 0x07, 0xC1, 0xDD, 0x08, 0x7B, 0x8A, 0x0B, 0xB2, 0x0C, 0x0C, 0x9F, 0xC6, 0x0E, 0x75, 0x75, 0x93,
  0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x29, 0x26, 0x29, 0x26, 0xEF, 0x26, 0x26, 0x79, 0x26, 0x26, 0x26, 
        0x79, 0x79, 0x28, 0x71, 0x79, 0x28, 0x28, 0x79, 0x19, 0x19, 0x19, 0x24, 0x7D, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x17, 0x9B, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x9D, 0x9D, 0x1F, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x02, 
        0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 0x60, 0x06, 0x06, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0xE7, 0xD6, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 
        0x51, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 0x98, 0x05, 0x05, 0x05, 0x1F, 
        0x9D, 0x1D, 0x1B, 0xAE, 0x86, 0x13, 0x77, 0xCE, 0x0F, 0x91, 0x12, 0x78, 0x14, 0x14, 0x1E, 0x1E, 0x90, 0x90, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x10, 0x10, 0x10, 0x10, 0xED, 0x38, 0x38, 0x3A, 0xBC, 0x36, 0xE4, 0xE4, 0xE4, 0x2C, 0x96, 0x27, 0x94, 0x07, 0x07, 0xC1, 0xBB, 0x74, 0x08, 0x08, 0xA0, 0xB3, 0x0B,
  0xDD, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0xA9, 0x27, 0x96, 0xD1, 0x2C, 0x2B, 0x2B, 0x2B, 0x34, 0x38, 0x38, 0x10, 0x10, 0x44, 0x10, 0x10, 0xAD, 0xAD, 0x25, 0x25, 0x10, 0x25, 0x25, 0x25, 0xAD, 0xAD, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x14, 0x14, 0x78, 0x78, 0x78, 0x95, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0xDC, 0x1D, 0x1F, 0x1D, 0x9C, 0x9C, 0x66, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x2E, 
        0x2E, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x23, 0x02, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x85, 0x85, 0xCA, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 
        0x03, 0x03, 0x09, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x89, 0x04, 0x89, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 
        0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x97, 0x97, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9D, 0x9D, 0x1B, 
        0x73, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x1A, 0x77, 0x77, 0xCE, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x4E, 0x2C, 0x41, 0xD2, 0xD2, 0x49, 0x49, 0x49, 0x94, 0x94, 0x07, 0x07, 0x07,
  0xA8, 0x0B, 0x0B, 0xB3, 0x08, 0x08, 0x08, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x2C, 0xAA, 0xC7, 0x36, 0x36, 0x2B, 0x2B, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0xAC, 0x36, 0x34, 0x34, 0x34, 0x34, 0x34, 0x3A, 0x38, 0x38, 0x10, 0x25, 
        0x25, 0x25, 0x29, 0x29, 0x79, 0x79, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 
        0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x1D, 0x1D, 0x1F, 0x1D, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1D, 0x1F, 0x9C, 0xFD, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x2E, 
        0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x55, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0xDF, 0x23, 0xDF, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x82, 0x82, 0x16, 0x16, 0x03, 0x03, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0xD6, 
        0xD6, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x37, 0x05, 0x05, 0x9C, 0x1F, 0x9D, 0x31, 0x73, 0x17, 0xAE, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 
        0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0xCE, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x90, 0x90, 0x90, 0x21, 0x24, 0x79, 0x26, 0x29, 0x29, 0x25, 0x38, 0x34, 0x34, 
        0x2B, 0x41, 0xD2, 0x27, 0x07, 0x07, 0xC1, 0xBB, 0x08, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0xBA, 0xB2, 0x0C, 0x0C, 0x8F, 0x8F, 0x8F, 0xE2, 0x9F, 0x9F, 0x9F, 0x9F, 0x9F, 0x0E,
  0xE4, 0x2B, 0xE4, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0xAC, 0xAC, 0x5A, 0xEC, 0xAC, 0x34, 0x38, 0x38, 0x10, 0x10, 0x44, 0x25, 0x25, 0x25, 0xF0, 0x29, 0x26, 0x79, 0x79, 0x79, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 
        0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 
        0x1E, 0x80, 0x80, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x11, 0x77, 0x77, 0x13, 0x9B, 0x13, 0x13, 0x17, 0x17, 0x9B, 0x17, 0x86, 0x86, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x17, 
        0x1B, 0x1B, 0x9D, 0x9D, 0x1F, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x37, 0x2E, 0x84, 0x3D, 0x3D, 0x98, 0x2E, 0x3D, 0x04, 0x3D, 0x04, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x02, 0x23, 0x02, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x51, 
        0xE7, 0x51, 0x51, 0x51, 0x70, 0x70, 0x70, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x70, 0x52, 0x52, 0x51, 0x70, 0x70, 0x51, 0xE7, 0x70, 0x70, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
        0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x03, 0xE6, 0x5B, 
        0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x92, 0x92, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x66, 0x1D, 0x1D, 0x1D, 0x73, 0x17, 0x17, 0x17, 0x9B, 0x9B, 
        0x13, 0x1A, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x95, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x25, 0x25, 0x10, 0x34, 
        0x36, 0xAB, 0xD2, 0x94, 0x07, 0xBB, 0x08, 0xB3, 0x0B, 0xB2, 0x0C, 0x0C, 0xE2, 0x0E, 0xB1, 0xC0, 0xC0, 0x0D, 0x6B, 0x6B, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57,
  0x27, 0x96, 0x2C, 0x36, 0x36, 0xAC, 0x34, 0xD3, 0x10, 0x10, 0x25, 0xF0, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x90, 0x1E, 0x20, 0x80, 0x78, 0x15, 0x91, 
        0x0F, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x86, 0xE5, 0x1A, 0x13, 0x13, 0x1A, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x77, 0x77, 
        0x13, 0x13, 0x13, 0x86, 0x17, 0x86, 0x17, 0x17, 0x1B, 0x1D, 0xDC, 0x66, 0x05, 0x05, 0x05, 0x98, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 
        0x06, 0x62, 0x51, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0x62, 0x70, 0x70, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 
        0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x05, 0x05, 0x05, 0x9C, 
        0x1F, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x59, 
        0x10, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x2C, 0x27, 0x27, 0x94, 0x94, 0x07, 0x07, 0xC1, 0x6D, 0xDD, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0x8A, 0x0B, 0x0B, 0xA8, 0xA8,
  0xBB, 0xDD, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x74, 0xBB, 0xBB, 0xBB, 0xDA, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0xD2, 0xD2, 0xD1, 0xAA, 0x36, 0x36, 0x36, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 
        0x80, 0x8E, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0xDE, 0xDE, 0x0F, 0x0F, 0xCE, 0x13, 0x13, 0x9B, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0xDC, 0x9D, 0xFD, 0x05, 0x05, 0x05, 0x37, 0x98, 0x84, 0x37, 0x37, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x55, 0x04, 0x04, 0x89, 0x89, 0x55, 0x55, 0x55, 0x04, 0x55, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0xE6, 0x82, 0x03, 0x5B, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x51, 0x62, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0xE7, 0xE7, 0x62, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x23, 0x5F, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x2E, 0x2E, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x9D, 0x9D, 0x1B, 0x17, 0x17, 0x17, 
        0x86, 0x86, 0x9B, 0x13, 0x13, 0x77, 0x77, 0x77, 0x11, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x90, 0x24, 
        0x19, 0x28, 0x29, 0x25, 0x10, 0x34, 0xAC, 0xAB, 0xD1, 0x27, 0x07, 0x6D, 0x08, 0x08, 0xA0, 0x0B, 0xA8, 0x0C, 0x0C, 0x8F, 0x9F, 0x0E, 0x75, 0x93, 0x0D, 0x0D, 0x6B, 0x6B,
  0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x96, 0x2C, 0xAB, 0xAA, 0xAA, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 
        0x29, 0x25, 0x25, 0x25, 0x29, 0xF0, 0xF0, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x73, 0x73, 0x73, 0x1D, 0x1B, 0x9D, 
        0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x66, 0x1D, 0x9C, 0x9C, 0x66, 0x66, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0xDF, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0xA3, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x03, 0x03, 0xE6, 0xE6, 0x16, 0xE6, 0xE6, 0x16, 0x5B, 0x16, 0x16, 0x5B, 0x16, 0x16, 
        0x5B, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x51, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 
        0x51, 0x52, 0x70, 0x70, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 0x51, 0xE7, 0xE7, 0xE7, 0x51, 0x51, 0xE7, 0x51, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 
        0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x9C, 0xFD, 0x1D, 0x1D, 0x1B, 0x1B, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 
        0x42, 0x17, 0x86, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x9B, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x90, 0x90, 0x21, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 
        0x25, 0x25, 0x10, 0x38, 0x38, 0x34, 0x34, 0x2B, 0x4E, 0x4E, 0x4E, 0x41, 0x41, 0x41, 0xD2, 0x27, 0x27, 0x94, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1,
  0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x4E, 0xAB, 0xAB, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 
        0x79, 0x19, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 
        0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x91, 0x77, 0x77, 0x13, 0x86, 0x17, 0x1B, 0x9D, 0x9D, 0xFD, 0x05, 0x05, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 
        0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x92, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x60, 0x06, 0x16, 0x60, 0x16, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x62, 0x51, 0x51, 0x51, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 
        0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x51, 0x51, 0x06, 0x06, 0x06, 0x06, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x16, 0xE6, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0xDF, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x3D, 0x3D, 0x98, 0x98, 0x37, 
        0x05, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x73, 0x73, 0x17, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x14, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 
        0x79, 0x28, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x38, 0x34, 0x34, 0x2B, 0x2B, 0x2C, 0x96, 0x27, 0x94, 0x07, 0x07, 0xBB, 0xDD, 0x08, 0xA0, 0x0B, 0x0B, 0x0B, 0xA8,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0xC2, 0x2C, 0x2C, 0xAA, 0xAA, 0x36, 0xEC, 0x38, 0xD3, 0x10, 0x59, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 
        0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x87, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x12, 
        0x12, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x42, 0x17, 0x17, 0x1B, 0x1D, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x84, 0x37, 0x3D, 0x3D, 0x2E, 0xFE, 0xFE, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x62, 0x62, 0x06, 0x62, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0xE7, 0x62, 0x06, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x3D, 0x98, 0x84, 
        0x84, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x86, 0x86, 0x86, 0x13, 0x77, 0x0F, 0x0F, 0x12, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x26, 0x29, 0x29, 0x25, 0x25, 0x10, 
        0x10, 0x10, 0x3A, 0x34, 0x34, 0x34, 0xAC, 0x36, 0x2B, 0xAB, 0xAB, 0xD1, 0x96, 0x96, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08,
  0x07, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x27, 0x96, 0x2C, 0x41, 0x2C, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x7D, 0x21, 0xCD, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x8E, 0x14, 0x14, 0xFC, 0x78, 0x78, 0x95, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x91, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0xCE, 0x11, 0x77, 0x77, 0x1A, 0x9B, 0x9B, 0x9B, 0x86, 0xAE, 0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 
        0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 0x89, 0x89, 0x55, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x60, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0x06, 0x62, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 
        0x52, 0x52, 0x51, 0x70, 0x70, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x04, 0x04, 0xFE, 0x2E, 0x98, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0xAE, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x20, 0x1E, 0x1E, 0x21, 0x7D, 0x24, 0x19, 0x79, 0x26, 0x26, 0x29, 0x25, 0x10, 0x10, 
        0x38, 0x34, 0x34, 0x2B, 0x2B, 0x4E, 0x4E, 0x41, 0x49, 0x49, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B,
  0xDA, 0x74, 0x74, 0x6D, 0xDA, 0xDA, 0xDD, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x6D, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0xCC, 0x94, 0x27, 0xD2, 0x96, 0x2C, 0x4E, 0xAB, 0xE4, 0x2B, 0x36, 0x34, 0x34, 0x34, 0xD3, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x87, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x11, 0x11, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x05, 0x05, 0x37, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 0x37, 0x37, 0x98, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x05, 0x37, 0x37, 0x84, 0x84, 0x3D, 0x3D, 0xFE, 0xFE, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 0x16, 0x60, 0x06, 0x06, 0x60, 0x16, 0x60, 0x60, 0x60, 0x60, 0x5B, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x16, 0xE6, 0x03, 0x5B, 0x5B, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x06, 0x06, 0x06, 0x62, 0x62, 0x62, 0x62, 0x62, 0x62, 0x62, 0xE7, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x09, 
        0x09, 0x09, 0x92, 0x09, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0xA3, 0x89, 0x89, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x84, 0x05, 0x05, 
        0x9C, 0xFD, 0x1F, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x14, 0x14, 0x18, 0x18, 0x18, 0x18, 0x18, 0x14, 0x14, 0x14, 0xFC, 0xFC, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x18, 0x8E, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x19, 0x79, 0x26, 0x25, 0x44, 0xD4, 0x34, 0x36, 0xAB, 0x96, 0x27, 0xCC, 0x07, 0x07, 0xBB, 0x08, 0x08, 0x8A,
  0x10, 0x10, 0x10, 0xD3, 0x38, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x4E, 0x4E, 0x2C, 0x2C, 0x27, 0x27, 0x27, 0x27, 0xCC, 0xCC, 0x65, 0x65, 0x65, 0xCC, 0x65, 0x65, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x4E, 0xAB, 0x36, 0x2B, 0xEC, 0x3A, 0xD3, 0x44, 0x10, 0x25, 0x25, 
        0x25, 0x29, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x95, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0xAE, 0x1B, 0x1B, 0x9D, 0x1D, 0x9C, 0x9C, 0x05, 
        0x05, 0x3D, 0x3D, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x5F, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x16, 0x60, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0xE7, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x60, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 
        0x16, 0x16, 0x5B, 0x5B, 0x5B, 0x16, 0xE6, 0x5B, 0x16, 0xE6, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x16, 0x16, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0xD6, 0x62, 0xD6, 0x62, 
        0xD6, 0xD6, 0x62, 0xE7, 0xE7, 0x62, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x05, 
        0x9C, 0xFD, 0x1F, 0x1D, 0x1B, 0x1B, 0xAE, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0xCE, 0xCE, 0xCE, 0xCE, 0xCE, 0xCE, 0xCE, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0xDE, 0xDE, 0xDE, 0x12, 0x12, 0x15, 0x78, 0x78, 0x14, 0x80, 0x20, 0x1E, 0x90, 0x21, 0x22, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x29, 0xF0, 0x25, 0x25, 0x10, 0x10,
  0x65, 0xA9, 0xA9, 0x27, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0x4E, 0xAB, 0xAB, 0xAB, 0x36, 0x36, 0x36, 0x36, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0x4E, 0x4E, 0x4E, 0x2C, 0x2C, 0x2C, 0xD1, 0x96, 0x96, 0xD2, 0x41, 0x4E, 
        0xAB, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0xCE, 0x0F, 0x0F, 0x0F, 0x11, 0x11, 0x77, 0x13, 0x9B, 0x13, 0x9B, 0x17, 0x17, 0x73, 0x73, 0x9D, 0x9D, 0x1F, 0x9C, 0x05, 0x05, 0x98, 0x98, 0x98, 0x2E, 
        0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x98, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0xFD, 0xFD, 0xFD, 0x1F, 0x9C, 0x9C, 0x66, 0x66, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x3D, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 
        0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x5B, 0x5B, 0x5B, 0x16, 0x16, 0x03, 0x5B, 0x16, 0x82, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0xE7, 0x62, 0x62, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 
        0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 
        0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0xFE, 0x84, 0x84, 0x84, 0x37, 0x37, 0x05, 0x9C, 0x9C, 0x1D, 0x9D, 0x17, 0x17, 0x17, 0x86, 0x13, 0x13, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x80, 0x80, 0x20, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x21, 
        0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x87, 0x29, 0x25, 0x25, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25,
  0x0C, 0x8D, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x74, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD1, 0x41, 0x41, 0x41, 0x2C, 0x4E, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 
        0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x7D, 0x21, 0x90, 0x1E, 0x80, 0x14, 
        0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x77, 0x77, 0x13, 0x9B, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0xAE, 0xAE, 0x17, 0x73, 0x17, 0x17, 0x1B, 0x9D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 
        0x04, 0x55, 0x55, 0x89, 0x89, 0xA3, 0x04, 0x89, 0x89, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 
        0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x60, 0x06, 0x06, 0x06, 0x16, 0x16, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x97, 0x8C, 0x6C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 
        0x5F, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x2E, 0x37, 0x37, 0x05, 0x05, 0xFD, 0x1F, 0x1D, 0x1B, 0xAE, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x19, 
        0x79, 0x79, 0x26, 0x29, 0x29, 0xEE, 0x44, 0xD3, 0x3A, 0xAC, 0xAC, 0x36, 0xAB, 0xD1, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 0xCC, 0x65, 0x65, 0x07, 0x65, 0x65, 0x07,
  0xCC, 0xCC, 0x65, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0xE4, 0xE4, 0x36, 0x36, 0xAC, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x29, 0x26, 0x26, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 
        0x14, 0x12, 0x12, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0xAE, 0x73, 0xAE, 0x17, 0x17, 0x1B, 0xDC, 0xDC, 0x1D, 0x1D, 0x66, 0x66, 
        0x9C, 0x05, 0x05, 0x05, 0x98, 0x37, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 
        0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x60, 0x60, 0x60, 0x06, 0x60, 0x16, 0x60, 0x16, 0x60, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 
        0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0xA3, 0x55, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x98, 0x37, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x9D, 0x1B, 0x1B, 0x17, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x19, 0x79, 0x26, 
        0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0xAB, 0xAA, 0xAB, 0x2B, 0x2B, 0x4E, 0x2B,
  0x94, 0x94, 0x27, 0x27, 0x27, 0x94, 0x27, 0x41, 0x41, 0x96, 0x2C, 0x2C, 0x2C, 0xAB, 0xAB, 0xE4, 0x36, 0x36, 0x36, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x3A, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x21, 0x90, 0x80, 0x14, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x13, 
        0x13, 0x13, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x66, 0x9C, 0x9C, 0x9C, 0x1D, 0xDC, 0x66, 0x9C, 0x1D, 0x1D, 0x9C, 
        0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x2E, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x23, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 
        0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x82, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x5B, 0x16, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x5B, 
        0x03, 0x82, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x62, 0x06, 0xE7, 0xE7, 0x62, 0x62, 0x62, 0xE7, 0xE7, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x05, 
        0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9D, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x11, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 
        0x19, 0x19, 0x19, 0x19, 0x87, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0xAB, 0x41, 0x2C, 0xC2, 0xD2, 0x49, 0x27,
  0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x2C, 0x2C, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x26, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x90, 0x90, 0x90, 0x80, 0x80, 0x80, 0x78, 0x78, 
        0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0xCE, 0x11, 0x11, 0x11, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x73, 0xAE, 0xAE, 0x73, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 
        0x1F, 0x66, 0x9C, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x03, 0x16, 0x16, 0x16, 0xE6, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 
        0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 
        0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x60, 0x06, 0x16, 0x60, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x3D, 0x98, 0x05, 0x05, 0x05, 0xFD, 0x1F, 
        0x1D, 0xDC, 0x1D, 0x1D, 0x73, 0x73, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x21, 0x21, 0x21, 0x21, 0x21, 
        0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x79, 0x26, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0xD3, 0xD3, 0x38, 0x34, 0x34,
  0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0x08, 0x74, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x36, 0x36, 0x34, 0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 
        0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 
        0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x1A, 0x1A, 0x86, 0x86, 0x86, 0x17, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x9D, 0xDC, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x37, 0x98, 0x84, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x23, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x51, 0x52, 0x52, 0x51, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0xD6, 0xD6, 0x51, 0x51, 0x51, 0x51, 
        0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x92, 0x92, 0x09, 0x09, 0x85, 0x85, 0x09, 0xCA, 0xCA, 0x09, 0xCA, 0xCA, 0xCA, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x8C, 0x02, 0x02, 
        0x02, 0x5F, 0x89, 0x55, 0x04, 0x04, 0x2E, 0x2E, 0x05, 0x05, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x90, 0x90, 0xCD, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 
        0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34, 0xAC, 0x2B, 0x2B, 0x36,
  0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0xAA, 0x2C, 0x2C, 0x96, 0x96, 0xD2, 0x96, 0x96, 0x27, 0x96, 0x96, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0x2C, 0xAB, 0x2B, 0x4E, 0x2B, 0x2B, 0x34, 0x38, 
        0x38, 0x10, 0x10, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x80, 
        0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 
        0x2E, 0x2E, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x3D, 0xFE, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0xE7, 0xE7, 0x62, 0x51, 0xE7, 0x62, 0x51, 0xE7, 0x51, 0x51, 0x52, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x16, 0xE6, 0x03, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x62, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 
        0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x70, 0x51, 0x51, 0xE7, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x84, 0x37, 
        0x05, 0x1F, 0x9D, 0x1B, 0xAE, 0x86, 0x86, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x12, 0x12, 
        0x78, 0x14, 0x80, 0x20, 0x1E, 0x90, 0x21, 0x24, 0x19, 0x19, 0x28, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x10,
  0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x2B, 0x2B, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x29, 0x29, 0x29, 0x26, 0x79, 0x24, 0x24, 0x24, 0x22, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 
        0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x77, 0x13, 0x1A, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x31, 0x1D, 0x1D, 0x9D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x84, 0x98, 0x98, 0x84, 0x84, 0x3D, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x5F, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 
        0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 
        0x51, 0x51, 0x51, 0x62, 0xE7, 0xD6, 0xD6, 0x62, 0xE7, 0x62, 0x62, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x02, 0x23, 
        0x23, 0x23, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0x37, 0x37, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x9C, 0x9C, 0x66, 0x66, 0x9C, 0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x12, 0x78, 
        0x80, 0x20, 0x90, 0x24, 0x19, 0x19, 0x26, 0x25, 0x25, 0x10, 0x38, 0xAC, 0x36, 0xAA, 0x4E, 0xD1, 0xD2, 0x94, 0x94, 0xCC, 0x07, 0x07, 0x07, 0x07, 0xC1, 0x07, 0x07, 0xC1,
  0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x7B, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x6D, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x94, 0xD2, 0xD1, 0xD1, 0x4E, 0xE4, 0x36, 0xAC, 0xEC, 0xD3, 
        0x10, 0x10, 0x25, 0x25, 0x25, 0x26, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x17, 0x73, 0x73, 0x1B, 0x1B, 
        0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x9D, 0x9D, 0x1B, 0x1B, 0x9D, 0xAE, 0x17, 0x17, 0x86, 0x86, 0x9B, 0x1A, 0x13, 0x11, 0xCE, 0x0F, 0xCE, 0xCE, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x13, 0x13, 0x13, 0x13, 
        0xAE, 0xAE, 0x1B, 0x9D, 0xDC, 0x9D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 
        0x62, 0xE7, 0x51, 0x51, 0x51, 0x52, 0x52, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0xE6, 0xE6, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x9D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x9B, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x91, 
        0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x90, 0x24, 0x19, 0x19, 0x79, 0x26, 0x29, 0xEE, 0x44, 0x44, 0xD4, 0x3A, 0xBC, 0xBC, 0x36, 0xAA, 0x4E, 0xD1, 0x96, 0x27,
  0x0C, 0x0C, 0x0C, 0xB9, 0xB9, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0xD2, 0xD2, 0x4E, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 
        0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x55, 0xA3, 0x23, 0x23, 0x5F, 0x5F, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x62, 0x62, 0x51, 0xD6, 0x62, 0x51, 0xD6, 0x51, 0xD6, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 0xD6, 0x62, 0x62, 0x06, 0x06, 0x60, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x62, 0x62, 0x62, 0x62, 0x06, 0x06, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 
        0x89, 0x89, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x2E, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x9D, 0x9D, 0x1D, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x17, 0x9B, 0x13, 0x13, 0x1A, 0x1A, 0xCE, 0xCE, 0xCE, 0x0F, 0x91, 0x12, 0x12, 0x15, 0x78, 0x78, 
        0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0xCD, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x21, 0x21, 0x24, 0x24, 0x19, 0x24, 0x24,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x07, 0x94, 0x94, 0xA9, 0x27, 0x27, 0x96, 0x96, 0x2C, 0xAA, 0xAB, 0x2B, 0x34, 0x34, 0xD3, 0xD3, 0x44, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x80, 
        0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x90, 0x90, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x86, 0x86, 0x17, 0x1B, 0x1D, 0xDC, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x3D, 0x04, 0x04, 
        0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x97, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x03, 0x5B, 0x5B, 0x03, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x5B, 0xE6, 0x16, 0xE6, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0xD6, 0x06, 0x51, 0xD6, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x92, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 
        0x8C, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x86, 0x86, 0x13, 0x13, 0x77, 
        0x91, 0x91, 0x12, 0x78, 0x14, 0x8E, 0x20, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25, 0x29, 0x25, 0x25,
  0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x8A, 0xA0, 0x08, 0x08, 0xDD, 0x6D, 0xC1, 0x07, 0x07, 0x65, 0x65, 0xCC, 0xD2, 0x41, 0x2C, 0x2C, 0x2C, 0xE4, 0xE4, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xEC, 0x34, 0xD3, 
        0xED, 0xED, 0x44, 0xAD, 0xAD, 0xAD, 0x25, 0x5E, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x89, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x84, 0x98, 0x98, 0x98, 0x37, 0x84, 0x84, 0x05, 0x98, 0x98, 0x37, 0x84, 0x84, 0x84, 0x3D, 0x3D, 0x84, 0x84, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x97, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 
        0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x06, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0xE6, 0xE6, 
        0x5B, 0xE6, 0xE6, 0xE6, 0xE6, 0xE6, 0xE6, 0x16, 0x5B, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x82, 0x82, 0x82, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x03, 0x03, 
        0x82, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x82, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x60, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 
        0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x55, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x2E, 0x2E, 0x98, 0x37, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x73, 0x73, 0x17, 0x9B, 0x9B, 0x13, 0x77, 0x11, 
        0x91, 0x91, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x26, 0x26, 0x26, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34,
  0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0x4E, 0x41, 0x41, 0x27, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x94, 0x94, 0x27, 0x96, 0x96, 0x4E, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x21, 0x21, 0x1E, 0x80, 0x80, 0x8E, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x1A, 0x13, 0x13, 0x13, 0x13, 0x13, 0x17, 0x17, 0x86, 0x17, 0x17, 0x17, 0xAE, 0x1B, 0x1B, 0x1D, 0x1D, 0xDC, 0x9D, 0x1F, 0x1F, 0x9C, 
        0x05, 0x05, 0x05, 0x98, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x8C, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x5B, 0x5B, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0x06, 0x51, 0x70, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x70, 0x52, 0x51, 0x51, 0x51, 0x51, 0x06, 0x62, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x97, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x9C, 0x1F, 0x1D, 0x1B, 0x1B, 0x17, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x21, 0x19, 0x19, 0x79, 0x26, 0x29, 0x29, 0x29, 0x25, 0x25,
  0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x96, 0x96, 0x96, 0x2C, 0xAB, 0xAB, 0x2C, 0x4E, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x34, 0xBC, 0xAC, 0x34, 0xAC, 0x36, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 
        0x2C, 0x2C, 0xAB, 0xAA, 0x36, 0x36, 0x36, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x22, 0x22, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0xDC, 
        0x1D, 0x9D, 0x1D, 0x66, 0x66, 0x66, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x98, 0x98, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x5B, 0x16, 0x5B, 0x16, 0x82, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x60, 0x06, 0x16, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x51, 0x51, 0xD6, 0xD6, 0xE7, 0xE7, 0x51, 0xE7, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0xE7, 0xE7, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0xD6, 0xD6, 0xE7, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x62, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x5B, 0x5B, 0x5B, 0x5B, 0x5B, 0x5B, 0x5B, 0x03, 0x03, 0x03, 0x03, 
        0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x09, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0xDF, 0xA3, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x9C, 0x1F, 0x1B, 0x1B, 0x1B, 0x17, 0xAE, 0x13, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0xCD, 0x22, 0x22,
  0x65, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0xD2, 0xD2, 0x96, 0xD1, 0x41, 0x41, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x41, 0x96, 0x96, 0xD2, 0xD2, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x49, 
        0x49, 0xCC, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x94, 0x94, 0xD2, 0x2C, 0x2C, 0xAB, 0x36, 0x2B, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x24, 0x24, 0x90, 0x90, 0x1E, 0x80, 
        0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x66, 0xFD, 0xFD, 0xFD, 0x9C, 0x05, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x98, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0xFE, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 
        0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0xE7, 0x51, 0x62, 0x70, 0x70, 0x70, 0x51, 0xE7, 0xE7, 
        0x70, 0x51, 0x70, 0xE7, 0xE7, 0x70, 0x70, 0x70, 0x70, 0x70, 0x70, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 0x16, 0x5B, 0xE6, 0xE6, 0x16, 0x16, 
        0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x06, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0xE6, 
        0xE6, 0xE6, 0x5B, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x66, 0x1D, 0x1D, 0x1D, 0x17, 0x17, 0x17, 0x86, 0x13, 0x1A, 0x77, 0x0F, 0x0F, 
        0x91, 0xDE, 0xDE, 0x12, 0x12, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x22, 0x24, 0x24, 0x24, 0x24, 0x19,
  0xE2, 0xCB, 0x0C, 0x0C, 0xB9, 0xB2, 0xA7, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0xB3, 0x08, 0x08, 0x08, 0x74, 0xDD, 0xDA, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0xCC, 0x94, 0xCC, 0x94, 0x27, 0x27, 0x49, 0x94, 0xA9, 0xA9, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 
        0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x96, 0xD1, 0xD1, 0xD1, 0x2C, 0x2C, 0xAA, 0xAB, 0x36, 0x34, 0xAC, 0x34, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x37, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x0A, 
        0x8C, 0x8C, 0x8C, 0x02, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x5B, 0x5B, 0x16, 0x16, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x62, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0xD6, 0x06, 0x06, 0x62, 0x62, 0x06, 0x62, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x16, 0x16, 0x60, 0x06, 0x06, 0x60, 0x60, 0x16, 0x16, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 
        0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x98, 0x05, 0x84, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0xDC, 0x1D, 0x1B, 0x17, 0x17, 0x13, 0x9B, 
        0x1A, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x28,
  0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0xD2, 0x96, 0xD2, 0xD2, 0xC2, 0x2C, 0xD1, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0xD1, 0x2C, 0x2C, 0x2C, 0x2C, 0xAB, 0xE4, 0x36, 
        0x36, 0x5A, 0x34, 0x34, 0x38, 0xD3, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x19, 0x24, 0x24, 0x7D, 0x7D, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x86, 0x17, 0x1B, 0x1D, 0x9C, 0x05, 0x05, 0x37, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x5F, 0x02, 0x02, 0x02, 0x5F, 0x5F, 0x02, 0x02, 0xDF, 
        0x23, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x31, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x66, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 
        0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x89, 0x89, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x16, 0x06, 0x16, 0x06, 0x06, 
        0x62, 0x06, 0xE7, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x62, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x06, 0xE6, 0x5B, 0x16, 0x82, 0x03, 0x5B, 0x03, 0x5B, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 
        0x16, 0xE6, 0xE6, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x62, 0x62, 0x62, 0xE7, 0x51, 0x62, 0x62, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x92, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 
        0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x23, 0x89, 0x89, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x2E, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 
        0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0xCD,
  0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 
        0x25, 0x29, 0x26, 0x26, 0x19, 0x24, 0x7D, 0x21, 0x90, 0x90, 0x20, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 
        0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x11, 0x11, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x13, 0xAE, 0x1B, 
        0x1B, 0x1D, 0xDC, 0x1D, 0x1F, 0x66, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x98, 0x98, 0x98, 0x98, 0x98, 0x37, 0x84, 0x98, 0x84, 0x37, 0x37, 0x37, 0x84, 0x84, 0x37, 0x84, 0x98, 0x84, 0x37, 0x98, 0x98, 0x84, 0x2E, 0x3D, 0x3D, 0x3D, 
        0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0xE7, 0xE7, 0xE7, 0x70, 0x70, 
        0xE7, 0x70, 0x70, 0x51, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x51, 0x62, 0x62, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x06, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x82, 0x82, 0x16, 0x16, 0x16, 0x82, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0xD6, 0x51, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0xFE, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x9C, 0x9D, 0x9D, 0x17, 0x17, 0x86, 
        0x13, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26,
  0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x96, 0x2C, 0xE4, 0xE4, 0xEC, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 
        0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x20, 0x80, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x17, 0x17, 0x73, 0x73, 0x1B, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x73, 0x73, 0x73, 0x73, 0x17, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x73, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0xFD, 0x66, 0x05, 0x05, 0x05, 0x05, 0x3D, 0x3D, 0x04, 
        0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 
        0x23, 0xDF, 0xDF, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x62, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x62, 
        0xE7, 0xE7, 0xE7, 0x51, 0x70, 0x70, 0x70, 0x70, 0x70, 0x62, 0xD6, 0x62, 0x51, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 
        0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0x23, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x98, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x86, 
        0x13, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24,
  0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x2B, 0x2B, 0x36, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0xAD, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 
        0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 
        0x29, 0x29, 0xF0, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x1B, 0x1B, 0x9D, 0x1D, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x04, 0x55, 0x55, 0x55, 0x04, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x55, 0x89, 0x89, 0x04, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x55, 0x89, 0x55, 0x89, 0xA3, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 
        0x98, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x98, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 
        0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x51, 
        0x51, 0xE7, 0x51, 0x51, 0x52, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0x51, 0x51, 0x52, 0x51, 0x51, 
        0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0xF2, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x89, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x05, 0x05, 0x9C, 0x1B, 0x1B, 0x17, 0x86, 
        0x13, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x25, 0x25, 0x25,
  0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0x07, 0x07, 0xC1, 0x07, 0x07, 0xC1, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0xA9, 0x27, 0x96, 0xC2, 0xC2, 0x2C, 0x4E, 
        0xAB, 0x4E, 0x2B, 0x36, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x20, 0x80, 0x80, 0x8E, 0x14, 0x14, 0x14, 0x78, 0x78, 
        0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x17, 0xAE, 0xAE, 0x17, 0x73, 0x73, 0x73, 0x73, 0x1B, 
        0xDC, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x3D, 0xFE, 0x2E, 0x3D, 0x2E, 0xFE, 0x3D, 0xFE, 0x2E, 0x3D, 0x3D, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x62, 0x06, 0x62, 0x62, 0x62, 0x62, 0x62, 0x51, 0x51, 0xE7, 0x62, 0x51, 0x51, 0x51, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x62, 0x62, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0xD6, 0xD6, 0x62, 0x06, 
        0x06, 0x06, 0x60, 0x16, 0xE6, 0xE6, 0x5B, 0x03, 0x03, 0xCA, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x97, 0x6C, 0x02, 0x02, 
        0x02, 0x02, 0xDF, 0x89, 0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x98, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x1D, 0x1B, 0x1B, 0x17, 
        0xAE, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80,
  0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0xB2, 0x8D, 0x0B, 0x0B, 0x8A, 0x7B, 0x08, 0x6D, 0xDA, 0x07, 0x65, 0x65, 0x27, 0xD2, 0xD2, 0x41, 0x4E, 0x2B, 0x36, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x22, 0x21, 
        0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9C, 0x9C, 0x9D, 0x1F, 0x9C, 0xFD, 0x66, 0x05, 0x05, 0x05, 0x05, 0x66, 0xFD, 0xFD, 0x66, 0x9D, 0xDC, 0xDC, 
        0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x73, 0x17, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x84, 0x2E, 0x98, 0xFE, 0xFE, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 
        0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x82, 0x82, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x16, 0x16, 0x82, 0x82, 0x16, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x51, 0xE7, 0xE7, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x82, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 
        0x0A, 0x97, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x89, 0x89, 0x23, 0x89, 0x89, 0x23, 0x89, 0xA3, 0xA3, 0x89, 0x89, 0x89, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x84, 0x84, 0x3D, 0x98, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x9C, 0x66, 0x1D, 0x1D, 0x73, 0x1B, 0x1B, 0x86, 0x17, 0x9B, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78,
  0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xC6, 0xC6, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xE3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x74, 0xDA, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 
        0x65, 0xCC, 0x27, 0xD2, 0x96, 0x4E, 0xAB, 0x4E, 0x2B, 0x36, 0x34, 0x34, 0x34, 0x3A, 0x38, 0x10, 0x25, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x28, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x7D, 0x7D, 0x21, 0x90, 0x90, 0x20, 0x80, 0x8E, 0x14, 
        0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x66, 0x1D, 0x9C, 0x66, 0x66, 0x9C, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x05, 0x37, 0x37, 0x98, 0x05, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x60, 0x60, 0x06, 0x06, 0x62, 0x62, 0x62, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x06, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0xE7, 0x06, 0x62, 0x06, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0xCA, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x55, 0xA3, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x2E, 0x05, 0x37, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x9B, 0x86, 0x86, 0x86, 0x13, 0x86, 0x9B,
  0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x96, 0x2C, 0xAB, 0xAB, 0x36, 0x36, 0xEC, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0xAD, 0xAD, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x80, 0x80, 0x80, 0x80, 0x14, 0x80, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x20, 0x80, 0x80, 0x20, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x9D, 
        0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x37, 0x84, 0x84, 0x98, 0x37, 0x84, 0x98, 0x84, 0x84, 0x84, 0x98, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x05, 0x37, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x98, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 
        0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x03, 0x03, 0x09, 0x03, 0x09, 0x85, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x16, 
        0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x82, 0x5B, 0x5B, 0xE6, 0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x62, 0x62, 0x62, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0x62, 
        0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x01, 
        0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1F, 0x1D, 0x9D, 0x1B, 0x17, 
        0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x21,
  0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x49, 0x27, 0xD2, 0x41, 0x4E, 0xAB, 0x36, 0x2B, 0x2B, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 
        0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 
        0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x73, 0x17, 0x17, 0x17, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x73, 0x73, 0x73, 0x73, 
        0x73, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0xFD, 0xFD, 0xFD, 0xFD, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x98, 0x37, 0x37, 0x98, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x92, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x82, 0x82, 0x16, 0x16, 0x16, 
        0x60, 0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x51, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78,
  0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x27, 0x27, 0x41, 0x2C, 0x2C, 0x2B, 0x2B, 0x34, 
        0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0xFC, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0x77, 0x1A, 0x1A, 0x9B, 0x9B, 0x17, 0x17, 0x17, 0x17, 0x73, 0x1D, 0xDC, 0x1D, 0x9C, 0x9C, 0x9C, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x55, 0x55, 0xA3, 0xA3, 0x23, 0x23, 0xDF, 0xDF, 0x02, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0xA3, 
        0xA3, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x89, 0x89, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x01, 
        0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x51, 0x51, 0x70, 0x70, 0x52, 
        0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0xD6, 0xD6, 0xD6, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0x62, 0x06, 0xE7, 0xE7, 0xE7, 0x62, 0x62, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0xE7, 0x62, 0x06, 0x06, 0xE7, 0x62, 0xE7, 0x06, 0x62, 0x06, 0xE7, 0x62, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 0x37, 0x05, 0x05, 0x1F, 0x9D, 0x1B, 0x1B, 
        0x1B, 0x1B, 0xAE, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13,
  0xD8, 0x8F, 0x0C, 0x0C, 0x0C, 0xA7, 0xA7, 0xA8, 0x0B, 0x8A, 0x8A, 0xB3, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x94, 0x27, 0xD2, 0x41, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x2B, 0x34, 
        0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x26, 0x79, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x18, 0xFC, 0x12, 0x12, 0x91, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0xCE, 0x77, 0x13, 0x13, 0x13, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 
        0x13, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x17, 0x17, 0x1B, 0x9D, 0x9D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x84, 0x2E, 0x2E, 0xFE, 0x3D, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0x84, 0x98, 0x84, 
        0x37, 0x05, 0x98, 0x84, 0x05, 0x05, 0x05, 0x98, 0x98, 0x05, 0x05, 0x05, 0x37, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x16, 0x16, 0x16, 0x60, 0x60, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x70, 0x70, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 
        0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0xE7, 0xE7, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x97, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x9D, 
        0x1B, 0x17, 0x86, 0x86, 0x86, 0x13, 0x63, 0x11, 0x77, 0x0F, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x79, 0x79,
  0x8A, 0x8A, 0xB3, 0xB3, 0x8A, 0x8A, 0x8A, 0x8A, 0x8A, 0x8A, 0x8A, 0x8A, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x74, 0x08, 0xBB, 0xBB, 0xDA, 0x6D, 0x6D, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 
        0x94, 0x94, 0x27, 0xD2, 0xD2, 0x41, 0x41, 0x4E, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x29, 0x29, 0x79, 0x79, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1D, 0x9D, 0x1D, 0x66, 0xFD, 0x1F, 0x9C, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x1D, 0x9D, 0x9D, 0x1B, 0xAE, 0xAE, 0xAE, 0xAE, 0x13, 
        0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x3D, 0x2E, 0x2E, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x03, 
        0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x60, 0x06, 0x60, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x5B, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xD6, 0xE7, 0x06, 0xD6, 0xD6, 0xD6, 0xD6, 0x62, 0x62, 0xD6, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x60, 0x60, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x23, 0x23, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x2E, 
        0x3D, 0x3D, 0x84, 0x3D, 0x3D, 0x84, 0x84, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1B, 0x1B, 0x17, 0x86, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x78, 0x78,
  0x93, 0x0D, 0x93, 0x93, 0x0D, 0x0D, 0x93, 0x93, 0x93, 0x93, 0x93, 0x75, 0x0E, 0x9F, 0x9F, 0x8F, 0x8F, 0x0C, 0xA7, 0xA7, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0xDD, 0xBB, 0x6D, 0x07, 0x65, 0x49, 0x27, 0x27, 0xD2, 0xD1, 0xD1, 0x2C, 0x2C, 0x96, 0x2C, 0x2C, 
        0xAB, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x77, 0xCE, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x95, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0xCE, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x73, 0x73, 0x1B, 0x9D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 
        0x89, 0x89, 0x89, 0x5F, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x16, 0x60, 0x60, 0x16, 0x5B, 0x16, 
        0x16, 0x16, 0x16, 0x60, 0x16, 0x16, 0x16, 0x60, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x06, 0xD6, 0x51, 0x62, 0x62, 0x51, 0xD6, 0xE7, 0x51, 0xE7, 0x62, 0x62, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 
        0x3D, 0x84, 0x84, 0x37, 0x05, 0x05, 0xFD, 0xFD, 0x9C, 0x1F, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F,
  0x0D, 0x0D, 0x88, 0x88, 0x0D, 0xC0, 0xC0, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xBA, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xDD, 0xDD, 0x6D, 0x07, 0x65, 0x65, 0x27, 0x27, 0x41, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x36, 0xAC, 0x34, 0x38, 
        0x38, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0x87, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 
        0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x15, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x1A, 
        0x86, 0x86, 0x17, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 
        0x23, 0x23, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 
        0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x06, 0x06, 
        0x06, 0x62, 0x62, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x70, 0x51, 0x51, 0x62, 0x62, 0xD6, 0x51, 0x62, 0xD6, 0x51, 0x51, 0x62, 
        0x62, 0x62, 0x06, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x60, 
        0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x02, 
        0x02, 0xDF, 0x23, 0x89, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x84, 0x05, 0x05, 0x1F, 0x9D, 0x1B, 0xAE, 0x13, 0x13, 0x0F, 0x91, 0x91, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x21,
  0x6A, 0xB8, 0xB8, 0xB8, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0xB9, 0x8D, 0x0B, 0xB3, 0xA0, 0x08, 0xBB, 0xC1, 0x07, 0x94, 0x94, 0xD2, 0x2C, 0xE4, 0x2B, 0x34, 0x38, 0x10, 
        0x25, 0x25, 0x25, 0x29, 0x26, 0x28, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 
        0x1E, 0x80, 0x80, 0x78, 0x78, 0x78, 0x78, 0x12, 0x0F, 0x11, 0x11, 0x13, 0x13, 0x13, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x37, 0x37, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x31, 0x1D, 0x9D, 0x1D, 0x1D, 0xFD, 0x05, 0x05, 
        0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x89, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xD6, 0xD6, 0xE7, 0xE7, 0x51, 0x51, 0x52, 0x51, 0x70, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x52, 
        0x52, 0x51, 0x51, 0x52, 0x70, 0x70, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 
        0x89, 0x89, 0x04, 0x04, 0x3D, 0x2E, 0x98, 0x05, 0x9C, 0x1F, 0x1B, 0xAE, 0xAE, 0x86, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x78, 0x14, 0x20, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24,
  0x8F, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x27, 
        0x49, 0xD2, 0x27, 0xD2, 0xD2, 0xD2, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 
        0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x95, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x86, 0x17, 0x1B, 0x1B, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0xFE, 0xFE, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x73, 0x86, 0x17, 0x17, 0x86, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x9D, 0x1D, 0x05, 0x05, 0x05, 0x84, 0x84, 0x3D, 0x2E, 0x2E, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x03, 
        0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 
        0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x09, 0x09, 0x92, 0x09, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x16, 0x5B, 0x5B, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x62, 0x62, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 
        0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x84, 0x37, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x73, 0xAE, 0xAE, 0x86, 0xAE, 0xAE, 0xAE, 0x73, 0x73,
  0x7B, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xDD, 0xDD, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x27, 
        0xD2, 0xD2, 0xD2, 0xD1, 0xD1, 0x2C, 0x2C, 0xD1, 0xD1, 0x2C, 0x2C, 0x2C, 0xAB, 0xAA, 0xE4, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x19, 0x21, 0x21, 0x90, 0x90, 0x80, 0x14, 
        0x14, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x98, 0x98, 0x2E, 0x2E, 0x2E, 0xFE, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x6C, 0x6C, 0x97, 0x97, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 
        0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x37, 0x84, 0x37, 0x05, 0x05, 0x84, 0x84, 0x84, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x70, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x06, 0x06, 0x06, 0x16, 0x06, 0x16, 0x16, 0x16, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86,
  0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xB3, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xB3, 0xA0, 0x08, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xDD, 0x74, 0x6D, 
        0xDA, 0x6D, 0x6D, 0x65, 0x65, 0x49, 0x49, 0x61, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 
        0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x11, 0x77, 0x13, 0x9B, 0x9B, 0x9B, 0x13, 0x9B, 0x9B, 0x9B, 0x9B, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x1B, 
        0x1B, 0x73, 0x1B, 0x1D, 0x9D, 0x1D, 0xFD, 0xFD, 0x1D, 0x9C, 0x9C, 0x66, 0x66, 0x05, 0x66, 0x66, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1F, 0x1D, 0x9D, 0x9D, 0xDC, 0xDC, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x9B, 0x86, 0x86, 0x86, 0x86, 0x86, 
        0x86, 0xAE, 0x17, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0x9D, 0x66, 0xFD, 0x05, 0x05, 0x98, 0x98, 0x37, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x5B, 
        0x5B, 0x5B, 0xE6, 0x16, 0x5B, 0x60, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x01, 0x85, 0x01, 0x92, 0x92, 0x92, 0x85, 0x85, 
        0x92, 0x92, 0x85, 0x09, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x16, 0x16, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0xE6, 0xE6, 0x16, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x62, 0xE7, 0x70, 0x70, 0x51, 0x70, 0x70, 0x51, 0x51, 0x70, 0x52, 0x52, 0x52, 0x70, 0x70, 0x70, 0x70, 0x70, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x04, 0x04, 0x89, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x3D, 0x84, 0x84, 0x84, 0x37, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x9D, 0x9D, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F,
  0x75, 0x0E, 0x0E, 0x9F, 0x9F, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x49, 0x41, 0x41, 0x41, 0x4E, 0x4E, 
        0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 
        0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x79, 0x24, 0x24, 0x24, 0x7D, 0x21, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0x20, 0x20, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x11, 0x11, 0x11, 0x13, 0x13, 
        0x13, 0x13, 0x17, 0x73, 0x1D, 0x73, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x9C, 0xFD, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 
        0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0xE6, 
        0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x60, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x62, 0x62, 0x51, 0xD6, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0xD6, 0x51, 0x51, 0xD6, 0x51, 0x51, 0x62, 0x62, 0x06, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x60, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x23, 0x23, 
        0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1B, 0x1D, 0x1D, 0x73, 0x1B, 0x1B,
  0x0D, 0x93, 0x93, 0x93, 0x93, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0xD1, 0x4E, 0x2C, 0xAB, 
        0xAB, 0x2B, 0x2B, 0xE4, 0x2B, 0x2B, 0xE4, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0xE4, 0x36, 0x36, 0xE4, 0xE4, 0xAB, 0xAB, 0xE4, 0x2B, 0x2B, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x19, 
        0x24, 0x24, 0x22, 0xCD, 0x21, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x18, 0x18, 0x14, 0x78, 0x78, 0x78, 0x15, 0x12, 0x15, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 
        0x1A, 0x1A, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x9B, 0xAE, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x73, 0x73, 0x9D, 0x9D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x98, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x04, 
        0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x51, 0xD6, 0x51, 0x51, 
        0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0x51, 0xE7, 0x51, 0xD6, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x06, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 
        0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9D, 0x9D, 0x1D, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x1A, 0x77,
  0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xDA, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x27, 0x4E, 0xAB, 0xAB, 
        0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x10, 0x10, 0x10, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 0x24, 0x21, 0x1E, 0x1E, 0x14, 0x78, 0x12, 0x0F, 0x0F, 0x77, 0x13, 
        0x86, 0x17, 0x9D, 0x1F, 0x9C, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x05, 0x98, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 
        0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x9D, 0x1F, 0x1F, 0xFD, 0x05, 0x37, 0x2E, 
        0xFE, 0x2E, 0x04, 0x04, 0x04, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x92, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0xE7, 0x51, 0xD6, 0xE7, 0xE7, 0xE7, 0xE7, 0xD6, 0xE7, 0xE7, 0xE7, 0x51, 0x51, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x55, 0x55, 0xA3, 0xA3, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x2E, 0x2E, 0x37, 0x98, 0x84, 0x84, 0x84, 0x37, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05,
  0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x9F, 0x9F, 0x9F, 0x9F, 0x9F, 0x8F, 0xCB, 0xCB, 0x0C, 0xB9, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x65, 0x49, 0x49, 0x61, 0x41, 0x4E, 0xAB, 0x2B, 0x34, 0x38, 0x38, 0x10, 0x10, 0x44, 
        0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0xED, 0x10, 0x10, 0x44, 0x10, 0x10, 0x44, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 
        0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x9B, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x84, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 
        0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x55, 0x55, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x5F, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x62, 0xE7, 
        0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x37, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 0x9C, 0x1F, 0x66, 0x9C, 0x9C, 0x1F, 0x9C, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05,
  0x57, 0x57, 0x1C, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x7E, 0x7E, 0x6B, 0x6B, 0x0D, 0x0D, 0x0D, 0x93, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x74, 0x6D, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x27, 0x27, 0x27, 0x27, 0x41, 0x2C, 0x4E, 0x4E, 0x2B, 0xE4, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x1A, 0xE5, 0x9B, 0xAE, 0x73, 0x73, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 
        0x37, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x98, 0x37, 0x37, 0x37, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x66, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 
        0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x16, 0x16, 0x16, 0x03, 0x03, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0xE6, 
        0x60, 0x06, 0x06, 0x06, 0x06, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xD6, 0x06, 0x06, 0x16, 0x60, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0xDF, 0x23, 0x23, 0xA3, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0xAE, 0x1B, 0x1B, 0xAE, 0xAE, 0x17, 0x17,
  0x0E, 0x9F, 0x9F, 0x8F, 0x8F, 0x8F, 0x0C, 0xB2, 0xB2, 0xBA, 0xA8, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x36, 0xBC, 0xBC, 0xEC, 0x38, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x38, 0x34, 0xAC, 0x36, 0x36, 0x2B, 0xAB, 0x4E, 0x4E, 0x2C, 0x41, 0xD2, 0x41, 0x41, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 
        0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x19, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0xDC, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x66, 0x66, 0x1D, 0x1D, 0x73, 0x73, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x77, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x15, 0x15, 0x12, 0x95, 0x95, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x1A, 0x1A, 0x9B, 0x17, 0x17, 
        0x17, 0x73, 0x1D, 0x1D, 0x1D, 0x1F, 0x05, 0x05, 0x98, 0x98, 0x98, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x70, 0x70, 0x70, 0x51, 0x70, 0x70, 0x70, 0x70, 0x51, 0x51, 0x70, 0x70, 0x70, 0x70, 0x70, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 
        0x60, 0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0xD6, 0x06, 0xD6, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x23, 0x89, 0x23, 0x23, 0x55, 0x55, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 
        0x2E, 0x2E, 0x2E, 0x2E, 0x05, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D,
  0xCC, 0xCC, 0xCC, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x27, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x96, 0x96, 0x96, 0x27, 0x27, 0x94, 0x27, 0x27, 0x27, 0x27, 0x96, 0x27, 0x96, 0x96, 0xC2, 0x2C, 0xAB, 0xAA, 0xAA, 0xAA, 0x36, 
        0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x24, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x78, 0x95, 0x95, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x13, 
        0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x73, 0x73, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 0x98, 0x98, 0x98, 0x98, 0x84, 0x05, 0x98, 
        0x98, 0x98, 0x98, 0x98, 0x84, 0x2E, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x55, 0x55, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 
        0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x03, 0x16, 0x16, 0x16, 0x16, 0x82, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x92, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x89, 0x23, 0x23, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0xFD, 0xFD, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x73,
  0xB9, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 0x49, 0x27, 
        0x27, 0x27, 0x27, 0x49, 0x49, 0x49, 0xCC, 0xCC, 0xCC, 0x65, 0x65, 0x65, 0xCC, 0x65, 0x65, 0xCC, 0x94, 0x27, 0x27, 0xD2, 0x41, 0xD1, 0x2C, 0x2C, 0x2B, 0x36, 0xAC, 0x34, 0x3A, 0x3A, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x28, 
        0x79, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0xCD, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 
        0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x05, 0x37, 0x37, 0x37, 0x37, 0x37, 0x98, 0x98, 
        0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x3D, 0x3D, 0x3D, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x51, 0x51, 0x52, 0x51, 0x51, 0x52, 0x51, 
        0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0x62, 0x51, 0x62, 0x51, 0xE7, 0xE7, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x5F, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C,
  0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 
        0xAC, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x28, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x22, 0x22, 0x22, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x24, 0x19, 0x19, 0x79, 0x19, 0x79, 0x19, 0x19, 
        0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x86, 0xAE, 0x17, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 
        0x3D, 0x3D, 0x04, 0x98, 0x84, 0x98, 0x98, 0x98, 0x98, 0x98, 0x98, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x60, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x60, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x5B, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x60, 0x60, 0x60, 0x06, 0x06, 0x60, 0x60, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x92, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x0A, 0x8C, 
        0x8C, 0x6C, 0x6C, 0x02, 0x02, 0xA3, 0x89, 0x23, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x04, 0x3D, 0x3D, 0x3D, 0x2E, 0x2E, 0xFE, 0x2E,
  0xB2, 0x8D, 0x8D, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0xB3, 0x8A, 0x8A, 0x8A, 0x7B, 0xA0, 0xA0, 0xA0, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 
        0x6D, 0x6D, 0x6D, 0x65, 0xCC, 0x49, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x3A, 0xD3, 0xD3, 0x10, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 
        0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x11, 0x11, 0x77, 0x1A, 0x9B, 0x13, 0x13, 0x86, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0xAE, 0xAE, 0xAE, 0xAE, 0x86, 
        0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x3D, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x23, 0x23, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x5F, 0x23, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x55, 0xA3, 0xA3, 0x55, 0x89, 0x55, 0x55, 0x89, 0xA3, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x09, 0x09, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x92, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x16, 0x16, 0xE6, 0x60, 0x06, 0x06, 0x06, 0x62, 0x62, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x62, 0x62, 0x62, 0x06, 0x06, 0x06, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x60, 
        0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x5B, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x60, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 
        0x97, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x23, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0xFD, 0x1F, 0x9C, 0x9C, 0x1D, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x1D, 0x1F, 0x9C, 0xFD,
  0x0D, 0x0D, 0x0D, 0x0D, 0x93, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0x8F, 0x8F, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xDD, 
        0xDD, 0xDD, 0x6D, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x2C, 0x41, 0x4E, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x20, 0x80, 
        0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x11, 0x77, 0x13, 0x13, 0x86, 0x17, 0x17, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x9D, 0x9D, 
        0x17, 0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0xAE, 0x17, 0x1B, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x98, 0x37, 0x84, 0x84, 0x84, 0x98, 0x84, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x3D, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 
        0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x82, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0x70, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0xD6, 0xD6, 0x62, 
        0x62, 0x06, 0x06, 0x06, 0x06, 0x60, 0x60, 0x60, 0x16, 0xE6, 0xE6, 0xE6, 0xE6, 0xE6, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x89, 0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x3D, 0x3D, 0x37, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1F, 0xFD, 0x66,
  0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0xC1, 0x07, 
        0x07, 0x07, 0xCC, 0x49, 0x27, 0xD2, 0x41, 0xAB, 0xAB, 0x2B, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x77, 
        0x13, 0x13, 0x17, 0x17, 0x17, 0x1B, 0x9D, 0x1F, 0x66, 0x9C, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x98, 0x98, 0x37, 0x37, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x2E, 0x98, 0x98, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0xCA, 0xCA, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0xCA, 0x09, 0x09, 0xCA, 0x09, 0x09, 0xCA, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x03, 0x03, 0xCA, 0x09, 0x09, 0x03, 0x03, 0x09, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 
        0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xA3, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x37,
  0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x6D, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x65, 0x65, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0x2B, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0x79, 0x19, 0x24, 
        0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x86, 0x1B, 0x1B, 
        0x1B, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x55, 0x55, 0x55, 0x55, 0x89, 0x89, 0x89, 0x89, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0xFE, 
        0xFE, 0x2E, 0x2E, 0x3D, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x05, 0x05, 0x37, 0x98, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x37, 0x37, 0x05, 0x37, 0x05, 0x98, 0x98, 0x98, 0x98, 0x2E, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 
        0x89, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x06, 0x06, 0x16, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0xE6, 0x5B, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0xE6, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x97, 0x01, 0x01, 
        0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C,
  0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 
        0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x6D, 0x6D, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x65, 0x49, 0xD2, 0x41, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x19, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 
        0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 
        0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x55, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0xFE, 0x3D, 0x2E, 0x2E, 0x2E, 0x84, 0x98, 0x2E, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 
        0x3D, 0x2E, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x3D, 0xFE, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x60, 0x60, 0x60, 0x60, 0x60, 0x60, 0x06, 0x06, 0x06, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xD6, 0xD6, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x60, 0x60, 0x60, 0x60, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 
        0xA3, 0x89, 0x89, 0x89, 0x04, 0x55, 0x89, 0x89, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x5F, 0x5F, 0x5F, 0xDF, 0xDF, 0xDF,
  0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0x8D, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0x07, 0x07, 0x94, 0x27, 0xD2, 0x41, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x29, 0x29, 0xF0, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0xAE, 0x73, 0x73, 0x73, 0x1B, 0x1B, 
        0x73, 0x73, 0x1B, 0xAE, 0x17, 0x73, 0x73, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x31, 0x31, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xFD, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9D, 0x9D, 
        0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x73, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x17, 0x86, 0x17, 0x17, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x05, 0x05, 0x05, 0x05, 0x98, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x55, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x97, 
        0xF3, 0x01, 0xF3, 0x01, 0x01, 0x97, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x62, 0x51, 0xE7, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x62, 0xE7, 0x51, 0x51, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0xF2, 0x6C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 
        0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x8A, 0x8A, 0xB3, 0x8A, 0x7B, 0x8A, 0x7B, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xDA, 0x6D, 0x07, 0x07, 0x07, 0xCC, 0x27, 0xD2, 0x2C, 0x4E, 0x2B, 0x2B, 0xAC, 0x38, 0x10, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x87, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x28, 0x79, 
        0x79, 0x26, 0x26, 0x26, 0x29, 0x26, 0x29, 0x29, 0x26, 0x26, 0x29, 0x29, 0x26, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0xDE, 0xDE, 0x91, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x1A, 0x9B, 0x13, 0x9B, 0x9B, 0x86, 0x86, 0x17, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x9C, 0x66, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 
        0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x55, 0x89, 0x89, 0x55, 0x04, 0x89, 0x89, 0x89, 0x89, 
        0x55, 0x89, 0x89, 0xA3, 0xA3, 0x89, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0xCA, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0xCA, 0xCA, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0xE6, 0xE6, 0x16, 0x16, 0x60, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 
        0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x92, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 
        0x0A, 0xF2, 0xF2, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 0x84, 0x05, 0x05,
  0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0xB3, 0x8A, 0x08, 0x08, 0x74, 0xDD, 0x6D, 0x6D, 0x6D, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0x07, 0x07, 0xCC, 0x49, 0x27, 0x27, 0x27, 0x49, 0x49, 0x27, 0x27, 0x27, 0x27, 0x49, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 
        0x2B, 0xAB, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 
        0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x73, 0x73, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1D, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x9C, 0x66, 0x66, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 
        0x37, 0x98, 0x3D, 0x37, 0x37, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0x51, 0x51, 0xE7, 0x70, 0xE7, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x52, 0x52, 0x52, 0x52, 0x51, 0x51, 0x51, 0x51, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 
        0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x5F, 0x5F, 0x23, 0xA3, 0x5F, 0x23, 0x89, 0x5F, 0x5F, 0x02, 0x5F, 0x89, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x55, 0x55, 0x89, 0x04, 0x55, 0x55, 0x55, 0x55, 0x04,
  0x0E, 0x9F, 0x8F, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xA7, 0xA7, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0xCC, 0x27, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0x36, 0xC8, 0x3A, 0xD3, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x29, 0x25, 0xF0, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x34, 0x34, 0x34, 0x34, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xAC, 0xAC, 0x36, 0xBC, 0xBC, 0x34, 0x3A, 0xD3, 0x10, 0x10, 0x10, 
        0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 
        0x78, 0x91, 0x0F, 0x0F, 0x77, 0x13, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xFD, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0x73, 
        0x73, 0x73, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x66, 0x66, 0x66, 0x66, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0x62, 0x06, 0x06, 0x06, 0x06, 0x62, 0xD6, 0x62, 0x62, 0xD6, 0x62, 0xE7, 0xD6, 0x51, 0xE7, 0x51, 0x51, 0x51, 0x70, 0x51, 0x51, 0x51, 0x51, 0x70, 0xE7, 0xE7, 0x51, 0x70, 0xE7, 0x70, 0x51, 0x62, 0xE7, 
        0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xA3, 0x55, 0x55, 
        0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B,
  0x3C, 0x3F, 0xB6, 0x50, 0x50, 0x2D, 0xB7, 0x57, 0x1C, 0x6A, 0xB8, 0xA6, 0x0D, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x7B, 0x7B, 0x08, 0x08, 0x08, 0x08, 0x74, 0xDD, 0xDD, 0xDD, 0xDA, 0xDA, 0x6D, 
        0x6D, 0xBB, 0xDA, 0xDA, 0x6D, 0xDD, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x6D, 0xC1, 0x6D, 0xCC, 0x49, 0x49, 0x49, 0x41, 
        0x41, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x87, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x91, 0x0F, 0x77, 
        0x77, 0x13, 0x86, 0x86, 0x86, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x73, 0x1B, 0x1D, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 
        0x66, 0x66, 0x66, 0x66, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x37, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 
        0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x0A, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x89, 0x55, 0x55, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C,
  0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xC0, 0xC0, 0x93, 0x93, 0xC0, 0xC0, 0x93, 0xC0, 0x93, 0x88, 0x88, 0x75, 0x75, 0x75, 0x0E, 0x0E, 0x9F, 0x9F, 
        0x8F, 0x0C, 0x0C, 0x0C, 0x8D, 0x0B, 0x0B, 0x8A, 0x7B, 0x7B, 0x08, 0xDD, 0x6D, 0x6D, 0x07, 0x65, 0xCC, 0xCC, 0x27, 0xD2, 0xC2, 0x4E, 0x2C, 0xAB, 0xAB, 0x2B, 0x2B, 0x36, 0x2B, 0xAC, 0xAC, 0xAC, 0x34, 0x34, 0x34, 0x3A, 0x34, 0x38, 0x10, 0x10, 0x10, 
        0x25, 0x25, 0x25, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 
        0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x1B, 0x73, 0x73, 0x1B, 0x9D, 0x1D, 
        0x1D, 0xDC, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x92, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x09, 0x92, 0x92, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 
        0x01, 0x0A, 0x0A, 0x0A, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x23, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05,
  0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xDD, 0x6D, 0xC1, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0xCC, 0xCC, 0x49, 0x49, 0x49, 0x49, 0x27, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0xD1, 0xD1, 0x2C, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0xE4, 0x36, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 
        0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x86, 0xAE, 0xAE, 0x1B, 0x1B, 0x9D, 0x1F, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 
        0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x84, 0x84, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x23, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x23, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0xF2, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x09, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x62, 0x51, 0x51, 0x62, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x60, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0xDF, 0xDF, 0xDF, 0x5F, 0x5F, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84,
  0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0x0D, 0xC0, 0xC0, 0xB1, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0xB3, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0xAA, 0xAA, 0x2B, 0x34, 0xBC, 0x3A, 0x10, 0x10, 0x25, 0x29, 0x29, 0x29, 0x26, 0x79, 
        0x24, 0x24, 0x7D, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 
        0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x11, 0x11, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0xDE, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 
        0xF1, 0xCE, 0x77, 0x77, 0x1A, 0x13, 0x86, 0x17, 0x73, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x37, 0x98, 0x98, 0x98, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0xCA, 0xCA, 0xCA, 
        0xCA, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x85, 0xCA, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x60, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x8C, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 
        0x23, 0x5F, 0xDF, 0x23, 0x23, 0xA3, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x37, 0x37, 0x05,
  0x4B, 0x3C, 0x3C, 0x54, 0xBE, 0x50, 0x2D, 0x57, 0x1C, 0x1C, 0x6A, 0x6B, 0x0D, 0x93, 0xCF, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x8A, 0x8A, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0xD2, 0x41, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0xF0, 0x26, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x28, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x19, 0x24, 0x21, 0x21, 0x1E, 0x80, 0x80, 0x14, 
        0x78, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x55, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x98, 0x05, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x9D, 0x73, 0x1B, 0x1B, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x9B, 0x86, 0x17, 0x17, 0x73, 0x73, 0x73, 0x1B, 0x1D, 0x9D, 0x1D, 
        0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x98, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 
        0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x97, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x97, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x54, 0x54, 0x54, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0xB7, 0x57, 0x57, 0x1C, 0x1C, 0x6A, 0x6B, 0x0D, 0x0D, 0x0D, 0xB1, 0x0E, 0xE2, 0x0C, 0x0C, 0x0C, 0xB2, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x65, 0xCC, 0xCC, 0xCC, 0xCC, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xDA, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x6D, 0x6D, 0xDA, 0x6D, 0x07, 0x65, 0x49, 0x27, 0x41, 0x4E, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x26, 0x26, 0x79, 
        0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x80, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x13, 0x13, 0x86, 0x17, 0xAE, 0x73, 0x1B, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x98, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0xFE, 0x04, 0x2E, 0x84, 0x98, 0x2E, 0x2E, 0x84, 0x37, 0x37, 0x98, 0x84, 0x84, 0x98, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x98, 0x98, 0x3D, 0x3D, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x16, 0x60, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x5B, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x16, 0x16, 0x5B, 0x5B, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x8C, 
        0x97, 0xF2, 0x0A, 0x0A, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x5F, 0x5F, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E,
  0x50, 0xBE, 0x50, 0xB6, 0x3F, 0x54, 0x54, 0x3F, 0x3F, 0xB6, 0x54, 0xB6, 0x54, 0xB6, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0x1C, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 
        0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0x2B, 0x36, 0x36, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xD3, 0xD3, 0xD3, 0xD4, 0xD4, 0x44, 0x10, 0x44, 0x10, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x25, 0xAD, 0xAD, 
        0x25, 0xF0, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x95, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x11, 0x13, 0x13, 0xAE, 0x1B, 0x1B, 0x9D, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 
        0x84, 0x84, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x5F, 0x5F, 0xDF, 0x02, 0x02, 0x02, 0x6C, 0xF2, 0x97, 0x97, 0xF2, 0x97, 0x97, 0x8C, 0x6C, 0x6C, 0x6C, 0x6C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x82, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 
        0xF2, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x23, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0xFE, 0x04, 0x04, 0xFE,
  0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x6B, 0x6B, 0x6B, 0x0D, 0x88, 0x93, 0x75, 0x75, 0x75, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 
        0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x74, 0x08, 0xBB, 0x74, 0x74, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x74, 0x74, 0xDD, 0xDA, 0xDA, 0x07, 0x65, 0xCC, 0x27, 0x27, 0x2C, 0x36, 0x36, 0xEC, 0x3A, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0x73, 0x1D, 0x9D, 0x66, 0x66, 0x9C, 0x05, 0x05, 0x05, 
        0x84, 0x84, 0x2E, 0x2E, 0x3D, 0x3D, 0x84, 0x84, 0x3D, 0x3D, 0x98, 0x98, 0x98, 0x98, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x3D, 0x3D, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 
        0xA3, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 
        0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 
        0x09, 0x09, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0xF2, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x92, 0x01, 0x01, 0x92, 0x92, 0x85, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x6C, 0x6C, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E,
  0x8A, 0x7B, 0x7B, 0x7B, 0xA0, 0xA0, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x94, 0x96, 0xD1, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0xF0, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x19, 0x79, 0x19, 0x19, 0x19, 0x24, 0x22, 0xCD, 0xCD, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 
        0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x86, 0x17, 0x17, 0x17, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x2E, 0x2E, 
        0x84, 0x2E, 0x37, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x98, 0x05, 0x05, 0x98, 0x98, 0x2E, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0xCA, 0x03, 0x09, 0x09, 
        0x09, 0x85, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xB8, 0xA6, 0xA6, 0xA6, 0xB8, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 
        0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x27, 0x96, 0x2C, 0xAB, 0xAB, 0xE4, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x34, 0x34, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 
        0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x95, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x9B, 0x17, 0x17, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x73, 0x73, 0x17, 0x17, 
        0x1B, 0x1B, 0x1B, 0x17, 0x73, 0x17, 0xAE, 0xAE, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0xDC, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xFD, 0xFD, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 
        0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x60, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x92, 0x92, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0xF2, 0xF2, 0x97, 0x0A, 0x8C, 
        0x6C, 0xF2, 0xF2, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0xF2, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
  0x7E, 0x1C, 0x6B, 0xA6, 0x6B, 0x0D, 0x0D, 0x0D, 0x93, 0x93, 0xC0, 0xB1, 0x0E, 0x0E, 0x9F, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x8D, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x7B, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xDA, 0x6D, 0x6D, 0x07, 0x07, 
        0x65, 0xCC, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x41, 0x2C, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x79, 0x19, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x1E, 0x14, 0x14, 0x14, 0x78, 0x12, 
        0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x73, 0x73, 0x1D, 0xDC, 0x1D, 0x1D, 0x66, 0x05, 0x05, 0x05, 0x37, 0x37, 0x84, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x04, 0x04, 0x04, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x84, 0x2E, 0x2E, 0x84, 0x98, 0x05, 0x05, 0x05, 0x05, 0x9C, 
        0x05, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x03, 0x5B, 0x5B, 0xE6, 0xE6, 0xE6, 0xE6, 0xE6, 0xE6, 
        0x5B, 0x60, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x02, 0x02, 0xDF, 0xDF, 0x02,
  0x6A, 0x6A, 0x6B, 0x6B, 0x6B, 0x6B, 0x0D, 0x88, 0xC0, 0xB1, 0xB1, 0x0E, 0xE2, 0x9F, 0xCB, 0x0C, 0x0C, 0xA8, 0xA8, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0xDD, 0xDA, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x08, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0xDD, 0xBB, 0x6D, 0x6D, 0x07, 0x65, 0xCC, 0xCC, 0x27, 0x41, 0x4E, 0xAB, 0xAA, 0x36, 0x2B, 0x34, 0x34, 0xD3, 0x38, 0x38, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 
        0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0xCE, 0x1A, 0x9B, 0x86, 0x17, 0x73, 0x73, 0x9D, 0x9C, 0x9C, 0x05, 0x37, 0x84, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x37, 0x37, 0x05, 0x9C, 0x66, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x17, 0x17, 0x17, 0x13, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x73, 0xAE, 0xAE, 0x17, 0x17, 0x73, 
        0x1B, 0x1B, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0xFD, 0x05, 0x05, 0x37, 0x98, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x8C, 
        0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 
        0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x6C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x5F, 0x5F, 0x89, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04,
  0x6A, 0xB8, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0x8D, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 
        0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0xB2, 0xA8, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x49, 0x49, 0x49, 0x49, 0xD2, 0x41, 0x41, 0x41, 0x4E, 0xAB, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 
        0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x1A, 0x9B, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 
        0xDC, 0xDC, 0x1D, 0x1D, 0xDC, 0xDC, 0x66, 0x66, 0x66, 0x1D, 0x1D, 0x9C, 0x9C, 0x66, 0x1D, 0x1D, 0x9C, 0x66, 0x66, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xDC, 0x1D, 0x73, 0x73, 0x1B, 0x17, 0x17, 0xAE, 0x73, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1D, 0x9D, 
        0x1D, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x55, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 
        0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x55, 0xA3, 0xA3, 0x04, 0x04, 0x04,
  0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0xBF, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x93, 0xC0, 0xCF, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0xA7, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0xD2, 0x2C, 0x2C, 0x2C, 0x36, 0x36, 0x36, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 
        0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x24, 0x24, 0x7D, 0x21, 0x7D, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0xFC, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x12, 0x78, 0x78, 0xDE, 0x12, 0x78, 0x78, 
        0x14, 0x14, 0x8E, 0x80, 0x80, 0x20, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x80, 0x18, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x13, 0x17, 0x73, 0x73, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x37, 
        0x84, 0x84, 0x2E, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0xFE, 0x2E, 0x3D, 0x3D, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0xFE, 0xFE, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 
        0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 
        0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x0D, 0x0D, 0xA6, 0xB8, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xC5, 0x2D, 0x2D, 0x2D, 0x2D, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0x57, 0x1C, 0x1C, 0x1C, 0xB8, 0x6B, 0x0D, 0x88, 0xCF, 0xCF, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 
        0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x96, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 
        0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x2C, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0xAB, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x19, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x78, 
        0x91, 0x0F, 0x77, 0x77, 0x77, 0x86, 0x86, 0x86, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1B, 0x9D, 0x1D, 0x1B, 0x1B, 0x1B, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x17, 0x86, 0x17, 0x17, 0x17, 0x17, 0xAE, 0x13, 0x13, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0x66, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x05, 0x05, 0x37, 0x98, 
        0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x98, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x23, 0x23, 0x23, 0x23, 0x23, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0xE7, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x97, 0x0A, 0x97, 0x6C,
  0x8D, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0xB1, 0xCF, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0x6A, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0xC5, 0xC5, 0x57, 0x57, 0x5C, 0xC5, 0xC5, 0x1C, 0xC5, 0xC5, 0x1C, 0x1C, 0x7E, 0x6B, 
        0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xD8, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x8A, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x4E, 0x4E, 
        0x2B, 0x2B, 0x36, 0x36, 0x36, 0x2B, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0xD3, 0x10, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 
        0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x18, 0x18, 0xFC, 0x78, 0x14, 0x15, 0x15, 0xDE, 0x12, 0x91, 0x6F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x0F, 0x0F, 
        0xF1, 0xCE, 0x77, 0xCE, 0x9B, 0x9B, 0x9B, 0x9B, 0x17, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x98, 0x98, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x55, 0xA3, 0x5F, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x97, 0x0A, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x6C, 0x6C, 0x8C, 0x6C, 0x6C, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x97, 0x97, 0x01, 0x01, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
  0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xA7, 0xA7, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x07, 0x94, 0x94, 0xA9, 0x27, 0x27, 0x27, 
        0xD2, 0x41, 0x2C, 0x2C, 0x4E, 0x4E, 0xAB, 0xAB, 0x36, 0x36, 0x36, 0x2B, 0xAC, 0xAC, 0x34, 0x34, 0x34, 0x34, 0xD3, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x19, 0x19, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x20, 0x14, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x86, 0x17, 0x73, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x37, 0x98, 0x98, 0x84, 
        0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x2E, 0x98, 0x98, 0x2E, 0x2E, 0x98, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 
        0x55, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x23, 
        0x89, 0x23, 0x89, 0x23, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 
        0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x0A, 0xF2, 0x6C, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x23, 0x23, 0x89,
  0x2D, 0x2D, 0xB7, 0xB7, 0x2D, 0xB7, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0xB8, 0xB8, 0xB8, 0x0D, 0x0D, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x9F, 0xE2, 0x0E, 0xE2, 
        0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x8F, 0x8F, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 
        0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x96, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0xCE, 0xCE, 0xCE, 0xCE, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x77, 0x1A, 0x13, 0x17, 0x17, 0x17, 0x86, 0x17, 0x73, 0x1B, 0x1D, 0x1B, 0x73, 0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0xDC, 0x1D, 0x1D, 
        0x1D, 0x66, 0x66, 0x66, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x5B, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x0A, 0x8C, 0x0A, 0x0A, 0x97, 0x97, 0x97, 0x97, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x02,
  0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0xB6, 0x54, 0x50, 0x50, 0xBE, 0x2D, 0x2D, 0xB7, 0xEB, 0xEB, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0x0D, 
        0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x27, 0xD2, 0x41, 0x4E, 0x4E, 0x2B, 0x34, 0x38, 
        0x10, 0x25, 0x25, 0x25, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 0x26, 0x29, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x24, 0x24, 0x24, 
        0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0xCD, 0xCD, 0x90, 0x90, 0x21, 0x90, 0x90, 0x21, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x95, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x17, 
        0xAE, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x37, 0x05, 0x05, 0x37, 0x2E, 0x37, 0x37, 0x84, 0x84, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 
        0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 
        0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 
        0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0xF2, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3,
  0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x7E, 0x6A, 0x6A, 0xB8, 0x6B, 0x0D, 0x0D, 0x88, 0x93, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 
        0x27, 0x27, 0xA9, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x34, 0xEC, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x24, 0x21, 0x90, 0x90, 
        0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x0F, 0x0F, 0x0F, 0x11, 0x11, 0x11, 0x63, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x1A, 0x1A, 0x1A, 0x13, 0x77, 0x1A, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x9B, 0x9B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x1B, 0x73, 0x1D, 0x73, 0x1D, 0x1D, 0x9D, 0x66, 0xFD, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x84, 
        0x84, 0x98, 0x98, 0x84, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0xFE, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x55, 0x55, 0x89, 0x89, 0x89, 0x23, 0x02, 0x23, 0xDF, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0xF2, 0x0A, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 
        0x03, 0x03, 0x09, 0x03, 0x03, 0x09, 0x03, 0x09, 0x09, 0x03, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0xCA, 0xCA, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x97, 0xF2, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xDF, 0xDF, 0x55, 0xA3, 0xA3,
  0x50, 0x50, 0x50, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x50, 0x2D, 0x2D, 0xB7, 0xB7, 0xB7, 0xB7, 0xB7, 0x57, 0x57, 0x1C, 0x1C, 0x6A, 0x6A, 0x6B, 0x6B, 0x0D, 0x88, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 
        0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xBB, 0xBB, 0xC1, 0xBB, 0xC1, 0xC1, 0xC1, 
        0xC1, 0xC1, 0xBB, 0xBB, 0xC1, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x49, 0x49, 0xD2, 0x41, 0x41, 0x41, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x26, 0x79, 0x79, 
        0x24, 0x22, 0xCD, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0xAE, 0xAE, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x11, 0x11, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x31, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x37, 0x37, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x23, 0x23, 0x23, 0x5F, 0xDF, 0x23, 0x02, 0x5F, 0x5F, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x97, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x03, 0x16, 0x16, 0x16, 0x03, 0x03, 
        0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x92, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x97, 
        0x0A, 0x97, 0x97, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x97, 0x97, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0xCF, 0xC0, 0xCF, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xC6, 
        0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0x0C, 0x0C, 0xE2, 0xE2, 0xCB, 0xCB, 0xE2, 0xE2, 0xCB, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0x8D, 
        0xA8, 0xA8, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x94, 0x94, 0x96, 0x2C, 0xAB, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x14, 0x14, 0x95, 0x91, 
        0x91, 0x77, 0x13, 0x13, 0x86, 0x17, 0x17, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x37, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x37, 0x84, 0x2E, 0x2E, 0x2E, 0x37, 0x2E, 0x37, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x9D, 0x9D, 0xDC, 
        0x1D, 0x1D, 0x66, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x98, 0x37, 0x3D, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x0A, 0x8C, 0x8C, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0xF2, 
        0x8C, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x6C, 0x6C, 0x02, 0x8C, 0x8C, 0x6C, 0x6C, 0xF2, 0x8C, 0xF2, 0x6C, 0x8C, 0xF2, 0x97, 0x0A, 0x0A,
  0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6B, 0x6B, 0xB8, 0xB8, 0xB8, 0x0D, 0x0D, 0x88, 0x88, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xE3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0x6D, 0xC1, 
        0xC1, 0xC1, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x27, 0x96, 0x2C, 0x4E, 0xAB, 0xAB, 0x36, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x3A, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 
        0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x0F, 0x0F, 
        0x77, 0x13, 0x86, 0x86, 0x17, 0x9D, 0x1F, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x55, 0xA3, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x37, 0x37, 0x37, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0x23, 0x23, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x6C, 0xF2, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 
        0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x23, 0x5F, 0x5F, 0x23, 0x5F, 0xA3, 0x89, 0x89,
  0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xB8, 0xB8, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x88, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0x9F, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0xB2, 0xB2, 0xA7, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x94, 0x27, 0x41, 0x4E, 
        0x36, 0x34, 0x38, 0x44, 0x25, 0x29, 0x26, 0x19, 0x24, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x13, 0x77, 0x77, 0x13, 0x13, 0x9B, 0x9B, 0x9B, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x17, 0x73, 0x73, 0x9D, 
        0x9D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x55, 0x55, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0xF2, 0x0A, 0x0A, 0x97, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x05, 0x05, 0x98, 0x98, 0x05, 0x05, 0x37, 0x84, 0x84, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 
        0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x5B, 0x5B, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 
        0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 0x06, 0x60, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x92, 0x92, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
  0x0D, 0x88, 0x0D, 0x88, 0x88, 0x88, 0x88, 0x88, 0xC0, 0xC0, 0xC0, 0xC0, 0x88, 0x88, 0x88, 0xC0, 0xC0, 0x0D, 0x0D, 0xA6, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0xC5, 0xEB, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0x2D, 0xBE, 0xF7, 
        0x50, 0x2D, 0x2D, 0xB7, 0x57, 0x1C, 0x1C, 0xBF, 0xA6, 0x0D, 0xC0, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0xA8, 0xA8, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0x6D, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0xD2, 0x96, 0x27, 0x96, 0x96, 0x2C, 0xAA, 0x2C, 0x2C, 0x2C, 
        0xAA, 0x36, 0x36, 0x36, 0xBC, 0x36, 0xBC, 0x2B, 0x34, 0x34, 0x34, 0xAC, 0xBC, 0xBC, 0x34, 0x34, 0x34, 0x34, 0x38, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x34, 0x38, 0x10, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x19, 0x19, 
        0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x20, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x17, 0x17, 0x73, 0x1B, 0x1D, 0xDC, 0x1D, 0x66, 0x66, 0x9C, 0x9C, 0x9C, 0x9C, 0x66, 0xFD, 0x1F, 0x1D, 0x31, 0x17, 0x17, 
        0x17, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0xFC, 0x95, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x9B, 0x9B, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 
        0x17, 0x17, 0x86, 0x86, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x9B, 0x13, 0x13, 0xE5, 0x17, 0x17, 0x17, 0x17, 0x73, 0x1B, 0x9D, 0x9D, 0x66, 0x66, 0x05, 0x05, 0x05, 0x98, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x5B, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x09, 0x85, 
        0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x09, 0x09, 0x09, 0xCA, 0xCA, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x5B, 0x5B, 0xE6, 0xE6, 0x16, 0x16, 0x16, 0xE6, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x09, 0x03, 0x03, 0x85, 
        0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x8C, 0x02, 0xF2, 
        0x8C, 0x8C, 0xF2, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09,
  0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 
        0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0x6D, 0x6D, 0x6D, 0x6D, 0xDA, 0x6D, 0x6D, 0x6D, 0x6D, 0x6D, 0x6D, 0x6D, 0xDD, 0x74, 0x74, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0x8A, 0x8A, 
        0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x8A, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x74, 0xBB, 0xC1, 0x6D, 0x07, 0x07, 0x07, 0x65, 0x65, 0xCC, 0xCC, 0x27, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x2B, 0x4E, 0x2B, 0x2B, 0xAC, 0x38, 0x34, 0xD3, 0x10, 
        0x10, 0x44, 0x25, 0x25, 0x25, 0xF0, 0x26, 0x26, 0x79, 0x79, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 
        0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x17, 0xAE, 0x1B, 0x1B, 0x73, 0x1D, 0x1D, 0x66, 0x05, 0x05, 0x05, 0x98, 0x98, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x3D, 0x98, 0x98, 0x98, 0x98, 0x37, 0x98, 0x98, 0x2E, 0x98, 0x3D, 0x3D, 0x2E, 0x2E, 0x3D, 0x2E, 0x2E, 0x04, 0x04, 0x3D, 
        0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x97, 0x97, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x6C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x97, 0x97, 0x6C, 0x8C, 0x8C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 
        0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x96, 0x96, 0x2C, 0x2C, 0xE4, 0x2B, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x34, 0x36, 0x36, 0x36, 0x2B, 0x2B, 
        0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0xAC, 0xAC, 0x34, 0x2B, 0x34, 0x34, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xEC, 0x38, 0x38, 0x34, 0x34, 
        0x3A, 0x38, 0xD3, 0x38, 0x34, 0x38, 0x3A, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x87, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x80, 0x14, 
        0x78, 0x78, 0x12, 0x0F, 0x11, 0x1A, 0x86, 0x86, 0xAE, 0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x1F, 0x1D, 0x9C, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x66, 0x66, 0x66, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x37, 0x37, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x8C, 0x8C, 0xF2, 0x97, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 
        0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x92, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x97, 
        0x97, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF,
  0x7A, 0x7A, 0xA5, 0xA5, 0x4D, 0x2F, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x33, 0x56, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0x2D, 0x5C, 0x5C, 0xC5, 0x1C, 0x6A, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xBA, 0xBA, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0xA8, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x74, 0x08, 0xDD, 0xBB, 0xBB, 0xBB, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0x49, 0x27, 0x27, 0x49, 0x41, 0x4E, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x29, 0x26, 0x26, 0x79, 
        0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x20, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x9C, 0x66, 0x9C, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x66, 0x66, 0x9C, 0x66, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x73, 0x17, 0x17, 0x86, 0x86, 0x86, 
        0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x11, 0x11, 0x77, 0xCE, 0xCE, 0x77, 0x77, 0x9B, 0x86, 0x86, 0xAE, 0x73, 0x1D, 0x1D, 0x05, 0x05, 0x05, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 
        0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 
        0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x0A, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x89, 0x23, 0x89, 0x89, 0xA3, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A,
  0xA5, 0x4D, 0x4D, 0x4D, 0x2F, 0x6E, 0x6E, 0x48, 0xF5, 0x33, 0x4B, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0x50, 0x50, 0x2D, 0x5C, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x6A, 0xA6, 0x0D, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0x7B, 0x08, 
        0x08, 0x08, 0xDA, 0x07, 0x07, 0x07, 0x65, 0x65, 0x94, 0x27, 0x27, 0x2C, 0x2C, 0x2C, 0x36, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x44, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 
        0x80, 0x8E, 0x8E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x7D, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x15, 0x15, 0x95, 0x12, 0xDE, 0x12, 0x91, 0x0F, 0x0F, 0x11, 0x1A, 0x1A, 0x1A, 0x9B, 0x86, 0x17, 0x73, 0x1B, 
        0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 
        0x89, 0x89, 0x89, 0x89, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 
        0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0xF2, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x97, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x6C, 0x6C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0xB6, 0x54, 0x50, 0xBE, 0x50, 0xBE, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0x5C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x1C, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 
        0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xC1, 0xC1, 0x07, 0x94, 0x96, 0x2C, 0xAA, 0x36, 0x36, 0x3A, 0xD3, 0x10, 0x44, 0xD5, 0x25, 0x25, 0xF0, 0x26, 0x26, 
        0x26, 0x28, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x59, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 
        0xAC, 0x34, 0x34, 0x34, 0x38, 0xD3, 0xD3, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 
        0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x86, 0xAE, 0x17, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x37, 0x05, 0x05, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0x04, 0x2E, 0x2E, 0x3D, 0x2E, 0x98, 0x98, 0x37, 0x37, 0x2E, 0x2E, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x3D, 0x3D, 0x98, 0x98, 0x84, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x06, 0x16, 
        0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x03, 0x09, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x8C, 0x97, 0x97, 0xF2, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0xF2, 0xF2, 0x8C, 0xF2, 0x0A, 0x0A, 0xF2, 0xF2, 0x0A, 0x97, 
        0x97, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x92, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01,
  0xA1, 0x4F, 0x2A, 0x7A, 0xA5, 0x2F, 0x6E, 0x6E, 0x48, 0x33, 0x56, 0x4B, 0x3C, 0x54, 0x50, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0x1C, 0x1C, 0x1C, 0x6A, 0xB8, 0xB8, 0x0D, 0x0D, 0x0D, 0x88, 0x88, 0x93, 0x93, 0x88, 0x93, 0x75, 0x75, 0x75, 0x93, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xBF, 0xA6, 0xA6, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 
        0x08, 0x74, 0x6D, 0x6D, 0x07, 0x65, 0xCC, 0x27, 0xD2, 0x41, 0x4E, 0xAB, 0x2B, 0x2B, 0xAC, 0xAC, 0x2B, 0xAC, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0xAA, 0xAA, 0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 
        0xAB, 0xAB, 0xE4, 0x36, 0x36, 0x36, 0x5A, 0x3A, 0x3A, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x17, 0x1B, 0x1D, 0x9C, 0x05, 
        0x05, 0x2E, 0x2E, 0x2E, 0x55, 0x55, 0xA3, 0x55, 0x55, 0xA3, 0x5F, 0x5F, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xA3, 0xA3, 0x55, 0x04, 0x04, 0x04, 0xFE, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1B, 0x17, 0x86, 0x1A, 0x0F, 
        0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x18, 0x14, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x17, 0x73, 0x1B, 0x1D, 0x1D, 0x1F, 0x05, 0x05, 0x05, 0x98, 0x84, 0x2E, 0xFE, 0xFE, 
        0x04, 0x04, 0x04, 0x55, 0x55, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 
        0x23, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x03, 0x03, 0x16, 0x03, 0x16, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x03, 0x16, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x16, 0x03, 0x03, 0x03, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x97, 0x97, 0x97, 0x97, 0x97, 0xF2, 0xF2, 0x97, 0x0A, 0x8C, 0x0A, 0x0A, 0xF2, 0x97, 0x0A, 0x97, 
        0x97, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x97, 0x97, 0x8C,
  0x2F, 0x2F, 0x6E, 0x48, 0x33, 0x33, 0xB5, 0xB5, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0xC4, 0x54, 0x50, 0x50, 0x2D, 0x5C, 0x5C, 0xC5, 0x1C, 0x1C, 0x6A, 0x1C, 0x1C, 0x6A, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0xA6, 0x0D, 0x0D, 0x88, 0x88, 0x0D, 0x93, 0xB1, 
        0xB1, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x9F, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 
        0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x96, 0x96, 0x4E, 0x4E, 0x2B, 
        0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x26, 0x19, 0x24, 0x24, 0x21, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x12, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x91, 
        0x91, 0x12, 0x12, 0x12, 0x12, 0x91, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x1B, 0x9D, 0x31, 0x9D, 0x1D, 0x1B, 0x9D, 0x9D, 0x9D, 0x9D, 
        0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x1D, 0x1D, 0x73, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x9D, 0x9D, 0x9D, 0x1D, 0x9C, 0x05, 0x05, 0x37, 0x37, 
        0x98, 0x2E, 0x04, 0x04, 0x04, 0x89, 0x5F, 0xDF, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x97, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0xCA, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 
        0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x09, 0x09, 0x85, 0x85, 0x85, 0x09, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x0A, 0x0A, 0xF2, 0x6C, 0x6C, 0x8C, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x3C, 0x3C, 0x3C, 0x4B, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0x56, 0xB5, 0xB5, 0x4B, 0xEA, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0xEA, 0xEA, 0x3C, 0x3C, 0x3C, 0xE0, 0x3F, 0x3F, 0xB6, 0xB6, 0xBE, 0xBE, 0xF7, 0x2D, 0x2D, 0x2D, 0xC5, 0x1C, 
        0x1C, 0xBF, 0xA6, 0x0D, 0xC0, 0xB1, 0x0E, 0xE2, 0xCB, 0x0C, 0xB2, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xB2, 
        0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0x07, 0x07, 0x07, 0x94, 0x27, 0x2C, 0x4E, 0x2B, 0x34, 0x38, 0x10, 0x25, 0x25, 0x26, 0x26, 0x79, 0x24, 0x22, 0x21, 0x90, 0x90, 
        0x80, 0x80, 0x14, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x77, 0x77, 0x0F, 0x91, 0x12, 0x12, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 
        0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x9D, 0x1F, 0x1F, 0x9C, 
        0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x37, 0x37, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1F, 0x1D, 0x1D, 0x1D, 
        0x1D, 0xDC, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x1D, 0x1D, 0xDC, 0xDC, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0xA3, 0x55, 0x23, 0x89, 0x89, 0x23, 0x23, 0x23, 0x5F, 
        0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x85, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x06, 0x06, 0x06, 0x06, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x85, 0x85, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x0A,
  0x3C, 0xE0, 0x3F, 0x54, 0x50, 0x50, 0x2D, 0x5C, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xBF, 0x6B, 0xA6, 0xA6, 0xA6, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x93, 0x93, 0xC0, 0xCF, 0x75, 0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 
        0xB2, 0xB2, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xA8, 0xA8, 0x8D, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 
        0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x8A, 0xB3, 0xB3, 0x7B, 0xA0, 0x08, 0x08, 0x74, 0x6D, 0x6D, 0x07, 0x65, 
        0xCC, 0x27, 0x2C, 0x2C, 0x2B, 0xAC, 0x34, 0xD3, 0xED, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x15, 0x91, 0x91, 0x0F, 0x77, 0x1A, 0x9B, 0x17, 0xAE, 0x1B, 0x1D, 0x1F, 0x9C, 0x05, 0x05, 0x37, 0x84, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0x2E, 
        0x84, 0x2E, 0x2E, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9D, 0xDC, 0x1D, 0x1D, 0x9C, 0x9C, 0x66, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 
        0x98, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x04, 0x89, 0x89, 0x55, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0xF2, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xF2, 0xF2, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x8C, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x2D, 0x5C, 0xC5, 0x1C, 0x1C, 0x6A, 0xBF, 0xA6, 0x0D, 0x0D, 0x93, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 
        0xE2, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0x6B, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x6B, 0x6B, 0xA6, 0x0D, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x8A, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x27, 0x41, 0x41, 0xAB, 0x36, 
        0x36, 0xAC, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x24, 0x90, 
        0x90, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x86, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 
        0x05, 0x05, 0x9C, 0x1D, 0x1D, 0x1B, 0xAE, 0x86, 0x13, 0x1A, 0x63, 0xCE, 0x0F, 0x0F, 0xCE, 0xCE, 0x0F, 0x0F, 0xCE, 0x1A, 0x77, 0x1A, 0x9B, 0x13, 0x17, 0x1B, 0x1D, 0x9D, 0x66, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x84, 0x3D, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x55, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x23, 
        0x23, 0x23, 0x23, 0x89, 0x89, 0x04, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 
        0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x97, 0x97, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0xF2, 0x0A, 0x8C, 0xF2, 0x97,
  0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0xA5, 0x2F, 0x2F, 0x6E, 0xA2, 0x33, 0x33, 0xB5, 0x4B, 0x3C, 0x3F, 0x54, 0x50, 0x50, 0x5C, 0xC5, 0x57, 0x1C, 0x6A, 0xB8, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0x75, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0xB1, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0xBF, 0xBF, 0x1C, 0x1C, 0xBF, 0x1C, 0x1C, 0xBF, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0xA0, 0x08, 0x08, 
        0xBB, 0xBB, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x4E, 0xAB, 0xAB, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x34, 0x34, 0x38, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0xAC, 0x2B, 0xE4, 0x2B, 0xAB, 0x4E, 
        0x2C, 0x41, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 0x27, 0x27, 0x49, 0x49, 0x49, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x79, 0x19, 0x19, 0x24, 
        0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x11, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x1A, 0x9B, 
        0x9B, 0x9B, 0x42, 0x17, 0x17, 0x73, 0x73, 0x73, 0x73, 0x73, 0x17, 0x17, 0x17, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x73, 0x17, 0x73, 0x17, 0x73, 0x1B, 0x17, 0x73, 0x31, 0x73, 0x73, 0x1D, 0x1D, 0x66, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x3D, 0x3D, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x55, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x02, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 0x16, 
        0x16, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x85, 0x85, 0x01, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x92, 0x92, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x0A, 0x8C, 0xF2, 0x97, 0x97, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x97, 0x0A, 0x97, 0x97, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x97, 0x97, 0x97, 0x97, 0x0A, 0x97, 0x97, 0x97, 0xF2, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x6C, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xDF, 0xDF, 0xDF, 0x5F, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0xA3, 0xA3, 0x55, 0x04, 0x04,
  0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x1C, 0x57, 0xC5, 0x1C, 0x1C, 0xC5, 0xC5, 0x5C, 0x5C, 0x2D, 0x5C, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xBE, 0xBE, 0x50, 0x50, 
        0x50, 0x50, 0xBE, 0xBE, 0x50, 0x50, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0xB3, 
        0xA0, 0x08, 0x08, 0xC1, 0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x36, 0x2B, 0x34, 0x3A, 0x10, 0x44, 0x10, 0x25, 0xEE, 0x29, 0x26, 0x26, 0x87, 0x26, 0x26, 0x79, 0x79, 0x28, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x79, 0x79, 0x79, 0x79, 0x79, 0x28, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x25, 0x10, 0x10, 0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x19, 0x19, 0x24, 0x21, 0x21, 
        0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x13, 0x13, 0x86, 0x86, 0x1B, 0x1D, 
        0x1D, 0x9D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x98, 0x98, 0x05, 0x98, 0x37, 0x37, 0x37, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x66, 0x66, 0x66, 0x1D, 0x9D, 0x9D, 0x1D, 0x73, 0x1D, 0x1B, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 
        0xDC, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x37, 0x37, 0x84, 0x84, 0x98, 0x37, 0x37, 0x37, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x55, 0x55, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 
        0x09, 0x09, 0x85, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x97, 0xF2, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0xDF, 0x5F, 0x23, 0xDF, 0x23, 0x02, 0x23, 
        0xDF, 0x02, 0xDF, 0x5F, 0x02, 0xDF, 0x23, 0x5F, 0xDF, 0xDF, 0x5F, 0x5F, 0x5F, 0x5F, 0xA3, 0x5F, 0x23, 0x89, 0xA3, 0xA3, 0x5F, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x89,
  0x7A, 0x4D, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0xE0, 0xE0, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0xEA, 0x4B, 0x4B, 0x4B, 0xB5, 0x56, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 
        0x33, 0x33, 0x33, 0x56, 0x56, 0xB5, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0xF7, 0xBE, 0x2D, 0xEB, 0xC5, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xC0, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 
        0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x65, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0x41, 0x4E, 0x4E, 0x4E, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 
        0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 
        0x19, 0x19, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 
        0x0F, 0x0F, 0x77, 0x1A, 0x1A, 0x9B, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x73, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0x17, 
        0x17, 0x73, 0x73, 0x1B, 0x31, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x66, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x37, 0x2E, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x04, 0x3D, 0x3D, 0x2E, 0x3D, 0x3D, 0x3D, 0x2E, 0x2E, 0xFE, 
        0xFE, 0x04, 0x3D, 0x04, 0x04, 0x04, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x02, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 
        0x85, 0x01, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x97, 0x97, 0x0A, 0x0A, 0x0A, 0x8C, 0xF2, 0x97, 0xF2, 0xF2, 0xF2, 0xF2, 0xF2, 0x97, 0x97, 0x97, 0x97, 0x97, 0x8C, 0xF2, 0xF2, 0x97, 0x0A, 0x0A,
  0x53, 0x53, 0x53, 0x53, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x4F, 0x2A, 0x2A, 0xA5, 0x2F, 0x2F, 0xA2, 0x48, 0x33, 0x56, 0x4B, 0x3C, 0x3C, 0x3F, 0xC4, 0x50, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0xEB, 
        0xC5, 0x1C, 0x1C, 0x6A, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
        0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x8A, 0x8A, 0x7B, 0x8A, 0x8A, 0x7B, 0xB3, 0x8A, 0x8A, 0x0B, 0x0B, 0x0B, 0x8D, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 
        0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0xB3, 0x8A, 0x08, 0x08, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x49, 0x49, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x24, 0x21, 0x90, 0x1E, 0x14, 0x78, 
        0x12, 0x12, 0x12, 0x0F, 0xCE, 0x1A, 0x13, 0x86, 0x17, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x66, 0x1D, 0x1D, 0x1F, 0x1D, 0xDC, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0xDC, 0x31, 0x1B, 0x17, 0x1B, 0xAE, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x73, 0x1D, 0x1D, 0x1D, 0x31, 0x73, 0x31, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0xA3, 0x23, 0xDF, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x55, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x3D, 0x2E, 0x2E, 0x84, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 0x85, 
        0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x97, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0xF2, 0xF2, 0x8C, 0xF2, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x89, 0xA3, 0x55, 0xA3, 0xA3, 0x04, 0x04, 0x55,
  0x4D, 0xA5, 0xA5, 0x2A, 0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x33, 0xB5, 0xB5, 0x4B, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 
        0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x74, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x7B, 0x7B, 0x7B, 0x7B, 0x7B, 0xA0, 0x08, 0x08, 0x08, 0x08, 
        0x74, 0xDD, 0xDA, 0x07, 0x07, 0x07, 0x49, 0x27, 0xD2, 0xD1, 0xAB, 0x36, 0x36, 0x34, 0x38, 0x3A, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x21, 0x90, 0x90, 0x90, 0x21, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0xFC, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x91, 0x12, 0x91, 
        0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x13, 0x86, 0x86, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0xAE, 0x17, 0x73, 0x73, 0x17, 0x73, 0x73, 
        0x73, 0x73, 0x73, 0x17, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x17, 0x73, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x9C, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x55, 0x55, 0x89, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x23, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x97, 0x8C, 0x0A, 0x0A, 0x8C, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 
        0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 
        0x8C, 0xF2, 0xF2, 0xF2, 0x8C, 0x8C, 0x6C, 0x6C, 0x6C, 0x6C, 0x02, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x6C, 0xF2, 0x0A, 0x97, 0x97, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
  0x2A, 0x2A, 0x2A, 0x4D, 0x2F, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 0x54, 0x50, 
        0x50, 0x50, 0x50, 0x5C, 0x2D, 0x5C, 0x5C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xDA, 0x6D, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x65, 0x65, 0x49, 0x49, 0x49, 0x27, 0x27, 0x49, 0x27, 
        0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x2C, 0x4E, 0xAB, 0x2B, 0x2B, 0x2B, 0xAC, 0x38, 0x38, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x19, 0x24, 0x21, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x91, 0x91, 0x91, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 
        0x13, 0x13, 0x77, 0xCE, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x8E, 0x8E, 0x80, 0x14, 0x14, 0x80, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x86, 0x86, 0x86, 0x1B, 0x1D, 0x9D, 0x1D, 0xFD, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 0x37, 
        0x37, 0x37, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x13, 0x13, 0xAE, 0x17, 0xAE, 0xAE, 0xAE, 0xAE, 0x17, 0x17, 0xAE, 0x17, 0x17, 0xAE, 0x73, 0x31, 0x31, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 
        0x1F, 0x66, 0xFD, 0xFD, 0x9C, 0x9C, 0x9C, 0x05, 0x37, 0x37, 0x05, 0x37, 0x37, 0xFE, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x01, 0x01, 0x01, 
        0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x03, 0x03, 0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x92, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x8C, 0x8C, 0x8C, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x5F, 0x5F, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x55, 0x04, 0xA3, 0x89, 0x89, 0x55, 0xA3, 0xA3, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0xF2, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01,
  0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0xF6, 0x33, 0x33, 0x48, 0xF5, 0xF5, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x4B, 0x4B, 0xEA, 0x3C, 0x3C, 0x3F, 0xC4, 0x54, 0xBE, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 
        0x5C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0xB8, 0xB8, 0xB8, 0xB8, 0x0D, 0xB8, 0xB8, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 
        0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x2C, 0x41, 0x2C, 0x2C, 0x4E, 0x2C, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0xAC, 0x34, 0x34, 0x34, 0x38, 
        0x3A, 0xD3, 0x10, 0x10, 0x10, 0x25, 0x25, 0xF0, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x19, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x28, 0x19, 0x19, 0x24, 0x24, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x9B, 0x1A, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x77, 0x77, 0x11, 0x11, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x1A, 0xCE, 0xCE, 0xCE, 0x77, 0x77, 0x1A, 0x1A, 0x1A, 0x1A, 0x9B, 0x9B, 0x9B, 0x9B, 0x17, 0x9B, 0x17, 0x42, 0x13, 0x9B, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 
        0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x37, 0x05, 0x37, 0x05, 0x37, 0x05, 0x05, 0x37, 
        0x05, 0x37, 0x37, 0x37, 0x37, 0x37, 0x05, 0x37, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x84, 0x98, 0x98, 0x05, 0x05, 0x98, 0x98, 0x84, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 
        0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x09, 0x09, 0x09, 0x85, 0x01, 
        0x85, 0x01, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0x5F, 0x5F, 0x5F, 0x89, 0x89, 0xA3, 
        0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x23, 0x23, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x23, 
        0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 0x23, 0x89, 0xA3, 0xA3, 0x23, 0x23, 0xDF, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0xB5, 0xB5, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x3F, 0x3F, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0xF7, 0xBE, 0xBE, 0x2D, 0xEB, 0xEB, 0x1C, 0x1C, 0xA6, 0x0D, 0x0D, 0xC0, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 
        0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xBB, 0xBB, 0x6D, 0x6D, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x27, 0xD2, 0xD2, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x38, 
        0x10, 0x10, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x7D, 0x7D, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x26, 0x26, 0x87, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0xDE, 0x91, 
        0x91, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x66, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 
        0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x77, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x84, 0x98, 0x3D, 0x98, 0x2E, 0x98, 0x98, 0x37, 0x37, 0x05, 0x05, 0x05, 
        0x05, 0xFD, 0x66, 0xFD, 0x1D, 0x9D, 0x9D, 0x1B, 0x1B, 0xAE, 0xAE, 0xAE, 0xAE, 0x86, 0x13, 0x86, 0xAE, 0x73, 0x73, 0x1B, 0x1B, 0x1B, 0x31, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x84, 0x84, 0x2E, 0xFE, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x02, 0x02, 0x02, 
        0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x97, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0xDF, 0xDF, 0x5F, 0x5F, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0xDF, 0x5F, 0x5F, 0x23, 0x5F, 0x02, 0xDF, 0x02, 0x02, 0xDF, 0xDF, 0xDF, 0xDF, 0x02, 0x02, 0x02, 
        0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x5F, 0x5F, 0x02, 0x02, 0x5F, 0x02, 0xDF, 0xDF, 0x02, 0x5F, 0x5F, 0x02, 0x02,
  0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0xB5, 0xB5, 0xB5, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x50, 
        0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0xB7, 0x57, 0x5C, 0x5C, 0x5C, 0xEB, 0xC5, 0x5C, 0x5C, 0x5C, 0x5C, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 
        0x0B, 0x0B, 0x0B, 0x8A, 0xB3, 0x7B, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x41, 0x96, 0x41, 0x41, 0xD1, 0x41, 
        0xD2, 0x27, 0x49, 0x49, 0x65, 0x65, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0x65, 0x65, 0x65, 0x49, 0x49, 0xD2, 0x41, 0x41, 0x2B, 0x2B, 0x34, 0x34, 0x10, 0x10, 0x25, 0x29, 0x29, 0x26, 0x19, 0x24, 0x22, 0x21, 0x90, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x15, 0x15, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0xCE, 0x1A, 0x1A, 0x1A, 
        0xE5, 0x9B, 0x9B, 0x17, 0x73, 0x73, 0x73, 0x73, 0x73, 0x1D, 0xDC, 0x1D, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9C, 0x66, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 
        0x1D, 0x9D, 0x9D, 0xDC, 0x1D, 0x1D, 0x1D, 0xDC, 0xDC, 0x66, 0x1D, 0x1F, 0x66, 0x66, 0x66, 0x1D, 0x66, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x66, 0x66, 0x1D, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0xFE, 0xFE, 
        0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x0A, 0x0A, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 
        0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x5F, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x5F, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x23, 0x89, 0x89, 0xA3, 0xA3, 0xA3, 0x55, 0x04, 0x04, 
        0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x84, 0x37, 0x98, 0x98, 0x84, 0x84, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0xFE, 0x3D, 0xFE, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0xA3, 0xA3, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 0x02, 0xDF, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C,
  0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0x3F, 0x3F, 0x3F, 0xBE, 
        0xBE, 0xBE, 0x2D, 0x2D, 0x5C, 0x5C, 0x5C, 0xEB, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0x1C, 0xC5, 0xC5, 0xC5, 0xE1, 0xC5, 0xEB, 0xEB, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xB7, 0x57, 0x57, 0x57, 0x1C, 0x1C, 
        0x1C, 0x1C, 0x6A, 0x6B, 0x6B, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB9, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 
        0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0x41, 0xD1, 0x4E, 0xAB, 0x2B, 0x36, 0x34, 0x34, 0x34, 0x3A, 0xD3, 0x10, 0xAD, 0x29, 0x29, 0x26, 0x79, 0x19, 0x24, 0x24, 0x24, 0x90, 0x90, 
        0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x20, 0x80, 0x80, 0x80, 0x20, 0x20, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x9B, 0x9B, 0x9B, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 
        0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x84, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x23, 0x23, 
        0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x84, 0x84, 0x98, 
        0x37, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x3D, 0x3D, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x55, 0x89, 0x55, 0x89, 0x89, 0xA3, 0x89, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x23, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x8C, 
        0x8C, 0xF2, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x0A, 0x01, 0x01, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0xF2, 0x6C, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x5F, 0x5F, 
        0x5F, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3, 0x89, 0x23, 0x23, 0x23, 0xDF, 0x02, 0x02,
  0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0x32, 0xB4, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x4D, 0xA5, 0x4D, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x48, 0x33, 0x56, 0x4B, 0x4B, 0xE0, 
        0x3F, 0x3F, 0x54, 0xBE, 0xBE, 0x2D, 0xC5, 0x1C, 0x1C, 0x7E, 0xA6, 0x0D, 0x0D, 0x88, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x8D, 0x8D, 0xB2, 0x8D, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 
        0x8A, 0x08, 0x08, 0x08, 0x74, 0x74, 0xDA, 0x6D, 0x07, 0x07, 0x65, 0xCC, 0xA9, 0x27, 0xD2, 0x41, 0x41, 0x41, 0x41, 0x2C, 0x2C, 0x4E, 0xAB, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0xE4, 0x36, 0x36, 
        0x2B, 0xAB, 0x2C, 0x2C, 0x2C, 0x41, 0x41, 0xD2, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x07, 0x07, 0x65, 0xCC, 0xCC, 0x94, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x96, 0x96, 0xC2, 0x2C, 0x4E, 0x4E, 0xAB, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 
        0x34, 0x34, 0x34, 0x38, 0xD3, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x26, 0x26, 0x26, 0x79, 0x19, 0x24, 0x21, 0x90, 0x90, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 
        0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x1A, 0x1A, 0x86, 0x86, 0x9B, 0x9B, 0x9B, 0x17, 0x17, 0x17, 
        0x73, 0x73, 0x73, 0x73, 0x73, 0x73, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xFD, 0xFD, 0x9C, 0x9C, 0x9C, 0x66, 0x66, 0xFD, 0x9C, 0x9C, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x73, 0x73, 0x17, 0x17, 0x17, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x3D, 0x3D, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x84, 0x2E, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x84, 0x84, 
        0x84, 0xFE, 0xFE, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x55, 0xA3, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x5F, 0x23, 0x23, 
        0xA3, 0x89, 0x89, 0x55, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x04, 0x89, 0x89, 0x89, 0x89,
  0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0xA5, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0xB5, 0x4B, 0x3C, 
        0x3F, 0x3F, 0x50, 0x50, 0x2D, 0x2D, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0x8D, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 
        0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0xCC, 0xCC, 0xCC, 0x49, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 
        0x49, 0x49, 0x49, 0xCC, 0x65, 0x65, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x41, 0x4E, 0x41, 0x4E, 0x4E, 0x2B, 0x2B, 0xE4, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 
        0x2B, 0xAB, 0x2B, 0xAB, 0x4E, 0x2C, 0x4E, 0x4E, 0x2C, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x9B, 0x86, 0x17, 0x17, 0x73, 0xDC, 0x66, 0x66, 0x9C, 0x05, 0x05, 0x05, 0x98, 0x98, 0x98, 0x98, 0x98, 0x3D, 0x3D, 0x98, 
        0x98, 0x98, 0x37, 0x98, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x73, 0x73, 0x73, 0x17, 0x17, 0x17, 0x9B, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x9D, 
        0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x3D, 0xFE, 0xFE, 0x3D, 0x3D, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 0xA3, 0xA3, 0x89, 0x55, 0x55, 0x89, 0x89, 0x89, 0x55, 0x89, 0x04, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x55, 0x55, 0x55, 0x04, 0x89, 0x23, 0x23, 0x23, 
        0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x02, 0x02, 0xDF, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x55, 
        0x89, 0x89, 0x89, 0x89, 0x04, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x55, 0xA3, 0xA3, 0xA3, 0xA3, 0xA3, 0x5F, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x6C,
  0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0xB5, 0xB5, 0x3C, 
        0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0xC5, 0x1C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0xC0, 0xCF, 0xCF, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 
        0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x93, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x8D, 0x8D, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 
        0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x96, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x44, 0x25, 0x25, 
        0x25, 0x29, 0xF0, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 
        0x29, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0xDE, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0xCE, 0x77, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x73, 0x73, 0x73, 0x31, 0x9D, 0x1D, 0xDC, 0xDC, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1D, 0xDC, 0x9D, 0x1D, 0x9D, 0x1D, 0x1D, 0x66, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x84, 0x84, 0x84, 0x2E, 0x3D, 0x3D, 0x3D, 0xFE, 0x2E, 0x3D, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0xA3, 0x04, 0x89, 0x89, 0xA3, 0x23, 0x23, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x02, 0x02, 0x8C, 0x0A, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x85, 0x85, 0x85, 0x85, 0x09, 0x09, 0x09, 0x85, 0x09, 0x09, 0x09, 0x09, 0x09, 0x85, 0x85, 0x85, 0x01, 0x01, 0x01, 0x01, 0x01, 0x8C, 0x8C, 0x8C, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x89, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0xA3, 
        0x5F, 0x5F, 0x5F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x6C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x5F, 0x5F, 0x5F, 0x89, 0x89, 0x04,
  0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0x33, 0x33, 0xB5, 0xB5, 0xB5, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 
        0x50, 0xBE, 0xBE, 0x2D, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xEB, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 
        0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 0x7B, 0x08, 0x74, 0xDD, 0xDD, 0xDD, 0xBB, 0xBB, 0xC1, 0x6D, 0x6D, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 
        0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0x6D, 0x6D, 0x6D, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x6D, 0x6D, 0xDD, 0xDA, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x65, 0x65, 0x27, 0x27, 0x27, 0xD2, 0xD1, 0x2C, 0x2C, 0xAB, 0xAB, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 
        0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0xF0, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x22, 0x21, 0xCD, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 
        0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0xCE, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0xCE, 0x77, 0x77, 0x0F, 
        0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0x3D, 0x3D, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x23, 0x23, 0xDF, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x5F, 0x23, 0x23, 0x89, 0x23, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0xDF, 0x23, 
        0x5F, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0xDF, 0x02, 0x02, 
        0x02, 0x02, 0xDF, 0x23, 0x23, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0xA3, 0x89, 0x23, 0x5F, 0xA3, 0x89, 0x89, 0x89, 0x89, 0x89, 0x5F, 0x5F, 0x02, 0x02, 0x5F, 0xDF, 0xDF, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0x89, 0x55, 0x55, 0x55, 0x04, 0x04,
  0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 
        0xBE, 0xBE, 0xF7, 0xF7, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x93, 0x93, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 
        0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0x0C, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xDA, 0xC1, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0xCC, 0x94, 0x27, 0x49, 0x27, 0x27, 0x27, 0x41, 0x41, 0x4E, 0x4E, 0x2B, 0x36, 0x36, 0xAC, 0x34, 
        0x38, 0x38, 0x10, 0x10, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 
        0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x77, 0x77, 0x77, 0x13, 0x86, 0x86, 0x86, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x66, 0x9C, 0x9D, 
        0x1B, 0x17, 0x17, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x11, 0x11, 0x0F, 0x0F, 0x77, 0x11, 0x11, 0x77, 0x13, 0x13, 0x13, 0x13, 0x9B, 0x9B, 0x13, 0x13, 0x9B, 0x1A, 0x86, 0x86, 
        0x13, 0x42, 0x42, 0xAE, 0x73, 0x73, 0x73, 0x73, 0x73, 0x9D, 0x9D, 0x66, 0x66, 0x05, 0x05, 0x05, 0x84, 0x84, 0x3D, 0xFE, 0xFE, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x3D, 0x2E, 0x2E, 0x2E, 0x98, 0x98, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x66, 0x66, 0x9C, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x84, 0x84, 0x98, 0x2E, 0x3D, 0x2E, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E,
  0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0xA5, 0xA5, 0x2F, 0x6E, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x3F, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0xB7, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 
        0xA8, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x8D, 0xB2, 0xBA, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xF8, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 
        0x07, 0x07, 0x65, 0x65, 0x27, 0xD2, 0xD2, 0xD2, 0x41, 0x2B, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 
        0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x12, 0x91, 0x12, 0x91, 
        0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x98, 0x37, 0x98, 0x98, 0x3D, 0x98, 0x98, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x0A, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x23, 0x23, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x89, 
        0x89, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x23, 0xDF, 0xDF, 0x23, 0x23, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x23, 0x02, 0x02, 0x02, 0x23, 0xDF, 0xDF, 0xDF, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x89, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02,
  0x45, 0xC3, 0xC3, 0x43, 0x35, 0x35, 0xA4, 0x4A, 0x4A, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 
        0xA2, 0xA2, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0xB5, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0x50, 0x2D, 0x5C, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xE2, 0xE2, 
        0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0x0E, 0xE2, 0xCB, 
        0x0C, 0x0C, 0xB2, 0x0B, 0xB3, 0xA0, 0x08, 0xBB, 0xC1, 0x07, 0x65, 0x65, 0x49, 0x27, 0xD2, 0x41, 0x4E, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x34, 0x34, 0x2B, 0x34, 0x34, 0x2B, 0x34, 0x34, 0xAC, 0x2B, 0x34, 0x34, 0x34, 
        0x34, 0x34, 0x34, 0xAC, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x1B, 0x1B, 0x1D, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x2E, 0x04, 0x2E, 
        0x2E, 0xFE, 0x2E, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x73, 0x73, 0x73, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x73, 0x73, 0x73, 0x1D, 
        0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 0x04, 0xFE, 0x04, 0x2E, 0xFE, 0x2E, 0x2E, 0x2E, 0xFE, 0xFE, 0x2E, 0x3D, 0x3D, 
        0xFE, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 
        0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x5F, 0xA3, 0x89, 0x23, 0x89, 0x55, 0xA3, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x84, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x55, 0x55, 0xA3,
  0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 
        0x33, 0x33, 0x33, 0x33, 0x56, 0xEA, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x50, 0xBE, 0xBE, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 
        0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x7B, 0x7B, 0x08, 0x08, 0x08, 0x08, 0x08, 0xDA, 0x07, 0x07, 0x07, 0x07, 0x65, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x2C, 0x2C, 0x2C, 0xE4, 0x36, 0x36, 
        0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 
        0x90, 0x90, 0x1E, 0x1E, 0x14, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x9B, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x86, 0xAE, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 
        0x17, 0x1B, 0x1B, 0x73, 0x73, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x55, 0x89, 0x89, 0x55, 0x89, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x98, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x3D, 0x3D, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55, 0x55, 0x89, 0x89, 0x23, 0x23, 0x23, 0x23, 0x89, 
        0x89, 0x23, 0x89, 0x89, 0x89, 0x89, 0x89, 0x55, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x3D, 0x3D, 0x2E, 0x2E, 0x2E, 0x3D, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x2E, 0x84, 0x2E, 0x84, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x37, 0x37, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x98, 0x3D, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 
        0x23, 0x5F, 0x23, 0x5F, 0x5F, 0x5F, 0x5F, 0x23, 0x23, 0x5F, 0x23, 0x23, 0x89, 0x89, 0xA3, 0x55, 0x55, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x05,
  0x30, 0x30, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x6E, 0x48, 0x48, 0x48, 0xF5, 0x48, 0x48, 0x48, 0x33, 0x33, 0x48, 
        0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0xE0, 0xE0, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x2D, 0xB7, 0xB7, 0x2D, 0x2D, 0x2D, 0xB7, 0x5C, 0xB7, 0xB7, 0xB7, 0xB7, 
        0x57, 0xC5, 0xC5, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x1C, 0x6A, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 
        0xA8, 0x0B, 0x0B, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xD1, 0x2C, 0x2C, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2C, 0x4E, 0xAA, 0x2C, 0x4E, 0x4E, 0x4E, 0xAA, 0xE4, 
        0x2B, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0xF0, 0x26, 0x26, 0x26, 0x26, 0x26, 0x28, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x79, 0x79, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 
        0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 
        0x05, 0x05, 0x9C, 0x66, 0x1D, 0x1F, 0x1D, 0xDC, 0x1D, 0x1D, 0x9D, 0x9D, 0xDC, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x66, 0x66, 0x1F, 0xFD, 0x66, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x73, 0x73, 0x17, 0xAE, 0xAE, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x42, 0x17, 0x73, 0x1B, 0xAE, 0x73, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x98, 0x2E, 0x2E, 0x84, 0xFE, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 
        0x23, 0x02, 0x02, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0x23, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x84, 0x84, 0x37, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x37, 0x37, 0x84, 0x84, 0x05, 0x84, 0x84, 
        0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84,
  0x7A, 0x7A, 0x7A, 0x7A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x4F, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x7A, 0x4D, 0x4D, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 
        0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x48, 0x33, 0x33, 0xF6, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x54, 0xB6, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 
        0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 
        0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x2E, 0x84, 0x84, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0xFE, 
        0xFE, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x23, 0x23, 0xDF, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x6C, 0x6C, 0x6C, 0x6C, 0x8C, 0x8C, 0x6C, 0x6C, 0x8C, 0x8C, 0x02, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x02, 0x02, 0x02, 0x02, 
        0x02, 0x02, 0x02, 0x23, 0x23, 0x23, 0x89, 0x89, 0x89, 0x89, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x04, 0x04, 0x2E, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 0x55,
  0x7A, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x48, 
        0x33, 0x33, 0x56, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x5C, 0x5C, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 
        0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 
        0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x94, 0x94, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0xCC, 0x65, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x96, 0xD2, 0x2C, 0x2C, 0x2C, 0x2B, 0x36, 0xAC, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 
        0x11, 0x1A, 0x1A, 0x13, 0x86, 0x17, 0x73, 0x73, 0x1B, 0x1D, 0x73, 0x1B, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x1F, 0x1D, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x98, 0x2E, 0x2E, 0x3D, 0x04, 0x04, 0x55, 0x55, 0x89, 0x02, 0x02, 0x02, 
        0x8C, 0x8C, 0x6C, 0x97, 0x01, 0x01, 0x0A, 0x0A, 0x01, 0x0A, 0x01, 0x0A, 0x0A, 0x0A, 0x0A, 0x6C, 0xF2, 0x02, 0x02, 0xDF, 0x23, 0x89, 0x55, 0x55, 0x04, 0x04, 0x2E, 0x37, 0x98, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0xFD, 0xFD, 
        0x1F, 0x1F, 0xFD, 0x1F, 0xFD, 0xFD, 0x1D, 0xDC, 0xDC, 0x1D, 0x1D, 0x1D, 0xFD, 0xFD, 0xFD, 0xFD, 0x66, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0x04, 0x04, 
        0x04, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0xFE, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0xA3, 0xA3, 0xDF, 0x23, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x8C, 0x8C, 0x02, 0x8C, 0x8C, 0x8C, 0x8C, 0x8C, 0x0A, 0x0A,
  0x30, 0x30, 0x99, 0xA1, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0xB5, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0xBE, 0xBE, 
        0x50, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x50, 0xBE, 0xBE, 0x54, 0x54, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x3C, 0x3C, 0x4B, 0xEA, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0xB6, 0xB6, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 
        0x5C, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 
        0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x94, 0x94, 0x94, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x94, 0x94, 0x94, 0x96, 0x96, 0xD2, 0x41, 0x4E, 0x4E, 0x4E, 0x34, 0x34, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x79, 0x79, 0x26, 0x26, 0x79, 0x79, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 
        0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x0F, 0xF1, 0x77, 0x13, 0x86, 0x17, 0x1B, 
        0x1B, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x37, 0x37, 0x37, 0x2E, 0x3D, 0x3D, 0x3D, 0xFE, 0xFE, 0x3D, 0x04, 0x04, 0x2E, 0x2E, 0x3D, 0x3D, 0xFE, 0xFE, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x2E, 0x98, 0x98, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x98, 0x98, 0x37, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x05, 0x05, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0x89, 0x89, 0x23, 0x23, 0xDF, 0xDF,
  0x35, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x99, 0x99, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 
        0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0xA2, 0x48, 0x33, 0x33, 0x33, 0xF6, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x56, 0x4B, 0xB5, 0x4B, 0xEA, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0xB6, 0xBE, 0x50, 
        0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0xC1, 0xC1, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x27, 
        0x27, 0x27, 0x96, 0x2C, 0x4E, 0x2B, 0xE4, 0x36, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 
        0x14, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x26, 0x79, 
        0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 
        0x37, 0x37, 0x84, 0x84, 0x98, 0x98, 0x84, 0x2E, 0x2E, 0x2E, 0x98, 0x98, 0x2E, 0x2E, 0x37, 0x98, 0x98, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1F, 
        0x1F, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x9D, 0x9D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x37, 0x98, 0x2E, 0xFE, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x55, 
        0x55, 0x89, 0x89, 0xA3, 0xA3, 0xA3, 0x04, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x05, 0x05, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 
        0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04,
  0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x46, 0xC3, 0xC3, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x33, 0x33, 0x33, 
        0x33, 0x33, 0xB5, 0xB5, 0x33, 0xB5, 0xB5, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0xE0, 0x3C, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0xBE, 0x50, 0x2D, 0x2D, 0x5C, 0xB7, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x6A, 0xBF, 0xB8, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 
        0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x2C, 
        0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xEC, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 
        0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x90, 0x21, 0x21, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 
        0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x12, 0x0F, 0x0F, 0x77, 0x13, 0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9C, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x1D, 
        0x9D, 0x9D, 0x1D, 0x1B, 0x17, 0x17, 0x86, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x77, 0x13, 0x13, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x9D, 0x1D, 0x1D, 0x66, 0x1F, 0xFD, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x37, 0x84, 0x84, 0x05, 0x84, 0x84, 0x05, 0x84, 0x05, 0x37, 0x37, 0x05, 0x37, 0x37, 0x05, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 
        0x1D, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x84, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x55, 0x89, 0x89, 0x89, 0x23, 
        0x23, 0x5F, 0x5F, 0xA3, 0x89, 0xA3, 0xA3, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x2E, 0x84, 0x2E, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1B, 0x73, 0x17, 0x17, 
        0xAE, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C,
  0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x7A, 0x7A, 0x4D, 0x4D, 0x6E, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x56, 0x56, 
        0x56, 0x4B, 0x4B, 0x56, 0x56, 0x56, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xF5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0x50, 
        0x50, 0x2D, 0x2D, 0x2D, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x0D, 0x0D, 0x0D, 0x88, 0xCF, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 
        0x07, 0x07, 0x94, 0x27, 0x96, 0x2C, 0x4E, 0x4E, 0xE4, 0x2B, 0x2B, 0xAC, 0x34, 0x34, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x26, 0x28, 0x28, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x14, 0x78, 
        0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 
        0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 
        0xDC, 0x9D, 0x1D, 0x1D, 0x1F, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x98, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x84, 0x84, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1D, 0x9D, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0xAE, 0x17, 0xAE, 0xAE, 0x1B, 0x1B, 0x1B, 0x31, 0x9D, 0x9D, 0x9D, 0x9D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x2E, 0x2E, 
        0x84, 0x2E, 0x2E, 0x84, 0x98, 0x98, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x2E,
  0xA4, 0xA4, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x56, 0x56, 0x56, 0x56, 0x56, 0x4B, 0xB5, 0x56, 
        0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0xF5, 0xF5, 0x33, 0x56, 
        0x56, 0x4B, 0x4B, 0xEA, 0xEA, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x50, 0xBE, 0xBE, 0x2D, 0x2D, 0x5C, 0xEB, 0xEB, 0xB7, 0x1C, 0x1C, 0xBF, 0xBF, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 
        0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0x08, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x27, 0x27, 0xD2, 0xD1, 0x2C, 0x4E, 0x2B, 0x36, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x36, 0x2B, 0xAB, 0xAB, 0xAB, 0x2C, 0x2C, 
        0x4E, 0x4E, 0x4E, 0x4E, 0x2C, 0x4E, 0xAB, 0x36, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x0F, 0x77, 0x77, 0x86, 
        0x86, 0x86, 0x17, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x1B, 0x1D, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 
        0x13, 0x86, 0x86, 0x86, 0x13, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x13, 0x13, 0x77, 0x77, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x9B, 
        0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1D, 0x1D, 0x66, 0x66, 0x1F, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x9C, 0x1D, 0x1D, 0x66, 0x66, 0x1F, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x9D, 0x9D, 
        0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1B, 0x9D, 0x1B, 0x1B, 0x31, 0x9D, 0x9D, 0x1B, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x2E, 0xFE, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0x89, 0xA3, 0x55, 0x55, 0x55, 0x55, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xFE, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x1F, 0x9C, 0x9C, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84,
  0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x4A, 0x4A, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x81, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x2F, 0x6E, 0x6E, 0x6E, 0x48, 0xF6, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x54, 0x50, 0x2D, 0xB7, 0x57, 0x1C, 0xB8, 0x0D, 0x0D, 0x93, 0xCF, 0x0E, 0x0E, 0x0E, 0x9F, 0x8F, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xD8, 
        0xD8, 0x9F, 0x0E, 0x0E, 0x0E, 0x0E, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xEB, 0xB7, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 
        0x0E, 0x0E, 0x0E, 0xC6, 0xC6, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 
        0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x27, 0x96, 0x96, 0xC2, 0x4E, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 
        0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 
        0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0xFC, 0xFC, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x9D, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x1D, 0xDC, 0x9D, 0xDC, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x37, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x2E, 0x2E, 0x04, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x04, 0x2E, 0x2E, 0x3D, 0xFE, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84,
  0x43, 0x43, 0xC3, 0xC3, 0xC3, 0xC3, 0x43, 0x43, 0x43, 0x45, 0x43, 0xC3, 0xC3, 0xC3, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0xA4, 0xA4, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x4F, 
        0x4F, 0x2A, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0xA2, 0x48, 0x33, 0x33, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x5C, 0x57, 0x57, 0x57, 0x5C, 0xB7, 0xB7, 0x5C, 0xB7, 0xB7, 0xB7, 0x5C, 0x2D, 0x5C, 0xB7, 0x2D, 
        0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 
        0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x96, 0x96, 0xAA, 0x36, 0x36, 0xBC, 0x38, 0x38, 0x10, 0x25, 0x25, 0x26, 0x29, 0x29, 0x87, 0x26, 0x28, 0x28, 0x28, 0x79, 0x79, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x17, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 
        0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x37, 0x98, 0x2E, 0x2E, 0x3D, 0x3D, 0x3D, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x3D, 0x2E, 0x98, 0x84, 0x84, 0x37, 0x05, 0x05, 0x05, 0x9C, 0x1D, 
        0x9D, 0x9D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x86, 0x17, 0x1B, 0x17, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x1F, 0x9C, 0x1F, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0xA3, 0xA3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04,
  0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x2A, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 
        0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0x6E, 0xA2, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x4B, 
        0x3C, 0xE0, 0x3F, 0x54, 0x54, 0xBE, 0x2D, 0x5C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x7E, 0x7E, 0x1C, 0xBF, 0x7E, 0x1C, 0x1C, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0x1C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0x0D, 0x0D, 0x0D, 
        0xB1, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0xB2, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0xC1, 0x07, 0xC1, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x65, 0xCC, 0xCC, 0x27, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0xF0, 0xF0, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 
        0x77, 0x77, 0x77, 0x1A, 0x13, 0x77, 0x1A, 0x13, 0x13, 0x1A, 0x1A, 0x11, 0xCE, 0xCE, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0xDE, 0xDE, 0x12, 0x15, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x91, 0x91, 
        0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x9B, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x77, 0x77, 0x13, 0x1A, 0x13, 0x86, 0x86, 
        0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1D, 0x9C, 0xFD, 0x9C, 0x05, 0x05, 0x05, 0x05, 0xFD, 0xFD, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 
        0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x9D, 0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x84, 0x84, 0x84, 0x2E, 
        0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x2E, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C,
  0x64, 0x64, 0x64, 0x3E, 0x64, 0x64, 0x3E, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0xC3, 0x43, 0x43, 0x35, 0x35, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 
        0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0xB6, 0x50, 0x50, 0x50, 0x50, 0x2D, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x6A, 0xB8, 0xB8, 0xB8, 0x0D, 0x0D, 0x88, 
        0x0D, 0x93, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0x6B, 0x6B, 0x7E, 0x1C, 0x57, 0x57, 0xC5, 0xC5, 0x57, 0x57, 0xB7, 0xB7, 0xB7, 0x2D, 0xB7, 0xB7, 0xC5, 0xC5, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 
        0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x27, 0x96, 0x96, 
        0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x49, 0x27, 
        0x27, 0x41, 0x41, 0x41, 0x4E, 0x36, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x79, 0x79, 0x79, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 
        0x80, 0x1E, 0x1E, 0x1E, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0xCE, 0xCE, 0x77, 0x77, 0x13, 
        0x13, 0x13, 0x86, 0x17, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x66, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1B, 0x17, 0xAE, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0xAE, 0x17, 0xAE, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0xAE, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1D, 0x1D, 
        0x1D, 0x1D, 0x9D, 0x1D, 0x1F, 0x9C, 0x9C, 0xFD, 0xFD, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0xFD, 0xFD, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x9C, 0x9C, 
        0xFD, 0x9C, 0x9C, 0x66, 0x66, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1F, 0x1D, 0x1D, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05,
  0x45, 0x43, 0x35, 0x35, 0x35, 0x67, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x33, 
        0x33, 0xB5, 0xB5, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x3F, 0x54, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0xE0, 0xE0, 0xE0, 0xE0, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x56, 0x56, 0x33, 0xF6, 0x33, 0x56, 0x56, 0x56, 0x4B, 
        0x4B, 0xEA, 0xEA, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 0xF7, 0xF7, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0x57, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x7E, 0x6A, 0xB8, 0x6A, 0x6A, 0xBF, 0xBF, 0xBF, 0xA6, 0x6B, 
        0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x07, 0x07, 
        0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xDA, 0xDA, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x6D, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0x27, 0xD2, 0x41, 
        0x2C, 0x2C, 0xAB, 0x4E, 0x4E, 0xAB, 0x36, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 
        0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x17, 0x86, 0x17, 0x17, 0x86, 
        0x17, 0x17, 0x17, 0x1B, 0x1B, 0x73, 0x17, 0x17, 0x17, 0x73, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0xAE, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x17, 0x86, 0x86, 
        0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0xAE, 0x86, 0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x9C, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1F, 0x1F, 0x9D, 0x9D, 0x9D, 0x1B, 0x9D, 0x9D, 0x1B, 0x9D, 0x9D, 0x1B, 0x9D, 0x9D, 0x9D, 0x1B, 0x1B, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x84, 0x84, 0x84, 0x2E, 0x3D, 0x98, 0x84, 0x2E, 0x84, 0x84, 0x84, 
        0x05, 0x37, 0x05, 0x05, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E,
  0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x35, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0xA2, 0x33, 0x33, 0x33, 
        0xB5, 0xB5, 0xB5, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x3F, 0x54, 0xBE, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 
        0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x94, 0x94, 0x94, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0x2C, 
        0xAA, 0x2C, 0xAA, 0xAA, 0xAB, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 
        0x4E, 0x41, 0xD2, 0x49, 0x49, 0x49, 0x49, 0x49, 0x49, 0xCC, 0xCC, 0xCC, 0x49, 0x49, 0x49, 0x49, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 
        0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x86, 0x86, 0x17, 0x17, 0x86, 0xAE, 0xAE, 0xAE, 0x86, 0x17, 0x17, 0x17, 0xAE, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x11, 0xCE, 
        0x77, 0x77, 0x77, 0x13, 0x1A, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x17, 0x17, 0xAE, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 
        0xFD, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x98, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0xFE, 0x04, 0x04, 0x04, 0x04, 0x04, 0x2E, 0x2E, 0x04, 0x2E, 0x3D, 0x2E, 0x2E, 0x04, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x9C, 
        0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B,
  0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0x3E, 0x3E, 0x39, 0x46, 0x46, 0x45, 0x43, 0x43, 0x35, 0x67, 0x67, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x81, 0x81, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 
        0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0xA1, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0x54, 0xBE, 0x2D, 0x2D, 0x57, 0xC5, 
        0x1C, 0x6A, 0x6A, 0xBF, 0x0D, 0x0D, 0x88, 0x93, 0x93, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x93, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 
        0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 
        0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x07, 0x07, 0x07, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0x2B, 
        0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
        0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 
        0x78, 0x12, 0x12, 0x12, 0x91, 0x12, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x05, 0x9C, 
        0x9C, 0xFD, 0x66, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x1F, 0x1D, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x0F, 
        0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x86, 0x17, 0x17, 0xAE, 0x73, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x9C, 0x05, 0x05, 0x05, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0xFD, 0xFD, 0x05, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1B, 0x1B, 0x9D, 0x31, 0x73, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x9D, 0x9D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x1F, 0x9C, 
        0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05,
  0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x46, 0xC3, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x81, 0x81, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 0x3C, 0x3C, 0x4B, 0xEA, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 
        0x4B, 0x4B, 0xB5, 0x4B, 0x4B, 0x4B, 0x4B, 0xB5, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0xE0, 0xE0, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xBE, 0xBE, 0x50, 0x2D, 0x5C, 0xC5, 0x1C, 0x1C, 0x6A, 0x6A, 0xA6, 0xA6, 0x0D, 0x0D, 0xC0, 
        0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 
        0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x49, 0x27, 0x49, 0x94, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x27, 0x27, 0x27, 0x49, 0x27, 0x49, 0x49, 
        0x27, 0x27, 0x49, 0x27, 0x94, 0xCC, 0xCC, 0xCC, 0xCC, 0x65, 0x07, 0x94, 0x49, 0xCC, 0x27, 0xD2, 0xD2, 0x41, 0x41, 0x41, 0x2C, 0x2C, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 
        0x90, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 
        0x77, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x86, 
        0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1D, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0xFD, 0xFD, 0x05, 0x9C, 0x05, 0x05, 
        0x05, 0x9C, 0x9C, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x2E, 0x2E, 0x04, 0x2E, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 
        0x04, 0x04, 0x04, 0x2E, 0x04, 0x04, 0x84, 0x84, 0x2E, 0x2E, 0x2E, 0x84, 0x84, 0x84, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C,
  0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x32, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x32, 0xB4, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x2A, 0x2A, 0x2A, 0x4D, 0x4D, 0x2F, 0x2F, 
        0x48, 0x33, 0x33, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0x2D, 0x2D, 0xB7, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x88, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 
        0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0xA0, 0x08, 0xA0, 0x08, 0xA0, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 
        0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x96, 0x41, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xE4, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x26, 0x26, 0x79, 0x79, 0x24, 0x21, 0x21, 0x21, 0x90, 
        0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 
        0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x28, 0x79, 0x19, 0x79, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x13, 0x42, 0x17, 0x73, 0x1B, 0x73, 0x1D, 
        0x1B, 0x9D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x37, 0x84, 0x84, 0x84, 0x05, 0x37, 0x37, 0x37, 0x84, 0x84, 0x84, 0x37, 0x84, 0x84, 0x37, 0x37, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x1F, 0x9D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x1B, 0x1B, 0x9D, 0x1D, 0x1D, 0x9D, 0x1F, 0x1F, 0x9C, 0x05, 
        0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C,
  0x64, 0x64, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x43, 0x35, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x4A, 0x4A, 0x32, 0x32, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 
        0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x2F, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0xF5, 0xF5, 0x33, 0x33, 0x56, 0xB5, 0xEA, 0x4B, 0x4B, 0xEA, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x3F, 0x54, 0x54, 0x54, 0x54, 0x54, 0x54, 0x54, 0xBE, 0xBE, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x7E, 0x7E, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 
        0xC0, 0x88, 0x88, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 
        0x07, 0xCC, 0x94, 0x27, 0x27, 0x27, 0xD2, 0x41, 0x2C, 0x41, 0x2C, 0x41, 0x4E, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 
        0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x14, 0x14, 0x78, 0x78, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x13, 0x1A, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 
        0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0xAE, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x9D, 0x1F, 0x1F, 0x9C, 0x9C, 
        0x1F, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1F, 0x1F, 0x1D, 
        0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x13, 0x86, 0x13, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x9D, 0x9D, 0x1B, 0x1D, 0x1B, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 0x13,
  0x64, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 
        0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0xE0, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 
        0xBE, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xBE, 0x2D, 0x2D, 0x5C, 0x2D, 0x5C, 0x5C, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0x6A, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 
        0x0D, 0x0D, 0xB8, 0xB8, 0x6A, 0xBF, 0xBF, 0x6A, 0x6A, 0x1C, 0x6A, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xC1, 0x07, 
        0x07, 0x07, 0x94, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x96, 0x96, 0x2C, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x94, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 
        0xBB, 0x6D, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x49, 0x49, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x34, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 
        0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 
        0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x14, 0x14, 0x8E, 0x8E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x95, 0x95, 0x78, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x11, 0x77, 0x77, 
        0x0F, 0x11, 0x0F, 0x11, 0x0F, 0x0F, 0x11, 0x11, 0x11, 0x11, 0x11, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 
        0x1B, 0x1D, 0x1D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x9D, 0x9D, 0x1D, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 
        0x13, 0x86, 0x13, 0x86, 0x86, 0x9B, 0x86, 0x86, 0x86, 0x86, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B,
  0x47, 0x47, 0x47, 0x76, 0x76, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0x64, 0x64, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0xC3, 0x43, 0x43, 0x35, 0xA4, 0xA4, 0x4A, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x4F, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0xA2, 
        0x48, 0x33, 0x33, 0xB5, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0xE0, 0x3C, 0x3C, 0xE0, 0x3C, 0x3C, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0x33, 0x48, 0x6E, 0x2F, 0x2F, 0x4D, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
        0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x2F, 0x6E, 0x48, 0x48, 0x33, 0x56, 0x4B, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 0x54, 0x54, 0xBE, 0xF7, 0xF7, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0xE0, 0xE0, 0x3C, 0x3C, 
        0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0x50, 0xBE, 0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 
        0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 0x49, 0x27, 0x27, 0x27, 0x27, 
        0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x41, 0x27, 0x27, 0x27, 0x49, 0x49, 0x49, 0x49, 0x49, 0x27, 0xD2, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 
        0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x95, 0x95, 0x78, 
        0x78, 0x12, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x1A, 0x13, 0x13, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x13, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0xAE, 
        0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x9D, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1F, 0x9C, 0x9C, 0x9C, 0x05, 0x1F, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x9C, 0x9C, 0x05, 
        0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77,
  0xBD, 0x76, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0xB0, 0xB0, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0xA4, 0xA4, 0xA4, 0x4A, 0xA4, 0x4A, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 
        0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0xA1, 0xA1, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 
        0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0xA5, 0xA5, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0x50, 0x50, 0x2D, 0x2D, 0x57, 0xC5, 0x57, 0x1C, 0x1C, 0x6A, 0xB8, 
        0x0D, 0x0D, 0x93, 0xB1, 0x0E, 0x0E, 0xE2, 0x9F, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 
        0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0x7B, 0x08, 0x08, 0x08, 
        0xDD, 0xDD, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0xD1, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x2B, 0x2B, 0x2B, 0xAC, 0x34, 0xBC, 0x34, 0x38, 0x34, 0x38, 0x10, 0x38, 0x10, 0x10, 0x10, 
        0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x78, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x21, 0x90, 0x90, 
        0x90, 0x1E, 0x1E, 0x1E, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0xDE, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x13, 0x13, 0x13, 
        0xAE, 0x17, 0x17, 0x1B, 0x1B, 0x1D, 0x1F, 0x9D, 0x9D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x1F, 0x1F, 0x1D, 0x9D, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x17, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x1A, 0x1A, 
        0x13, 0x13, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x11, 0x11, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x11, 0x11, 0x11, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x1B, 0x1B, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x17, 0x17,
  0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0x45, 0x45, 0x45, 0x43, 0x43, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x53, 0x30, 
        0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0xB5, 0x4B, 0xE0, 0x3F, 0x3F, 0x54, 0xBE, 0x2D, 
        0x2D, 0xEB, 0xC5, 0x1C, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 
        0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 
        0x6D, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0xCC, 0xCC, 0xCC, 0xCC, 0x49, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0xD2, 0x96, 0x96, 0x96, 0xD1, 0x41, 0x41, 0x41, 0x41, 0x41, 0x4E, 0xAB, 0xAB, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 
        0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 
        0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x18, 0x18, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 
        0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x9D, 0x9D, 0x1F, 0x1F, 0x1D, 0x1F, 0x1F, 0x9D, 0x1F, 0x1D, 0x1D, 0x1F, 0x1F, 0x1F, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 
        0x1B, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86,
  0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0xB4, 
        0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 
        0xE0, 0x3F, 0x3F, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 0xBE, 0xBE, 0x54, 0x50, 0xF7, 0x50, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0x57, 0xC5, 0x1C, 0x6A, 0x6A, 0x6B, 0x0D, 0x0D, 0x93, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 
        0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0x0E, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0x0E, 0xE2, 0xE2, 0xE2, 0x0C, 0x0C, 
        0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 
        0xA0, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xDD, 0xDA, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x65, 0x65, 0x49, 0x49, 0x49, 0x49, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x41, 0x41, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 
        0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x1B, 0x17, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x1B, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x17, 0x86, 0x86, 0x86, 0x13, 0x13,
  0xD7, 0x3B, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0x64, 0x3E, 0x3E, 0x39, 0xB0, 0x45, 0x45, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x81, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 
        0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 
        0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0x54, 0x54, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0xEB, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xB8, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0D, 0x0D, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xBF, 0xBF, 0x7E, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0x0D, 0x0D, 0x0D, 0x0D, 0xB1, 0x0E, 0x0E, 
        0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0x8D, 0xB2, 0x0B, 0x8D, 0xA8, 0x0B, 0xA8, 0x8D, 0x8D, 0x8D, 0x0B, 0xA8, 0xA8, 0x0B, 0x8D, 0x8D, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 
        0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x2C, 0x2C, 0x2C, 0xAB, 0xE4, 0x36, 0x36, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 
        0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x90, 0x90, 0x21, 0x90, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 
        0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x13, 0x77, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 
        0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x11, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 
        0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86,
  0x47, 0x47, 0xBD, 0xBD, 0x40, 0x3B, 0x3B, 0x64, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x45, 0x45, 0xC3, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 
        0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 
        0xEB, 0xEB, 0xEB, 0xE1, 0xC5, 0xC5, 0xEB, 0xEB, 0xEB, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0x50, 0xF7, 0x2D, 0x2D, 0x2D, 0xB7, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 
        0xC0, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xC6, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0x07, 0x07, 
        0x07, 0x07, 0x94, 0x27, 0x27, 0x94, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0x36, 0xAC, 0x2B, 0xAC, 0x2B, 0x34, 0x34, 0x38, 0x38, 0xD3, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x28, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x79, 0x79, 0x79, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x90, 0x90, 0x90, 0x90, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 
        0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x12, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x14, 0x14, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 
        0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x13, 0x13, 0x86, 0x86, 0x17, 
        0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x9C, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x84, 0x84, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05,
  0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x43, 0xC3, 0x43, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0x4A, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 
        0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0xC3, 0xC3, 0xC3, 0xC3, 0x45, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 
        0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0x4D, 0xA5, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x2D, 0x2D, 0xB7, 0xC5, 0x1C, 0x1C, 0x6A, 0x6A, 0x0D, 0x0D, 
        0x0D, 0x88, 0xCF, 0xCF, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 
        0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 
        0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x49, 0x49, 0x27, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0x4E, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2C, 0x2C, 0x41, 0x41, 0x41, 0x41, 0xD1, 0xD1, 0x41, 0x41, 0x4E, 0x41, 
        0x41, 0x41, 0x2C, 0x4E, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 
        0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x14, 0x80, 0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x13, 0x77, 0x77, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x9B, 0x9B, 0x86, 0x86, 0x86, 0x13, 0x13, 
        0x86, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x78, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x42, 0xAE, 0xAE, 0x17, 0x17, 
        0x17, 0x17, 0x17, 0x17, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x13, 0x86, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 0x0F, 0x0F, 0x11, 0x11, 0x0F,
  0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0xB4, 0xB4, 0x81, 0x32, 0x4A, 0x4A, 0x4A, 0xA4, 0x35, 0x35, 0x43, 0x45, 0x45, 
        0x45, 0x46, 0xB0, 0x45, 0x45, 0x46, 0xC3, 0xC3, 0x43, 0x43, 0x43, 0x35, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x7A, 0x4D, 0x4D, 0x2F, 0x6E, 
        0x6E, 0x48, 0x33, 0x33, 0x56, 0x56, 0xEA, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xC5, 0xC5, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x88, 0x93, 
        0x93, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x41, 0x2C, 0x2C, 0xAB, 0x4E, 0x4E, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0xAD, 0x25, 
        0x25, 0x25, 0xEE, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 
        0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x79, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 
        0x90, 0x90, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x21, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x77, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x11, 0x77, 0x77, 0x1A, 0x13, 0x86, 0x86, 
        0x86, 0xAE, 0x17, 0xAE, 0xAE, 0x17, 0x17, 0x17, 0x17, 0xAE, 0xAE, 0x1B, 0xAE, 0x17, 0x17, 0xAE, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0x17, 0xAE, 0xAE,
  0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0xC3, 0xC3, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x35, 0x35, 
        0x35, 0x35, 0x67, 0x67, 0x4A, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x81, 0x81, 0xB4, 0x53, 0x81, 0xB4, 0x32, 0x32, 0xB4, 0x81, 0x81, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 
        0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 
        0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x50, 0x50, 0x2D, 0xB7, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0xB8, 0xB8, 0x6B, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0xAB, 0x36, 0x36, 0xAC, 0x34, 0xEC, 0x3A, 0xD3, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 
        0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x25, 0x26, 0x26, 
        0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 
        0x78, 0x78, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x86, 0x17, 0x17, 0x86, 0x86, 0x86, 0x86, 0x86, 0x13, 0x86, 0x86, 0x13, 
        0x13, 0x77, 0x77, 0x0F, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x80, 0x80, 0x80, 0x14, 0x78, 0x78, 0x78, 0x12, 0x12, 
        0x91, 0x91, 0x91, 0x0F, 0x0F, 0x11, 0x11, 0x77, 0x77, 0x13, 0x77, 0x13, 0x13, 0x13, 0x86, 0x86, 0x13, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x86, 0x9B, 0x9B, 0x86,
  0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0xA4, 0x67, 0x67, 0xA4, 0xA4, 0x4A, 0x4A, 0xA4, 
        0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x81, 0x32, 0x81, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0x6E, 0x6E, 
        0x48, 0x33, 0xF6, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x3F, 0x54, 0x54, 0x3F, 0x54, 0x54, 0x54, 0x54, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 
        0xBE, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0x5C, 0x5C, 0xC5, 0xC5, 0x1C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0xCB, 
        0xCB, 0xCB, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0xE2, 0x0E, 0x0E, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 
        0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x27, 0x27, 0x41, 0x41, 
        0x41, 0x41, 0x2B, 0x2B, 0x2B, 0x34, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x87, 0x28, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x1E, 0x80, 0x14, 0x14, 0x78, 0x12, 
        0x91, 0x91, 0x91, 0x0F, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x91, 0x91, 0x91, 0x12, 0x78, 0x78, 0x78, 0x78, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x22, 0x22, 0x24, 0x22, 0x22, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 
        0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x77, 0x77, 0x13, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 
        0x78, 0x95, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E,
  0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0xB0, 0xB0, 0x45, 0xB0, 0x45, 0x45, 0x45, 0x45, 0xC3, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0xA4, 0x4A, 
        0x4A, 0x4A, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 
        0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0xB5, 0x4B, 0x4B, 0x4B, 0x3C, 0xE0, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0x54, 0xBE, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 
        0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0x57, 0x57, 0xEB, 0xEB, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x7E, 0x7E, 0x6A, 0xBF, 0x6A, 0xBF, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 
        0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 
        0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xDA, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAB, 0x2B, 0x36, 0x36, 0x36, 0x34, 0x34, 0x34, 0x34, 0x34, 
        0x34, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0xF0, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 
        0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91,
  0x4A, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0xD7, 0x64, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0xB0, 0x45, 0x45, 0x43, 0x43, 
        0x35, 0x67, 0xA4, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0xA1, 0xA1, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x53, 0x53, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x32, 0x4A, 0x4A, 
        0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0xEA, 0x4B, 0x3C, 0x3F, 0x3F, 0x54, 0xB6, 0x50, 0x2D, 0xB7, 
        0x57, 0x57, 0x1C, 0x6A, 0xB8, 0x0D, 0x0D, 0x75, 0xCF, 0x0E, 0xC6, 0xC6, 0xD8, 0x8F, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0x0C, 0xA7, 0xA7, 0xA7, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xC0, 0x93, 0x93, 0x88, 
        0x0D, 0x0D, 0xB8, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 
        0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xDD, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0xD2, 0xD1, 0x2C, 0x41, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0xAA, 
        0x2B, 0xAA, 0xAA, 0x2C, 0xC2, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0xAA, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 
        0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x25, 0x29, 0x25, 
        0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 0x77, 
        0x13, 0x13, 0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x12, 0x91, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 
        0x77, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x1B, 0x1B, 0x1B, 0x1B, 0x1D, 0x1D, 
        0x1D, 0x9C, 0x1D, 0x1D, 0x9C, 0x05, 0x05, 0x05, 0x05, 0x05, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x9C, 0x1D, 0x1D, 0x1D, 0x1D, 0x1B, 0x1B, 0x1B, 0x1B, 0x1B, 0x17, 0x17,
  0x40, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0xBD, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 
        0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0x67, 0xA4, 0xA4, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x32, 0x32, 
        0xB4, 0x81, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x7A, 0x7A, 0x7A, 0x4D, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 
        0x3F, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x50, 0x50, 0x2D, 0xB7, 0x57, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0xB8, 0xBF, 0xBF, 0xA6, 0xBF, 0xA6, 0xBF, 0xBF, 0xBF, 0x7E, 0xBF, 0x1C, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 
        0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 
        0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0x07, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0xDD, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 
        0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x07, 0x07, 0xCC, 0x94, 0x27, 0x27, 0x94, 0x27, 0x27, 0xD1, 0x2C, 0x2C, 0x4E, 0xAA, 0xAA, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x3A, 0x10, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 
        0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x26, 0x79, 0x26, 
        0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x24, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x11, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 
        0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x12, 0x12, 0x91, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x13, 0x77, 
        0x11, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21,
  0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3E, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x45, 0x45, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x4F, 
        0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x53, 0xB4, 0xB4, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x7A, 0x4D, 0x2F, 0x6E, 0x6E, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x56, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 
        0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0xE0, 0x3F, 0x3F, 0x3F, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xEB, 0xC5, 0x1C, 
        0x1C, 0x1C, 0xBF, 0xBF, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xBB, 0x08, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 
        0x96, 0x96, 0x2C, 0xAB, 0x2B, 0x2B, 0x2B, 0x2B, 0xAC, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0xD3, 0x3A, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x24, 
        0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 
        0x14, 0x14, 0x78, 0x14, 0x78, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x80, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x24, 0x24, 0x24, 0x24, 0x24, 
        0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 
        0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80,
  0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0xB0, 0x46, 0xB0, 0x45, 0xC3, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 
        0x67, 0x35, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0xA1, 0x99, 0x99, 0x4F, 0x2A, 
        0x4F, 0x2A, 0x7A, 0x7A, 0x7A, 0x7A, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x48, 0x48, 0x48, 0x6E, 0x6E, 0xA2, 0xA2, 0xA2, 0x6E, 0x6E, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 
        0x6E, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0xE0, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0xF7, 0xF7, 0xF7, 0xBE, 0xBE, 0xBE, 0xBE, 0x2D, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xB7, 0x57, 
        0x57, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0xA6, 0xA6, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0x0B, 
        0x0B, 0xB3, 0xB3, 0xA0, 0xA0, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x65, 0xCC, 0xCC, 0xCC, 0x49, 0xCC, 0xCC, 0x49, 0x49, 0x27, 0x27, 0x49, 0x27, 0x96, 0xD1, 0x41, 0x4E, 0x2C, 0x2B, 0x2B, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x29, 0x29, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x24, 0x24, 0x21, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x18, 0x18, 0x80, 0x14, 0x14, 0x18, 0xFC, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x20, 
        0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x21, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x78, 0x14, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 
        0x77, 0x77, 0x77, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x13, 0x13, 0x13, 0x13, 0x86, 0x86,
  0x76, 0x40, 0x40, 0x40, 0x3B, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3E, 
        0x3E, 0x64, 0x64, 0x3E, 0x3E, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0xC3, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x67, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x81, 0x81, 0x32, 0x32, 0x32, 0xB4, 0x32, 0x32, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 
        0x3F, 0xB6, 0xBE, 0x50, 0x2D, 0x5C, 0xB7, 0x5C, 0x57, 0x1C, 0x1C, 0x6A, 0xB8, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xCF, 0xCF, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xC0, 0xC0, 0x93, 0x0D, 0x0D, 
        0x6B, 0x6B, 0xB8, 0xBF, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0x1C, 0xBF, 0xBF, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 
        0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0xC2, 0x4E, 0x4E, 0x2C, 0x2C, 0x4E, 
        0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x28, 0x79, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 
        0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x38, 0x38, 0x10, 0x10, 0x38, 0x3A, 0x38, 0x3A, 0x38, 
        0x38, 0x34, 0xBC, 0xAC, 0x38, 0x34, 0xAC, 0xAC, 0xBC, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x24, 0x22, 0x21, 0xCD, 0x90, 0x1E, 0x1E, 0x80, 0x18, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 
        0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x77, 0x0F, 0x77, 0x77, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F,
  0x64, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x46, 0x45, 0x43, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0xB0, 0xB0, 
        0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x35, 0x67, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 
        0x4F, 0x2A, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0xA2, 0xA2, 0x6E, 0xA2, 0xA2, 
        0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x4B, 0xEA, 0xE0, 0xE0, 0x3F, 0x3F, 0xBE, 0xBE, 0x2D, 0x2D, 0x5C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xB8, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xB8, 0xB8, 0xB8, 0xBF, 0xBF, 0x6A, 
        0x6A, 0x6A, 0x6A, 0x7E, 0x6A, 0x6A, 0x1C, 0x1C, 0x6A, 0x7E, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x6B, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0x6B, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 
        0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0xBC, 0x34, 0xBC, 0x34, 0x34, 0x2B, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x10, 0x10, 
        0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x26, 0xF0, 0x5E, 0x29, 0x29, 0x25, 0x25, 0x25, 
        0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x19, 0x24, 0x24, 0x7D, 0x21, 0xCD, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x18, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x78, 0x14, 0x78, 0x78, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x91, 0x91, 0x78, 0x78, 0x78, 0x14, 0x14, 0x80, 0x80, 0x80, 0x1E, 0x90, 0x21, 0x21, 0x90, 0xCD, 0x21, 0x21, 0x90, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x1E,
  0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 
        0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0xD7, 0x64, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0x45, 0x45, 0xC3, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0x53, 
        0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xF5, 0x33, 0x56, 0x4B, 
        0x3C, 0x3F, 0x3F, 0x54, 0xBE, 0x2D, 0x2D, 0x5C, 0x57, 0x57, 0xC5, 0x1C, 0x1C, 0x6A, 0x1C, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x6A, 0x1C, 0x1C, 0x6A, 0x1C, 0x1C, 
        0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x93, 0xC0, 0xCF, 0xB1, 0x0E, 0x0E, 0x0E, 0x9F, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 
        0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0x07, 0x07, 0xCC, 0xCC, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x34, 0x38, 0x38, 0x10, 0x10, 0x38, 
        0x38, 0x38, 0x38, 0x38, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x38, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x44, 0x44, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0xF0, 
        0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x7D, 0x21, 0x21, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0xEF, 0xEF, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x78, 0x78, 0x12, 
        0x78, 0x78, 0x12, 0x12, 0x12, 0x78, 0x12, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77,
  0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x4C, 0x47, 0x47, 0xBD, 0xBD, 0x40, 0x3B, 0x3B, 0xD7, 0xD7, 0x64, 0xD7, 0x3E, 0x39, 
        0x39, 0xB0, 0x45, 0x45, 0xC3, 0x43, 0x43, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x81, 0x81, 0x81, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 
        0x48, 0xF5, 0x33, 0x33, 0x33, 0x33, 0xF6, 0x33, 0x33, 0x33, 0xF6, 0x33, 0xF5, 0x33, 0x33, 0x48, 0x48, 0x48, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x2F, 0x2F, 0xA2, 0x48, 0xF5, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0xEA, 0xEA, 
        0xEA, 0xEA, 0xEA, 0xEA, 0x4B, 0x4B, 0x4B, 0x4B, 0x56, 0x56, 0x33, 0x48, 0x48, 0x48, 0x48, 0x6E, 0x6E, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0xE0, 0xE0, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 
        0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
        0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0x0B, 
        0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xDD, 0xDD, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x27, 0x27, 0x27, 0xD2, 0x41, 0x41, 0x4E, 0x4E, 0x2C, 0x4E, 0x4E, 0xE4, 0x36, 0x2B, 0x2B, 0x34, 
        0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 
        0x90, 0x1E, 0x20, 0x20, 0x80, 0x80, 0x80, 0x80, 0x14, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x8E, 0x8E, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0x19, 0x26, 
        0x26, 0x29, 0x26, 0x25, 0xD5, 0xAD, 0x25, 0xEE, 0xEE, 0xAD, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x44, 0x10, 0xAD, 0xAD, 0x25, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x24, 0x21, 0x21, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x14, 0x14, 0x14, 
        0x14, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x13, 0x77, 0x77, 0x13, 0x13, 0x77, 0x86, 0x86, 0x17, 0x17, 0x17, 0x17, 0x17,
  0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x64, 0x64, 0x64, 0x64, 0xD7, 0x3E, 0x39, 0x3E, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x46, 
        0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 
        0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0xA5, 0xA5, 0xA5, 0x4D, 
        0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0xBE, 0xF7, 0x2D, 
        0x2D, 0xB7, 0xEB, 0x1C, 0x1C, 0x1C, 0x6A, 0xB8, 0x0D, 0x0D, 0x0D, 0x0D, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0x0E, 0x0E, 0x0E, 0xB1, 0x0E, 
        0x0E, 0xB1, 0xB1, 0xC0, 0xC0, 0xB1, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0xA9, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x27, 0xD2, 0x96, 0x96, 0x96, 0xD2, 0xD2, 0x2C, 
        0x2C, 0x4E, 0xAB, 0xAA, 0x36, 0xAA, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x29, 0x87, 0x79, 0x79, 0x79, 0x79, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 
        0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0xCD, 0x1E, 
        0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x18, 0x80, 0x80, 0x80, 0x18, 0x18, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 
        0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x0F, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 
        0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x78, 0x14, 0x78, 0x14, 0x14, 0x78, 0x78, 0x78,
  0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0xD9, 0xD9, 0x4C, 0xD9, 0x4C, 0x4C, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x46, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 
        0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x35, 0x67, 0x67, 0x35, 0x35, 0x67, 0x35, 0x35, 0x67, 0x35, 0x67, 0x67, 0x67, 
        0x67, 0x67, 0x35, 0x67, 0xA4, 0xA4, 0xA4, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0x30, 0x30, 0x30, 0x4F, 0x2A, 0x2A, 0x4D, 0x4D, 0x2F, 0x6E, 0xF5, 0x48, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x4B, 
        0x4B, 0x4B, 0x4B, 0xB5, 0xB5, 0xB5, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0x48, 0x33, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0x33, 0x33, 0x56, 0x56, 0x56, 0x56, 0xB5, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 
        0x3C, 0x3C, 0xE0, 0xE0, 0x3F, 0x54, 0xBE, 0xBE, 0x2D, 0x2D, 0xC5, 0x1C, 0x1C, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xE2, 0x0E, 0x0E, 
        0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0xA6, 0xA6, 0xBF, 0x6A, 0x1C, 0x1C, 0xBF, 0xBF, 0x1C, 0xBF, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 
        0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x49, 0x49, 0x27, 0x27, 0x27, 0x27, 0x41, 0x41, 0x41, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAB, 
        0x4E, 0x2B, 0x2B, 0x2B, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x25, 0x29, 0x29, 0x29, 0x29, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x7D, 0x21, 0x21, 0x21, 
        0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x7D, 0x21, 0x90, 0x90, 0x1E, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x78, 0x78, 0x14, 
        0x14, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 
        0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78,
  0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0x40, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 
        0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0xC3, 0xC3, 0x43, 0x43, 0xC3, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0xA4, 
        0xA4, 0x67, 0x35, 0xA4, 0xA4, 0xA4, 0xA4, 0xA4, 0x4A, 0xA4, 0xA4, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x2F, 0x2F, 
        0x2F, 0xA2, 0xA2, 0xA2, 0x33, 0x33, 0x33, 0x56, 0xB5, 0xB5, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0xBE, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0xC5, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 
        0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0D, 0xC0, 0x0E, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 
        0xA8, 0xA8, 0x0B, 0x0B, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 
        0x0B, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0xCC, 0x49, 0x27, 0x27, 0x61, 0x41, 0x2C, 0x4E, 0x4E, 0x2B, 0x2B, 0x36, 0x2B, 0x2B, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 
        0x38, 0x34, 0x34, 0x38, 0x34, 0x38, 0x38, 0x38, 0xD3, 0x3A, 0xD3, 0x38, 0x10, 0xD3, 0x34, 0x38, 0xD3, 0xD3, 0x38, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x38, 
        0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x38, 0x34, 0x34, 0x38, 0x38, 0xD3, 0x10, 0x38, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x79, 
        0x79, 0x79, 0x79, 0x26, 0x26, 0x79, 0x79, 0x79, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x24, 0x24, 0x19, 0x24, 0x8B, 0x22, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 
        0x19, 0x19, 0x24, 0x24, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x21, 0x24, 0x21, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90,
  0x39, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x3E, 0xD7, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 0x40, 
        0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0x3E, 0x39, 0x39, 0x39, 0x45, 0x45, 0x43, 0x43, 0x35, 0x67, 0x67, 0x67, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0xA4, 0xA4, 0x35, 0x35, 0x35, 
        0x35, 0xA4, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x7A, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 
        0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x4B, 0x4B, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0x3F, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x3F, 0x3F, 0x3F, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0xB6, 0x50, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0xEB, 0xB7, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 
        0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 
        0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x07, 0x07, 0x07, 0x94, 0x07, 0x07, 0x94, 0x94, 0x94, 0x49, 0x27, 0x94, 0x94, 0xCC, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0x96, 0x2C, 
        0x4E, 0x2C, 0xAB, 0x36, 0x2B, 0xAC, 0x34, 0x38, 0x38, 0x44, 0x44, 0x44, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x44, 0xED, 0x44, 0x10, 
        0x10, 0x10, 0x10, 0x10, 0xD3, 0x38, 0x38, 0x10, 0x10, 0x44, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x24, 0x21, 0x90, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 
        0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x8E, 0x14, 0x80, 0x80, 0x14, 0x14, 0x80, 0x80, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90,
  0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x3B, 0x3B, 0x64, 0x3E, 0x3E, 0x39, 
        0x39, 0x46, 0x46, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x4A, 0x4A, 0x4A, 0xA4, 0xA4, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 
        0x64, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x45, 0x45, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x32, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0xA1, 0x4F, 0x2A, 0x2A, 0x7A, 0x4D, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0xF5, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 
        0x54, 0x54, 0xBE, 0xBE, 0x2D, 0xBE, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x50, 0x50, 0x50, 0xF7, 0xB6, 0x50, 0x50, 0x50, 0x54, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x4B, 0x4B, 0x4B, 0x56, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x33, 0x48, 0xA2, 0xA2, 0x48, 
        0x48, 0x48, 0x48, 0x33, 0x33, 0xB5, 0xB5, 0xB5, 0x4B, 0xEA, 0xEA, 0x3C, 0x3C, 0x3C, 0x54, 0xF7, 0xBE, 0x50, 0x50, 0x50, 0x2D, 0xB7, 0xEB, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0xA6, 0x6B, 0xA6, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x74, 0x74, 0xBB, 0xBB, 0xC1, 0xC1, 0xBB, 0xBB, 0xC1, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xC1, 0x07, 0xC1, 0x6D, 0x07, 0x65, 0xCC, 0x49, 0x49, 0x27, 0xD2, 
        0x41, 0x4E, 0x4E, 0x2B, 0xE4, 0x2B, 0x2B, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x38, 0x10, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0xAC, 0x36, 0x34, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x3A, 
        0x38, 0x38, 0x38, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x19, 0x24, 0x24, 
        0x24, 0x19, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x21, 0x21, 0x7D, 0x21, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 
        0x80, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x12, 0x78, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 
        0x0F, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80,
  0x68, 0xE8, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0x46, 0x46, 0xB0, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3E, 0x39, 0x39, 0xB0, 0xB0, 0x45, 
        0x43, 0x35, 0x35, 0x67, 0x67, 0x67, 0x4A, 0x32, 0x81, 0x81, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x48, 0xF5, 0x48, 0x48, 0xF5, 
        0xF5, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0x50, 0x50, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xC5, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6B, 0x6B, 0x6B, 
        0x0D, 0x0D, 0x0D, 0x88, 0x93, 0x75, 0x75, 0x75, 0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xC0, 0xC0, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0x6A, 
        0x6A, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x65, 0x94, 0x27, 0x27, 0x27, 0x96, 
        0x2C, 0xAB, 0xAB, 0x36, 0xAC, 0x34, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x59, 0x25, 0x25, 0x25, 0x25, 0x25, 0xF0, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x25, 0x25, 0x29, 0x25, 0x25, 0xF0, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 
        0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0xF0, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xD5, 0xD5, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 
        0x79, 0x26, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x29, 0x5E, 0x26, 0x26, 0xEF, 0x26, 0x26, 0x26, 0x28, 0x79, 0x79, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x12, 0x12, 0x12, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x91, 0x91, 0x91, 0x91, 0x91, 
        0x12, 0x12, 0x12, 0x12, 0x12, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x1E, 0x1E, 0x90,
  0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0x40, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x64, 
        0xD7, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x64, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0x46, 0x46, 0x45, 0x45, 0x45, 0x43, 0x35, 0x43, 0x43, 
        0x35, 0x67, 0x67, 0x67, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 
        0x4D, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0xF6, 0x56, 0x4B, 0x4B, 0x3C, 0xE0, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0xBE, 0xBE, 0xBE, 0xBE, 0xF7, 0x54, 0x54, 0x54, 0x54, 0xB6, 0x54, 0x54, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x54, 0x54, 0xB6, 0xB6, 0xB6, 0x54, 0xB6, 0x50, 0x50, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0xC5, 0x1C, 0xC5, 0x1C, 0x1C, 0x1C, 
        0x1C, 0xBF, 0xBF, 0x6A, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 
        0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 
        0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x49, 0x27, 0x27, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAB, 0x2B, 0x36, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xEC, 0x34, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x34, 
        0xBC, 0xBC, 0xAC, 0xBC, 0xEC, 0x34, 0x34, 0xBC, 0x34, 0xBC, 0xBC, 0x34, 0x34, 0xEC, 0xBC, 0x36, 0x36, 0xBC, 0xBC, 0xC8, 0xBC, 0xBC, 0x3A, 0x3A, 0x34, 0x38, 0x38, 0x38, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x79, 0x79, 0x19, 0x19, 
        0x19, 0x24, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x20, 0x20, 0x80, 0x80, 0x1E, 0x20, 0x20, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x22, 0xCD, 0x7D, 0x24, 0x24, 0x21, 0x24, 0x24, 0x24, 0x22, 0x22, 0x24, 
        0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x80, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x14, 0x14, 0x14, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 0x78, 
        0x78, 0x78, 0x78, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x14, 0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E,
  0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 
        0x47, 0x47, 0x47, 0x47, 0x76, 0x76, 0x76, 0x40, 0x40, 0x40, 0x3B, 0x64, 0x3E, 0x3E, 0x39, 0x46, 0x45, 0x45, 0x43, 0x35, 0x67, 0x4A, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x99, 0x99, 
        0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x4F, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x7A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x7A, 0x7A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 
        0xA5, 0xA5, 0x7A, 0x7A, 0xA5, 0xA5, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x48, 0x33, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 
        0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0xB6, 0xB6, 0xB6, 0xB6, 0xF7, 0xF7, 0xB6, 0xF7, 0xF7, 0xF7, 0x50, 0xF7, 0xF7, 0x50, 0x50, 0xF7, 0x2D, 0x2D, 0x2D, 0xB7, 0xB7, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0xA6, 0x6B, 0x0D, 0x0D, 
        0x0D, 0xC0, 0x75, 0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x9F, 0x9F, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x08, 0xA0, 0xA0, 0xA0, 0xA0, 0xA0, 
        0xA0, 0xA0, 0xA0, 0xA0, 0xB3, 0xA0, 0xB3, 0xB3, 0x8A, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0x94, 0x27, 0x2C, 0xAB, 0x36, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0x2B, 
        0xAC, 0xAC, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2B, 0x2B, 0x34, 0x34, 0xAC, 0x34, 0x38, 0xD3, 0xD3, 0xD3, 0x10, 0x10, 0x44, 0x59, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 
        0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 
        0x79, 0x26, 0x26, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 
        0x80, 0x14, 0x14, 0x14, 0x12, 0x12, 0x12, 0x91, 0x91, 0x91, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x77, 0x77, 0x77, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x0F, 0x12, 0x91, 0x91,
  0x7C, 0x68, 0x68, 0x68, 0xE8, 0x58, 0x58, 0xD9, 0xD9, 0x47, 0x47, 0x47, 0xBD, 0x3B, 0x3B, 0x3B, 0x3B, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 
        0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x67, 0xA4, 0x4A, 0x32, 0x32, 
        0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 
        0x4D, 0x4D, 0x2F, 0x4D, 0x4D, 0x2F, 0x2F, 0x6E, 0x48, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0xEA, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0x50, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 
        0x57, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0xBF, 0xBF, 0x6B, 0x6B, 0x6B, 0xA6, 0x0D, 0x0D, 0xA6, 0x0D, 0xA6, 0xA6, 0xA6, 0xA6, 0xBF, 0xB8, 0xB8, 0xBF, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 
        0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0x6B, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0xA0, 0xA0, 
        0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x27, 0x27, 0x27, 0x96, 0xD2, 0x96, 0x96, 0x96, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x27, 0x49, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x6D, 0x6D, 0x07, 0xCC, 0xCC, 0x65, 0x65, 0x49, 0x49, 0x49, 0x49, 0x49, 0xD2, 0x41, 0x41, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0xAC, 0xAC, 0x34, 0x38, 0x3A, 0x38, 0x38, 
        0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0xEE, 0x25, 0xAD, 0x44, 0x44, 0xED, 0x44, 0x44, 0x10, 0xED, 0xED, 0xED, 0x10, 0xED, 0x10, 0x44, 0xED, 0x10, 0xAD, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x7D, 0x7D, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x7D, 0x21, 
        0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 
        0x90, 0x90, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90,
  0x47, 0x47, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x46, 0x45, 0x43, 0x43, 0x43, 
        0x35, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 
        0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x45, 0x45, 0x43, 0x43, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x32, 0x81, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0xE0, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0x50, 0x50, 0xBE, 0x50, 0x50, 0x2D, 0x2D, 
        0x2D, 0x5C, 0x2D, 0x2D, 0x2D, 0xEB, 0xEB, 0xEB, 0xE1, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0xB1, 0xB1, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0xBF, 0xBF, 0x1C, 0x1C, 0xBF, 0xBF, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xBF, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 
        0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0x8D, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 
        0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x41, 0x41, 0x4E, 0xAB, 0x2B, 0x2B, 0x34, 0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x29, 0x26, 0x26, 
        0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0xF0, 0xF0, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x29, 0x29, 0x29, 0x26, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x5E, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x20, 0x1E, 0x20, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x22, 0x22, 0x22, 0x8B, 0x22, 0x24, 0x22, 0x22, 0x22, 0x22,
  0x3B, 0x3B, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x4C, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0xE8, 0x5D, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x3B, 0x3B, 0x3B, 0x64, 0xD7, 
        0xD7, 0xD7, 0xD7, 0x3E, 0xD7, 0xD7, 0xD7, 0xD7, 0x3E, 0x3E, 0xD7, 0x64, 0xD7, 0xD7, 0x3B, 0x3B, 0xD7, 0xD7, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x43, 0x43, 0x35, 0x35, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x81, 0x81, 0x53, 
        0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x30, 
        0x30, 0x99, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x7A, 0x7A, 0x7A, 0x4D, 0x4D, 0xA5, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0xBE, 0xF7, 0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0x1C, 0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 
        0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xB2, 0xA8, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xA0, 0x08, 
        0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x65, 0x49, 0x49, 0x49, 0x27, 0x27, 0x41, 0x41, 0x41, 0x41, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 
        0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xF0, 0x29, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x25, 0x25, 0x10, 0x44, 0x44, 0x10, 0x10, 0x3A, 0x38, 0x34, 0x3A, 0x3A, 0x34, 
        0x34, 0xAC, 0xAC, 0xEC, 0x34, 0xAC, 0xEC, 0xEC, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD3, 0xD3, 0xD3, 0xD3, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x3A, 0x3A, 0xD3, 0xD3, 0xD3, 0x3A, 0xD3, 0x3A, 0xD4, 0xD3, 0xD3, 0xD4, 0xD4, 
        0x10, 0x44, 0x44, 0x44, 0x44, 0x44, 0xEE, 0x25, 0x25, 0x5E, 0x5E, 0x5E, 0xEF, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x24, 0x24, 0x22, 0x22, 0x24, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 
        0x22, 0x22, 0x21, 0x21, 0x21, 0x22, 0x22, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x21, 0x90, 0x90, 0x90, 0x90, 0xCD, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x90,
  0xF4, 0xAF, 0xAF, 0xAF, 0x9E, 0x9E, 0x83, 0x72, 0x72, 0x72, 0x72, 0x72, 0x68, 0x68, 0xE8, 0x5D, 0x58, 0x58, 0x58, 0xD9, 0x4C, 0x4C, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x3B, 0x3B, 0x64, 0x64, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 
        0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 
        0x3E, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x81, 0x81, 0x81, 0x81, 0x53, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
        0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x99, 0x99, 0x4F, 0x2A, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x4B, 
        0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x54, 0x50, 0x50, 0xBE, 0xF7, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xEB, 0xEB, 0xC5, 0xC5, 0xEB, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x7E, 
        0xBF, 0xBF, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 
        0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 
        0x07, 0x07, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x07, 0x94, 0x27, 0x27, 0x27, 0xD2, 0xD2, 0x41, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAB, 0xAA, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 
        0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0xAB, 0x2C, 0x2C, 0x4E, 0xAB, 0xAA, 0x4E, 0xAA, 0xAA, 0x2C, 0x2C, 0xAA, 0xAA, 0xE4, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x36, 0xAC, 0xAC, 0x34, 0x34, 0x34, 0xC8, 0xC8, 0x34, 
        0x38, 0x38, 0x34, 0x38, 0x38, 0x3A, 0x10, 0x10, 0x10, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x79, 0x79, 0x28, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 
        0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 
        0x24, 0x22, 0x21, 0x21, 0x21, 0x22, 0x22, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x19, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26,
  0x58, 0xD9, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x39, 0x39, 0xB0, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x46, 0x46, 
        0x39, 0x39, 0x3E, 0x3E, 0x64, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x76, 0xBD, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 
        0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0x45, 0x43, 0x43, 0x43, 0x35, 0x67, 0x4A, 0x32, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x4F, 0xA1, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 
        0x3F, 0x3F, 0x54, 0x54, 0x54, 0xF7, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xBE, 0xF7, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xF7, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xF7, 0x2D, 0x2D, 0xF7, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 
        0x5C, 0x2D, 0x2D, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x7B, 0x7B, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xB3, 0xA0, 0xA0, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 
        0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0xCC, 0xCC, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x94, 0x27, 0x27, 0x27, 0x94, 0x27, 0x27, 0x27, 
        0x27, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0xD2, 0xD2, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0xAB, 0xAB, 0x36, 0x2B, 0x2B, 0xAC, 0x34, 0x34, 0x38, 0x38, 0x38, 0xD3, 0xD3, 0xD3, 0xD3, 0xD3, 0xD3, 0xD3, 
        0xD3, 0xD3, 0x10, 0x10, 0xD3, 0x10, 0x10, 0x38, 0xD3, 0xD3, 0x38, 0x10, 0x44, 0x38, 0x10, 0x10, 0x10, 0x44, 0x44, 0x44, 0x10, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x25, 0xEE, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 
        0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 
        0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x90,
  0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x9E, 0x83, 0x83, 0x83, 0x83, 0x83, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x7C, 0x7C, 0x68, 0x68, 0x68, 0x5D, 0x5D, 0x5D, 0x58, 0xD9, 0x4C, 0x47, 0x47, 0xBD, 0x3B, 
        0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x46, 0x46, 0xB0, 0xB0, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x46, 0x46, 0x46, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x81, 0x53, 0x53, 0x30, 0x30, 0x30, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 
        0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0xA5, 0x7A, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0xA1, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x7A, 0x7A, 0x7A, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x4D, 
        0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3F, 0x3F, 0xB6, 0x50, 0x50, 0x50, 0x2D, 0x5C, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x1C, 0xBF, 0xBF, 0xBF, 0xB8, 0xB8, 
        0xB8, 0xB8, 0xB8, 0xBF, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0xB1, 0xB1, 0x93, 0x88, 0x88, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0x0D, 0x0D, 0x88, 0xC0, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0xD2, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x96, 0x27, 0xD2, 0xD1, 0x41, 0x41, 0x41, 0x4E, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 
        0xAC, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x24, 0x24, 0x22, 0x22, 0x22, 0x22, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x7D, 0x24, 0x24, 0x24, 0x19, 0x19, 0x79, 0x79, 0x26, 
        0x5E, 0x29, 0x25, 0x10, 0xD4, 0xD3, 0x34, 0x36, 0x36, 0x36, 0x36, 0x2B, 0xAA, 0x2C, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xAC, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xED, 0xD4, 0x44, 0x44, 0x44, 0xAD, 0xAD, 0xAD, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x29, 0x26, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 
        0x21, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x19, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19,
  0x68, 0x68, 0x68, 0x68, 0x68, 0xE8, 0xE8, 0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0xB0, 0x46, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0x45, 0xB0, 0x45, 0x45, 0xB0, 0xB0, 0x46, 0x45, 0x45, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 
        0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x32, 0x32, 0x81, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0x53, 0x53, 0xB4, 0x53, 0x53, 0x53, 0xB4, 0x53, 0x53, 
        0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0xF6, 0x33, 0x56, 0x56, 0x56, 0x4B, 0xEA, 0x3C, 0xE0, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0xE0, 
        0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0x54, 0x54, 0x50, 0x50, 0xBE, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x5C, 0x5C, 0x5C, 0x5C, 0x57, 0x57, 0xC5, 0xC5, 0xEB, 0xEB, 0xEB, 0xEB, 0xB7, 0xEB, 
        0xEB, 0xC5, 0xC5, 0xEB, 0xC5, 0x57, 0xEB, 0xEB, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0xBF, 0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x6B, 0x6B, 0xA6, 
        0x6B, 0x6B, 0xBF, 0xBF, 0x6B, 0xA6, 0xBF, 0xA6, 0x6B, 0xA6, 0x0D, 0x0D, 0x0D, 0xC0, 0x75, 0xB1, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0xB3, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x94, 
        0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x94, 0x94, 0x94, 0x07, 0x94, 0x94, 0x07, 0x65, 0x65, 0x07, 0x65, 0x94, 0x07, 0x07, 0xCC, 0xCC, 0xCC, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x2C, 
        0x2C, 0x2C, 0xAB, 0xE4, 0x36, 0x36, 0xAC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0xAD, 
        0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x44, 0xAD, 0xAD, 0x25, 0x25, 0x25, 0x25, 0xAD, 0x25, 0x25, 0x10, 0x25, 0x25, 0x25, 0x29, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x29, 0xF0, 0x29, 0x29, 0x29, 0x26, 
        0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x28, 0x19, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x29, 0x26, 0xEF, 0x26, 0xEF, 0xEF, 0x26, 0x26, 0xEF, 0x26, 0xEF, 0x29, 0x26, 0x29, 0x87, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26,
  0xD9, 0xD9, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0x4C, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0x3B, 0x3B, 0x3B, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 
        0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x4A, 0x4A, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 
        0x45, 0x45, 0x45, 0x43, 0x43, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x67, 0xA4, 0xA4, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0xA5, 0xA5, 0x2F, 0x2F, 0x4D, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x4D, 0x7A, 0x7A, 0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0x7A, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x33, 0x56, 
        0x56, 0x4B, 0x4B, 0xEA, 0x3C, 0x3C, 0xE0, 0xE0, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0x54, 0xF7, 0xBE, 0x54, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0xF7, 0xB6, 0xF7, 0x54, 0x54, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 
        0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0xB6, 0xB6, 0xB6, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 0x57, 0x1C, 0x1C, 0x1C, 0x6A, 0xB8, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0x93, 0x75, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 0x0E, 
        0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x8A, 0xA0, 0xA0, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0xBB, 
        0x08, 0x08, 0xBB, 0xC1, 0xC1, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x94, 0xCC, 0xCC, 0x94, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xE4, 0xAA, 0x36, 0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x2B, 0x36, 0x36, 0x2B, 
        0x2B, 0x36, 0x36, 0xAB, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x41, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0x27, 0xD2, 0x96, 0xD1, 0x2C, 0x2C, 0x2C, 0x2B, 0x36, 0x36, 0x36, 0xEC, 0x3A, 0x3A, 0x3A, 0xED, 0x44, 0x10, 
        0x25, 0x25, 0x25, 0x25, 0x26, 0x5E, 0x25, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x26, 0x5E, 0xEF, 0xEF, 0x26, 0x26, 0x26, 0x29, 0x5E, 0x26, 0xEF, 0xEF, 0xEF, 0x29, 0x26, 0x26, 0x87, 0x26, 0x29, 0x26, 0x29, 0x26, 0x26, 0x29, 0x87, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x24, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 
        0x90, 0xCD, 0xCD, 0x22, 0x21, 0x21, 0x22, 0x7D, 0x24, 0x24, 0x22, 0x24, 0x8B, 0x24, 0x24, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x19, 0x19, 0x19, 0x19,
  0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 0x5D, 0x5D, 0xE8, 0xE8, 0xE8, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0xE8, 0xE8, 0xE8, 0x58, 0x58, 0x58, 0x58, 0x4C, 0x4C, 0x47, 0x47, 0xBD, 0xBD, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 
        0x3E, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0xB0, 0x46, 0x46, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 
        0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0xB0, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 0x81, 0x81, 0x81, 0xB4, 0x53, 0x53, 0x53, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 
        0x30, 0x99, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x4D, 0x7A, 0x7A, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x33, 
        0x56, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0xC5, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 
        0x0D, 0xC0, 0xC0, 0xB1, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xC6, 0xC6, 0xE2, 0xCB, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0xA7, 0x0C, 0xB2, 0xB2, 0xB2, 0x8D, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x8D, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0xA8, 0xB2, 
        0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xCB, 0xCB, 0xCB, 0xCB, 0xCB, 0xE2, 0xE2, 0x9F, 0x8F, 0xCB, 0xCB, 0x8F, 0xCB, 0x8F, 0x8F, 0x0C, 0x0C, 0x0C, 0xA7, 0xA7, 0xBA, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 
        0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x07, 0x07, 0x07, 0x07, 0x94, 0x27, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xC7, 0x36, 0x36, 0x34, 0x34, 0x34, 0x34, 0x38, 0x38, 0x38, 0x38, 0x38, 0x38, 
        0x38, 0x38, 0x38, 0x10, 0x10, 0x10, 0x10, 0x38, 0x38, 0x38, 0x38, 0x38, 0x34, 0x34, 0x38, 0x38, 0x38, 0x34, 0x34, 0x34, 0x34, 0x3A, 0x3A, 0x3A, 0xBC, 0xBC, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0xD3, 0x38, 0x38, 0x38, 0x38, 0x38, 
        0x38, 0x10, 0x10, 0x10, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0xF0, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xAD, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0xD3, 0x3A, 0x38, 0x34, 0x34, 0x34, 0x34, 0x34, 0xAC, 0xAC, 0x36, 0x2B, 0x2B, 
        0xAC, 0xAC, 0xAC, 0xEC, 0xEC, 0x34, 0x34, 0x34, 0x34, 0xD3, 0xD3, 0x10, 0x44, 0x44, 0x44, 0x44, 0xD5, 0xAD, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x22, 0x22, 0x22, 0x22, 0x22, 
        0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0xDB, 0x80, 0x80, 0x1E, 0x1E, 0x18, 0x80, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14, 0x78, 0x78, 0x14, 0x14, 0x14, 0x14, 0x14,
  0xE8, 0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 
        0x47, 0x76, 0x40, 0x40, 0x3B, 0x64, 0x3E, 0x3E, 0x39, 0x39, 0x46, 0x46, 0x46, 0xC3, 0xC3, 0xC3, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x39, 0x3E, 0x3E, 0x3E, 
        0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0xD7, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0xB0, 0xB0, 0x45, 0x43, 0x43, 0xE9, 0x67, 0x4A, 0x4A, 0x32, 0xB4, 0x30, 0x30, 0x4F, 0x4F, 0x4F, 
        0x2A, 0xA5, 0xA5, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x6E, 0xA2, 0x6E, 0x6E, 0x6E, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x2F, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 
        0x2F, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x6E, 0x48, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x56, 0x56, 0x4B, 0x4B, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0xBE, 0xF7, 0xF7, 0xF7, 0xF7, 0xBE, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 
        0x2D, 0x2D, 0xEB, 0xEB, 0xB7, 0xEB, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0xA6, 0x6B, 0xBF, 0xBF, 0xA6, 0xA6, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0x1C, 0x6A, 0xBF, 0xBF, 0xB8, 0x6A, 0x6A, 0xB8, 0xB8, 
        0xA6, 0x0D, 0x0D, 0x0D, 0x88, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 
        0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0x07, 0x94, 0xCC, 0x65, 0x94, 0x94, 0x94, 0x94, 
        0x27, 0x94, 0x94, 0x27, 0x96, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0x2C, 0x2C, 0xAA, 0x36, 0x36, 0x36, 0x36, 0xBC, 0x34, 0xAC, 0x34, 0xD3, 0x10, 0x38, 0x38, 0x10, 0x10, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 
        0x29, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 0x29, 0x25, 0x25, 0x25, 0x10, 0x10, 0x10, 0x44, 0x44, 0x44, 0x3A, 0x3A, 0xD4, 0xD4, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x29, 0x26, 0x26, 0x19, 0x19, 0x19, 0x19, 0x24, 0x22, 0x24, 0x24, 0x21, 
        0x21, 0x21, 0x21, 0x21, 0x21, 0x24, 0x24, 0x21, 0x21, 0x24, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x69, 0x69, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x44, 0xAD, 0xAD, 0x10, 0x44, 0x44, 0x44, 
        0x10, 0x10, 0x10, 0x44, 0x44, 0x44, 0xED, 0x44, 0x44, 0x44, 0x44, 0xD5, 0xD5, 0xC9, 0xC9, 0x29, 0xF0, 0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x24,
  0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3E, 0x39, 0x39, 
        0x39, 0x46, 0x46, 0x45, 0x45, 0x43, 0xC3, 0x35, 0x35, 0x35, 0x35, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x45, 0x46, 0x39, 0x39, 0x3E, 0xD7, 0x3B, 0x3B, 0x40, 0xBD, 0x47, 0x47, 0x4C, 0x4C, 0x58, 0x58, 0x58, 0x58, 0x5D, 0x5D, 
        0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x9A, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0x40, 0x3B, 0x3B, 0xD7, 0x3E, 0x39, 0xB0, 0xB0, 0x43, 0x43, 0x35, 0x35, 0xA4, 0x4A, 0x32, 0x53, 0x30, 0x30, 0x99, 
        0x4F, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0x2F, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x4F, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x48, 0x33, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3F, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 
        0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0xC4, 0xC4, 0x50, 0xBE, 0x50, 0x2D, 0x2D, 0x2D, 0xEB, 0xC5, 0xC5, 0xC5, 0x1C, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0x9F, 0xCB, 0x0C, 0x0C, 0x0C, 
        0x0C, 0xA7, 0xA7, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0x08, 0x08, 0x74, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xBB, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0x08, 
        0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0x7B, 0xB3, 0xB3, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 0xB3, 0x0B, 
        0x0B, 0x0B, 0xB3, 0xE3, 0xA0, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x94, 0x27, 0xD2, 0x96, 0x2C, 0x2C, 0xAA, 0x36, 0xAC, 0xBC, 0xEC, 0x38, 0x38, 0x38, 0x34, 0x38, 0x38, 0x44, 0x10, 0xD5, 0x25, 0x25, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x29, 0x25, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xEE, 0xD5, 0x10, 0x10, 0x44, 0x44, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x44, 0x44, 0x10, 0x25, 0x25, 0x10, 0x10, 0xAD, 0xAD, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x79, 0x19, 0x79, 0x19, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x19, 0x79, 0x26, 0x26, 0x26, 
        0x87, 0x26, 0x26, 0x29, 0x5E, 0x25, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x29, 0x29, 0x25, 0x5E, 0x5E, 0x29, 0x29, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x79,
  0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x76, 0x76, 
        0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0xBD, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 
        0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0xC3, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x67, 0x4A, 0x32, 0x32, 0x81, 0x53, 0x53, 0x30, 0x99, 0x2A, 0x2A, 0x2A, 0x2A, 0x7A, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x4D, 0x4D, 
        0xA5, 0xA5, 0xA5, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 
        0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0x2A, 0x2A, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x48, 0x48, 0xF5, 0x33, 0x56, 0xB5, 0x4B, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x54, 0x50, 0x50, 0xBE, 0xF7, 0xBE, 0x50, 0x50, 0x2D, 0x2D, 0x2D, 0x2D, 
        0x2D, 0x2D, 0x2D, 0xB7, 0xC5, 0xC5, 0x57, 0x57, 0x57, 0x57, 0x57, 0xC5, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0x6A, 0xBF, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0xC0, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0xCB, 0x0C, 0x0C, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 
        0xB3, 0xA0, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xC1, 0xC1, 0xC1, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xA0, 0xA0, 0xA0, 0xB3, 0xB3, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x8A, 0x8A, 0x8A, 0x8A, 0x8A, 0x7B, 0x08, 0x08, 0x08, 0xDD, 0xDA, 0x07, 0x07, 0x07, 0x65, 0x49, 0x27, 0x27, 0x96, 0x96, 0x96, 0xAB, 0x4E, 0x4E, 0x2C, 0x2B, 0x4E, 
        0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x36, 0x2B, 0xAB, 0xAA, 0xAA, 0xAB, 0xAA, 0x2C, 0xAA, 0xAA, 0x2C, 0xAA, 0xAA, 0xAB, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0xAA, 0xAA, 0xAA, 
        0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0xBC, 0xBC, 0xC8, 0x3A, 0x3A, 0xD3, 0xF9, 0x10, 0x10, 0x59, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x29, 0x87, 0x26, 0x26, 0x29, 0x26, 0x29, 0x29, 0x26, 0x26, 0x26, 0xF0, 0x5E, 
        0x5E, 0xD5, 0xD5, 0x44, 0x44, 0x44, 0x44, 0x44, 0xD4, 0xD4, 0xD4, 0xED, 0x44, 0x44, 0xED, 0xED, 0xD4, 0x44, 0x44, 0x44, 0xAD, 0xAD, 0x44, 0x44, 0xD5, 0x44, 0x44, 0xAD, 0xD5, 0xD5, 0xD5, 0x25, 0x25, 0x25, 0x25, 0xF0, 0x29, 0x29, 0x29, 0x29, 0x29, 
        0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x19, 0x19, 0x19, 0x19, 0x19, 0x24, 0x24, 0x24, 0x24, 0x24, 0x24, 0x22, 0x21, 0x21, 0x21, 0x21, 0x22, 0x21, 0x22, 0x21, 0x21, 0x22,
  0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x7C, 0x7C, 0x7C, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0xE8, 0xE8, 0xE8, 0xE8, 0x5D, 0x5D, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x40, 0x40, 0x40, 0x3B, 0x64, 0x3E, 
        0x3E, 0x3E, 0x39, 0x39, 0x46, 0x45, 0x45, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x45, 0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x39, 0x3E, 0x3E, 0x3E, 0x64, 0xD7, 0xD7, 0xD7, 0xD7, 
        0xD7, 0x64, 0xD7, 0x3E, 0x3E, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x39, 0x39, 0x46, 0xB0, 0x46, 0x45, 0x45, 0x43, 0x43, 0x43, 0x43, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x32, 0x32, 
        0x32, 0x32, 0x32, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0xA5, 
        0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0x48, 0x48, 0x48, 0x33, 0x33, 0x33, 0x33, 0x56, 0xB5, 0x4B, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x54, 0x54, 0xBE, 0xBE, 0x2D, 0x2D, 0x2D, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 0xBF, 
        0xBF, 0xA6, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x88, 0x0D, 0x0D, 0xC0, 0xC0, 0xC0, 0x75, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0x0E, 0xE2, 0xC6, 0xE2, 0xCB, 
        0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xA7, 0x8D, 0x8D, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0xA8, 0x8D, 0xB2, 0xA8, 0xA8, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 
        0xB3, 0xB3, 0xB3, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xDD, 0xDD, 0xBB, 0xDA, 0x6D, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0xDA, 0xBB, 0xBB, 0xC1, 
        0xBB, 0xBB, 0xDA, 0x6D, 0x6D, 0xC1, 0xC1, 0xC1, 0x07, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0x07, 0x65, 0xCC, 0x94, 0x94, 0xCC, 0x94, 0x94, 0x27, 0x27, 0x27, 0x27, 0x96, 0xD2, 0xD2, 0x96, 0x2C, 0xAB, 0xAB, 
        0xAB, 0xE4, 0x36, 0x36, 0x34, 0xEC, 0x34, 0xD3, 0xD3, 0xED, 0xED, 0x44, 0x44, 0xAD, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x10, 0x10, 0x44, 0x10, 0x10, 0x10, 0x10, 0xD4, 0x10, 0xD4, 0xD4, 0xD4, 0x3A, 
        0x3A, 0x3A, 0x34, 0x34, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0x3A, 0xD4, 0xD4, 0xD3, 0xD3, 0xD4, 0xD4, 0x44, 0xAD, 0xD5, 0x25, 0x25, 0x29, 0x29, 0x87, 0x26, 0x26, 0x19, 0x19, 0x24, 0x24, 0x21, 0x21, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x1E, 0x80, 
        0x80, 0x80, 0x80, 0x80, 0x80, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x21, 0x24, 0x24, 0x24, 0x24, 0x19, 0x79, 0x79, 0xEF, 0xEF, 0xEF, 0x5E, 0xD5, 0xD5, 0xD5, 0x44, 0x44, 0x44,
  0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x83, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x68, 0x68, 0x7C, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0x68, 0xE8, 0x5D, 0x5D, 0x5D, 0x58, 
        0x58, 0x58, 0x4C, 0x47, 0x47, 0xBD, 0x40, 0x3B, 0xD7, 0x3E, 0x39, 0x39, 0x46, 0x43, 0x43, 0x35, 0x67, 0x4A, 0x32, 0x32, 0x32, 0x81, 0x81, 0x81, 0x81, 0x81, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x4A, 0x67, 0x67, 0x67, 0x35, 0x35, 0x43, 0x45, 
        0x45, 0xB0, 0xB0, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0x46, 0xC3, 0xC3, 0xC3, 0x43, 0x35, 0x35, 0x35, 0x35, 0x35, 0xA4, 0xA4, 
        0xA4, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 
        0x2A, 0x2A, 0xA5, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x2F, 0x6E, 0x6E, 0x48, 0xA2, 0x48, 0x48, 0x48, 0x33, 0x56, 0x4B, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0xB6, 0x50, 0x50, 0x2D, 0x50, 0x2D, 0x5C, 0x5C, 0xEB, 0xC5, 
        0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x6A, 0x6A, 0xB8, 0xB8, 0x6B, 0xA6, 0xA6, 0x0D, 0x0D, 0x0D, 0xA6, 0xA6, 0xA6, 0xB8, 0xBF, 0xBF, 0x6A, 0x1C, 0x6A, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 
        0x5C, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x6A, 0x6A, 0x6A, 0x6B, 0x0D, 0x0D, 0x0D, 0x93, 0x93, 0x75, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xCB, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 
        0xA8, 0x0B, 0x0B, 0xB3, 0xB3, 0x08, 0x08, 0xDD, 0x6D, 0xC1, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0xD2, 0x27, 0x96, 0x96, 0xD2, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x94, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0xD2, 0x96, 0x2C, 0xAA, 0x2B, 0x36, 0x36, 0x34, 0x34, 0x34, 0xD3, 0xD3, 0x38, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x44, 0x44, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x25, 0x25, 0x10, 0x10, 0x25, 0x25, 0x25, 
        0x25, 0x25, 0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0x25, 0xAD, 0x10, 0x10, 0xED, 0xD4, 0xD4, 0x3A, 0x3A, 0x3A, 0xBC, 0xBC, 0x3A, 0xBC, 0xBC, 0xBC, 0xBC, 0x36, 0x36, 0xBC, 0xBC, 0xBC, 0xEC, 0x3A, 0x3A, 0xD4, 0x44, 0x44, 0x44, 0x10, 0x25, 
        0xAD, 0x25, 0x25, 0x25, 0x29, 0x29, 0x25, 0x5E, 0x26, 0x26, 0x26, 0xEF, 0x79, 0x26, 0x28, 0x79, 0x19, 0x19, 0x79, 0x79, 0x79, 0x79, 0x24, 0x24, 0x24, 0x24, 0x24, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 
        0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x21, 0x90, 0x90, 0x21, 0x21, 0x90, 0x90, 0x90, 0x90, 0x21, 0x21, 0x21,
  0x83, 0x83, 0x83, 0x83, 0x83, 0x83, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x72, 0x7C, 0x68, 0x68, 0x68, 0x68, 0x68, 0xE8, 0x5D, 0x5D, 0x58, 0x58, 0xD9, 0x4C, 0x4C, 0x47, 
        0x47, 0x47, 0x40, 0x40, 0xBD, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0xB0, 0x46, 0x46, 0x45, 0x43, 0x35, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 
        0x4A, 0x32, 0x32, 0x32, 0x81, 0x53, 0x53, 0x53, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x99, 0xA1, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x4F, 0x4F, 0x99, 0x30, 0x30, 0x30, 
        0x53, 0x53, 0x53, 0xB4, 0xB4, 0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x35, 0x67, 0x67, 0x67, 0x67, 0x4A, 0x4A, 0x4A, 0xA4, 0x32, 0x32, 0x32, 0xB4, 0x53, 0x53, 0x30, 0x30, 0x99, 0xA1, 0xA1, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x2F, 0x2F, 0x2F, 
        0x2F, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0xA2, 0x48, 0x33, 0x48, 0x48, 0x33, 0x56, 0x56, 0x56, 0x33, 0x56, 0x4B, 0xB5, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x3F, 0x54, 0xB6, 0x50, 0x50, 0x50, 0x50, 0x50, 0xF7, 0xF7, 0xF7, 
        0xF7, 0xF7, 0x2D, 0x2D, 0x2D, 0x2D, 0x5C, 0x2D, 0xEB, 0xC5, 0xEB, 0xEB, 0xC5, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x1C, 0x7E, 0xB8, 0xB8, 0xBF, 0xBF, 0x6A, 0xBF, 0xB8, 0x6A, 0xBF, 0xA6, 0x6B, 0x6B, 0x6B, 0x6B, 
        0xB8, 0x6B, 0x6B, 0x0D, 0x6B, 0x6B, 0x6B, 0x6A, 0x6B, 0x6B, 0x6B, 0x6B, 0x6B, 0x6B, 0x6B, 0x0D, 0x0D, 0x0D, 0x0D, 0x88, 0x88, 0xC0, 0x0D, 0x93, 0xCF, 0xC0, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 
        0x0B, 0xB3, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xC1, 0xC1, 0xBB, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xC1, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0x08, 0x08, 0xBB, 0xBB, 0x08, 0xBB, 0x08, 
        0x08, 0x08, 0xBB, 0xBB, 0x74, 0x08, 0xBB, 0xC1, 0xC1, 0xBB, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x94, 0x94, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0xAA, 0x2C, 0xAB, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 
        0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x96, 0x96, 0x2C, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0xBC, 0xBC, 0x3A, 0xD4, 0xD4, 0x3A, 0xD4, 0xD4, 0xD4, 0x44, 0x44, 0x44, 0x44, 0x44, 0xAD, 0xD5, 
        0xAD, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x44, 0x10, 0x44, 0x44, 0x25, 0x25, 0x10, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x29, 0x25, 0x25, 0x29, 0x29, 0x26, 0x26, 0x29, 0x29, 0x29, 0x26, 0x29, 0x29, 0x26, 0x26, 0x26, 0x29, 0x29, 0x29, 0x87, 0x29, 
        0x29, 0x29, 0x29, 0x29, 0x29, 0x26, 0x26, 0x29, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x19, 0x26, 0x79, 0x26, 0x26, 0x26, 0x26,
  0x68, 0x68, 0x68, 0x5D, 0x5D, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0x58, 0xD9, 0xD9, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0x58, 0x58, 0xD9, 0xD9, 0xD9, 0xD9, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0xBD, 0xBD, 0x40, 0x3B, 0x3B, 0xD7, 
        0x3E, 0x39, 0x39, 0x46, 0x46, 0x45, 0x45, 0x43, 0x35, 0x35, 0x67, 0x67, 0x67, 0x35, 0x67, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0x4A, 0xA4, 0x67, 0x4A, 0x4A, 0xA4, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x43, 0x43, 0x43, 0x43, 0x43, 0x45, 
        0x45, 0x45, 0x45, 0x46, 0x46, 0x46, 0x39, 0x39, 0x39, 0x39, 0x39, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x39, 0x39, 0x46, 0x46, 0x46, 0x46, 0xC3, 0x43, 0x43, 0x43, 0x35, 0x67, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0xB4, 0x53, 0x53, 0x53, 0x53, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x99, 0x4F, 0x4F, 
        0x4F, 0x4F, 0x4F, 0x4F, 0x4F, 0x2A, 0x2A, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x4D, 0x2F, 0x2F, 0x2F, 0xA2, 0xA2, 0x48, 0x33, 0xB5, 0xB5, 0x3C, 0x3C, 0x3F, 0x3F, 0x54, 0x50, 0x50, 0x50, 0x2D, 0x5C, 0xB7, 0x57, 0x57, 0x57, 0x57, 0x1C, 0x1C, 0x1C, 0x1C, 
        0x1C, 0xBF, 0xBF, 0xBF, 0xBF, 0x6B, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0xBF, 0x6A, 0x6A, 0x1C, 0x1C, 0x1C, 0x1C, 0x57, 0x57, 0x57, 0x57, 0x57, 0x57, 0xB7, 0xB7, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0x2D, 0xC5, 0xC5, 0xC5, 0x1C, 0x1C, 
        0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0xB1, 0x0E, 0x0E, 0x0E, 0xE2, 0xCB, 0xCB, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 
        0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0xA8, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0x0B, 0xB3, 0xB3, 0xB3, 0xA0, 0xA0, 0xA0, 0x08, 0x08, 0x08, 0x08, 0xBB, 0xBB, 0xDA, 0xC1, 0xC1, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 
        0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x07, 0x65, 0x65, 0x07, 0x94, 0x94, 0x94, 0x94, 0xA9, 0x27, 0x27, 0x27, 0x96, 0x96, 0x96, 0x2C, 0x2C, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0x36, 0x36, 0x36, 0xAA, 0xAA, 0xAA, 
        0xAA, 0xAA, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x96, 0x96, 0x96, 0x96, 0xD2, 0x27, 0x27, 0x27, 0x27, 0x96, 0x27, 0x27, 0x2C, 0xAA, 0xAA, 0x2C, 0xAA, 0x36, 0x36, 0x36, 0x36, 0x3A, 0x3A, 0xD4, 0xD4, 0xED, 0x10, 0x44, 0x10, 0x10, 0x44, 0xD5, 0xAD, 0x10, 
        0xAD, 0xD5, 0xD5, 0xD5, 0xD5, 0xD5, 0x25, 0xD5, 0x5E, 0xEE, 0x25, 0x25, 0xD5, 0xEE, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0x5E, 0x26, 0xEF, 0x26, 0x26, 0x26, 0xEF, 0xEF, 0x26, 0xEF, 0xEF, 0x26, 0x69, 0x71, 0x69, 0x26, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 
        0x26, 0x26, 0x26, 0x26, 0x26, 0x79, 0x79, 0x79, 0x79, 0x79, 0x19, 0x79, 0x79, 0x79, 0x79, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26, 0x26,
  0x4C, 0x47, 0x47, 0xBD, 0x40, 0x40, 0x40, 0x40, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x3B, 0x40, 0x40, 0x40, 0xBD, 0xBD, 0x47, 0x47, 0x47, 0x47, 0x47, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x4C, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 0x47, 
        0x47, 0x47, 0x47, 0xBD, 0x40, 0x3B, 0x3B, 0x64, 0xD7, 0x3E, 0x3E, 0x3E, 0x39, 0x39, 0x46, 0x45, 0x45, 0x43, 0x43, 0x35, 0x35, 0x35, 0xA4, 0xA4, 0x4A, 0x4A, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x81, 0x32, 0x32, 0x32, 0x32, 0x32, 
        0x32, 0x32, 0x4A, 0x4A, 0x4A, 0x4A, 0x67, 0xA4, 0x67, 0x67, 0x67, 0x67, 0x67, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x67, 0xE9, 0xE9, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 0x35, 
        0x35, 0x35, 0x35, 0xA4, 0xA4, 0xA4, 0x4A, 0x32, 0x32, 0x32, 0xB4, 0xB4, 0x30, 0x30, 0x30, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0xA5, 0xA5, 0x4D, 0x4D, 0x4D, 0x4D, 0x2F, 0x2F, 0x4D, 0x4D, 0x4D, 0x4D, 0xA5, 0x7A, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x4F, 0x99, 
        0x99, 0x99, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x99, 0x99, 0x99, 0x4F, 0x2A, 0x2A, 0x2A, 0x4D, 0x2F, 0x2F, 0xA2, 0x48, 0x33, 0x33, 0x33, 0x56, 0x4B, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3F, 0x54, 0x3F, 0x3F, 0xC4, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 0x3F, 
        0x3F, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3C, 0x3F, 0x3F, 0x3C, 0x3C, 0xC4, 0x3F, 0x54, 0xB6, 0xB6, 0x54, 0xB6, 0xB6, 0xB6, 0xB6, 0xB6, 0xB6, 0xB6, 0x50, 0xB6, 0xB6, 0xB6, 0xF7, 0x50, 0x50, 0x50, 0x50, 0xBE, 0x2D, 0x5C, 0x5C, 0xC5, 0x1C, 
        0x1C, 0xBF, 0xBF, 0xA6, 0x0D, 0x0D, 0xC0, 0xB1, 0x0E, 0x0E, 0xE2, 0xE2, 0x0C, 0x0C, 0x0C, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xA8, 0xB2, 0xB2, 0xB2, 0x0C, 0xB2, 0xB2, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 0x0C, 
        0xB2, 0xB2, 0xA8, 0x0B, 0x0B, 0x0B, 0xB3, 0x7B, 0xA0, 0x08, 0x08, 0x74, 0xBB, 0xBB, 0xC1, 0x07, 0x07, 0xCC, 0xCC, 0x94, 0x27, 0x27, 0x96, 0x96, 0xD1, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0x4E, 0x2B, 0x2B, 0x2B, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 
        0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 0x36, 0x36, 0x2B, 0x2C, 0x2C, 0x2C, 0xD1, 0x2C, 0x41, 0x2C, 0x96, 0x96, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x2C, 0x4E, 0xAB, 0xE4, 0x2B, 0x2B, 0x2B, 0x2B, 0x2B, 
        0x2B, 0xAA, 0x2B, 0x36, 0x36, 0x36, 0x2B, 0x34, 0x34, 0x34, 0x34, 0x34, 0xBC, 0x3A, 0x3A, 0xD4, 0xD4, 0x44, 0x44, 0xAD, 0xD5, 0xEE, 0x25, 0x25, 0x25, 0x29, 0x29, 0x29, 0x26, 0x26, 0x26, 0x26, 0x26, 0x29, 0xF0, 0x29, 0x29, 0x29, 0x29, 0x29, 0x25, 
        0x29, 0x29, 0x25, 0x25, 0x25, 0x25, 0x25, 0x44, 0x44, 0x44, 0x10, 0x10, 0xAD, 0xEE, 0xEE, 0xD5, 0x25, 0xD5, 0x25, 0xEE, 0x5E, 0xD5, 0xD5, 0x25, 0x25, 0xD5, 0xD5, 0xC9, 0xC9, 0xAD, 0x5E, 0x5E, 0x5E, 0x29, 0x25, 0x5E, 0x5E, 0x29, 0x25, 0xEE, 0x25, 
        0x5E, 0x5E, 0x29, 0x29, 0x28, 0x19, 0x19, 0x79, 0x19, 0x24, 0x24, 0x21, 0x21, 0x21, 0x90, 0x90, 0x90, 0x1E, 0x1E, 0x1E, 0x1E, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90
};

GUI_CONST_STORAGE GUI_BITMAP bmBackGround_480x272 = {
  480, // xSize
  272, // ySize
  480, // BytesPerLine
  8, // BitsPerPixel
  _acBackGround_480x272,  // Pointer to picture data (indices)
  &_PalBackGround_480x272   // Pointer to palette
};

/*********************************************************************
*
*       Guitar In/Out
*/
static GUI_CONST_STORAGE unsigned long _acGuitarInOut[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFE6D7085, 0xFD999CB1, 0xF8ACAFC4, 0xF66F7588, 0xF96B7184, 0xFD7B8597, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE828699, 0xFC7F8395, 
        0xF588889A, 0xE5656577, 0xCC3B3B4D, 0xBF36384A, 0xCF46485A, 0xE9636779, 0xF9828698, 0xFE8D94A3, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD454C5F, 0xF6565A6D, 0xE544485A, 
        0xC609091B, 0x99171729, 0x6D3F3F51, 0x5C5D5F71, 0x74353749, 0xA40D1123, 0xD4333749, 0xEF575E6D, 0xFB5E6574, 0xFE727C8D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD5D6271, 0xF7808090, 0xE7767785, 0xC84F4C5B, 0x9C201D2C, 
        0x6A57505F, 0x3E9992A1, 0x21908998, 0x17716D79, 0x26716D79, 0x4A73717D, 0x8044424E, 0xB812121E, 0xE1666672, 0xF56A707D, 0xFD4F5365, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD79808F, 0xF77D808F, 0xE87D8291, 0xCB4B4B5B, 0xA01F202E, 0x6D4C4958, 0x3F83808F, 
        0x219E97A6, 0x0E87808F, 0x04696271, 0x027E7A86, 0x0674707C, 0x146D6B77, 0x309694A0, 0x5C757581, 0x96171723, 0xC9343A47, 0xEA767A8C, 0xF96B7281, 0xFE63697C, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD616173, 0xF8858194, 0xEA8A8993, 0xCE655F6A, 0xA227212C, 0x70504A55, 0x4396909B, 0x23756B77, 0x0E493E48, 
        0x06493E48, 0x021D121C, 0x00251A24, 0x003D323C, 0x00312630, 0x02342B35, 0x0A3F3640, 0x1B766F76, 0x3E898289, 0x7154505B, 0xA9282332, 0xD8696773, 0xF17D7D8D, 0xFC7E8190, 0xFE585E71, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD5C6475, 0xF9969AAC, 0xEB808092, 0xD04A4659, 0xA6302F39, 0x74423C47, 0x4578727D, 0x235C5661, 0x10120C17, 0x06190F1B, 0x022E232D, 
        0x00352A34, 0x00483D47, 0x00493E48, 0x00463B45, 0x003F343E, 0x002B222C, 0x020A010B, 0x04413A41, 0x10575057, 0x263E3A45, 0x4F736E7D, 0x87292733, 0xBD343444, 0xE3767988, 0xF67E8497, 0xFD71788B, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE6C7082, 0xF97F7F91, 0xED928D9C, 0xD36E6474, 0xA9352838, 0x77453848, 0x487E767D, 0x265F575E, 0x10281D25, 0x064E434B, 0x026F646C, 0x00786D75, 0x007C7076, 
        0x006E6268, 0x00887C82, 0x0060545A, 0x007B6F75, 0x007A6E74, 0x00877C7F, 0x0083787B, 0x006D6467, 0x02352C2F, 0x081E151F, 0x16504751, 0x33756D77, 0x62574F59, 0x9C292530, 0xCD4E4E5C, 0xEC868795, 0xFA797D8F, 0xFE5A6174, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE677587, 0xFA576173, 0xEE85899B, 0xD57D7D8F, 0xAE373241, 0x7C352B3B, 0x4B766979, 0x287F7282, 0x12574F56, 0x06625A61, 0x02776C74, 0x006D626A, 0x00443941, 0x003E333B, 0x002F2329, 
        0x0032262C, 0x0030242A, 0x001E1218, 0x002E2228, 0x002D2127, 0x004A3F42, 0x004B4043, 0x00635A5D, 0x00847B7E, 0x00615862, 0x04403741, 0x0C3E3640, 0x1F544C56, 0x43696570, 0x77393947, 0xB0292A38, 0xDC636779, 0xF3747B8E, 0xFC525D73, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE8E93A8, 0xFA65667B, 0xEF5C5B6B, 0xD88C8697, 0xB04A4352, 0x7F312636, 0x4F706672, 0x2A9B8D99, 0x14857580, 0x084C3C47, 0x026B6167, 0x0063595F, 0x003C3238, 0x00342A30, 0x002C2326, 0x0022191C, 0x001F1619, 
        0x001D1417, 0x001A1114, 0x00261D20, 0x002E2627, 0x00120A0B, 0x00221A1B, 0x00221A1B, 0x002A2223, 0x00352D2E, 0x00554A4D, 0x006F6467, 0x02564D50, 0x06453C3F, 0x10595257, 0x2A6C636D, 0x5558545A, 0x8C32313B, 0xC25A5C67, 0xE7858A99, 0xF84E5667, 
        0xFD7B869A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFE8D9AB0, 0xFB878FA6, 0xF173788D, 0xDA5D5E73, 0xB34F4E5E, 0x811C1627, 0x525B5463, 0x2C8B8090, 0x144C424E, 0x083E303C, 0x027B6B76, 0x005C4C57, 0x00372D33, 0x0042383E, 0x00241A20, 0x001D1319, 0x0020171A, 0x00342B2E, 0x00595053, 
        0x00544B4E, 0x0061585B, 0x00534A4D, 0x00605859, 0x00585051, 0x00484041, 0x002C2425, 0x002A2223, 0x00251D1E, 0x00261B1E, 0x00281D20, 0x00463D40, 0x0071686B, 0x0240393E, 0x083C333D, 0x174F4B51, 0x375F5E68, 0x68343641, 0xA1232837, 0xD2626A7B, 
        0xEF556074, 0xFB7B889E, 0xFE909FB9, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFE8C9CB3, 0xF7919CB0, 0xE07E8196, 0xB8343446, 0x861F162A, 0x55564C5C, 0x2E908393, 0x16918591, 0x084C404C, 0x02554D54, 0x00847C83, 0x004A4449, 0x00352F34, 0x00393033, 0x000C0306, 0x002F282B, 0x00564F52, 0x00615A5D, 0x00554E51, 0x00352E31, 
        0x002E272A, 0x00231D1E, 0x00211B1C, 0x00292324, 0x002F292A, 0x00494344, 0x00605A5B, 0x00635D5E, 0x00403A3B, 0x00322626, 0x001B0F0F, 0x002D2121, 0x00382C2C, 0x003E3434, 0x00564C4C, 0x04443C3D, 0x0C3D373C, 0x23646065, 0x4875747D, 0x7D34353F, 
        0xB5292C3A, 0xDF474C5B, 0xF58C93A6, 0xFD858C9F, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFAA0B0C7, 0xD98691A5, 0x990F1227, 0x5C4C4C5E, 0x3092899D, 0x17B0A6B6, 0x08807383, 0x02231723, 0x003E323E, 0x007A7279, 0x00352D34, 0x003C363B, 0x00100A0F, 0x00180F12, 0x00544B4E, 0x006B6467, 0x00332C2F, 0x001B1417, 0x001D1619, 0x002B2427, 
        0x004A4346, 0x00615B5C, 0x00635D5E, 0x00544E4F, 0x00413B3C, 0x00241E1F, 0x00050000, 0x001A1415, 0x004E4849, 0x005C5050, 0x003F3333, 0x00392D2D, 0x00231717, 0x002A2020, 0x00504646, 0x00837B7C, 0x02363035, 0x06020003, 0x12504F58, 0x2E9E9FA9, 
        0x5A565967, 0x93262B3A, 0xCB596073, 0xEF878EA1, 0xFD8C97AD, 0xFFFFFFFF,
  0xFE7390A5, 0xF3869BB1, 0xB3232E44, 0x58393D50, 0x1FB0ACBF, 0x0A5B5060, 0x045C4D5B, 0x00241523, 0x00463B45, 0x008C818B, 0x00393338, 0x0027262A, 0x000D0F10, 0x00333536, 0x006A6366, 0x0050494C, 0x00211A1D, 0x002B2427, 0x007A7577, 0x009E999B, 0x00AAA8A8, 
        0x009D9B9B, 0x00878585, 0x008F8D8D, 0x00888686, 0x009C9A9A, 0x00B1ACAD, 0x00989394, 0x00555150, 0x000D0908, 0x00241816, 0x005C504E, 0x00544945, 0x00332824, 0x00332824, 0x00190E0A, 0x00554C48, 0x00A59B9B, 0x00433B3C, 0x02060005, 0x0A4F4B51, 
        0x1B878690, 0x3F6F6F7B, 0x81353847, 0xCC4D505E, 0xF6707788, 0xFFFFFFFF,
  0xFE84A1B6, 0xEE8196AC, 0xA1162137, 0x3EA3A7BA, 0x0C6C687B, 0x00796E7E, 0x002E1F2D, 0x003F303E, 0x008A7F89, 0x00332832, 0x00352F34, 0x00030206, 0x004B4D4E, 0x0067696A, 0x001A1316, 0x00090205, 0x00898285, 0x00BAB3B6, 0x006D686A, 0x00252022, 0x000C0A0A, 
        0x00020000, 0x00020000, 0x000A0808, 0x000D0B0B, 0x000B0909, 0x00090405, 0x004E494A, 0x00A39F9E, 0x00A8A4A3, 0x00554947, 0x000F0301, 0x00423733, 0x00564B47, 0x00312622, 0x00352A26, 0x00100703, 0x007C7272, 0x00B5ADAE, 0x005A5459, 0x00070309, 
        0x04201F29, 0x164C4C58, 0x4B9C9FAE, 0xAB242735, 0xEF6A7182, 0xFE91A9BF,
  0xFE9BA7BF, 0xED575C71, 0x9D464255, 0x38978C9C, 0x0A5B4B56, 0x006C5E64, 0x002F2125, 0x0066585C, 0x004E474A, 0x00383134, 0x00080207, 0x005C565B, 0x00706C71, 0x000A050E, 0x00454752, 0x00BCBEC9, 0x0070717B, 0x000D0E18, 0x0004030C, 0x0043424B, 0x007C7A80, 
        0x00BBB9BF, 0x00CECAD0, 0x00E6E2E8, 0x00D0CED4, 0x00BCBAC0, 0x0074717A, 0x0029262F, 0x00010009, 0x003B3A43, 0x00ACA3A6, 0x007A7174, 0x000F0A0B, 0x002A2526, 0x0050514F, 0x002F302E, 0x00181917, 0x001C1817, 0x00868180, 0x00918A8D, 0x00312A2F, 
        0x002C232D, 0x0A221B28, 0x3A4B4858, 0x9DA9A8B8, 0xEC7E8497, 0xFE95A0B6,
  0xFE838FA7, 0xEC454A5F, 0x9D555164, 0x38554A5A, 0x0A756570, 0x0013050B, 0x00635559, 0x00706266, 0x003F383B, 0x00090205, 0x003C363B, 0x00898388, 0x00020003, 0x006C6770, 0x00C0C2CD, 0x0021232E, 0x001B1C26, 0x0041424C, 0x00C8C7D0, 0x00FDFCFF, 0x00DFDDE3, 
        0x00A4A2A8, 0x0098949A, 0x00706C72, 0x00848288, 0x00A9A7AD, 0x00E1DEE7, 0x00FEFBFF, 0x009F9EA7, 0x0026252E, 0x0021181B, 0x006C6366, 0x00A49FA0, 0x00100B0C, 0x0020211F, 0x00646563, 0x002F302E, 0x0014100F, 0x002B2625, 0x00ABA4A7, 0x0070696E, 
        0x00271E28, 0x08403946, 0x351E1B2B, 0x98737282, 0xEB6E7487, 0xFE818CA2,
  0xFE606B81, 0xEC6B6F82, 0x9D4E4859, 0x386E616F, 0x0A5D4D58, 0x0046383E, 0x00655A5D, 0x003E3336, 0x00241E23, 0x00282227, 0x0098949A, 0x00020004, 0x0056535C, 0x00D7D4DD, 0x0015171F, 0x001A1C24, 0x0098989E, 0x00FDFDFF, 0x00C8C7CB, 0x004F4E52, 0x00181517, 
        0x00030002, 0x00040001, 0x00140F11, 0x00020001, 0x00161315, 0x00231F24, 0x00666267, 0x00F0EFF3, 0x00ECEBEF, 0x00524B50, 0x00070005, 0x006B686A, 0x00CAC7C9, 0x000C0C0C, 0x002B2B2B, 0x00616161, 0x00211C1D, 0x001A1213, 0x004E4647, 0x009F9699, 
        0x00352A32, 0x082C242F, 0x332A2534, 0x97545363, 0xEB5D5E72, 0xFE7E8598,
  0xFE59647A, 0xEC6F7386, 0x9D3E3849, 0x386F6270, 0x0A23131E, 0x006A5C62, 0x0072676A, 0x0043383B, 0x00070106, 0x00817B80, 0x002C282E, 0x00363238, 0x00E1DEE7, 0x002B2831, 0x000C0E16, 0x00ABADB5, 0x00FCFCFF, 0x006C6C72, 0x00000003, 0x000D0C10, 0x001A1719, 
        0x002B282A, 0x002F2A2C, 0x00302B2D, 0x00302D2F, 0x00232022, 0x00151116, 0x000C080D, 0x0008070B, 0x00ABAAAE, 0x00FFFCFF, 0x00787176, 0x00020001, 0x00646163, 0x00A3A3A3, 0x00080808, 0x00585858, 0x00544F50, 0x00241C1D, 0x00292122, 0x00999093, 
        0x005C5159, 0x08231B26, 0x33322D3C, 0x96595868, 0xEA606175, 0xFE6D7487,
  0xFE697083, 0xEC818191, 0x9D4F4857, 0x386A5C68, 0x0A2D1E26, 0x005A4B53, 0x0052464C, 0x00110A0F, 0x003B353A, 0x0064616A, 0x00080710, 0x00C4C2CE, 0x00646470, 0x00050511, 0x00939596, 0x00FAF7F9, 0x004D4B4B, 0x00070505, 0x00353130, 0x00262221, 0x002F2A27, 
        0x0027221F, 0x00221D1A, 0x002D2825, 0x00231E1B, 0x002B2623, 0x0024201F, 0x00332F2E, 0x0014100F, 0x00070302, 0x00827F81, 0x00FBF7FD, 0x007D7B81, 0x00020006, 0x00A8A8AE, 0x0066666C, 0x00030204, 0x00706B6D, 0x00332E2D, 0x00090000, 0x00706666, 
        0x007B7073, 0x08282027, 0x31413B46, 0x9375707F, 0xEA5F5D70, 0xFE676B7E,
  0xFE585F72, 0xEC7A7A8A, 0x9D4D4655, 0x38564854, 0x0A2D1E26, 0x0062535B, 0x0040343A, 0x001E171C, 0x00605A5F, 0x002E2B34, 0x004F4E57, 0x00C0BECA, 0x00090915, 0x0051515D, 0x00F8FAFB, 0x006F6C6E, 0x00090707, 0x002B2929, 0x00292524, 0x00211D1C, 0x00332E2B, 
        0x001F1A17, 0x0025201D, 0x003A3532, 0x00241F1C, 0x0027221F, 0x00332F2E, 0x001D1918, 0x00231F1E, 0x002D2928, 0x00020001, 0x00B2AEB4, 0x00FBF9FF, 0x00333137, 0x00323238, 0x00B5B5BB, 0x000C0B0D, 0x00544F51, 0x00575251, 0x00180E0E, 0x00493F3F, 
        0x0074696C, 0x06595158, 0x304F4954, 0x90635E6D, 0xE979778A, 0xFE7B7F92,
  0xFE727688, 0xEC6C6978, 0x9D5C525F, 0x38352732, 0x0A493B41, 0x006E6066, 0x002C2228, 0x001C161B, 0x00838187, 0x00000009, 0x00B5B7C1, 0x005B5C6A, 0x000A0A1A, 0x00E5E5F5, 0x00E1DFDE, 0x00050000, 0x002B2623, 0x00231E1B, 0x002F2924, 0x0027211C, 0x00302821, 
        0x002E261F, 0x00282118, 0x00261F16, 0x00231B14, 0x00271F18, 0x002D2720, 0x002E2821, 0x002E2B23, 0x0025201D, 0x000F0E10, 0x00302E34, 0x00ECEBF4, 0x00CBC9D5, 0x0000000A, 0x009393A1, 0x0068646F, 0x00130C13, 0x005F5A59, 0x00271D1D, 0x002E2522, 
        0x00685F5C, 0x06483F42, 0x2E3B343B, 0x8F544D5A, 0xE85C5969, 0xFE8A899D,
  0xFE7A7E90, 0xEC7A7786, 0x9D534956, 0x382E202B, 0x0A8A7C82, 0x0055474D, 0x001C1218, 0x00373136, 0x00656369, 0x001F202A, 0x00D3D5DF, 0x00050614, 0x00696979, 0x00FAFAFF, 0x005F5D5C, 0x00110C0B, 0x00342F2C, 0x0027221F, 0x002A241F, 0x002A241F, 0x0029211A, 
        0x002D251E, 0x002A231A, 0x002F281F, 0x00342C25, 0x00383029, 0x001C160F, 0x00342E27, 0x0028251D, 0x0027221F, 0x00242325, 0x00000004, 0x008D8C95, 0x00F7F5FF, 0x003E3E4C, 0x00444452, 0x008C8893, 0x00150E15, 0x00565150, 0x00382E2E, 0x003F3633, 
        0x00372E2B, 0x06574E51, 0x2CABA4AB, 0x8E463F4C, 0xE85F5C6C, 0xFE87869A,
  0xFE818090, 0xEC77737F, 0x9D524854, 0x38493C44, 0x0A80747A, 0x00483C42, 0x00150E13, 0x006A666B, 0x00393C41, 0x0053545E, 0x00BABCC7, 0x0000000B, 0x00BABACC, 0x00E6E6F8, 0x001D1A15, 0x00211B16, 0x00262019, 0x002A241D, 0x00373027, 0x00251E15, 0x002D241A, 
        0x0032291F, 0x0031281E, 0x0030271D, 0x002F261C, 0x002E251B, 0x002C251C, 0x002C251C, 0x002A231A, 0x00282118, 0x0020211D, 0x002F2E32, 0x00403F48, 0x00FCF9FF, 0x009290A3, 0x000D0B1E, 0x008E8998, 0x00211924, 0x00464041, 0x00413835, 0x00383029, 
        0x00332B24, 0x06665E5E, 0x2A8A838A, 0x8C716A77, 0xE87B768B, 0xFE757288,
  0xFE7C7B8B, 0xEC7B7783, 0x9D3A303C, 0x38756870, 0x0A73676D, 0x0041353B, 0x00130C11, 0x006C686D, 0x00191C21, 0x009C9DA7, 0x00858792, 0x00000010, 0x00EDEDFF, 0x008F8FA1, 0x00090601, 0x003C3631, 0x00251F18, 0x00302A23, 0x002D261D, 0x00292219, 0x002A2117, 
        0x002D241A, 0x0030271D, 0x0030271D, 0x002F261C, 0x0030271D, 0x002E271E, 0x002E271E, 0x002D261D, 0x002C251C, 0x002A2B27, 0x001B1A1E, 0x0027262F, 0x00D6D3E3, 0x00D3D1E4, 0x0019172A, 0x00676271, 0x003A323D, 0x00413B3C, 0x003E3532, 0x002A221B, 
        0x00362E27, 0x045E5656, 0x28463F46, 0x8A9B94A1, 0xE77F7A8F, 0xFD918EA4,
  0xFE8C8A9D, 0xEC6E6978, 0x9D4C3F4D, 0x38928791, 0x0A594F55, 0x003E343A, 0x00120C11, 0x00666569, 0x000C0F14, 0x00A9AAB4, 0x004C4E58, 0x00242533, 0x00EFEFFF, 0x005B5B6B, 0x00050200, 0x0038322D, 0x00262019, 0x002F2922, 0x00241D14, 0x002F281F, 0x002E251B, 
        0x002B2218, 0x002E251B, 0x002E251B, 0x002E251B, 0x002F261C, 0x002E271E, 0x002F281F, 0x002E271E, 0x002D261D, 0x0025261D, 0x00312F2F, 0x0018151E, 0x00AEA8B9, 0x00FAF4FF, 0x002E2841, 0x00676075, 0x003C3340, 0x00393334, 0x00413835, 0x00453D36, 
        0x00231B14, 0x043F393A, 0x26918C95, 0x88777484, 0xE77C778C, 0xFD878297,
  0xFE747285, 0xEC837E8D, 0x9D504351, 0x38726771, 0x0A81777D, 0x0031272D, 0x00120C11, 0x0087868A, 0x0005080D, 0x00A6A7B1, 0x004E505A, 0x00272836, 0x00FAFAFF, 0x004E4E5E, 0x0017140F, 0x00231D18, 0x002D2720, 0x002B251E, 0x00272017, 0x00302920, 0x00352C22, 
        0x002D241A, 0x002E251B, 0x002E251B, 0x002E251B, 0x002F261C, 0x002E271E, 0x002F281F, 0x002E271E, 0x002D261D, 0x0024251C, 0x002A2828, 0x00000006, 0x00A7A1B2, 0x00F9F3FF, 0x0028223B, 0x00625B70, 0x00463D4A, 0x00383233, 0x00483F3C, 0x002F2720, 
        0x002C241D, 0x04565051, 0x26BEB9C2, 0x876A6777, 0xE6797489, 0xFD827D92,
  0xFE79778B, 0xEC837D8E, 0x9D4B424F, 0x38695E68, 0x0A746971, 0x0040353D, 0x000F090E, 0x007F7E82, 0x000E1115, 0x00ACAEB6, 0x0060626A, 0x00161622, 0x00F8F8FF, 0x00545462, 0x0015120E, 0x002F2825, 0x002D2722, 0x002B2520, 0x00312922, 0x002A221B, 0x00332A21, 
        0x002E251C, 0x0031281F, 0x0030271E, 0x0030271E, 0x0030271E, 0x002F2720, 0x002F2720, 0x002E261F, 0x002D251E, 0x0029261E, 0x002E2B23, 0x000C080E, 0x00B4ADBC, 0x00F4EBFF, 0x00312843, 0x00716980, 0x004C4252, 0x00362D30, 0x003B3530, 0x003F3A31, 
        0x003A352C, 0x04A29D9E, 0x26A5A2AB, 0x86A19FB5, 0xE56A687E, 0xFD767186,
  0xFE878599, 0xEC736D7E, 0x9D3A313E, 0x384A3F49, 0x0A81767E, 0x00362B33, 0x00060005, 0x0067666A, 0x0015181C, 0x0090929A, 0x007F8189, 0x000C0C18, 0x00D6D6E4, 0x008D8D9B, 0x00040100, 0x00423B38, 0x00221C17, 0x0029231E, 0x00342C25, 0x00261E17, 0x002F261D, 
        0x0031281F, 0x002F261D, 0x002E251C, 0x002D241B, 0x002E251C, 0x002C241D, 0x002C241D, 0x002A221B, 0x0029211A, 0x0028251D, 0x004C4941, 0x001F1B21, 0x00CFC8D7, 0x00E9E0FB, 0x00241B36, 0x009991A8, 0x00342A3A, 0x00433A3D, 0x004D4742, 0x001E1910, 
        0x00363128, 0x047A7576, 0x25ACA9B2, 0x849694AA, 0xE4757389, 0xFD787388,
  0xFE7C7A90, 0xEC696578, 0x9D776C7C, 0x38473D49, 0x0AA199A0, 0x005B535A, 0x00060005, 0x0068676B, 0x001F2226, 0x0064666E, 0x00B7B9C1, 0x0000000C, 0x00B7B7C3, 0x00D9D5E1, 0x00161110, 0x00292423, 0x0025201D, 0x00241F1C, 0x002D2722, 0x002A1F1B, 0x0030261F, 
        0x0030261F, 0x002D231C, 0x002C221B, 0x002C221B, 0x002C221B, 0x002A211D, 0x002A211D, 0x0027211C, 0x00251F1A, 0x00322E23, 0x00332F24, 0x002F292E, 0x00FBF1FF, 0x00B1A8C3, 0x00100722, 0x00A199B0, 0x0023182C, 0x004F484B, 0x00514D48, 0x00242218, 
        0x0058564C, 0x04A09E9E, 0x25B1AFBB, 0x839F9EB8, 0xE36A6983, 0xFD8C879C,
  0xFE848298, 0xEC625E71, 0x9D685D6D, 0x38675D69, 0x0A635B62, 0x00625A61, 0x00150F14, 0x0038373B, 0x004D5054, 0x00363840, 0x00C9CBD3, 0x00090915, 0x007A7A86, 0x00F6F2FE, 0x00544F4E, 0x00050000, 0x003C3734, 0x0025201D, 0x0029231E, 0x00302521, 0x00312720, 
        0x002A2019, 0x0030261F, 0x002F251E, 0x002F251E, 0x002F251E, 0x002E2521, 0x002E2521, 0x002B2520, 0x0029231E, 0x00332F24, 0x000B0700, 0x006D676C, 0x00FFF9FF, 0x0059506B, 0x00413853, 0x00ADA5BC, 0x00251A2E, 0x00544D50, 0x004E4A45, 0x00201E14, 
        0x00525046, 0x043C3A3A, 0x25CCCAD6, 0x81B4B3CD, 0xE371708A, 0xFD676277,
  0xFE6D7287, 0xEC595B6D, 0x9D343442, 0x38524E59, 0x0AA9A2A9, 0x00584D55, 0x0030262C, 0x0022181E, 0x00746D72, 0x00060207, 0x00CFCDD3, 0x0060616B, 0x00282A34, 0x00F1F3FD, 0x00CAC6CC, 0x00060002, 0x00261F22, 0x002B2625, 0x0025201D, 0x003B332C, 0x00251C12, 
        0x0030271D, 0x002C2319, 0x00231A10, 0x00342B21, 0x002C2319, 0x00342B22, 0x002D221E, 0x002A211D, 0x00362C2C, 0x00171B20, 0x0000010B, 0x00D1D2DC, 0x00EBE7F2, 0x0016111A, 0x009B929C, 0x0083797F, 0x00282021, 0x006B6363, 0x00484040, 0x001C1718, 
        0x00645E63, 0x047A7681, 0x25F7F1FF, 0x80948EA7, 0xE274718A, 0xFD677689,
  0xFE63687D, 0xEC535567, 0x9D61616F, 0x3837333E, 0x0AC0B9C0, 0x00857A82, 0x003A3036, 0x001C1218, 0x00645D62, 0x00322E33, 0x005B595F, 0x00C1C2CC, 0x00141620, 0x00858791, 0x00FCF8FE, 0x006C6568, 0x000B0407, 0x00312C2B, 0x001D1815, 0x00251D16, 0x0030271D, 
        0x0032291F, 0x003C3329, 0x00261D13, 0x00281F15, 0x002C2319, 0x00261D14, 0x002E231F, 0x003B322E, 0x00241A1A, 0x00000005, 0x00747680, 0x00FBFCFF, 0x0078747F, 0x00211C25, 0x00D0C7D1, 0x002F252B, 0x00494142, 0x00766E6E, 0x001A1212, 0x00443F40, 
        0x00746E73, 0x04BCB8C3, 0x23FFF9FF, 0x7F958FA8, 0xE1716E87, 0xFD657487,
  0xFE62687F, 0xEC54586B, 0x9D9191A1, 0x381C1A26, 0x0A918B96, 0x00AFA7AE, 0x00463C42, 0x001D1319, 0x00362F34, 0x00645D62, 0x000C080E, 0x00BEBAC0, 0x00504F58, 0x00181720, 0x00D9D7DD, 0x00FAF8FE, 0x001C181D, 0x00130F14, 0x002A2526, 0x0036332F, 0x00242119, 
        0x0027241C, 0x001E1B13, 0x002D2A22, 0x0028251D, 0x002F2C24, 0x002F2C27, 0x00302C2B, 0x00272420, 0x000E090A, 0x00424549, 0x00F9FBFF, 0x00C1C0C9, 0x00020006, 0x00AEA7AE, 0x009E939B, 0x001C1316, 0x007C7376, 0x00524A4A, 0x002B2323, 0x00645F60, 
        0x007D7C80, 0x04DCDBE5, 0x23FAFAFF, 0x7D9794AD, 0xDF6D6F87, 0xFC59677A,
  0xFE666C83, 0xEC424659, 0x9D5F5F6F, 0x380A0814, 0x0A8E8893, 0x00DED6DD, 0x0072686E, 0x002C2228, 0x00221B20, 0x005B5459, 0x003D393F, 0x00403C42, 0x00DDDCE5, 0x00201F28, 0x001A181E, 0x00C4C2C8, 0x00ECE8ED, 0x0029252A, 0x00080304, 0x001C1915, 0x002A271F, 
        0x002D2A22, 0x00302D25, 0x001D1A12, 0x0035322A, 0x00232018, 0x00211E19, 0x00231F1E, 0x00040100, 0x00514C4D, 0x00EBEEF2, 0x00E1E3EB, 0x00292831, 0x0069646D, 0x00CBC4CB, 0x001F141C, 0x004D4447, 0x00736A6D, 0x002D2525, 0x00372F2F, 0x00615C5D, 
        0x0079787C, 0x04FDFCFF, 0x23F0F0FF, 0x7D7A7790, 0xDF6B6D85, 0xFC5B697C,
  0xFE4F5873, 0xED434960, 0xA0868A9D, 0x3A00000F, 0x0C2E2938, 0x00E9E1EC, 0x00A59DA4, 0x002C242B, 0x00211A1F, 0x002F282D, 0x00676067, 0x00040004, 0x00807C82, 0x00E7E3E9, 0x0026222D, 0x00100C17, 0x00AEABB4, 0x00FFFCFF, 0x008E8B8D, 0x00120F11, 0x00090707, 
        0x00040202, 0x00110F0E, 0x00151312, 0x00040503, 0x00070806, 0x00070909, 0x0025262A, 0x00797C80, 0x00FBFEFF, 0x00C2C3C7, 0x001C181D, 0x003C383E, 0x00D9D1D8, 0x00292128, 0x00392C34, 0x0083787B, 0x00584D50, 0x00150D0E, 0x00666162, 0x005C5A5A, 
        0x00C9CACE, 0x04FAFCFF, 0x23EEF2FF, 0x7C9092AA, 0xDE585E75, 0xFC7D8EA1,
  0xFE8992AD, 0xEF242A41, 0xAB6D7184, 0x4A404050, 0x14191423, 0x04B4ACB7, 0x00E2DAE1, 0x00817980, 0x00423B40, 0x000D060B, 0x00554E55, 0x00655E65, 0x00020004, 0x005F5B61, 0x00C9C5D0, 0x003B3742, 0x0019161F, 0x006F6C75, 0x00E5E2E4, 0x00F2EFF1, 0x00B3B1B1, 
        0x00646262, 0x003C3A39, 0x00444241, 0x00393A38, 0x00727371, 0x00979999, 0x00DFE0E4, 0x00F3F6FA, 0x0055585C, 0x00000003, 0x005C585D, 0x00D8D4DA, 0x00473F46, 0x00352D34, 0x0074676F, 0x006F6467, 0x001E1316, 0x00403839, 0x00797475, 0x00828080, 
        0x00F9FAFE, 0x04F9FBFF, 0x21EEF2FF, 0x7A9395AD, 0xDC585E75, 0xFC8E9FB2,
  0xFFFFFFFF, 0xF6232F47, 0xCA61677E, 0x7C606477, 0x3800000F, 0x16575561, 0x06E9E5F0, 0x02BDB5C0, 0x00595158, 0x00282027, 0x00272025, 0x00423B40, 0x005F585D, 0x001E171C, 0x005C5562, 0x00E4DDEA, 0x00807883, 0x00110914, 0x00160E18, 0x00736B75, 0x00CAC4C9, 
        0x00F9F3F8, 0x00FCF8FD, 0x00FBF7FC, 0x00FFFEFF, 0x00E2E1E5, 0x00CECED4, 0x00727278, 0x00000109, 0x00181A22, 0x00A29FA1, 0x00C4BDC0, 0x00423A41, 0x00362E35, 0x00665B63, 0x005D525A, 0x0031272D, 0x00241A20, 0x00928B8E, 0x00242123, 0x00CED0D1, 
        0x00F5F9FE, 0x06DEE7F1, 0x25DAE5F3, 0x7D949CB3, 0xDC525F75, 0xFC9BAEC3,
  0xFFFFFFFF, 0xFD808CA4, 0xEE757B92, 0xC57A7E91, 0x874E4E5E, 0x4A13111D, 0x1F9E9AA5, 0x0AEBE3EE, 0x02918990, 0x0050484F, 0x00140D12, 0x00251E23, 0x004D464B, 0x00625B60, 0x00150E1B, 0x00342D3A, 0x00B5ADB8, 0x00CDC5D0, 0x008B838D, 0x0028202A, 0x00262025, 
        0x00292328, 0x002A262B, 0x003D393E, 0x003A393D, 0x00060509, 0x000C0C12, 0x0036363C, 0x0082848C, 0x00DADCE4, 0x00888587, 0x00292225, 0x0040383F, 0x005E565D, 0x00766B73, 0x0040353D, 0x00190F15, 0x00786E74, 0x003A3336, 0x00A5A2A4, 0x00FBFDFE, 
        0x04E8ECF1, 0x12D8E1EB, 0x3AE1ECFA, 0x8F9098AF, 0xE38794AA, 0xFC8194A9,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFD5F6B83, 0xF29BA4B8, 0xD56A7083, 0xA13C3F4E, 0x62333341, 0x30ACA8B3, 0x12D9D6DF, 0x06837B85, 0x02676067, 0x00201920, 0x001F181D, 0x0050494E, 0x006C5F6D, 0x003B2E3C, 0x000F030F, 0x004E424E, 0x00A799A5, 0x00CEC0CC, 0x00D6C8D3, 
        0x00B0A2AD, 0x00918690, 0x007D727C, 0x00887F89, 0x00A097A1, 0x00B9B3BE, 0x00C9C3CE, 0x008D8994, 0x00393540, 0x001E1B1D, 0x004F4C4E, 0x006B656A, 0x00655D67, 0x00382E3A, 0x00110713, 0x00756C76, 0x00413842, 0x00706C71, 0x02FDFEFF, 0x0AE6ECF1, 
        0x1BF2FBFF, 0x3EDCE8F4, 0x77D6E5F5, 0xBEAAB7CF, 0xF06D7F96, 0xFE697E93,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE545D71, 0xF8B5BBCE, 0xE59295A4, 0xBB525260, 0x7F4A4651, 0x45DFDCE5, 0x1FC4BCC6, 0x0A8C858C, 0x02433C43, 0x001B1419, 0x001C151A, 0x00392C3A, 0x00837684, 0x00665A66, 0x00251925, 0x0021131F, 0x00372935, 0x00564853, 
        0x00685A65, 0x00877C86, 0x008C818B, 0x00877E88, 0x006B626C, 0x0048424D, 0x002C2631, 0x0026222D, 0x0046424D, 0x00666365, 0x006B686A, 0x00696368, 0x001C141E, 0x000D030F, 0x00685E6A, 0x003E353F, 0x026B626C, 0x08FFFDFF, 0x16F9FAFE, 0x31F8FEFF, 
        0x5DD9E2EB, 0x96B1BDC9, 0xC9A8B7C7, 0xEC929FB7, 0xFC899BB2, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFC8C93A6, 0xF0A9ADBF, 0xD18E8F9D, 0x9C61636E, 0x5FF5F3FF, 0x2EDFDEE8, 0x1288828D, 0x045D5A63, 0x00352D37, 0x00170F19, 0x001B101A, 0x00645963, 0x007A6F79, 0x00746671, 0x005D4F5A, 0x00291B26, 
        0x003F313C, 0x00382A35, 0x003D2F3A, 0x00372C36, 0x00312630, 0x00463D47, 0x005F5660, 0x0068606A, 0x007F7781, 0x00636468, 0x003B3C40, 0x00000004, 0x002D2934, 0x00A69FAC, 0x025E5764, 0x0676727E, 0x10F2EEFA, 0x26F2F1FB, 0x4FF0F2FC, 0x84D6DFE8, 
        0xBAC1CDD9, 0xE16B7B8B, 0xF5798D9F, 0xFD7D93AC, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD707486, 0xF79293A1, 0xE391939E, 0xB8898793, 0x7AF5F4FE, 0x41FBF5FF, 0x1BCCC9D2, 0x08655D67, 0x024F4751, 0x00291E28, 0x000D020C, 0x001A0F19, 0x00463843, 0x006B5D68, 0x007B6D78, 
        0x007E707B, 0x00746671, 0x0072646F, 0x007B707A, 0x00786D77, 0x00766D77, 0x007B727C, 0x00574F59, 0x00261E28, 0x00090A0E, 0x00131418, 0x006C6A70, 0x00A29EA9, 0x049D96A3, 0x0CB0A9B6, 0x1FF2EEFA, 0x41FAF6FF, 0x74EFEEF8, 0xABBDBFC9, 0xD89CA5AE, 
        0xF14E5A66, 0xFB657585, 0xFE99ADBF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE757B8E, 0xFB868D9C, 0xEE8F92A1, 0xCE9599A4, 0x97D7D7E3, 0x59FAFCFF, 0x2AEDECF6, 0x10A7A8AC, 0x045B575C, 0x00575359, 0x00433F45, 0x00150E15, 0x000F080F, 0x00140C13, 
        0x00211920, 0x00302731, 0x00231A24, 0x002A2229, 0x00282027, 0x001A131A, 0x00191219, 0x00231F25, 0x00373339, 0x005E6568, 0x009EA5A8, 0x02A9ACB4, 0x08D9DBE6, 0x17E5E4F4, 0x35FBFAFF, 0x65F1F0FF, 0x9CC8C7D7, 0xCC90919F, 0xEBA1A7B4, 0xF9505C68, 
        0xFE566575, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD7A7D8C, 0xF68D919C, 0xDF9A9AA6, 0xB1ACAEB8, 0x74F6F5FF, 0x3EF7F8FC, 0x19E7E3E8, 0x08868288, 0x0268646A, 0x00746D74, 0x00595259, 0x00554D54, 
        0x00524A51, 0x003D343E, 0x003C333D, 0x00332B32, 0x00352D34, 0x004B444B, 0x00504950, 0x005D595F, 0x00959197, 0x02B8BFC2, 0x06E6EDF0, 0x12F4F7FF, 0x2CF5F7FF, 0x55FBFAFF, 0x8BCAC9D9, 0xC09E9DAD, 0xE49190A0, 0xF69697A5, 0xFD3F4552, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE7D8493, 0xFA7C7F8E, 0xEC9C9FAD, 0xC9A1A4B2, 0x92D8E0E0, 0x55F5FDFD, 0x28FAFFFF, 0x0EDCE1E2, 0x04B6BBBE, 0x008F9094, 0x00757379, 
        0x0078767C, 0x00656369, 0x007B797F, 0x007A787E, 0x0078767C, 0x00A1A0A4, 0x00C2C1C5, 0x00D3D2D6, 0x04FDFCFF, 0x0EF4FFFF, 0x23F4FEFF, 0x48E4EDF6, 0x7CD3D6E4, 0xB1A1A1B3, 0xDC838395, 0xF37A7A8C, 0xFC7C7C8E, 0xFE454A59, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD808391, 0xF5797C8A, 0xDC919999, 0xAEC7CFCF, 0x71EFF4F5, 0x3AF8FDFE, 0x17F8FDFF, 0x08FCFDFF, 0x02FCFAFF, 
        0x00F3F1F7, 0x00E3E1E7, 0x00EFEDF3, 0x00FDFBFF, 0x00F8F6FC, 0x00F9F8FC, 0x02FFFEFF, 0x0AFAF9FD, 0x1BF6F5F9, 0x3ADDE9EB, 0x6BCDD7DE, 0xA3A6AFB8, 0xD19B9EAC, 0xED88889A, 0xFA88889A, 0xFE5F5F71, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE828796, 0xFA878591, 0xEB888692, 0xC7B3B4BE, 0x8CE3E4EE, 0x50F5F8FD, 0x25F4F7FC, 0x0CEEF3F6, 
        0x04F6FBFE, 0x00F8FFFF, 0x00F2F9FC, 0x00F8FFFF, 0x02F1F7FE, 0x08E5EDF4, 0x14F4FAFF, 0x30EAF0FB, 0x5CC8CED9, 0x92AEB0BB, 0xC6ABADB8, 0xE8818590, 0xF85C6372, 0xFD848C9D, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFD7B7985, 0xF47E7F89, 0xD992939D, 0xA8CFD2D7, 0x6AFBFEFF, 0x35F5FAFD, 
        0x16EDF2F5, 0x08EFF6F9, 0x06F3FAFD, 0x08E3EAED, 0x14F3F9FF, 0x28ECF4FB, 0x4DDCE2ED, 0x81A9AFBA, 0xB8989EA9, 0xDF9B9DA8, 0xF47A7C87, 0xFD717580, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE697081, 0xF97C8394, 0xE86B7482, 0xC19EA7B5, 0x87E2EBF8, 
        0x4DEFF8FF, 0x2CF3FCFF, 0x25EDF6FF, 0x31F3FCFF, 0x4FE2EBF9, 0x79BCC6D7, 0xAA929CAD, 0xD5919BAD, 0xF0616B7D, 0xFB494F5C, 0xFE444A57, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFC5E6775, 0xF257606E, 0xD7555E6B, 
        0xA99BA4B1, 0x81CDD6E3, 0x7AD1DAE7, 0x8FB0B9C7, 0xB077808E, 0xD25D6778, 0xEC303A4B, 0xF94A5466, 0xFE454F61, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFE748298, 0xF95B6A7D, 
        0xEB617083, 0xDB6F7E91, 0xD97A899C, 0xE459667C, 0xF078859B, 0xF9737F97, 0xFD76829A, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

GUI_CONST_STORAGE GUI_BITMAP bmGuitarInOut = {
  47, // xSize
  53, // ySize
  188, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acGuitarInOut,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Segger Logo 80x40
*/
static GUI_CONST_STORAGE unsigned long _acSeggerLogo_80x40[] = {
  0xFF000000, 0x70000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x70000000, 0xFF000000,
  0x70000000, 0x00000000, 0x00101010, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00101010, 0x00000000, 0x70000000,
  0x00000000, 0x00101010, 0x00EFEFEF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EFEFEF, 0x00101010, 0x10000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00E1B9B9, 0x00D09090, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00D09090, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A62E2E, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B85858, 0x00A02020, 0x00A62E2E, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CA8282, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B24A4A, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00A62E2E, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00E7C7C7, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D09090, 0x00A02020, 0x00A02020, 0x00AC3C3C, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00BE6666, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00D59D9D, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00E7C7C7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A02020, 0x00E7C7C7, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A62E2E, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DBABAB, 0x00A02020, 0x00A02020, 0x00A62E2E, 
        0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00B85858, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C47474, 0x00A02020, 0x00A02020, 
        0x00AC3C3C, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00B24A4A, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00E7C7C7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00E7C7C7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00B24A4A, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 
        0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00A02020, 0x00D09090, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A02020, 0x00B85858, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00C47474, 0x00A02020, 0x00A02020, 
        0x00AC3C3C, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 
        0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00B85858, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00A62E2E, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DBABAB, 0x00A02020, 0x00A02020, 0x00A62E2E, 
        0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A02020, 0x00E7C7C7, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A02020, 0x00E7C7C7, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00D59D9D, 0x00FFFFFF, 
        0x00FFFFFF, 0x00EFEFEF, 0x00AFAFAF, 0x00808080, 0x00808080, 0x00AFAFAF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DFDFDF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00CFCFCF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DFDFDF, 
        0x009F9F9F, 0x00808080, 0x008F8F8F, 0x00CFCFCF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DFDFDF, 0x008F8F8F, 0x00808080, 0x008F8F8F, 0x00CFCFCF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EFEFEF, 0x00BFBFBF, 0x00BFBFBF, 
        0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00FFFFFF, 0x00FFFFFF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00CFCFCF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00BE6666, 0x00FFFFFF, 0x00FFFFFF, 
        0x00CFCFCF, 0x00101010, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00202020, 0x00DFDFDF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00DFDFDF, 0x00FFFFFF, 0x00707070, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00404040, 0x00EFEFEF, 0x00FFFFFF, 0x00FFFFFF, 0x00707070, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00505050, 0x00FFFFFF, 0x00FFFFFF, 0x00505050, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00BFBFBF, 0x00BFBFBF, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D09090, 0x00A02020, 0x00A02020, 0x00AC3C3C, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 
        0x00808080, 0x00000000, 0x00505050, 0x00DFDFDF, 0x00CFCFCF, 0x00303030, 0x00000000, 0x008F8F8F, 0x00FFFFFF, 0x00404040, 0x00000000, 0x008F8F8F, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00FFFFFF, 0x009F9F9F, 0x00000000, 0x00000000, 
        0x00808080, 0x00BFBFBF, 0x009F9F9F, 0x00101010, 0x00000000, 0x009F9F9F, 0x00FFFFFF, 0x00808080, 0x00000000, 0x00000000, 0x008F8F8F, 0x00BFBFBF, 0x008F8F8F, 0x00101010, 0x00000000, 0x00BFBFBF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00606060, 
        0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00303030, 0x00BFBFBF, 0x00BFBFBF, 0x00808080, 0x00000000, 0x00000000, 0x00BFBFBF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00D59D9D, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00E7C7C7, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00808080, 0x00000000, 0x00202020, 0x008F8F8F, 0x00CFCFCF, 0x00EFEFEF, 0x00BFBFBF, 0x00EFEFEF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x008F8F8F, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00DFDFDF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00606060, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00DFDFDF, 0x008F8F8F, 0x00EFEFEF, 0x00FFFFFF, 0x00202020, 0x00000000, 0x00808080, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CFCFCF, 0x008F8F8F, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00606060, 
        0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00DFDFDF, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00EFEFEF, 0x00202020, 0x00000000, 0x00BFBFBF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00A02020, 0x00A02020, 0x00A62E2E, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00A62E2E, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00CFCFCF, 0x00202020, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00505050, 0x00CFCFCF, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00101010, 0x00000000, 0x00AFAFAF, 
        0x00FFFFFF, 0x00DFDFDF, 0x00505050, 0x00404040, 0x00404040, 0x008F8F8F, 0x00FFFFFF, 0x00000000, 0x00000000, 0x00BFBFBF, 0x00FFFFFF, 0x00CFCFCF, 0x00505050, 0x00404040, 0x00404040, 0x008F8F8F, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00202020, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00101010, 0x00404040, 0x00404040, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00F9F1F1, 0x00AC3C3C, 0x00A02020, 0x00A02020, 0x00DBABAB, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B24A4A, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00BFBFBF, 0x00808080, 0x00505050, 0x00000000, 0x00000000, 0x00202020, 0x00FFFFFF, 0x00404040, 0x00000000, 0x008F8F8F, 0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00DFDFDF, 0x00FFFFFF, 0x00202020, 0x00000000, 0x008F8F8F, 
        0x00FFFFFF, 0x00CFCFCF, 0x00202020, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00000000, 0x00000000, 0x00AFAFAF, 0x00FFFFFF, 0x00BFBFBF, 0x00101010, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00606060, 
        0x00BFBFBF, 0x00BFBFBF, 0x00BFBFBF, 0x00CFCFCF, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00101010, 0x00404040, 0x00404040, 0x00101010, 0x00000000, 0x00303030, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00BE6666, 0x00A02020, 0x00A02020, 0x00C47474, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00CA8282, 0x00A02020, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x008F8F8F, 0x00000000, 0x009F9F9F, 0x00FFFFFF, 0x00FFFFFF, 0x00AFAFAF, 0x00000000, 0x00000000, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00BFBFBF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00606060, 0x00000000, 0x00202020, 
        0x00EFEFEF, 0x00FFFFFF, 0x00FFFFFF, 0x00808080, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00505050, 0x00000000, 0x00303030, 0x00EFEFEF, 0x00FFFFFF, 0x00FFFFFF, 0x00606060, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00808080, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00BFBFBF, 0x00000000, 0x00000000, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00A62E2E, 0x00A02020, 0x00B24A4A, 0x00F9F1F1, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00B85858, 0x00A02020, 0x00A62E2E, 0x00F3E3E3, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x009F9F9F, 0x00000000, 0x00000000, 0x00404040, 0x00606060, 0x00202020, 0x00000000, 0x00505050, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00101010, 0x00BFBFBF, 0x00DFDFDF, 0x00101010, 0x00000000, 
        0x00101010, 0x00404040, 0x00303030, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00CFCFCF, 0x00101010, 0x00000000, 0x00101010, 0x00404040, 0x00202020, 0x00000000, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00404040, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x009F9F9F, 0x00BFBFBF, 0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00000000, 0x00000000, 0x00CFCFCF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00E1B9B9, 0x00D09090, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EDD5D5, 0x00D09090, 0x00EDD5D5, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x009F9F9F, 0x00303030, 0x00000000, 0x00000000, 0x00202020, 0x00606060, 0x00EFEFEF, 0x00FFFFFF, 0x00808080, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00CFCFCF, 0x00FFFFFF, 0x00DFDFDF, 0x00606060, 
        0x00101010, 0x00000000, 0x00101010, 0x00808080, 0x00505050, 0x00505050, 0x00FFFFFF, 0x00FFFFFF, 0x00CFCFCF, 0x00505050, 0x00101010, 0x00000000, 0x00202020, 0x00808080, 0x00404040, 0x00505050, 0x00FFFFFF, 0x009F9F9F, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00AFAFAF, 0x00CFCFCF, 0x00404040, 0x00808080, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00505050, 0x00202020, 0x00DFDFDF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x00000000, 0x00404040, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00404040, 0x00000000,
  0x10000000, 0x00101010, 0x00EFEFEF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 
        0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00FFFFFF, 0x00EFEFEF, 0x00101010, 0x10000000,
  0x70000000, 0x00000000, 0x00101010, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 
        0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00404040, 0x00101010, 0x00000000, 0x70000000,
  0xFF000000, 0x70000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x70000000, 0xFF000000
};

GUI_CONST_STORAGE GUI_BITMAP bmSeggerLogo_80x40 = {
  80, // xSize
  40, // ySize
  320, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acSeggerLogo_80x40,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Button 30x30 unpressed
*/
static GUI_CONST_STORAGE unsigned long _acknob_gray_trans_30x30[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD1D1D1, 0xFFC0C0C0, 0xFFABABAB, 0xFF8E8E8F, 0xFF858585, 0xFF7C7C7C, 0xD189898A, 0x89949395, 0x4DA3A2A5, 0x28B0AFB3, 0x13BFBEC2, 0x10C6C5C9, 0x22BFBEC3, 0x42B9B8BB, 0x7AB5B5B6, 0xBFB4B3B5, 0xFEB5B4B6, 
        0xFFBABABA, 0xFFB9B9B9, 0xFFB8B8B8, 0xFFBFBFBF, 0xFFC3C3C3, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD1D1D1, 0xFFC0C0C0, 0xFFABABAB, 0xFF8E8E8F, 0xCA7E7E7E, 0x5B6A6A6A, 0x09727273, 0x00858486, 0x009C9A9D, 0x00B0AFB2, 0x00C2C2C3, 0x00D1D0D1, 0x00D7D6D7, 0x00D1D0D2, 0x00BFBEC0, 0x01B1B0B2, 0x44ACABAD, 
        0xB1B4B3B4, 0xFDB9B9B9, 0xFFB9B9B9, 0xFFBFBFBF, 0xFFC3C3C3, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD1D1D1, 0xFFC0C0C0, 0xE6A9A9A9, 0x5A8D8C8D, 0x08747475, 0x006B6A6B, 0x00807F81, 0x00969598, 0x00ABAAAB, 0x00BCBCBB, 0x00CDCDCD, 0x00DCDCDC, 0x00EEEEEE, 0x00FDFDFD, 0x00F9F9F9, 0x00DEDDDE, 0x00BEBEBE, 
        0x00ABAAAB, 0x42ABAAAB, 0xCBB5B5B5, 0xFFC0C0C0, 0xFFC3C3C3, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD0D0D0, 0xD0C1C1C1, 0x2CAFAFAF, 0x008B8A8C, 0x006D6C6E, 0x00767577, 0x00868587, 0x00959496, 0x00A7A7A8, 0x00B8B8B8, 0x00CBCBCB, 0x00DCDCDC, 0x00EFEFEF, 0x00FFFFFF, 0x00FAFAFA, 0x00E7E7E7, 0x00D1D1D1, 
        0x00BAB9BB, 0x00A9A9AA, 0x12A7A7A7, 0xADB8B8B8, 0xFFC5C5C5, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFD5D5D5, 0xFFD5D5D5, 0xFFD4D4D4, 0xD0D5D5D5, 0x1FD2D2D2, 0x00919191, 0x00555556, 0x005B5A5C, 0x006B6A6C, 0x007D7C7E, 0x008D8C8F, 0x00A3A3A3, 0x00B5B5B5, 0x00CACACA, 0x00DCDCDC, 0x00F2F2F2, 0x00FFFFFF, 0x00F1F1F1, 0x00DADADA, 0x00C3C3C3, 
        0x00B1B1B1, 0x00A0A0A0, 0x009F9F9F, 0x0CA8A7A9, 0xA8B9B9B9, 0xFFC8C8C8, 0xFFC6C6C6, 0xFFC6C6C6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFE5E5E5, 0xFFE5E5E5, 0xE7E9E9E9, 0x2AF7F7F7, 0x00A2A1A2, 0x00373737, 0x00434344, 0x00555356, 0x00636264, 0x00757476, 0x00878588, 0x009D9D9D, 0x00B2B2B2, 0x00C9C9C9, 0x00DDDDDD, 0x00F5F5F5, 0x00FFFFFF, 0x00E8E8E8, 0x00D0D0D0, 0x00B7B7B7, 
        0x00A3A3A3, 0x00919091, 0x00807F81, 0x00969597, 0x0AA9A9A9, 0xC4BDBDBD, 0xFFC7C7C7, 0xFFC5C5C5, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFCBCBCB, 0xFFCBCBCB, 0x5AF0F0F0, 0x00DBDBDB, 0x003C3B3D, 0x0029282A, 0x003A393B, 0x00484749, 0x00575658, 0x006A696B, 0x007D7C7E, 0x00959495, 0x00AEAEAE, 0x00C8C8C8, 0x00DEDEDE, 0x00F9F9F9, 0x00FAFAFA, 0x00DBDBDB, 0x00C1C1C1, 0x00A7A7A7, 
        0x00929292, 0x00808080, 0x006C6C6C, 0x00666666, 0x009A9A9A, 0x31B1B1B1, 0xF6C6C6C6, 0xFFC8C8C8, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFB4B4B4, 0xCDB4B4B4, 0x06CCCCCC, 0x006F6F70, 0x00343335, 0x00333234, 0x002F2E30, 0x003A393B, 0x0049484A, 0x005D5C5E, 0x00727174, 0x008C8B8C, 0x00A8A8A8, 0x00C6C6C6, 0x00E1E1E1, 0x00FCFCFC, 0x00F1F1F1, 0x00CDCDCD, 0x00B0B0B0, 0x00959595, 
        0x00808080, 0x006E6E6E, 0x005C5C5C, 0x00545454, 0x00727272, 0x00ABABAB, 0x99BFBFBF, 0xFFCCCCCC, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFE8D8D8D, 0x588D8D8D, 0x00878786, 0x004F4F4F, 0x004A494B, 0x00424143, 0x00353436, 0x002F2E30, 0x0039383A, 0x004E4D4F, 0x00656466, 0x00818081, 0x00A0A0A0, 0x00C4C4C4, 0x00E5E5E5, 0x00FBFBFB, 0x00E2E2E2, 0x00BABABA, 0x009B9B9B, 0x007F7F7F, 
        0x006B6B6B, 0x005C5C5C, 0x005A5A5A, 0x00616161, 0x00656565, 0x00979797, 0x26B5B5B5, 0xEEC7C7C7, 0xFFFFFFFF,
  0xFFFFFFFF, 0xD2666666, 0x065A5A5A, 0x00666667, 0x00606061, 0x005A595B, 0x00525153, 0x00484749, 0x003B3A3C, 0x00302F31, 0x00373638, 0x00525153, 0x00717072, 0x00959495, 0x00C1C1C1, 0x00E9E9E9, 0x00F6F6F6, 0x00CCCCCC, 0x009F9F9F, 0x007F7F7F, 0x00636363, 
        0x00585858, 0x005F5F5F, 0x00686868, 0x006D6D6D, 0x006F6F6F, 0x00878788, 0x00B3B3B5, 0x9CC2C1C2, 0xFFFFFFFF,
  0xFFFFFFFF, 0x88363636, 0x00363636, 0x00717071, 0x00706F72, 0x006A696B, 0x00636264, 0x005B5A5C, 0x00515052, 0x00424143, 0x00323133, 0x003A393B, 0x005B5A5C, 0x00858486, 0x00BBBBBB, 0x00EEEEEE, 0x00E6E6E6, 0x00ADADAD, 0x007E7E7E, 0x00616161, 0x005C5C5C, 
        0x00656565, 0x006D6D6D, 0x00747474, 0x00797878, 0x007B7A7C, 0x00848386, 0x00B4B3B8, 0x5EC0BFC2, 0xFFFFFFFF,
  0xFFFFFFFF, 0x4A0D0D0D, 0x002C2C2C, 0x00848384, 0x00807F81, 0x007B7A7C, 0x00767577, 0x00706F71, 0x00686769, 0x005E5D5F, 0x004F4E50, 0x0039383A, 0x00373638, 0x00676668, 0x00B3B3B3, 0x00F4F4F4, 0x00C4C4C4, 0x007A7A7A, 0x005D5D5D, 0x00616161, 0x00707070, 
        0x00777778, 0x007C7C7D, 0x00818082, 0x00858485, 0x00878688, 0x0089888A, 0x00B1B0B3, 0x37C3C2C5, 0xFFFFFFFF,
  0xFFFFFFFF, 0x26080808, 0x00424242, 0x00969597, 0x008D8C8E, 0x008A898B, 0x00878688, 0x00848385, 0x00807F81, 0x0079787A, 0x00706F71, 0x00616062, 0x00444345, 0x00403F41, 0x009B9B9B, 0x00E5E5E5, 0x00848485, 0x00616161, 0x00707070, 0x007D7D7D, 0x00838383, 
        0x00888788, 0x008B8A8C, 0x008E8D8F, 0x00909091, 0x00929193, 0x00909092, 0x00B0AFB3, 0x1FC7C7C9, 0xFFFFFFFF,
  0xFFFFFFFF, 0x121A1A1B, 0x005E5E60, 0x00A5A4A6, 0x009C9B9D, 0x009C9B9D, 0x009B9A9C, 0x009A999B, 0x00989799, 0x00979698, 0x00959496, 0x00908F92, 0x0089888A, 0x006E6D6F, 0x00737373, 0x009C9C9D, 0x007E7D7F, 0x008F8E90, 0x00969597, 0x0099989A, 0x009A999B, 
        0x009C9B9D, 0x009C9B9D, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009C9B9D, 0x00ACADB2, 0x11C7C7CB, 0xFFFFFFFF,
  0xFFFFFFFF, 0x102C2B2C, 0x00676668, 0x00A6A5A7, 0x009D9C9E, 0x009D9C9E, 0x009D9C9E, 0x009C9B9D, 0x009B9A9C, 0x009A999B, 0x00989799, 0x00959496, 0x008E8D8F, 0x007E7D7E, 0x009D9D9D, 0x00737172, 0x006D6C6F, 0x008A898B, 0x00908F91, 0x00959496, 0x00979698, 
        0x0099989A, 0x0099989A, 0x009B9A9C, 0x009C9B9D, 0x009D9C9D, 0x009B9A9D, 0x00A4A5A9, 0x10BCBCC0, 0xFFFFFFFF,
  0xFFFFFFFF, 0x21444344, 0x00636264, 0x00989799, 0x00929193, 0x00908F91, 0x008E8D8F, 0x008C8B8D, 0x00888789, 0x00838284, 0x007C7B7C, 0x00707070, 0x00616161, 0x00858585, 0x00E5E5E5, 0x009B9A9C, 0x00403F41, 0x00454446, 0x00616062, 0x00706F71, 0x0079787A, 
        0x00807F81, 0x00848385, 0x00878688, 0x008A898B, 0x008D8B8D, 0x008D8D8F, 0x0096979B, 0x1BAEAEB2, 0xFFFFFFFF,
  0xFFFFFFFF, 0x40646364, 0x005C5B5D, 0x008A898B, 0x00888788, 0x00858486, 0x00828182, 0x007D7C7D, 0x00777778, 0x00706F71, 0x00616162, 0x005D5D5C, 0x007B7B7A, 0x00C5C5C5, 0x00F4F4F4, 0x00B3B3B3, 0x00666567, 0x00373638, 0x00383739, 0x004F4E50, 0x005E5D5F, 
        0x00686769, 0x00706F71, 0x00767577, 0x007B7A7C, 0x007E7D7F, 0x00818082, 0x0088888C, 0x30A6A6A9, 0xFFFFFFFF,
  0xFFFFFFFF, 0x79858485, 0x005D5C5E, 0x007B7B7B, 0x007D7D7D, 0x00797979, 0x00747373, 0x006D6D6D, 0x00656565, 0x005C5C5C, 0x00616161, 0x007D7D7D, 0x00ADADAD, 0x00E6E6E6, 0x00EEEEEE, 0x00BBBBBB, 0x00858486, 0x005A595B, 0x0039383A, 0x00333234, 0x00434244, 
        0x00515052, 0x005B5A5C, 0x00636264, 0x006A696B, 0x00706F71, 0x00737274, 0x00777678, 0x55A5A4A5, 0xFFFFFFFF,
  0xFFFFFFFF, 0xC19E9D9F, 0x006F6E70, 0x00707070, 0x00737373, 0x006D6D6D, 0x00686868, 0x005E5E5E, 0x00585858, 0x00646464, 0x007F7F7F, 0x009F9F9F, 0x00CCCCCC, 0x00F6F6F6, 0x00EAEAEA, 0x00C0C0C0, 0x00959496, 0x00717072, 0x00525153, 0x00383739, 0x00302F31, 
        0x003C3B3D, 0x0049484A, 0x00535254, 0x005A595B, 0x00626163, 0x00636264, 0x0069686A, 0x89B4B3B4, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFBB0AFB1, 0x418D8C8F, 0x006F6F70, 0x00676767, 0x00616161, 0x005B5B5B, 0x005C5C5C, 0x006A6A6A, 0x007F7F7F, 0x009B9B9B, 0x00BABABA, 0x00E2E2E2, 0x00FCFCFC, 0x00E5E5E5, 0x00C4C4C4, 0x00A09FA1, 0x00818082, 0x00656466, 0x004E4D4F, 0x0039383A, 
        0x002F2E30, 0x00363537, 0x00424143, 0x004A494B, 0x00525153, 0x005E5D5F, 0x1579787A, 0xE2CECDCF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFBDBDBE, 0xB4AFAFAF, 0x00818082, 0x00636264, 0x00565657, 0x005D5D5D, 0x006E6E6E, 0x00808080, 0x00959595, 0x00AFAFAF, 0x00CDCDCD, 0x00F1F1F1, 0x00FCFCFC, 0x00E1E1E1, 0x00C6C6C6, 0x00A7A7A7, 0x008C8C8C, 0x00727173, 0x005D5C5E, 0x0049484A, 
        0x003A393B, 0x002F2E30, 0x00333234, 0x0039383A, 0x00575658, 0x007A797B, 0x79AFAEB0, 0xFFD5D4D6, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFBFBFBF, 0xFCC0BFBF, 0x3E9E9E9F, 0x007A797B, 0x00626262, 0x006E6E6E, 0x00808080, 0x00929292, 0x00A6A6A6, 0x00C0C0C0, 0x00DBDBDB, 0x00FAFAFA, 0x00F9F9F9, 0x00DEDEDE, 0x00C7C7C7, 0x00ADADAD, 0x00959495, 0x007D7C7E, 0x006A696B, 0x00575658, 
        0x00484749, 0x003A393B, 0x002A292B, 0x0039383A, 0x008A898B, 0x1DA1A0A2, 0xE8CECDCF, 0xFFCFCED0, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC0C0C0, 0xFFC1C1C1, 0xCEBABABA, 0x0E9A9A9A, 0x00808080, 0x007F7E80, 0x00919191, 0x00A3A3A3, 0x00B7B7B7, 0x00D0D0D0, 0x00E8E8E8, 0x00FFFFFF, 0x00F5F5F5, 0x00DDDDDD, 0x00C9C9C9, 0x00B2B2B2, 0x009D9C9C, 0x00878587, 0x00757476, 0x00636264, 
        0x00545355, 0x00414043, 0x00363538, 0x008F8F90, 0x00B8B8B9, 0xA1C6C6C6, 0xFFD4D3D4, 0xFFD1D1D1, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC3C3C3, 0xFFC3C3C3, 0xFFC5C5C5, 0xADB9B9B9, 0x0C979798, 0x00888789, 0x009C9C9C, 0x00B4B4B4, 0x00C5C5C5, 0x00DBDBDB, 0x00F2F2F2, 0x00FFFFFF, 0x00F2F2F2, 0x00DCDCDC, 0x00CACACA, 0x00B5B5B5, 0x00A2A2A2, 0x008E8D8F, 0x007C7B7D, 0x006B6A6C, 
        0x00575658, 0x005C5B5C, 0x00AFAEB0, 0x00DAD9DB, 0x80CACACA, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC6C6C6, 0xA9BABABA, 0x0C999999, 0x008B8B8B, 0x00ABABAB, 0x00D3D3D3, 0x00EBEBEB, 0x00FCFCFC, 0x00FFFFFF, 0x00EFEFEF, 0x00DCDCDC, 0x00CBCBCB, 0x00B8B8B8, 0x00A8A8A8, 0x00979698, 0x00868587, 0x00737274, 
        0x00838384, 0x00DFDFDF, 0x00FDFDFD, 0x80D4D4D4, 0xFFD1D1D1, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC3C3C3, 0xFFC6C6C6, 0xC1BBBBBB, 0x359C9C9C, 0x00828282, 0x00989898, 0x00C7C7C7, 0x00EEEEEF, 0x00FEFDFE, 0x00F5F5F5, 0x00E6E6E6, 0x00D8D8D8, 0x00C4C4C4, 0x00AEADAE, 0x00929193, 0x007C7B7D, 0x00868587, 
        0x00BABABA, 0x22E1E1E1, 0xA0D5D5D5, 0xFFCDCDCD, 0xFFD1D1D1, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC3C3C3, 0xFFC4C4C4, 0xFFC2C2C2, 0xF5BFBFBF, 0x97B5B5B5, 0x2A8F8F8F, 0x00707071, 0x006B6A6C, 0x00807F81, 0x008B8A8C, 0x00898889, 0x00797979, 0x00555555, 0x002E2D2E, 0x00232323, 0x00464646, 0x18878787, 
        0x79BDBDBD, 0xE6CCCCCC, 0xFFC9C9C9, 0xFFCECECE, 0xFFD1D1D1, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC4C4C4, 0xFFC3C3C3, 0xFFC4C4C4, 0xFFC1C1C1, 0xFFBDBDBD, 0xFFC8C8C8, 0xEEC4C4C4, 0x9CAFAEAF, 0x61909091, 0x39717071, 0x20565556, 0x123E3E3E, 0x102F2F2F, 0x1C262626, 0x31303030, 0x575E5E5E, 0x8A9E9E9E, 0xE1C7C7C7, 
        0xFFD0D0D0, 0xFFCECECE, 0xFFCACACA, 0xFFCECECE, 0xFFD1D1D1, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFD3D3D3, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

GUI_CONST_STORAGE GUI_BITMAP bmknob_gray_trans_30x30 = {
  30, // xSize
  30, // ySize
  120, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acknob_gray_trans_30x30,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       Button 30x30 pressed
*/
static GUI_CONST_STORAGE unsigned long _acknob_black_trans_30x30[] = {
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2E2E2E, 0xFF343434, 0xFF383838, 0xFF333333, 0xFF393939, 0xFF333333, 0xD23A3A3A, 0x854D4E4D, 0x4E4F504D, 0x274A4B47, 0x133F403C, 0x113A3B38, 0x223F403C, 0x45424240, 0x7A414140, 0xC5393A38, 0xFE353634, 
        0xFF3A3A3A, 0xFF373737, 0xFF353535, 0xFF343434, 0xFF2E2E2E, 0xFF2D2D2D, 0xFF2D2D2D, 0xFF2D2D2D, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2E2E2E, 0xFF343434, 0xFF373737, 0xFD313131, 0xB74C4C4D, 0x51727172, 0x0A858584, 0x007B7D7A, 0x00686966, 0x00535451, 0x00424341, 0x00323331, 0x002F2F2E, 0x00353634, 0x00424341, 0x034F504E, 0x424B4C4A, 
        0xA8424242, 0xF3363636, 0xFF343434, 0xFF343434, 0xFF2E2E2E, 0xFF2D2D2D, 0xFF2D2D2D, 0xFF2D2D2D, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2F2F2F, 0xFF2E2E2E, 0xFF333333, 0xE4393939, 0x4A5A5B5A, 0x00888988, 0x00A0A09F, 0x008A8B89, 0x006A6B69, 0x00575857, 0x00464646, 0x00363636, 0x00252525, 0x00161516, 0x00040504, 0x00070707, 0x00272726, 0x00484948, 
        0x00585857, 0x384F504F, 0xD4383838, 0xFF333333, 0xFF2E2E2E, 0xFF2D2D2D, 0xFF2D2D2D, 0xFF2D2D2D, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2E2E2E, 0xFF2E2E2E, 0xFF2E2E2E, 0xFF2E2E2E, 0xC7363636, 0x334B4B4B, 0x0070726F, 0x008C8D8B, 0x008C8D8B, 0x007A7B79, 0x006A6B69, 0x005A5B5A, 0x00484848, 0x00373737, 0x00242424, 0x00131313, 0x00010101, 0x00030303, 0x00161616, 0x002E2E2E, 
        0x00494A49, 0x00585958, 0x1A555555, 0xAC3E3E3E, 0xFF2B2B2B, 0xFF2D2D2D, 0xFF2D2D2D, 0xFF2D2D2D, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF353535, 0xFF353535, 0xFF363636, 0xC9343434, 0x0D2E2E2E, 0x00525252, 0x00A2A2A1, 0x00A5A6A4, 0x00949593, 0x00848583, 0x00717270, 0x005F605F, 0x004B4B4B, 0x00383838, 0x00242424, 0x00101010, 0x00000000, 0x000A0A0A, 0x00232323, 0x00383838, 
        0x004C4D4C, 0x005D5D5D, 0x005D5D5D, 0x06565755, 0xB03B3B3B, 0xFF2E2E2E, 0xFF2F2F2F, 0xFF2F2F2F, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF363636, 0xFF363636, 0xE4363636, 0x31191919, 0x00383838, 0x00A8A8A8, 0x00C0C0BF, 0x00ACADAB, 0x009C9D9B, 0x008C8D8B, 0x00797A78, 0x00656564, 0x004E4E4E, 0x003A3A3A, 0x00232323, 0x000D0D0D, 0x00000000, 0x00131313, 0x002D2D2D, 0x00444444, 
        0x005B5B5B, 0x006D6D6D, 0x007A7A79, 0x00656664, 0x11565656, 0xC43A3A3A, 0xFF303030, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF313131, 0xFB333333, 0x481A1A1B, 0x000C0C0C, 0x00AEAFAD, 0x00DBDCDB, 0x00C6C7C5, 0x00B7B8B6, 0x00A8A9A7, 0x00979896, 0x00828481, 0x006D6E6C, 0x00535353, 0x003C3C3C, 0x00222222, 0x00090909, 0x00050505, 0x00202020, 0x003C3C3C, 0x00545454, 
        0x006B6B6B, 0x007D7D7D, 0x00919191, 0x00949494, 0x005F5F5F, 0x314D4D4D, 0xFA313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF333333, 0xB93A3A3A, 0x002C2C2C, 0x00646463, 0x00CBCCCA, 0x00CDCECC, 0x00D1D2D0, 0x00C5C6C4, 0x00B5B6B4, 0x00A3A4A2, 0x008D8E8C, 0x00757775, 0x00595A59, 0x003E3E3E, 0x00202020, 0x00060606, 0x000D0D0D, 0x002D2D2D, 0x004D4D4D, 0x00656565, 
        0x007D7D7D, 0x008E8E8E, 0x00A0A0A0, 0x00ABABAB, 0x00868686, 0x00535353, 0x9B3F3F3F, 0xFF343434, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2E2E2E, 0x4E575757, 0x006C6C6C, 0x00A8A9A8, 0x00B7B8B6, 0x00BDBEBC, 0x00CACBC9, 0x00D1D2D0, 0x00C7C8C6, 0x00B3B4B2, 0x009B9C9A, 0x00828381, 0x00626262, 0x00414141, 0x001C1C1C, 0x00040404, 0x001C1C1C, 0x00404040, 0x00636363, 0x007C7C7C, 
        0x00949494, 0x00A4A4A4, 0x00A7A7A7, 0x00A0A0A0, 0x009C9C9C, 0x00686868, 0x1C4A4A4B, 0xEE333334, 0xFFFFFFFF,
  0xFFFFFFFF, 0xD43D3D3D, 0x09959595, 0x00959595, 0x00A1A2A1, 0x00A6A7A5, 0x00AEAFAD, 0x00B8B9B7, 0x00C5C6C4, 0x00D0D1CF, 0x00C7C8C6, 0x00ADAEAC, 0x00919190, 0x006C6D6C, 0x00454545, 0x00181818, 0x00060606, 0x002F2F2F, 0x00585858, 0x007C7C7C, 0x00969696, 
        0x00A5A5A5, 0x00A3A3A3, 0x009B9B9B, 0x00959595, 0x00939392, 0x00777777, 0x004D4D4C, 0x9E3A3A3A, 0xFFFFFFFF,
  0xFFFFFFFF, 0x83737373, 0x00D1D1D1, 0x00919291, 0x0090918E, 0x00969795, 0x009D9E9C, 0x00A5A6A4, 0x00AFB0AE, 0x00BEBFBD, 0x00CDCECC, 0x00C8C9C7, 0x00A8A9A7, 0x007D7E7C, 0x004C4D4C, 0x00111111, 0x00111111, 0x004E4E4E, 0x007B7B7B, 0x009E9E9E, 0x00A6A6A6, 
        0x009C9C9C, 0x00939393, 0x008D8D8E, 0x00888888, 0x00868785, 0x007C7D7A, 0x004B4C48, 0x5B40413F, 0xFFFFFFFF,
  0xFFFFFFFF, 0x4DABABAB, 0x00E7E7E7, 0x00808180, 0x00818280, 0x00868785, 0x008B8C8A, 0x00919290, 0x00999A98, 0x00A5A6A4, 0x00B4B5B3, 0x00C9CAC8, 0x00C5C6C4, 0x00999A98, 0x00575757, 0x000C0C0C, 0x002D2D2D, 0x007C7C7C, 0x009D9D9D, 0x00A1A1A1, 0x00959595, 
        0x008B8B8A, 0x00858584, 0x00808180, 0x007D7D7D, 0x007A7B7A, 0x00777876, 0x004F504C, 0x383D3E3C, 0xFFFFFFFF,
  0xFFFFFFFF, 0x25CACACA, 0x00D7D7D7, 0x0070706F, 0x00727471, 0x00767775, 0x00797A78, 0x007D7E7C, 0x00818280, 0x00888987, 0x00919290, 0x00A1A2A0, 0x00BBBCBA, 0x00C7C8C6, 0x00737373, 0x00151515, 0x00717171, 0x00A2A2A2, 0x00949494, 0x00868686, 0x007E7E7E, 
        0x007A7A79, 0x00757774, 0x00727371, 0x00717170, 0x006E6F6E, 0x006F706E, 0x004F504C, 0x1E383937, 0xFFFFFFFF,
  0xFFFFFFFF, 0x14C9C9C8, 0x00BCBDBB, 0x00616260, 0x00646563, 0x00666765, 0x00676866, 0x00686967, 0x006A6B69, 0x006D6E6C, 0x0070716F, 0x00757674, 0x007F807E, 0x009D9E9C, 0x008F8F8F, 0x00575757, 0x00878886, 0x007A7B79, 0x0070716F, 0x006B6C6A, 0x00696968, 
        0x00686967, 0x00666765, 0x00656664, 0x00656564, 0x00636462, 0x00666664, 0x0053524E, 0x12373734, 0xFFFFFFFF,
  0xFFFFFFFF, 0x11B9B9B9, 0x00ADAEAC, 0x005E5F5D, 0x00616260, 0x00626361, 0x00626361, 0x00636462, 0x00646563, 0x00656664, 0x00676866, 0x00696A69, 0x006F706E, 0x00828381, 0x00707070, 0x00919190, 0x00979895, 0x00757674, 0x006F706E, 0x006B6D6A, 0x00696A68, 
        0x00666765, 0x00656664, 0x00656664, 0x00646563, 0x00636462, 0x00656563, 0x005D5B57, 0x1143433F, 0xFFFFFFFF,
  0xFFFFFFFF, 0x219E9E9E, 0x00AAABA9, 0x00696A68, 0x006B6C6A, 0x006E6F6D, 0x006F716E, 0x00717270, 0x00747673, 0x007A7B79, 0x007F807F, 0x008B8B8B, 0x00999999, 0x008A8A8A, 0x002F2F2F, 0x00666766, 0x00BFC0BE, 0x00B7B8B6, 0x009C9D9B, 0x008D8E8C, 0x00858684, 
        0x007E7F7D, 0x00797A78, 0x00777876, 0x00737472, 0x00717270, 0x0072716F, 0x00696863, 0x1B50504C, 0xFFFFFFFF,
  0xFFFFFFFF, 0x447B7B7A, 0x00AAABA9, 0x00777876, 0x00777876, 0x007A7B79, 0x007E7E7D, 0x00828382, 0x00868786, 0x008F8F8E, 0x009C9C9B, 0x00A5A5A5, 0x008B8B8B, 0x00434343, 0x000E0E0E, 0x004B4B4B, 0x00949593, 0x00C9CAC8, 0x00C9CAC8, 0x00B2B3B1, 0x00A2A3A1, 
        0x00979896, 0x008F908E, 0x008A8B89, 0x00858684, 0x00818280, 0x007F7F7D, 0x00787774, 0x325A5A57, 0xFFFFFFFF,
  0xFFFFFFFF, 0x795A5B5A, 0x00A2A3A1, 0x00848584, 0x00818181, 0x00858585, 0x008A8A8A, 0x00909090, 0x00979797, 0x00A2A2A2, 0x00A2A2A2, 0x00898989, 0x005D5D5D, 0x001E1E1E, 0x000C0C0C, 0x00454545, 0x00797A78, 0x00A8A9A7, 0x00C6C7C5, 0x00CCCDCB, 0x00BCBDBB, 
        0x00ADAEAC, 0x00A3A4A2, 0x009B9C9A, 0x00949593, 0x008F908E, 0x008B8C8A, 0x00868785, 0x555C5D5C, 0xFFFFFFFF,
  0xFFFFFFFF, 0xC7373837, 0x01898A88, 0x00929392, 0x008C8C8C, 0x00919191, 0x00979797, 0x00A0A0A0, 0x00A7A7A7, 0x009E9E9E, 0x00868686, 0x00636363, 0x003C3C3C, 0x00090909, 0x00101010, 0x003F3F3F, 0x00686967, 0x008E8F8D, 0x00ACADAB, 0x00C8C9C7, 0x00D0D1CF, 
        0x00C4C5C3, 0x00B7B8B6, 0x00ADAEAC, 0x00A5A6A4, 0x009FA09E, 0x009D9E9C, 0x00979896, 0x8F4C4D4C, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFB2D2E2C, 0x40636462, 0x00919291, 0x00979797, 0x009C9C9C, 0x00A3A3A3, 0x00A6A6A6, 0x009B9B9B, 0x00848484, 0x006B6B6B, 0x004A4A4A, 0x00252525, 0x00020202, 0x00151516, 0x003C3C3C, 0x005D5E5C, 0x0080817F, 0x009A9B99, 0x00B3B4B2, 0x00C7C8C6, 
        0x00D1D2D0, 0x00C8C9C7, 0x00BCBDBB, 0x00B3B4B2, 0x00ADAEAC, 0x00A2A3A1, 0x148B8C8A, 0xE1333432, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF303030, 0xAA424241, 0x007A7B7A, 0x00969796, 0x00A9AAA9, 0x00A5A4A5, 0x00959596, 0x00838383, 0x006D6D6D, 0x00545454, 0x00353535, 0x00151515, 0x00010101, 0x001A1A1A, 0x00393939, 0x00565656, 0x00747473, 0x008B8C8A, 0x00A3A4A2, 0x00B5B6B4, 
        0x00C6C7C5, 0x00D1D2D0, 0x00CDCECC, 0x00C7C8C6, 0x00A9AAA8, 0x00868785, 0x84525351, 0xFF2C2D2B, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF303031, 0xF2303030, 0x35585857, 0x00818280, 0x009D9E9D, 0x00949394, 0x00828282, 0x00717171, 0x005B5B5B, 0x00434343, 0x00262626, 0x000A0A0A, 0x00040404, 0x001D1D1D, 0x00383838, 0x00515051, 0x006A6A6A, 0x0080817F, 0x00969795, 0x00A7A8A6, 
        0x00B7B8B6, 0x00C6C7C5, 0x00D6D7D5, 0x00C7C8C6, 0x00767675, 0x235E5F5D, 0xEE30312F, 0xFF2F302E, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF303030, 0xFF2E2E2E, 0xD6333333, 0x175E5E5E, 0x007E7E7E, 0x00828381, 0x00717271, 0x00606060, 0x004A4A4A, 0x00343434, 0x00191919, 0x00040404, 0x00090909, 0x001F1F1F, 0x00363636, 0x004C4C4C, 0x00636362, 0x00777876, 0x008B8C8A, 0x009B9C9A, 
        0x00ABACAA, 0x00BEBFBD, 0x00C9CAC8, 0x0070716F, 0x00474747, 0xAD3C3C3B, 0xFF2F2F2E, 0xFF303130, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2E2E2E, 0xFF2E2E2E, 0xFF2C2C2C, 0xAD3B3B3B, 0x07646463, 0x00767775, 0x00686868, 0x004F4F4F, 0x003C3C3C, 0x00292929, 0x000F0F0F, 0x00010101, 0x000D0D0D, 0x00202020, 0x00363636, 0x00494949, 0x005D5E5D, 0x0070716F, 0x00838482, 0x00929391, 
        0x00A9A9A8, 0x00A4A5A3, 0x00515250, 0x02252625, 0x8C373737, 0xFF313031, 0xFF313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF292929, 0xAF3B3B3A, 0x12616161, 0x00787878, 0x005C5C5C, 0x002F2F2F, 0x00171717, 0x00040404, 0x00000000, 0x00101010, 0x00222222, 0x00353534, 0x00464646, 0x00585857, 0x00686967, 0x007A7B79, 0x008B8D8B, 
        0x007D7D7C, 0x00212121, 0x01020202, 0x8C2B2B2B, 0xFF313131, 0xFF313131, 0xFF313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF323232, 0xC23B3B3B, 0x365B5B5B, 0x00797979, 0x006B6B6B, 0x003F3F3F, 0x00121211, 0x00020302, 0x00090909, 0x00171717, 0x00272728, 0x003A3A3A, 0x00525252, 0x006B6B6A, 0x00838483, 0x007C7D7C, 
        0x00464645, 0x281E1E1E, 0xAA2B2B2B, 0xFF353535, 0xFF303030, 0xFF313131, 0xFF313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF353535, 0xFF353535, 0xF8313131, 0x9B474747, 0x216E6E6E, 0x008C8D8C, 0x00979895, 0x00848583, 0x00757674, 0x00767776, 0x00868687, 0x00A7A7A7, 0x00D2D2D2, 0x00DEDEDE, 0x00BBBBBB, 0x187F8080, 
        0x84474747, 0xEC373737, 0xFF383838, 0xFF343434, 0xFF303030, 0xFF313131, 0xFF313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF2B2B2B, 0xFF353535, 0xFF363636, 0xFF333333, 0xFF393939, 0xEB353535, 0x9F474746, 0x5E6B6C6B, 0x3A898988, 0x1FA9AAA9, 0x12BEBFBE, 0x11D1D1D1, 0x1CDADADA, 0x33D0D0D0, 0x57AAAAAA, 0x8F626262, 0xE0393939, 
        0xFF393939, 0xFF363636, 0xFF363636, 0xFF343434, 0xFF303030, 0xFF313131, 0xFF313131, 0xFF313131, 0xFFFFFFFF,
  0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 
        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF
};

GUI_CONST_STORAGE GUI_BITMAP bmknob_black_trans_30x30 = {
  30, // xSize
  30, // ySize
  120, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acknob_black_trans_30x30,  // Pointer to picture data
  NULL,  // Pointer to palette
  GUI_DRAW_BMP8888
};

/*********************************************************************
*
*       _aDialogCreate
*/
static const GUI_WIDGET_CREATE_INFO _aDialogCreate[] = {
  { WINDOW_CreateIndirect,  "", ID_WIN_0,        0,   0,   600, 450, WM_CF_SHOW, 0, 0 },
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB0,    20,  185, 70,  70,  WM_CF_SHOW },       // Power
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB1,    270, 120, 140, 140, WM_CF_SHOW },       // Volume
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB2,    20,  20,  70,  70,  WM_CF_SHOW },       // Gain
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB3,    115, 20,  70,  70,  WM_CF_SHOW },       // High
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB4,    210, 20,  70,  70,  WM_CF_SHOW },       // Mid
  { KNOB_CreateIndirect,    "", GUI_ID_KNOB5,    305, 20,  70,  70,  WM_CF_SHOW },       // Low
  { BUTTON_CreateIndirect,  "", GUI_ID_BUTTON0,  415, 110,  30,  30,  },                 // Automode
};

/*********************************************************************
*
*       Animation coordinates
*/
static ANIM _aAnim[] = {
  // Standby On
  {  70, 240, 0, 200 },
  {  70, 220, 1, 200 },
  {  70, 220, 0, 200 },
  // Power On
  {  70, 240, 0, 200 },
  {  70, 220, 1, 200 },
  {  70, 220, 0, 200 },
  // Volume up
  { 290, 210, 0, 100 },
  { 300, 180, 1, 100 },
  { 330, 170, 1, 100 },
  { 360, 180, 1, 100 },
  { 370, 210, 1, 100 },
  { 360, 220, 1, 100 },
  { 330, 250, 1, 100 },
  { 300, 220, 1, 100 },
  { 290, 210, 1, 100 },
  // Gain up
  {  35,  80, 0, 100 },
  {  35,  30, 1, 100 },
  {  35,  80, 0,  50 },
  {  35,  30, 1,  50 },
  // High up
  { 130,  80, 0, 100 },
  { 130,  30, 1, 100 },
  { 130,  80, 0,  50 },
  { 130,  30, 1,  50 },
  // Middle up
  { 225,  80, 0, 100 },
  { 225,  40, 1, 100 },
  { 225,  80, 0,  50 },
  { 225,  60, 1,  50 },
  // Low up
  { 320,  80, 0, 100 },
  { 320,  40, 1, 100 },
  // Standby Off
  {  70, 230, 0, 200 },
  {  70, 250, 1, 200 },
  {  70, 250, 0, 200 },
  // Standby On
  {  70, 250, 0, 200 },
  {  70, 230, 1, 200 },
  // Low down
  { 320,  40, 0, 100 },
  { 320,  80, 1, 100 },
  // Middle down
  { 225,  40, 0, 100 },
  { 225,  80, 1, 100 },
  { 225,  40, 0,  50 },
  { 225,  80, 1,  50 },
  // High down
  { 130,  30, 0, 100 },
  { 130,  80, 1, 100 },
  { 130,  30, 0,  50 },
  { 130,  80, 1,  50 },
  // Gain down
  {  35,  30, 0, 100 },
  {  35,  80, 1, 100 },
  {  35,  30, 0,  50 },
  {  35,  80, 1,  50 },
  // Volume down
  { 280, 210, 0, 100 },
  { 280, 210, 1, 100 },
  { 290, 220, 1, 100 },
  { 320, 250, 1, 100 },
  { 350, 220, 1, 100 },
  { 360, 210, 1, 100 },
  { 350, 180, 1, 100 },
  { 320, 170, 1, 100 },
  { 290, 180, 1, 100 },
  { 280, 210, 1, 100 },
  // Standby Off
  {  70, 220, 0, 200 },
  {  70, 240, 1, 200 },
  {  70, 240, 0, 200 },
  // Power Off
  {  70, 220, 0, 200 },
  {  70, 240, 1, 200 },
  {  70, 240, 0, 200 },
};

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _DrawKnob
*/
static void _DrawKnob(GUI_MEMDEV_Handle hMem, GUI_COLOR Color) {
  int xSizeMem, ySizeMem;

  xSizeMem = GUI_MEMDEV_GetXSize(hMem);
  ySizeMem = GUI_MEMDEV_GetYSize(hMem);
  GUI_AA_PreserveTrans(1);
  GUI_MEMDEV_Select(hMem);
  GUI_SetBkColor(GUI_TRANSPARENT);
  GUI_Clear();
  GUI_SetColor(Color);
  GUI_AA_FillCircle(xSizeMem / 2 + xSizeMem / 3, ySizeMem / 2, 3);
  GUI_MEMDEV_Select(0);
  GUI_AA_PreserveTrans(0);
}

/*********************************************************************
*
*       _DrawKnobBig
*/
static void _DrawKnobBig(GUI_MEMDEV_Handle hMem, GUI_COLOR Color) {
  int xSizeMem, ySizeMem;

  xSizeMem = GUI_MEMDEV_GetXSize(hMem);
  ySizeMem = GUI_MEMDEV_GetYSize(hMem);
  GUI_AA_PreserveTrans(1);
  GUI_MEMDEV_Select(hMem);
  GUI_SetBkColor(GUI_TRANSPARENT);
  GUI_Clear();
  GUI_SetPenSize(3);
  GUI_SetColor(Color);
  GUI_AA_DrawLine(xSizeMem / 2 + 10, ySizeMem / 2, xSizeMem / 2 + xSizeMem / 3, ySizeMem / 2);
  GUI_SetPenSize(1);
  GUI_MEMDEV_Select(0);
  GUI_AA_PreserveTrans(0);
}

/*********************************************************************
*
*       _DrawScale
*/
static void _DrawScale(KNOB_Handle hKnob, int PowerOn) {
  GUI_COLOR DarkerGreen;
  I32       CosHQ, SinHQ;
  I32       Angle, Value;
  int       xPos,  yPos;

  DarkerGreen  = 0x00E800;
  Value = 270 - KNOB_GetValue(hKnob) / 10;
  xPos = WM_GetWindowOrgX(hKnob) + bmknob_gray_trans_70x70.XSize / 2;
  yPos = WM_GetWindowOrgY(hKnob) + bmknob_gray_trans_70x70.YSize / 2;
  for (Angle = 270; Angle >= 0; Angle -= 27) {
    if ((Angle < Value) && (PowerOn == 2) && (Angle < 118)) {
      GUI_SetColor(DarkerGreen);
    } else if((Angle < Value) && (PowerOn == 2) && (Angle < 218) && (Angle > 117)) {
      GUI_SetColor(GUI_YELLOW);
    } else if((Angle <= Value) && (PowerOn == 2) && (Angle > 217)) {
      GUI_SetColor(GUI_RED);
    } else {
      GUI_SetColor(AMP_COLOR_GRAY);
    }
    CosHQ = (GUI__CosHQ((Angle + 135) * 1000) * 1000) / 65536;
    SinHQ = (GUI__SinHQ((Angle + 135) * 1000) * 1000) / 65536;
    GUI_AA_DrawLine(xPos + 36 * CosHQ / 1000, yPos + 36 * SinHQ /1000, xPos  + 36 * CosHQ / 1000, yPos + 36 * SinHQ / 1000);
  }
}

/*********************************************************************
*
*       _MoveCursor
*/
static void _MoveCursor(ANIM * pAnim) {
  GUI_PID_STATE State = {0};
  static int    x  = 0;
  static int    y  = 150;
  int           Step;
  int           xPos;
  int           yPos;
  int           Pressed;
  
  xPos       = pAnim->x;
  yPos       = pAnim->y;
  Pressed    = pAnim->Pressed;
  if (xPos == 35) {
    xPos = xPos;
  }
  while (x != xPos || y != yPos) {
    State.x       = x;
    State.y       = y;
    State.Pressed = Pressed;
    GUI_PID_StoreState(&State);
    GUI_CURSOR_SetPosition(x, y);
    Step = (((x - xPos) < 3) && ((x - xPos) > -3)) ? 1 : 3;
    if (x < xPos) {
      x += Step;
    } else if (x > xPos) {
      x -= Step;
    } else {
      x = xPos;
    }
    if (y < yPos) {
      y += Step;
    } else if (y > yPos) {
      y -= Step;
    } else {
      y = yPos;
    }
    GUI_Delay(5);
  }
  State.x = x;
  State.y = y;
  State.Pressed = Pressed;
  GUI_PID_StoreState(&State);
}

/*********************************************************************
*
*       _ChangeMemdevColor
*/
static void _ChangeMemdevColor(GUI_MEMDEV_Handle hMem, GUI_COLOR Color) {
  int   NumItems;
  int   xSize, ySize;
  U32 * pData;
  U32   Data;
  
  pData = (U32 *)GUI_MEMDEV_GetDataPtr(hMem);
  xSize = GUI_MEMDEV_GetXSize(hMem);
  ySize = GUI_MEMDEV_GetYSize(hMem);
  NumItems = xSize * ySize;
  while (NumItems) {
    Data   = *pData;
    Data   = Data >> 24;
    Data   = (Data << 24) + Color;
    *pData = Data;
    pData++;
    NumItems--;
  }
}

/*********************************************************************
*
*       _DrawVol
*/
static void _DrawVol(int x0, int y0, int xSize, int ySize, KNOB_Handle hKnob, int PowerOn) {
  I32 Value;
  int i;
  
  Value = (7200 - KNOB_GetValue(hKnob)) * ySize / 7200;
  GUI_SetColor(AMP_COLOR_GRAY);
  GUI_AA_FillRoundedRect(x0, y0, x0 + xSize, y0 + ySize, 5);
  for (i = 0; i < ySize; i += 10) {
    if ((i < Value) && (PowerOn == 2) && (i < 44)) {
      GUI_SetColor(GUI_LIGHTGREEN);
    } else if((i < Value) && (PowerOn == 2) && (i < 86) && (i > 43)) {
      GUI_SetColor(GUI_LIGHTYELLOW);
    } else if((i < Value) && (PowerOn == 2) && (i > 85)) {
      GUI_SetColor(GUI_LIGHTRED);
    } else {
      GUI_SetColor(AMP_COLOR_GRAY);
    }
    GUI_AA_FillRoundedRect(x0 + 2, ySize + y0 - 8 - i, x0 + xSize - 2, ySize + y0 - 2 - i, 2);
    if ((i < Value) && (PowerOn == 2) && (i < 44)) {
      GUI_SetColor(AMP_COLOR_GREEN);
    } else if((i < Value) && (PowerOn == 2) && (i < 86) && (i > 43)) {
      GUI_SetColor(AMP_COLOR_YELLOW);
    } else if((i < Value) && (PowerOn == 2) && (i > 85)) {
      GUI_SetColor(GUI_RED);
    } else {
      GUI_SetColor(AMP_COLOR_GRAY);
    }
    GUI_AA_FillRoundedRect(x0 + 2, ySize + y0 - 6 - i, x0 + xSize - 4, ySize + y0 - 2 - i, 2);
  }
}

/*********************************************************************
*
*       _cbButton
*/
static void _cbButton(WM_MESSAGE * pMsg) {
  WM_HWIN               hWin;

  hWin  = pMsg->hWin;
  switch (pMsg->MsgId) {
  case WM_PAINT:
    if (BUTTON_IsPressed(hWin)) {
      GUI_DrawBitmap(&bmknob_black_trans_30x30, 0, 0);
    } else {
      GUI_DrawBitmap(&bmknob_gray_trans_30x30, 0, 0);
    }
    break;
  default:
    BUTTON_Callback(pMsg);
  }
}

/*********************************************************************
*
*       _cbDialog
*/
static void _cbDialog(WM_MESSAGE * pMsg) {
  static GUI_MEMDEV_Handle   hMemKnobBig;
  static GUI_MEMDEV_Handle   hMemKnobSmall;
  static GUI_COLOR           PwColor    = AMP_COLOR_GRAY;
  static GUI_COLOR           ColorKnob  = GUI_BLACK;
  static WM_HTIMER           hTimer;
  BUTTON_Handle              hButton;
  KNOB_Handle                hKnob;
  static int                 Index;
  static int                 ButtonPressed = 1;
  static U8                  PowerOn;
  GUI_RECT                   Rect;
  WM_HWIN                    hParent;
  WM_HWIN                    hWin;
  ANIM                     * pAnim;
  int                        NCode;
  int                        Id;
  int                        i;

  hWin      = pMsg->hWin;
  pAnim     = &_aAnim[Index];
  switch (pMsg->MsgId) {
  case WM_TIMER:
    //
    // Start Animation
    //
    if (ButtonPressed) {
      _MoveCursor(pAnim);
      WM_RestartTimer(hTimer, pAnim->Delay);
      Index = (Index == (GUI_COUNTOF(_aAnim) - 1)) ? 0 : Index + 1;
    }
    break;
  case WM_INIT_DIALOG:
    //
    // Create and fill memory devices
    //
    hMemKnobBig   = GUI_MEMDEV_CreateFixed32(0, 0, 140, 20);
    _DrawKnobBig(hMemKnobBig, ColorKnob);
    hMemKnobSmall = GUI_MEMDEV_CreateFixed32(0, 0,  70, 20);
    _DrawKnob(hMemKnobSmall, ColorKnob);
    //
    // Init KNOB On/Off
    //
    hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB0);
    KNOB_SetDevice(hKnob, hMemKnobSmall);
    KNOB_SetTickSize(hKnob, 450);
    KNOB_SetRange(hKnob, 0, 2);
    KNOB_SetOffset(hKnob, 450);
    KNOB_SetPeriod(hKnob, 10);
    //
    // Init KNOB Volume
    //
    hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB1);
    KNOB_SetDevice(hKnob, hMemKnobBig);
    KNOB_SetRange(hKnob, -7200, 0);
    KNOB_SetOffset(hKnob, 1800);
    KNOB_SetPeriod(hKnob, 500);
    //
    // Init KNOB Gain, High, Mid, Low
    //
    for (i = 0; i < 4; i++) {
      hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB2 + i);
      KNOB_SetDevice(hKnob, hMemKnobSmall);
      KNOB_SetRange(hKnob, -2700, 0);
      KNOB_SetOffset(hKnob, -1350);
      KNOB_SetPeriod(hKnob, 500);
    }
    //
    // Init 'Automode'-Button
    //
    hButton = WM_GetDialogItem(hWin, GUI_ID_BUTTON0);
    WM_SetHasTrans(hButton);
    WM_SetCallback(hButton, _cbButton);
    //
    // Start Animation at the beginning
    //
    if (!hTimer) {
      GUI_CURSOR_Show();
      hTimer = WM_CreateTimer(hWin, 0, 1500, 0);
      BUTTON_SetState(hButton, 1);
    }
    break;
  case WM_PAINT:
    //
    // Change Knob color if needed
    //
    if (PowerOn == 1 || PowerOn == 0) {
      _ChangeMemdevColor(hMemKnobSmall, ColorKnob);
      _ChangeMemdevColor(hMemKnobBig, ColorKnob);
    }
    //
    // Draw Background
    //
    GUI_DrawBitmap(&bmBackGround_480x272, 0, 0);
    GUI_DrawBitmap(&bmSeggerLogo_80x40, 430 - bmSeggerLogo_80x40.XSize / 2, 35);
    //
    // Draw scale
    //
    GUI_SetPenSize(3);
    for (i = 0; i <= 3; i++) {
      hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB2 + i);
      _DrawScale(hKnob, PowerOn);
    }
    //
    // KNOB Volume
    //
    GUI_SetTextMode(GUI_TM_TRANS);
    GUI_SetColor(AMP_COLOR_GRAY);
    GUI_DispStringHCenterAt("Volume", 340, 110);
    GUI_AA_FillCircle(340, 190, 63);
    GUI_DrawBitmap(&bmknob_gray_trans_140x140, 340 - bmknob_gray_trans_140x140.XSize / 2, 190 - bmknob_gray_trans_140x140.YSize / 2);
    //
    // Draw Volume bar
    //
    hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB1);
    _DrawVol(225, 120, 40,  130, hKnob, PowerOn);
    //
    // KNOB On/Off
    //
    GUI_SetColor(AMP_COLOR_GRAY);
    GUI_DispStringHCenterAt("ON/STDBY/OFF", 55, 145);
    GUI_AA_FillCircle(55, 220, 32);
    GUI_DrawBitmap(&bmknob_gray_trans_70x70, 55 - bmknob_gray_trans_70x70.XSize / 2, 220 - bmknob_gray_trans_70x70.YSize / 2);
    GUI_SetColor(PwColor);
    GUI_AA_FillCircle(55, 165, 5);
    GUI_SetPenSize(2);
    GUI_SetColor(GUI_BLACK);
    GUI_AA_DrawArc(55, 165, 5, 5, 0, 360);
    //
    // KNOB Gain
    //
    GUI_SetColor(AMP_COLOR_GRAY);
    GUI_DispStringHCenterAt("Gain", 55, 8);
    GUI_AA_FillCircle(55, 55, 32);
    GUI_DrawBitmap(&bmknob_gray_trans_70x70, 55 - bmknob_gray_trans_70x70.XSize / 2, 55 - bmknob_gray_trans_70x70.YSize / 2);
    //
    // KNOB High
    //
    GUI_DispStringHCenterAt("High", 150, 8);
    GUI_AA_FillCircle(150, 55, 32);
    GUI_DrawBitmap(&bmknob_gray_trans_70x70, 150 - bmknob_gray_trans_70x70.XSize / 2, 55 - bmknob_gray_trans_70x70.YSize / 2);
    //
    // KNOB Middle
    //
    GUI_DispStringHCenterAt("Middle", 245, 8);
    GUI_AA_FillCircle(245, 55, 32);
    GUI_DrawBitmap(&bmknob_gray_trans_70x70, 245 - bmknob_gray_trans_70x70.XSize / 2, 55 - bmknob_gray_trans_70x70.YSize / 2);
    //
    // KNOB Low
    //
    GUI_DispStringHCenterAt("Low", 340, 8);
    GUI_AA_FillCircle(340, 55, 32);
    GUI_DrawBitmap(&bmknob_gray_trans_70x70, 340 - bmknob_gray_trans_70x70.XSize / 2, 55 - bmknob_gray_trans_70x70.YSize / 2);
    //
    // PlugIn/Out
    //
    GUI_DispStringHCenterAt("Guitar In", 145, 185);
    GUI_DrawBitmap(&bmGuitarInOut, 145 - bmGuitarInOut.XSize / 2, 225 - bmGuitarInOut.YSize / 2);
    //
    // BUTTON Bk
    //
    GUI_DispStringHCenterAt("Automode", 430, 90);
    if (ButtonPressed) {
      GUI_SetColor(GUI_GREEN);
    } else {
      GUI_SetColor(AMP_COLOR_GRAY);
    }
    GUI_AA_FillCircle(415 + bmknob_gray_trans_30x30.XSize / 2, 110 + bmknob_gray_trans_30x30.YSize / 2, 17);
    break;
  case WM_NOTIFY_PARENT:
    Id    = WM_GetId(pMsg->hWinSrc);      // Id of widget
    NCode = pMsg->Data.v;                 // Notification code
    switch (NCode) {
    case WM_NOTIFICATION_VALUE_CHANGED:   // Value has changed
      switch (Id) {
      case GUI_ID_KNOB0:
        hKnob   = WM_GetDialogItem(hWin, GUI_ID_KNOB0);
        PowerOn = KNOB_GetValue(hKnob) / 450;
        WM_InvalidateWindow(hWin);
        if (PowerOn == 1) {
          PwColor   = GUI_RED;
          ColorKnob = GUI_GREEN;
        } else if (PowerOn == 2) {
          PwColor   = GUI_GREEN;
        } else {
          PwColor   = AMP_COLOR_GRAY;
          ColorKnob = GUI_BLACK;
        }
        break;
      case GUI_ID_KNOB1:                          // Volume
        hKnob = WM_GetDialogItem(hWin, Id);
        WM_GetWindowRectEx(hKnob, &Rect);
        Rect.x0 = 215;
        Rect.y0 = 125;
        Rect.x1 = 285;
        Rect.y1 = 275;
        hParent = WM_GetParent(hKnob);
        WM_InvalidateRect(hParent, &Rect);
        break;
      case GUI_ID_KNOB2:                          // Gain
      case GUI_ID_KNOB3:                          // High
      case GUI_ID_KNOB4:                          // Middle
      case GUI_ID_KNOB5:                          // Low
        hKnob = WM_GetDialogItem(hWin, Id);
        WM_GetWindowRectEx(hKnob, &Rect);
        Rect.x0 -= 10;
        Rect.y0 -= 10;
        Rect.x1 += 10;
        Rect.y1 += 10;
        hParent  = WM_GetParent(hKnob);
        WM_InvalidateRect(hParent, &Rect);
        break;
     }
    case WM_NOTIFICATION_RELEASED:
      switch (Id) {
      case GUI_ID_BUTTON0:
        hButton = WM_GetDialogItem(hWin, GUI_ID_BUTTON0);
        if (ButtonPressed) {
          //
          // Stop animation
          //
          ButtonPressed = 0;
          GUI_CURSOR_Hide();
          BUTTON_SetPressed(hButton, 0);
        } else {
          BUTTON_SetPressed(hButton, 1);
          ButtonPressed = 1;
          GUI_CURSOR_Show();
          for (i = 0; i <= 5; i++) {
            hKnob = WM_GetDialogItem(hWin, GUI_ID_KNOB0 + i);  // Set knobs to 0
            KNOB_SetPos(hKnob, 0);
          }
          Index = 0;
          WM_InvalidateWindow(hWin);
          if (hTimer) {
            WM_RestartTimer(hTimer, 100);
          }
        }
        WM_GetWindowRectEx(hButton, &Rect);
        Rect.x0 -= 10;
        Rect.y0 -= 10;
        Rect.x1 += 10;
        Rect.y1 += 10;
        hParent  = WM_GetParent(hButton);
        WM_InvalidateRect(hParent, &Rect);
        break;
      }
      break;
  }
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  GUI_Init();
  WM_SetCreateFlags(WM_CF_MEMDEV);
  while (1) {
    GUI_ExecDialogBox(_aDialogCreate, GUI_COUNTOF(_aDialogCreate), _cbDialog, WM_HBKWIN, 0, 0);
    GUI_Delay(100);
  }
}

/*************************** End of file ****************************/
